OPTIONS linesize = max;

LIBNAME nlsy 'C:\Users\alexa\Desktop\life\projects\disability\nlsy97\job trajectories\data';

data nlsy.jobtraj9715;
  merge nlsy.ex020618 nlsy.ex020818 nlsy.ex021118 nlsy.ex030818 nlsy.ex032918 nlsy.ex032918a nlsy.ex040118 nlsy.ex040318 nlsy.ex040318a nlsy.ex070618;
  by R0000100;

/* Parental education */

biodaded = .; if R1302400 ge 0 and R1302400 le 20 then biodaded = R1302400;
biomomed = .; if R1302500 ge 0 and R1302500 le 20 then biomomed = R1302500;
resdaded = .; if R1302600 ge 0 and R1302600 le 20 then resdaded = R1302600;
resmomed = .; if R1302700 ge 0 and R1302700 le 20 then resmomed = R1302700;

maxresed = .;  
  if resdaded >= resmomed then maxresed = resdaded;
  if resmomed >= resdaded then maxresed = resmomed;

maxbioed = .;
  if resdaded >= resmomed then maxbioed = resdaded;
  if resmomed >= resdaded then maxbioed = resmomed;

maxresbioed = .;
  if maxresed ne . then maxresbioed = maxresed;
  if maxresbioed = . and maxbioed ne . then maxresbioed = maxbioed;

/* R0681500: Does [this youth] now have or has [he/she] ever had a learning or emotional 	*/
/* problem that limits or has limited the kind of schoolwork or other daily 				*/
/* activities [he/she] can perform, the amount of time [he/she] can spend on these 			*/
/* activities or [his/her] performance in these activities?									*/

everlearn = .;
  if R0681500 ge 0 then everlearn = R0681500;

/* R0685400: Does [this youth] now have or has [he/she] ever had any other chronic health 	*/
/* condition or life threatening disease such as asthma, heart condition, anemia, 			*/
/* diabetes or cancer?																		*/

everchron = .;
  if R0685400 ge 0 then everchron = R0685400;

/* R0684400: Does [this youth] now have or has [he/she] ever had a part of [his/her] body 	*/
/* that (is/was) deformed or missing?														*/

everdeform = .;
  if R0684400 ge 0 then everdeform = R0684400;

/* R0682800: Does [this youth] now have or has [he/she] ever had trouble seeing, hearing or */
/* speaking?																				*/

eversense = .;
  if R0682800 ge 0 then eversense = R0682800;

/* Set to missing if any condition is missing */

everlearn_nm = .;
  if everlearn ge 0 and everchron ge 0 and everdeform ge 0 and eversense ge 0 then everlearn_nm = everlearn;

everchron_nm = .;
  if everlearn ge 0 and everchron ge 0 and everdeform ge 0 and eversense ge 0 then everchron_nm = everchron;

everdeform_nm = .;
  if everlearn ge 0 and everchron ge 0 and everdeform ge 0 and eversense ge 0 then everdeform_nm = everdeform;

eversense_nm = .;
  if everlearn ge 0 and everchron ge 0 and everdeform ge 0 and eversense ge 0 then eversense_nm = eversense;

/* Mutually exclusive measures of only having a single condition - versus multiple	*/

onlylearn = .;  
  if everlearn = 0 then onlylearn = 0;
  if everlearn = 1 and (everchron = 0 and everdeform = 0 and eversense = 0) then onlylearn = 1;
  if everlearn = 1 and (everchron = 1 or everdeform = 1 or eversense = 1) then onlylearn = 0;

onlychron = .;  
  if everchron = 0 then onlychron = 0;
  if everchron = 1 and (everlearn = 0 and everdeform = 0 and eversense = 0) then onlychron = 1;
  if everchron = 1 and (everlearn = 1 or everdeform = 1 or eversense = 1) then onlychron = 0;

onlydeform = .;  
  if everdeform = 0 then onlydeform = 0;
  if everdeform = 1 and (everchron = 0 and everlearn = 0 and eversense = 0) then onlydeform = 1;
  if everdeform = 1 and (everchron = 1 or everlearn = 1 or eversense = 1) then onlydeform = 0;

onlysense = .;  
  if eversense = 0 then onlysense = 0;
  if eversense = 1 and (everchron = 0 and everdeform = 0 and everlearn = 0) then onlysense = 1;
  if eversense = 1 and (everchron = 1 or everdeform = 1 or everlearn = 1) then onlysense = 0;

multidis = .;
  if everlearn = 0 and everchron = 0 and everdeform = 0 and eversense = 0 then multidis = 0;
  if everlearn = 1 and (everchron = 1 or everdeform = 1 or eversense = 1) then multidis = 1;
  if everchron = 1 and (everlearn = 1 or everdeform = 1 or eversense = 1) then multidis = 1;
  if everdeform = 1 and (everchron = 1 or everlearn = 1 or eversense = 1) then multidis = 1;
  if eversense = 1 and (everchron = 1 or everdeform = 1 or everlearn = 1) then multidis = 1;
  if multidis = . and everlearn = 1 and (everchron = 0 and everdeform = 0 and eversense = 0) then multidis = 0;
  if multidis = . and everchron = 1 and (everlearn = 0 and everdeform = 0 and eversense = 0) then multidis = 0;
  if multidis = . and everdeform = 1 and (everchron = 0 and everlearn = 0 and eversense = 0) then multidis = 0;
  if multidis = . and eversense = 1 and (everchron = 0 and everdeform = 0 and everlearn = 0) then multidis = 0;

neverdis = .;
  if everlearn = 0 and everchron = 0 and everdeform = 0 and eversense = 0 then neverdis = 1;
  if everlearn = 1 or everchron = 1 or everdeform = 1 or eversense = 1 then neverdis = 0;

anydis = .;
  if neverdis = 1 then anydis = 0;
  if neverdis = 0 then anydis = 1;

/* Create measures with no missings */

onlylearn_nm = .;  
  if everlearn_nm = 0 then onlylearn_nm = 0;
  if everlearn_nm = 1 and (everchron_nm = 0 and everdeform_nm = 0 and eversense_nm = 0) then onlylearn_nm = 1;
  if everlearn_nm = 1 and (everchron_nm = 1 or everdeform_nm = 1 or eversense_nm = 1) then onlylearn_nm = 0;

onlychron_nm = .;  
  if everchron_nm = 0 then onlychron_nm = 0;
  if everchron_nm = 1 and (everlearn_nm = 0 and everdeform_nm = 0 and eversense_nm = 0) then onlychron_nm = 1;
  if everchron_nm = 1 and (everlearn_nm = 1 or everdeform_nm = 1 or eversense_nm = 1) then onlychron_nm = 0;

onlydeform_nm = .;  
  if everdeform_nm = 0 then onlydeform_nm = 0;
  if everdeform_nm = 1 and (everchron_nm = 0 and everlearn_nm = 0 and eversense_nm = 0) then onlydeform_nm = 1;
  if everdeform_nm = 1 and (everchron_nm = 1 or everlearn_nm = 1 or eversense_nm = 1) then onlydeform_nm = 0;

onlysense_nm = .;  
  if eversense_nm = 0 then onlysense_nm = 0;
  if eversense_nm = 1 and (everchron_nm = 0 and everdeform_nm = 0 and everlearn_nm = 0) then onlysense_nm = 1;
  if eversense_nm = 1 and (everchron_nm = 1 or everdeform_nm = 1 or everlearn_nm = 1) then onlysense_nm = 0;

multidis_nm = .;
  if everlearn_nm = 0 and everchron_nm = 0 and everdeform_nm = 0 and eversense_nm = 0 then multidis_nm = 0;
  if everlearn_nm = 1 and (everchron_nm = 1 or everdeform_nm = 1 or eversense_nm = 1) then multidis_nm = 1;
  if everchron_nm = 1 and (everlearn_nm = 1 or everdeform_nm = 1 or eversense_nm = 1) then multidis_nm = 1;
  if everdeform_nm = 1 and (everchron_nm = 1 or everlearn_nm = 1 or eversense_nm = 1) then multidis_nm = 1;
  if eversense_nm = 1 and (everchron_nm = 1 or everdeform_nm = 1 or everlearn_nm = 1) then multidis_nm = 1;
  if multidis_nm = . and everlearn_nm = 1 and (everchron_nm = 0 and everdeform_nm = 0 and eversense_nm = 0) then multidis_nm = 0;
  if multidis_nm = . and everchron_nm = 1 and (everlearn_nm = 0 and everdeform_nm = 0 and eversense_nm = 0) then multidis_nm = 0;
  if multidis_nm = . and everdeform_nm = 1 and (everchron_nm = 0 and everlearn_nm = 0 and eversense_nm = 0) then multidis_nm = 0;
  if multidis_nm = . and eversense_nm = 1 and (everchron_nm = 0 and everdeform_nm = 0 and everlearn_nm = 0) then multidis_nm = 0;

neverdis_nm = .;
  if everlearn_nm = 0 and everchron_nm = 0 and everdeform_nm = 0 and eversense_nm = 0 then neverdis_nm = 1;
  if everlearn_nm = 1 or everchron_nm = 1 or everdeform_nm = 1 or eversense_nm = 1 then neverdis_nm = 0;

anydis_nm = .;
  if neverdis_nm = 1 then anydis_nm = 0;
  if neverdis_nm = 0 then anydis_nm = 1;

/* limited at least some in 1997 */

presentdis97 = .;
  if (anydis_nm >= 0 & anydis_nm <= 1) then presentdis97 = 0;
  if 

(R0682300 = 1 or R0682300 = 2) or
(R0682400 = 1 or R0682400 = 2) or
(R0682500 = 1 or R0682500 = 2) or
(R0682600 = 1 or R0682600 = 2) or
(R0682700 = 1 or R0682700 = 2) or

(R0683700 = 1 or R0683700 = 2) or
(R0683800 = 1 or R0683800 = 2) or
(R0683900 = 1 or R0683900 = 2) or
(R0684000 = 1 or R0684000 = 2) or
(R0684100 = 1 or R0684100 = 2) or
(R0684200 = 1 or R0684200 = 2) or
(R0684300 = 1 or R0684300 = 2) or

(R0685000 = 1 or R0685000 = 2) or
(R0685100 = 1 or R0685100 = 2) or
(R0685200 = 1 or R0685200 = 2) or
(R0685300 = 1 or R0685300 = 2) or
(R0685400 = 1 or R0685400 = 2) or

(R0686200 = 1 or R0686200 = 2) or
(R0686300 = 1 or R0686300 = 2) or
(R0686400 = 1 or R0686400 = 2) or
(R0686500 = 1 or R0686500 = 2) or
(R0686600 = 1 or R0686600 = 2) or
(R0686700 = 1 or R0686700 = 2) then presentdis97 = 1;

milddis97 = .;
  if (anydis_nm >= 0 & anydis_nm <= 1) then milddis97 = 0;
  if 

(R0682300 = 1) or
(R0682400 = 1) or
(R0682500 = 1) or
(R0682600 = 1) or
(R0682700 = 1) or

(R0683700 = 1) or
(R0683800 = 1) or
(R0683900 = 1) or
(R0684000 = 1) or
(R0684100 = 1) or
(R0684200 = 1) or
(R0684300 = 1) or

(R0685000 = 1) or
(R0685100 = 1) or
(R0685200 = 1) or
(R0685300 = 1) or
(R0685400 = 1) or

(R0686200 = 1) or
(R0686300 = 1) or
(R0686400 = 1) or
(R0686500 = 1) or
(R0686600 = 1) or
(R0686700 = 1) then milddis97 = 1;

severedis97 = .;
  if (anydis_nm >= 0 & anydis_nm <= 1) then severedis97 = 0;
  if 

(R0682300 = 2) or
(R0682400 = 2) or
(R0682500 = 2) or
(R0682600 = 2) or
(R0682700 = 2) or

(R0683700 = 2) or
(R0683800 = 2) or
(R0683900 = 2) or
(R0684000 = 2) or
(R0684100 = 2) or
(R0684200 = 2) or
(R0684300 = 2) or

(R0685000 = 2) or
(R0685100 = 2) or
(R0685200 = 2) or
(R0685300 = 2) or
(R0685400 = 2) or

(R0686200 = 2) or
(R0686300 = 2) or
(R0686400 = 2) or
(R0686500 = 2) or
(R0686600 = 2) or
(R0686700 = 2) then severedis97 = 1;

/* 0s have no dis and not currently limiting dis */

dissev_3cat = .;
  if (anydis_nm >= 0 & anydis_nm <= 1) then dissev_3cat = 0;
  if milddis97 = 1 then dissev_3cat = 1;
  if severedis97 = 1 then dissev_3cat = 2;

/* 0s are no dis ever; 1 is had a limitation, 2 is mild, 3 is severe */

dissev_4cat = .;
  if (anydis_nm >= 0 & anydis_nm <= 1) then dissev_4cat = 0;
  if anydis_nm = 1 then dissev_4cat = 1;
  if milddis97 = 1 then dissev_4cat = 2;
  if severedis97 = 1 then dissev_4cat = 3;

/* Age */

bdaycontmo = .; if R0536402 ne . & R0536401 ne . then bdaycontmo = ((R0536402-1980)*12) + R0536401;

contomoturn16 = bdaycontmo + 192;

agefirstint = .;
  if R1194100 = 12 then agefirstin = 0;
  if R1194100 = 13 then agefirstin = 1;
  if R1194100 = 14 then agefirstin = 2;
  if R1194100 = 15 then agefirstin = 3;
  if R1194100 >= 16 and R1194100 <= 18 then agefirstin = 4;

/* Rename employer eds for easier array */

/* 1997: up to 7 *********************************************************/

idjob1 = .; if (R0531100 >= 0 & R0531100 <= 300000) then idjob1 = R0531100;
idjob2 = .; if (R0531200 >= 0 & R0531200 <= 300000) then idjob2 = R0531200;
idjob3 = .; if (R0531300 >= 0 & R0531300 <= 300000) then idjob3 = R0531300;
idjob4 = .; if (R0531400 >= 0 & R0531400 <= 300000) then idjob4 = R0531400;
idjob5 = .; if (R0531500 >= 0 & R0531500 <= 300000) then idjob5 = R0531500;
idjob6 = .; if (R0531600 >= 0 & R0531600 <= 300000) then idjob6 = R0531600;
idjob7 = .; if (R0531700 >= 0 & R0531700 <= 300000) then idjob7 = R0531700;

whyleftjob1 = 	.; if (R0171200 >= 0 & R0171200 <= 50) then whyleftjob1 = R0171200;
whyleftjob2 = 	.; if (R0171300 >= 0 & R0171300 <= 50) then whyleftjob2 = R0171300;
whyleftjob3 = 	.; if (R0171400 >= 0 & R0171400 <= 50) then whyleftjob3 = R0171400;
whyleftjob4 = 	.; if (R0171500 >= 0 & R0171500 <= 50) then whyleftjob4 = R0171500;
whyleftjob5 = 	.; if (R0171600 >= 0 & R0171600 <= 50) then whyleftjob5 = R0171600;
whyleftjob6 = 	.; if (R0171700 >= 0 & R0171700 <= 50) then whyleftjob6 = R0171700;
whyleftjob7 = 	.; if (R0171800 >= 0 & R0171800 <= 50) then whyleftjob7 = R0171800;

curjob1 = .; if	R0525200	>= 0 &	R0525200	<= 1 then	curjob1 =	R0525200	;
curjob2	= .; if	R0525300	>= 0 &	R0525300	<= 1 then	curjob2	=	R0525300	;
curjob3	= .; if	R0525400	>= 0 &	R0525400	<= 1 then	curjob3	=	R0525400	;
curjob4	= .; if	R0525500	>= 0 &	R0525500	<= 1 then	curjob4	=	R0525500	;
curjob5	= .; if	R0525600	>= 0 &	R0525600	<= 1 then	curjob5	=	R0525600	;
curjob6	= .; if	R0525700	>= 0 &	R0525700	<= 1 then	curjob6	=	R0525700	;
curjob7	= .; if	R0525800	>= 0 &	R0525800	<= 1 then	curjob7	=	R0525800	;

weeksjob1 = .; if (R1219900 >= 0 & R1219900 <= 5000) then weeksjob1 = R1219900;
weeksjob2 = .; if (R1220000 >= 0 & R1220000 <= 5000) then weeksjob2 = R1220000;
weeksjob3 = .; if (R1220100 >= 0 & R1220100 <= 5000) then weeksjob3 = R1220100;
weeksjob4 = .; if (R1220200 >= 0 & R1220200 <= 5000) then weeksjob4 = R1220200;
weeksjob5 = .; if (R1220300 >= 0 & R1220300 <= 5000) then weeksjob5 = R1220300;
weeksjob6 = .; if (R1220400 >= 0 & R1220400 <= 5000) then weeksjob6 = R1220400;
weeksjob7 = .; if (R1220500 >= 0 & R1220500 <= 5000) then weeksjob7 = R1220500;

startmojob1 = .; if R0529701 >= 0 & R0529701 <= 12 then startmojob1 = R0529701;
startmojob2 = .; if R0529801 >= 0 & R0529801 <= 12 then startmojob2 = R0529801;
startmojob3 = .; if R0529901 >= 0 & R0529901 <= 12 then startmojob3 = R0529901;
startmojob4 = .; if R0530001 >= 0 & R0530001 <= 12 then startmojob4 = R0530001;
startmojob5 = .; if R0530101 >= 0 & R0530101 <= 12 then startmojob5 = R0530101;
startmojob6 = .; if R0530201 >= 0 & R0530201 <= 12 then startmojob6 = R0530201;
startmojob7 = .; if R0530301 >= 0 & R0530301 <= 12 then startmojob7 = R0530301;

startyrjob1 = .; if R0529702 >= 1980 & R0529702 <= 2050 then startyrjob1 = R0529702;
startyrjob2 = .; if R0529802 >= 1980 & R0529802 <= 2050 then startyrjob2 = R0529802;
startyrjob3 = .; if R0529902 >= 1980 & R0529902 <= 2050 then startyrjob3 = R0529902;
startyrjob4 = .; if R0530002 >= 1980 & R0530002 <= 2050 then startyrjob4 = R0530002;
startyrjob5 = .; if R0530102 >= 1980 & R0530102 <= 2050 then startyrjob5 = R0530102;
startyrjob6 = .; if R0530202 >= 1980 & R0530202 <= 2050 then startyrjob6 = R0530202;
startyrjob7 = .; if R0530302 >= 1980 & R0530302 <= 2050 then startyrjob7 = R0530302;

startcontmo1 = .; if startyrjob1 ne . & startmojob1 ne . then startcontmo1 = ((startyrjob1-1980)*12) + startmojob1;
startcontmo2 = .; if startyrjob2 ne . & startmojob2 ne . then startcontmo2 = ((startyrjob2-1980)*12) + startmojob2;
startcontmo3 = .; if startyrjob3 ne . & startmojob3 ne . then startcontmo3 = ((startyrjob3-1980)*12) + startmojob3;
startcontmo4 = .; if startyrjob4 ne . & startmojob4 ne . then startcontmo4 = ((startyrjob4-1980)*12) + startmojob4;
startcontmo5 = .; if startyrjob5 ne . & startmojob5 ne . then startcontmo5 = ((startyrjob5-1980)*12) + startmojob5;
startcontmo6 = .; if startyrjob6 ne . & startmojob6 ne . then startcontmo6 = ((startyrjob6-1980)*12) + startmojob6;
startcontmo7 = .; if startyrjob7 ne . & startmojob7 ne . then startcontmo7 = ((startyrjob7-1980)*12) + startmojob7;

endbyst1	= .; if	R0267200	ge 0 &	R0267200	le 1 then	endbyst1	=	R0267200	;
endbyst2	= .; if	R0267300	ge 0 &	R0267300	le 1 then	endbyst2	=	R0267300	;
endbyst3	= .; if	R0267400	ge 0 &	R0267400	le 1 then	endbyst3	=	R0267400	;
endbyst4	= .; if	R0267500	ge 0 &	R0267500	le 1 then	endbyst4	=	R0267500	;
endbyst5	= .; if	R0267600	ge 0 &	R0267600	le 1 then	endbyst5	=	R0267600	;
endbyst6	= .; if	R0267700	ge 0 &	R0267700	le 1 then	endbyst6	=	R0267700	;
endbyst7	= .; 								

intmo1 = R1209300;
intmo2 = R1209300;
intmo3 = R1209300;
intmo4 = R1209300;
intmo5 = R1209300;
intmo6 = R1209300;
intmo7 = R1209300;

jobsat1	= .;	if	R0244700	>= 1 and	R0244700	<= 5 then 	jobsat1	=	R0244700;
jobsat2	= .;	if	R0244800	>= 1 and	R0244800	<= 5 then 	jobsat2	=	R0244800;
jobsat3	= .;	if	R0244900	>= 1 and	R0244900	<= 5 then 	jobsat3	=	R0244900;
jobsat4	= .;	if	R0245000	>= 1 and	R0245000	<= 5 then 	jobsat4	=	R0245000;
jobsat5	= .;	if	R0245100	>= 1 and	R0245100	<= 5 then 	jobsat5	=	R0245100;
jobsat6	= .;	if	R0245200	>= 1 and	R0245200	<= 5 then 	jobsat6	=	R0245200;
jobsat7	= .;	if	R0245300	>= 1 and	R0245300	<= 5 then 	jobsat7	=	R0245300;

union1	= .;	if	R0244000	>= 0 and	R0244000	<= 1 then 	union1	=	R0244000	;
union2	= .;	if	R0244100	>= 0 and	R0244100	<= 1 then 	union2	=	R0244100	;
union3	= .;	if	R0244200	>= 0 and	R0244200	<= 1 then 	union3	=	R0244200	;
union4	= .;	if	R0244300	>= 0 and	R0244300	<= 1 then 	union4	=	R0244300	;
union5	= .;	if	R0244400	>= 0 and	R0244400	<= 1 then 	union5	=	R0244400	;
union6	= .;	if	R0244500	>= 0 and	R0244500	<= 1 then 	union6	=	R0244500	;
union7	= .;	if	R0244600	>= 0 and	R0244600	<= 1 then 	union7	=	R0244600	;

ben_med1	= .;	if	R0238701	>= 0 and	R0238701	<= 1 then 	ben_med1	=	R0238701	;
ben_med2	= .;	if	R0238801	>= 0 and	R0238801	<= 1 then 	ben_med2	=	R0238801	;
ben_med3	= .;	if	R0238901	>= 0 and	R0238901	<= 1 then 	ben_med3	=	R0238901	;
ben_med4	= .;	if	R0239001	>= 0 and	R0239001	<= 1 then 	ben_med4	=	R0239001	;
ben_med5	= .;	if	R0239101	>= 0 and	R0239101	<= 1 then 	ben_med5	=	R0239101	;
ben_med6	= .;	if	R0239201	>= 0 and	R0239201	<= 1 then 	ben_med6	=	R0239201	;
ben_med7	= .;	if	R0239301	>= 0 and	R0239301	<= 1 then 	ben_med7	=	R0239301	;

ben_flex1	= .;	if	R0238707	>= 0 and	R0238707	<= 1 then 	ben_flex1	=	R0238707	;
ben_flex2	= .;	if	R0238807	>= 0 and	R0238807	<= 1 then 	ben_flex2	=	R0238807	;
ben_flex3	= .;	if	R0238907	>= 0 and	R0238907	<= 1 then 	ben_flex3	=	R0238907	;
ben_flex4	= .;	if	R0239007	>= 0 and	R0239007	<= 1 then 	ben_flex4	=	R0239007	;
ben_flex5	= .;	if	R0239107	>= 0 and	R0239107	<= 1 then 	ben_flex5	=	R0239107	;
ben_flex6	= .;	if	R0239207	>= 0 and	R0239207	<= 1 then 	ben_flex6	=	R0239207	;
ben_flex7	= .;	if	R0239307	>= 0 and	R0239307	<= 1 then 	ben_flex7	=	R0239307	;

ben_life1	= .;	if	R0238702	>= 0 and	R0238702	<= 1 then 	ben_life1	=	R0238702	;
ben_life2	= .;	if	R0238802	>= 0 and	R0238802	<= 1 then 	ben_life2	=	R0238802	;
ben_life3	= .;	if	R0238902	>= 0 and	R0238902	<= 1 then 	ben_life3	=	R0238902	;
ben_life4	= .;	if	R0239002	>= 0 and	R0239002	<= 1 then 	ben_life4	=	R0239002	;
ben_life5	= .;	if	R0239102	>= 0 and	R0239102	<= 1 then 	ben_life5	=	R0239102	;
ben_life6	= .;	if	R0239202	>= 0 and	R0239202	<= 1 then 	ben_life6	=	R0239202	;
ben_life7	= .;	if	R0239302	>= 0 and	R0239302	<= 1 then 	ben_life7	=	R0239302	;

ben_dental1	= .;	if	R0238703	>= 0 and	R0238703	<= 1 then 	ben_dental1	=	R0238703	;
ben_dental2	= .;	if	R0238803	>= 0 and	R0238803	<= 1 then 	ben_dental2	=	R0238803	;
ben_dental3	= .;	if	R0238903	>= 0 and	R0238903	<= 1 then 	ben_dental3	=	R0238903	;
ben_dental4	= .;	if	R0239003	>= 0 and	R0239003	<= 1 then 	ben_dental4	=	R0239003	;
ben_dental5	= .;	if	R0239103	>= 0 and	R0239103	<= 1 then 	ben_dental5	=	R0239103	;
ben_dental6	= .;	if	R0239203	>= 0 and	R0239203	<= 1 then 	ben_dental6	=	R0239203	;
ben_dental7	= .;	if	R0239303	>= 0 and	R0239303	<= 1 then 	ben_dental7	=	R0239303	;

ben_pdleave1	= .;	if	R0238704	>= 0 and	R0238704	<= 1 then 	ben_pdleave1	=	R0238704	;
ben_pdleave2	= .;	if	R0238804	>= 0 and	R0238804	<= 1 then 	ben_pdleave2	=	R0238804	;
ben_pdleave3	= .;	if	R0238904	>= 0 and	R0238904	<= 1 then 	ben_pdleave3	=	R0238904	;
ben_pdleave4	= .;	if	R0239004	>= 0 and	R0239004	<= 1 then 	ben_pdleave4	=	R0239004	;
ben_pdleave5	= .;	if	R0239104	>= 0 and	R0239104	<= 1 then 	ben_pdleave5	=	R0239104	;
ben_pdleave6	= .;	if	R0239204	>= 0 and	R0239204	<= 1 then 	ben_pdleave6	=	R0239204	;
ben_pdleave7	= .;	if	R0239304	>= 0 and	R0239304	<= 1 then 	ben_pdleave7	=	R0239304	;

ben_unpdleave1	= .;	if	R0238705	>= 0 and	R0238705	<= 1 then 	ben_unpdleave1	=	R0238705	;
ben_unpdleave2	= .;	if	R0238805	>= 0 and	R0238805	<= 1 then 	ben_unpdleave2	=	R0238805	;
ben_unpdleave3	= .;	if	R0238905	>= 0 and	R0238905	<= 1 then 	ben_unpdleave3	=	R0238905	;
ben_unpdleave4	= .;	if	R0239005	>= 0 and	R0239005	<= 1 then 	ben_unpdleave4	=	R0239005	;
ben_unpdleave5	= .;	if	R0239105	>= 0 and	R0239105	<= 1 then 	ben_unpdleave5	=	R0239105	;
ben_unpdleave6	= .;	if	R0239205	>= 0 and	R0239205	<= 1 then 	ben_unpdleave6	=	R0239205	;
ben_unpdleave7	= .;	if	R0239305	>= 0 and	R0239305	<= 1 then 	ben_unpdleave7	=	R0239305	;

ben_retire1	= .;	if	R0238706	>= 0 and	R0238706	<= 1 then 	ben_retire1	=	R0238706	;
ben_retire2	= .;	if	R0238806	>= 0 and	R0238806	<= 1 then 	ben_retire2	=	R0238806	;
ben_retire3	= .;	if	R0238906	>= 0 and	R0238906	<= 1 then 	ben_retire3	=	R0238906	;
ben_retire4	= .;	if	R0239006	>= 0 and	R0239006	<= 1 then 	ben_retire4	=	R0239006	;
ben_retire5	= .;	if	R0239106	>= 0 and	R0239106	<= 1 then 	ben_retire5	=	R0239106	;
ben_retire6	= .;	if	R0239206	>= 0 and	R0239206	<= 1 then 	ben_retire6	=	R0239206	;
ben_retire7	= .;	if	R0239306	>= 0 and	R0239306	<= 1 then 	ben_retire7	=	R0239306	;

ben_tuition1	= .;	if	R0238708	>= 0 and	R0238708	<= 1 then 	ben_tuition1	=	R0238708	;
ben_tuition2	= .;	if	R0238808	>= 0 and	R0238808	<= 1 then 	ben_tuition2	=	R0238808	;
ben_tuition3	= .;	if	R0238908	>= 0 and	R0238908	<= 1 then 	ben_tuition3	=	R0238908	;
ben_tuition4	= .;	if	R0239008	>= 0 and	R0239008	<= 1 then 	ben_tuition4	=	R0239008	;
ben_tuition5	= .;	if	R0239108	>= 0 and	R0239108	<= 1 then 	ben_tuition5	=	R0239108	;
ben_tuition6	= .;	if	R0239208	>= 0 and	R0239208	<= 1 then 	ben_tuition6	=	R0239208	;
ben_tuition7	= .;	if	R0239308	>= 0 and	R0239308	<= 1 then 	ben_tuition7	=	R0239308	;

ben_child1	= .;	if	R0238709	>= 0 and	R0238709	<= 1 then 	ben_child1	=	R0238709	;
ben_child2	= .;	if	R0238809	>= 0 and	R0238809	<= 1 then 	ben_child2	=	R0238809	;
ben_child3	= .;	if	R0238909	>= 0 and	R0238909	<= 1 then 	ben_child3	=	R0238909	;
ben_child4	= .;	if	R0239009	>= 0 and	R0239009	<= 1 then 	ben_child4	=	R0239009	;
ben_child5	= .;	if	R0239109	>= 0 and	R0239109	<= 1 then 	ben_child5	=	R0239109	;
ben_child6	= .;	if	R0239209	>= 0 and	R0239209	<= 1 then 	ben_child6	=	R0239209	;
ben_child7	= .;	if	R0239309	>= 0 and	R0239309	<= 1 then 	ben_child7	=	R0239309	;

ben_stock1	= .;	if	R0238710	>= 0 and	R0238710	<= 1 then 	ben_stock1	=	R0238710	;
ben_stock2	= .;	if	R0238810	>= 0 and	R0238810	<= 1 then 	ben_stock2	=	R0238810	;
ben_stock3	= .;	if	R0238910	>= 0 and	R0238910	<= 1 then 	ben_stock3	=	R0238910	;
ben_stock4	= .;	if	R0239010	>= 0 and	R0239010	<= 1 then 	ben_stock4	=	R0239010	;
ben_stock5	= .;	if	R0239110	>= 0 and	R0239110	<= 1 then 	ben_stock5	=	R0239110	;
ben_stock6	= .;	if	R0239210	>= 0 and	R0239210	<= 1 then 	ben_stock6	=	R0239210	;
ben_stock7	= .;	if	R0239310	>= 0 and	R0239310	<= 1 then 	ben_stock7	=	R0239310	;

occcode1 	= .; if	S3659000	ge 0 and	S3659000	le 9990 then	occcode1	=	S3659000	;
occcode2	= .; if	S3659100	ge 0 and	S3659100	le 9990 then	occcode2	=	S3659100	;
occcode3	= .; if	S3659200	ge 0 and	S3659200	le 9990 then	occcode3	=	S3659200	;
occcode4	= .; if	S3659300	ge 0 and	S3659300	le 9990 then	occcode4	=	S3659300	;
occcode5	= .; if	S3659400	ge 0 and	S3659400	le 9990 then	occcode5	=	S3659400	;
occcode6	= .; if	S3659500	ge 0 and	S3659500	le 9990 then	occcode6	=	S3659500	;
occcode7	= .; if	S3659600	ge 0 and	S3659600	le 9990 then	occcode7	=	S3659600	;

indcode1	= .; if	S3658000	ge 0 and	S3658000	le 9990 then	indcode1	=	S3658000	;
indcode2	= .; if	S3658100	ge 0 and	S3658100	le 9990 then	indcode2	=	S3658100	;
indcode3	= .; if	S3658200	ge 0 and	S3658200	le 9990 then	indcode3	=	S3658200	;
indcode4	= .; if	S3658300	ge 0 and	S3658300	le 9990 then	indcode4	=	S3658300	;
indcode5	= .; if	S3658400	ge 0 and	S3658400	le 9990 then	indcode5	=	S3658400	;
indcode6	= .; if	S3658500	ge 0 and	S3658500	le 9990 then	indcode6	=	S3658500	;
indcode7	= .; if	S3658600	ge 0 and	S3658600	le 9990 then	indcode7	=	S3658600	;

jobtype1	= .; if	R0171900	ge 1 &	R0171900	le 5 then	jobtype1	=	R0171900	;
jobtype2	= .; if	R0172000	ge 1 &	R0172000	le 5 then	jobtype2	=	R0172000	;
jobtype3	= .; if	R0172100	ge 1 &	R0172100	le 5 then	jobtype3	=	R0172100	;
jobtype4	= .; if	R0172200	ge 1 &	R0172200	le 5 then	jobtype4	=	R0172200	;
jobtype5	= .; if	R0172300	ge 1 &	R0172300	le 5 then	jobtype5	=	R0172300	;
jobtype6	= .; if	R0172400	ge 1 &	R0172400	le 5 then	jobtype6	=	R0172400	;
jobtype7	= .; if	R0172500	ge 1 &	R0172500	le 5 then	jobtype7	=	R0172500	;

hourswk1	= .; if	R1209101	ge 0 &	R1209101	le 168 then	hourswk1	=	R1209101	;
hourswk2	= .; if	R1209102	ge 0 &	R1209102	le 168 then	hourswk2	=	R1209102	;
hourswk3	= .; if	R1209103	ge 0 &	R1209103	le 168 then	hourswk3	=	R1209103	;
hourswk4	= .; if	R1209104	ge 0 &	R1209104	le 168 then	hourswk4	=	R1209104	;
hourswk5	= .; if	R1209105	ge 0 &	R1209105	le 168 then	hourswk5	=	R1209105	;
hourswk6	= .; if	R1209106	ge 0 &	R1209106	le 168 then	hourswk6	=	R1209106	;
hourswk7	= .; if	R1209107	ge 0 &	R1209107	le 168 then	hourswk7	=	R1209107	;

anygap1	= .; if	R0246700	ge -2 &	R0246700	le 0 then	anygap1	=	0	;	if 	R0246700	eq 1 then	anygap1	=	1	;
anygap2	= .; if	R0246800	ge -2 &	R0246800	le 0 then	anygap2	=	0	;	if 	R0246800	eq 1 then	anygap2	=	1	;
anygap3	= .; if	R0246900	ge -2 &	R0246900	le 0 then	anygap3	=	0	;	if 	R0246900	eq 1 then	anygap3	=	1	;
anygap4	= .; if	R0247000	ge -2 &	R0247000	le 0 then	anygap4	=	0	;	if 	R0247000	eq 1 then	anygap4	=	1	;
anygap5	= .; if	R0247100	ge -2 &	R0247100	le 0 then	anygap5	=	0	;	if 	R0247100	eq 1 then	anygap5	=	1	;
anygap6	= .; if	R0247200	ge -2 &	R0247200	le 0 then	anygap6	=	0	;	if 	R0247200	eq 1 then	anygap6	=	1	;
anygap7	= .; if	R0247300	ge -2 &	R0247300	le 0 then	anygap7	=	0	;	if 	R0247300	eq 1 then	anygap7	=	1	;

worksched1	= .; if	R0209400	ge 1 &	R0209400	le 9 then	worksched1	=	R0209400	;	
worksched2	= .; if	R0209500	ge 1 &	R0209500	le 9 then	worksched2	=	R0209500	;	
worksched3	= .; if	R0209600	ge 1 &	R0209600	le 9 then	worksched3	=	R0209600	;	
worksched4	= .; if	R0209700	ge 1 &	R0209700	le 9 then	worksched4	=	R0209700	;	
worksched5	= .; if	R0209800	ge 1 &	R0209800	le 9 then	worksched5	=	R0209800	;	
worksched6	= .; if	R0209900	ge 1 &	R0209900	le 9 then	worksched6	=	R0209900	;	
worksched7	= .; if	R0210000	ge 1 &	R0210000	le 9 then	worksched7	=	R0210000	;	

/* 1998 */

idjob8 = .; if (R2476100 >= 0 & R2476100 <= 300000) then idjob8 = R2476100; 
idjob9 = .; if (R2476200 >= 0 & R2476200 <= 300000) then idjob9 = R2476200; 
idjob10 = .; if (R2476300 >= 0 & R2476300 <= 300000) then idjob10 = R2476300; 
idjob11 = .; if (R2476400 >= 0 & R2476400 <= 300000) then idjob11 = R2476400; 
idjob12 = .; if (R2476500 >= 0 & R2476500 <= 300000) then idjob12 = R2476500; 
idjob13 = .; if (R2476600 >= 0 & R2476600 <= 300000) then idjob13 = R2476600; 
idjob14 = .; if (R2476700 >= 0 & R2476700 <= 300000) then idjob14 = R2476700; 
idjob15 = .; if (R2476800 >= 0 & R2476800 <= 300000) then idjob15 = R2476800; 
idjob16 = .; if (R2476900 >= 0 & R2476900 <= 300000) then idjob16 = R2476900; 

whyleftjob8 = .; if (R2037700 >= 0 & R2037700 <= 50) then whyleftjob8 = R2037700;
whyleftjob9 = .; if (R2037800 >= 0 & R2037800 <= 50) then whyleftjob9 = R2037800;
whyleftjob10 = .; if (R2037900 >= 0 & R2037900 <= 50) then whyleftjob10 = R2037900;
whyleftjob11 = .; if (R2038000 >= 0 & R2038000 <= 50) then whyleftjob11 = R2038000;
whyleftjob12 = .; if (R2038100 >= 0 & R2038100 <= 50) then whyleftjob12 = R2038100;
whyleftjob13 = .; if (R2038200 >= 0 & R2038200 <= 50) then whyleftjob13 = R2038200;
whyleftjob14 = .; if (R2038300 >= 0 & R2038300 <= 50) then whyleftjob14 = R2038300;
whyleftjob15 = .;
whyleftjob16 = .; if (R2038400 >= 0 & R2038400 <= 50) then whyleftjob16 = R2038400;

curjob8	= .; if	R2468100	>= 0 &	R2468100	<= 1 then	curjob8	=	R2468100	;
curjob9	= .; if	R2468200	>= 0 &	R2468200	<= 1 then	curjob9	=	R2468200	;
curjob10 = .; if R2468300	>= 0 &	R2468300	<= 1 then	curjob10	=	R2468300	;
curjob11 = .; if R2468400	>= 0 &	R2468400	<= 1 then	curjob11	=	R2468400	;
curjob12 = .; if R2468500	>= 0 &	R2468500	<= 1 then	curjob12	=	R2468500	;
curjob13 = .; if R2468600	>= 0 &	R2468600	<= 1 then	curjob13	=	R2468600	;
curjob14 = .; if R2468700	>= 0 &	R2468700	<= 1 then	curjob14	=	R2468700	;
curjob15 = .; if R2468800	>= 0 &	R2468800	<= 1 then	curjob15	=	R2468800	;
curjob16 = .; if R2468900	>= 0 &	R2468900	<= 1 then	curjob16	=	R2468900	;

weeksjob8 = .; if (R2579200 >= 0 and R2579200 <= 5000) then weeksjob8 = R2579200;
weeksjob9 = .; if (R2579300 >= 0 and R2579300 <= 5000) then weeksjob9 = R2579300;
weeksjob10 = .; if (R2579400 >= 0 and R2579400 <= 5000) then weeksjob10 = R2579400;
weeksjob11 = .; if (R2579500 >= 0 and R2579500 <= 5000) then weeksjob11 = R2579500;
weeksjob12 = .; if (R2579600 >= 0 and R2579600 <= 5000) then weeksjob12 = R2579600;
weeksjob13 = .; if (R2579700 >= 0 and R2579700 <= 5000) then weeksjob13 = R2579700;
weeksjob14 = .; if (R2579800 >= 0 and R2579800 <= 5000) then weeksjob14 = R2579800;
weeksjob15 = .; if (R2579900 >= 0 and R2579900 <= 5000) then weeksjob15 = R2579900;
weeksjob16 = .; if (R2580000 >= 0 and R2580000 <= 5000) then weeksjob16 = R2580000;

intmo8 = R2568200;
intmo9 = R2568200;
intmo10 = R2568200;
intmo11 = R2568200;
intmo12 = R2568200;
intmo13 = R2568200;
intmo14 = R2568200;
intmo15 = R2568200;
intmo16 = R2568200;

startmojob8 = .; if R2472501 >= 0 & R2472501 <= 12 then startmojob8 = R2472501;
startmojob9 = .; if R2472601 >= 0 & R2472601 <= 12 then startmojob9 = R2472601;
startmojob10 = .; if R2472701 >= 0 & R2472701 <= 12 then startmojob10 = R2472701;
startmojob11 = .; if R2472801 >= 0 & R2472801 <= 12 then startmojob11 = R2472801;
startmojob12 = .; if R2472901 >= 0 & R2472901 <= 12 then startmojob12 = R2472901;
startmojob13 = .; if R2473001 >= 0 & R2473001 <= 12 then startmojob13 = R2473001;
startmojob14 = .; if R2473101 >= 0 & R2473101 <= 12 then startmojob14 = R2473101;
startmojob15 = .; if R2473201 >= 0 & R2473201 <= 12 then startmojob15 = R2473201;
startmojob16 = .; if R2473301 >= 0 & R2473301 <= 12 then startmojob16 = R2473301;

startyrjob8 = .; if R2472502 >= 1980 & R2472502 <= 2050 then startyrjob8 = R2472502;
startyrjob9 = .; if R2472602 >= 1980 & R2472602 <= 2050 then startyrjob9 = R2472602;
startyrjob10 = .; if R2472702 >= 1980 & R2472702 <= 2050 then startyrjob10 = R2472702;
startyrjob11 = .; if R2472802 >= 1980 & R2472802 <= 2050 then startyrjob11 = R2472802;
startyrjob12 = .; if R2472902 >= 1980 & R2472902 <= 2050 then startyrjob12 = R2472902;
startyrjob13 = .; if R2473002 >= 1980 & R2473002 <= 2050 then startyrjob13 = R2473002;
startyrjob14 = .; if R2473102 >= 1980 & R2473102 <= 2050 then startyrjob14 = R2473102;
startyrjob15 = .; if R2473202 >= 1980 & R2473202 <= 2050 then startyrjob15 = R2473202;
startyrjob16 = .; if R2473302 >= 1980 & R2473302 <= 2050 then startyrjob16 = R2473302;

startcontmo8 = .; if startyrjob8 ne . & startmojob8 ne . then startcontmo8 = ((startyrjob8-1980)*12) + startmojob8;
startcontmo9 = .; if startyrjob9 ne . & startmojob9 ne . then startcontmo9 = ((startyrjob9-1980)*12) + startmojob9;
startcontmo10 = .; if startyrjob10 ne . & startmojob10 ne . then startcontmo10 = ((startyrjob10-1980)*12) + startmojob10;
startcontmo11 = .; if startyrjob11 ne . & startmojob11 ne . then startcontmo11 = ((startyrjob11-1980)*12) + startmojob11;
startcontmo12 = .; if startyrjob12 ne . & startmojob12 ne . then startcontmo12 = ((startyrjob12-1980)*12) + startmojob12;
startcontmo13 = .; if startyrjob13 ne . & startmojob13 ne . then startcontmo13 = ((startyrjob13-1980)*12) + startmojob13;
startcontmo14 = .; if startyrjob14 ne . & startmojob14 ne . then startcontmo14 = ((startyrjob14-1980)*12) + startmojob14;
startcontmo15 = .; if startyrjob15 ne . & startmojob15 ne . then startcontmo15 = ((startyrjob15-1980)*12) + startmojob15;
startcontmo16 = .; if startyrjob16 ne . & startmojob16 ne . then startcontmo16 = ((startyrjob16-1980)*12) + startmojob16;

endbyst8	= .; if	R2083400	ge 0 &	R2083400	le 1 then	endbyst8	=	R2083400	;
endbyst9	= .; if	R2083500	ge 0 &	R2083500	le 1 then	endbyst9	=	R2083500	;
endbyst10	= .; if	R2083600	ge 0 &	R2083600	le 1 then	endbyst10	=	R2083600	;
endbyst11	= .; if	R2083700	ge 0 &	R2083700	le 1 then	endbyst11	=	R2083700	;
endbyst12	= .; if	R2083800	ge 0 &	R2083800	le 1 then	endbyst12	=	R2083800	;
endbyst13	= .; if	R2083900	ge 0 &	R2083900	le 1 then	endbyst13	=	R2083900	;
endbyst14	= .; if	R2084000	ge 0 &	R2084000	le 1 then	endbyst14	=	R2084000	;
endbyst15	= .; if	R2084100	ge 0 &	R2084100	le 1 then	endbyst15	=	R2084100	;
endbyst16	= .; if	R2084200	ge 0 &	R2084200	le 1 then	endbyst16	=	R2084200	;

/* No employer 8/job 15 */

jobsat8	= .;	if	R2050800	>= 1 and	R2050800	<= 5 then 	jobsat8	=	R2050800	;
jobsat9	= .;	if	R2050900	>= 1 and	R2050900	<= 5 then 	jobsat9	=	R2050900	;
jobsat10 = .;	if	R2051000	>= 1 and	R2051000	<= 5 then 	jobsat10	=	R2051000	;
jobsat11 = .;	if	R2051100	>= 1 and	R2051100	<= 5 then 	jobsat11	=	R2051100	;
jobsat12 = .;	if	R2051200	>= 1 and	R2051200	<= 5 then 	jobsat12	=	R2051200	;
jobsat13 = .;	if	R2051300	>= 1 and	R2051300	<= 5 then 	jobsat13	=	R2051300	;
jobsat14 = .;	if	R2051400	>= 1 and	R2051400	<= 5 then 	jobsat14	=	R2051400	;
jobsat15 = .;									;
jobsat16 = .;	if	R2051500	>= 1 and	R2051500	<= 5 then 	jobsat16	=	R2051500	;

union8	= .;	if	R2050000	>= 0 and	R2050000	<= 1 then 	union8	=	R2050000	;
union9	= .;	if	R2050100	>= 0 and	R2050100	<= 1 then 	union9	=	R2050100	;
union10	= .;	if	R2050200	>= 0 and	R2050200	<= 1 then 	union10	=	R2050200	;
union11	= .;	if	R2050300	>= 0 and	R2050300	<= 1 then 	union11	=	R2050300	;
union12	= .;	if	R2050400	>= 0 and	R2050400	<= 1 then 	union12	=	R2050400	;
union13	= .;	if	R2050500	>= 0 and	R2050500	<= 1 then 	union13	=	R2050500	;
union14	= .;	if	R2050600	>= 0 and	R2050600	<= 1 then 	union14	=	R2050600	;
union15	= .;									
union16	=.;	if	R2050700 >= 0 and	R2050700	<= 1 then 	union16	=	R2050700	;

ben_med8	= .;	if	R2043701	>= 0 and	R2043701	<= 1 then 	ben_med8	=	R2043701	;
ben_med9	= .;	if	R2043801	>= 0 and	R2043801	<= 1 then 	ben_med9	=	R2043801	;
ben_med10	= .;	if	R2043901	>= 0 and	R2043901	<= 1 then 	ben_med10	=	R2043901	;
ben_med11	= .;	if	R2044001	>= 0 and	R2044001	<= 1 then 	ben_med11	=	R2044001	;
ben_med12	= .;	if	R2044101	>= 0 and	R2044101	<= 1 then 	ben_med12	=	R2044101	;
ben_med13	= .;	if	R2044201	>= 0 and	R2044201	<= 1 then 	ben_med13	=	R2044201	;
ben_med14	= .;	if	R2044301	>= 0 and	R2044301	<= 1 then 	ben_med14	=	R2044301	;
ben_med15	= .;									
ben_med16	= .;	if	R2044401	>= 0 and	R2044401	<= 1 then 	ben_med16	=	R2044401	;

ben_flex8	= .;	if	R2043707	>= 0 and	R2043707	<= 1 then 	ben_flex8	=	R2043707	;
ben_flex9	= .;	if	R2043807	>= 0 and	R2043807	<= 1 then 	ben_flex9	=	R2043807	;
ben_flex10	= .;	if	R2043907	>= 0 and	R2043907	<= 1 then 	ben_flex10	=	R2043907	;
ben_flex11	= .;	if	R2044007	>= 0 and	R2044007	<= 1 then 	ben_flex11	=	R2044007	;
ben_flex12	= .;	if	R2044107	>= 0 and	R2044107	<= 1 then 	ben_flex12	=	R2044107	;
ben_flex13	= .;	if	R2044207	>= 0 and	R2044207	<= 1 then 	ben_flex13	=	R2044207	;
ben_flex14	= .;	if	R2044307	>= 0 and	R2044307	<= 1 then 	ben_flex14	=	R2044307	;
ben_flex15	= .;									
ben_flex16	= .;	if	R2044407	>= 0 and	R2044407	<= 1 then 	ben_flex16	=	R2044407	;

ben_life8	= .;	if	R2043702	>= 0 and	R2043702	<= 1 then 	ben_life8	=	R2043702	;
ben_life9	= .;	if	R2043802	>= 0 and	R2043802	<= 1 then 	ben_life9	=	R2043802	;
ben_life10	= .;	if	R2043902	>= 0 and	R2043902	<= 1 then 	ben_life10	=	R2043902	;
ben_life11	= .;	if	R2044002	>= 0 and	R2044002	<= 1 then 	ben_life11	=	R2044002	;
ben_life12	= .;	if	R2044102	>= 0 and	R2044102	<= 1 then 	ben_life12	=	R2044102	;
ben_life13	= .;	if	R2044202	>= 0 and	R2044202	<= 1 then 	ben_life13	=	R2044202	;
ben_life14	= .;	if	R2044302	>= 0 and	R2044302	<= 1 then 	ben_life14	=	R2044302	;
ben_life15	= .;									
ben_life16	= .;	if	R2044402	>= 0 and	R2044402	<= 1 then 	ben_life16	=	R2044402	;

ben_dental8	= .;	if	R2043703	>= 0 and	R2043703	<= 1 then 	ben_dental8	=	R2043703;
ben_dental9	= .;	if	R2043803	>= 0 and	R2043803	<= 1 then 	ben_dental9	=	R2043803;
ben_dental10	= .;	if	R2043903	>= 0 and	R2043903	<= 1 then 	ben_dental10	=	R2043903;
ben_dental11	= .;	if	R2044003	>= 0 and	R2044003	<= 1 then 	ben_dental11	=	R2044003;
ben_dental12	= .;	if	R2044103	>= 0 and	R2044103	<= 1 then 	ben_dental12	=	R2044103;
ben_dental13	= .;	if	R2044203	>= 0 and	R2044203	<= 1 then 	ben_dental13	=	R2044203;
ben_dental14	= .;	if	R2044303	>= 0 and	R2044303	<= 1 then 	ben_dental14	=	R2044303;
ben_dental15	= .;									
ben_dental16	= .;	if	R2044403	>= 0 and	R2044403	<= 1 then 	ben_dental16	=	R2044403;

ben_pdleave8	= .;	if	R2043704	>= 0 and	R2043704	<= 1 then 	ben_pdleave8	=	R2043704;
ben_pdleave9	= .;	if	R2043804	>= 0 and	R2043804	<= 1 then 	ben_pdleave9	=	R2043804;
ben_pdleave10	= .;	if	R2043904	>= 0 and	R2043904	<= 1 then 	ben_pdleave10	=	R2043904;
ben_pdleave11	= .;	if	R2044004	>= 0 and	R2044004	<= 1 then 	ben_pdleave11	=	R2044004;
ben_pdleave12	= .;	if	R2044104	>= 0 and	R2044104	<= 1 then 	ben_pdleave12	=	R2044104;
ben_pdleave13	= .;	if	R2044204	>= 0 and	R2044204	<= 1 then 	ben_pdleave13	=	R2044204;
ben_pdleave14	= .;	if	R2044304	>= 0 and	R2044304	<= 1 then 	ben_pdleave14	=	R2044304;
ben_pdleave15	= .;									
ben_pdleave16	= .;	if	R2044404	>= 0 and	R2044404	<= 1 then 	ben_pdleave16	=	R2044404;

ben_unpdleave8	= .;	if	R2043705	>= 0 and	R2043705	<= 1 then 	ben_unpdleave8	=	R2043705;
ben_unpdleave9	= .;	if	R2043805	>= 0 and	R2043805	<= 1 then 	ben_unpdleave9	=	R2043805;
ben_unpdleave10	= .;	if	R2043905	>= 0 and	R2043905	<= 1 then 	ben_unpdleave10	=	R2043905;
ben_unpdleave11	= .;	if	R2044005	>= 0 and	R2044005	<= 1 then 	ben_unpdleave11	=	R2044005;
ben_unpdleave12	= .;	if	R2044105	>= 0 and	R2044105	<= 1 then 	ben_unpdleave12	=	R2044105;
ben_unpdleave13	= .;	if	R2044205	>= 0 and	R2044205	<= 1 then 	ben_unpdleave13	=	R2044205;
ben_unpdleave14	= .;	if	R2044305	>= 0 and	R2044305	<= 1 then 	ben_unpdleave14	=	R2044305;
ben_unpdleave15	= .;									
ben_unpdleave16	= .;	if	R2044405	>= 0 and	R2044405	<= 1 then 	ben_unpdleave16	=	R2044405;

ben_retire8	= .;	if	R2043706	>= 0 and	R2043706	<= 1 then 	ben_retire8	=	R2043706;
ben_retire9	= .;	if	R2043806	>= 0 and	R2043806	<= 1 then 	ben_retire9	=	R2043806;
ben_retire10	= .;	if	R2043906	>= 0 and	R2043906	<= 1 then 	ben_retire10	=	R2043906;
ben_retire11	= .;	if	R2044006	>= 0 and	R2044006	<= 1 then 	ben_retire11	=	R2044006;
ben_retire12	= .;	if	R2044106	>= 0 and	R2044106	<= 1 then 	ben_retire12	=	R2044106;
ben_retire13	= .;	if	R2044206	>= 0 and	R2044206	<= 1 then 	ben_retire13	=	R2044206;
ben_retire14	= .;	if	R2044306	>= 0 and	R2044306	<= 1 then 	ben_retire14	=	R2044306;
ben_retire15	= .;									
ben_retire16	= .;	if	R2044406	>= 0 and	R2044406	<= 1 then 	ben_retire16	=	R2044406;

ben_tuition8	= .;	if	R2043708	>= 0 and	R2043708	<= 1 then 	ben_tuition8	=	R2043708;
ben_tuition9	= .;	if	R2043808	>= 0 and	R2043808	<= 1 then 	ben_tuition9	=	R2043808;
ben_tuition10	= .;	if	R2043908	>= 0 and	R2043908	<= 1 then 	ben_tuition10	=	R2043908;
ben_tuition11	= .;	if	R2044008	>= 0 and	R2044008	<= 1 then 	ben_tuition11	=	R2044008;
ben_tuition12	= .;	if	R2044108	>= 0 and	R2044108	<= 1 then 	ben_tuition12	=	R2044108;
ben_tuition13	= .;	if	R2044208	>= 0 and	R2044208	<= 1 then 	ben_tuition13	=	R2044208;
ben_tuition14	= .;	if	R2044308	>= 0 and	R2044308	<= 1 then 	ben_tuition14	=	R2044308;
ben_tuition15	= .;								
ben_tuition16	= .;	if	R2044408	>= 0 and	R2044408	<= 1 then 	ben_tuition16	=	R2044408;

ben_child8	= .;	if	R2043709	>= 0 and	R2043709	<= 1 then 	ben_child8	=	R2043709;
ben_child9	= .;	if	R2043809	>= 0 and	R2043809	<= 1 then 	ben_child9	=	R2043809;
ben_child10	= .;	if	R2043909	>= 0 and	R2043909	<= 1 then 	ben_child10	=	R2043909;
ben_child11	= .;	if	R2044009	>= 0 and	R2044009	<= 1 then 	ben_child11	=	R2044009;
ben_child12	= .;	if	R2044109	>= 0 and	R2044109	<= 1 then 	ben_child12	=	R2044109;
ben_child13	= .;	if	R2044209	>= 0 and	R2044209	<= 1 then 	ben_child13	=	R2044209;
ben_child14	= .;	if	R2044309	>= 0 and	R2044309	<= 1 then 	ben_child14	=	R2044309;
ben_child15	= .;								
ben_child16	= .;	if	R2044409	>= 0 and	R2044409	<= 1 then 	ben_child16	=	R2044409;

ben_stock8	= .;	if	R2043710	>= 0 and	R2043710	<= 1 then 	ben_stock8	=	R2043710;
ben_stock9	= .;	if	R2043810	>= 0 and	R2043810	<= 1 then 	ben_stock9	=	R2043810;
ben_stock10	= .;	if	R2043910	>= 0 and	R2043910	<= 1 then 	ben_stock10	=	R2043910;
ben_stock11	= .;	if	R2044010	>= 0 and	R2044010	<= 1 then 	ben_stock11	=	R2044010;
ben_stock12	= .;	if	R2044110	>= 0 and	R2044110	<= 1 then 	ben_stock12	=	R2044110;
ben_stock13	= .;	if	R2044210	>= 0 and	R2044210	<= 1 then 	ben_stock13	=	R2044210;
ben_stock14	= .;	if	R2044310	>= 0 and	R2044310	<= 1 then 	ben_stock14	=	R2044310;
ben_stock15	= .;								
ben_stock16	= .;	if	R2044410	>= 0 and	R2044410	<= 1 then 	ben_stock16	=	R2044410;

occcode8	= .; if	S3681000	ge 0 and	S3681000	le 9990 then	occcode8	=	S3681000	;
occcode9	= .; if	S3681100	ge 0 and	S3681100	le 9990 then	occcode9	=	S3681100	;
occcode10	= .; if	S3681200	ge 0 and	S3681200	le 9990 then	occcode10	=	S3681200	;
occcode11	= .; if	S3681300	ge 0 and	S3681300	le 9990 then	occcode11	=	S3681300	;
occcode12	= .; if	S3681400	ge 0 and	S3681400	le 9990 then	occcode12	=	S3681400	;
occcode13	= .; if	S3681500	ge 0 and	S3681500	le 9990 then	occcode13	=	S3681500	;
occcode14	= .; if	S3681600	ge 0 and	S3681600	le 9990 then	occcode14	=	S3681600	;
occcode15	= .; if	S3681700	ge 0 and	S3681700	le 9990 then	occcode15	=	S3681700	;
occcode16	= .; if	S3681800	ge 0 and	S3681800	le 9990 then	occcode16	=	S3681800	;

indcode8	= .; if	S3679000	ge 0 and	S3679000	le 9990 then	indcode8	=	S3679000	;
indcode9	= .; if	S3679100	ge 0 and	S3679100	le 9990 then	indcode9	=	S3679100	;
indcode10	= .; if	S3679200	ge 0 and	S3679200	le 9990 then	indcode10	=	S3679200	;
indcode11	= .; if	S3679300	ge 0 and	S3679300	le 9990 then	indcode11	=	S3679300	;
indcode12	= .; if	S3679400	ge 0 and	S3679400	le 9990 then	indcode12	=	S3679400	;
indcode13	= .; if	S3679500	ge 0 and	S3679500	le 9990 then	indcode13	=	S3679500	;
indcode14	= .; if	S3679600	ge 0 and	S3679600	le 9990 then	indcode14	=	S3679600	;
indcode15	= .; if	S3679700	ge 0 and	S3679700	le 9990 then	indcode15	=	S3679700	;
indcode16	= .; if	S3679800	ge 0 and	S3679800	le 9990 then	indcode16	=	S3679800	;

jobtype8	= .; if	R1846600	ge 1 &	R1846600	le 5 then	jobtype8	=	R1846600	;
jobtype9	= .; if	R1846700	ge 1 &	R1846700	le 5 then	jobtype9	=	R1846700	;
jobtype10	= .; if	R1846800	ge 1 &	R1846800	le 5 then	jobtype10	=	R1846800	;
jobtype11	= .; if	R1846900	ge 1 &	R1846900	le 5 then	jobtype11	=	R1846900	;
jobtype12	= .; if	R1847000	ge 1 &	R1847000	le 5 then	jobtype12	=	R1847000	;
jobtype13	= .; if	R1847100	ge 1 &	R1847100	le 5 then	jobtype13	=	R1847100	;
jobtype14	= .; if	R1847200	ge 1 &	R1847200	le 5 then	jobtype14	=	R1847200	;
jobtype15	= .; if	R1847300	ge 1 &	R1847300	le 5 then	jobtype15	=	R1847300	;
jobtype16	= .; if	R1847400	ge 1 &	R1847400	le 5 then	jobtype16	=	R1847400	;

hourswk8	= .; if	R2568001	ge 0 &	R2568001	le 168 then	hourswk8	=	R2568001	;
hourswk9	= .; if	R2568002	ge 0 &	R2568002	le 168 then	hourswk9	=	R2568002	;
hourswk10	= .; if	R2568003	ge 0 &	R2568003	le 168 then	hourswk10	=	R2568003	;
hourswk11	= .; if	R2568004	ge 0 &	R2568004	le 168 then	hourswk11	=	R2568004	;
hourswk12	= .; if	R2568005	ge 0 &	R2568005	le 168 then	hourswk12	=	R2568005	;
hourswk13	= .; if	R2568006	ge 0 &	R2568006	le 168 then	hourswk13	=	R2568006	;
hourswk14	= .; if	R2568007	ge 0 &	R2568007	le 168 then	hourswk14	=	R2568007	;
hourswk15	= .; if	R2568008	ge 0 &	R2568008	le 168 then	hourswk15	=	R2568008	;
hourswk16	= .; if	R2568009	ge 0 &	R2568009	le 168 then	hourswk16	=	R2568009	;

anygap8	= .; if	R2053100	ge -2 &	R2053100	le 0 then	anygap8	=	0	;	if 	R2053100	eq 1 then	anygap8	=	1	;
anygap9	= .; if	R2053200	ge -2 &	R2053200	le 0 then	anygap9	=	0	;	if 	R2053200	eq 1 then	anygap9	=	1	;
anygap10	= .; if	R2053300	ge -2 &	R2053300	le 0 then	anygap10	=	0	;	if 	R2053300	eq 1 then	anygap10	=	1	;
anygap11	= .; if	R2053400	ge -2 &	R2053400	le 0 then	anygap11	=	0	;	if 	R2053400	eq 1 then	anygap11	=	1	;
anygap12	= .; if	R2053500	ge -2 &	R2053500	le 0 then	anygap12	=	0	;	if 	R2053500	eq 1 then	anygap12	=	1	;
anygap13	= .; if	R2053600	ge -2 &	R2053600	le 0 then	anygap13	=	0	;	if 	R2053600	eq 1 then	anygap13	=	1	;
anygap14	= .; if	R2053700	ge -2 &	R2053700	le 0 then	anygap14	=	0	;	if 	R2053700	eq 1 then	anygap14	=	1	;
anygap15	= .; if	R2053800	ge -2 &	R2053800	le 0 then	anygap15	=	0	;	if 	R2053800	eq 1 then	anygap15	=	1	;
anygap16	= .; if	R2053900	ge -2 &	R2053900	le 0 then	anygap16	=	0	;	if 	R2053900	eq 1 then	anygap16	=	1	;

worksched8	= .; if	R2042900	ge 1 &	R2042900	le 9 then	worksched8	=	R2042900	;	
worksched9	= .; if	R2043000	ge 1 &	R2043000	le 9 then	worksched9	=	R2043000	;	
worksched10	= .; if	R2043100	ge 1 &	R2043100	le 9 then	worksched10	=	R2043100	;	
worksched11	= .; if	R2043200	ge 1 &	R2043200	le 9 then	worksched11	=	R2043200	;	
worksched12	= .; if	R2043300	ge 1 &	R2043300	le 9 then	worksched12	=	R2043300	;	
worksched13	= .; if	R2043400	ge 1 &	R2043400	le 9 then	worksched13	=	R2043400	;	
worksched14	= .; if	R2043500	ge 1 &	R2043500	le 9 then	worksched14	=	R2043500	;	
worksched15	= .;									
worksched16	= .; if	R2043600	ge 1 &	R2043600	le 9 then	worksched16	=	R2043600	;	

/* 1999: up to 9 ***********************************************************/

idjob17 = .; if (R3790000 >= 0 & R3790000 <= 300000) then idjob17 = R3790000; 
idjob18 = .; if (R3790100 >= 0 & R3790100 <= 300000) then idjob18 = R3790100; 
idjob19 = .; if (R3790200 >= 0 & R3790200 <= 300000) then idjob19 = R3790200; 
idjob20 = .; if (R3790300 >= 0 & R3790300 <= 300000) then idjob20 = R3790300; 
idjob21 = .; if (R3790400 >= 0 & R3790400 <= 300000) then idjob21 = R3790400; 
idjob22 = .; if (R3790500 >= 0 & R3790500 <= 300000) then idjob22 = R3790500; 
idjob23 = .; if (R3790600 >= 0 & R3790600 <= 300000) then idjob23 = R3790600; 
idjob24 = .; if (R3790700 >= 0 & R3790700 <= 300000) then idjob24 = R3790700; 
idjob25 = .; if (R3790800 >= 0 & R3790800 <= 300000) then idjob25 = R3790800; 

/* Skips emp 8 */

whyleftjob17 = .; if (R3375000	>= 0 & R3375000	<= 50) then	whyleftjob17 =	R3375000;
whyleftjob18 = .; if (R3375100	>= 0 & R3375100	<= 50) then	whyleftjob18 =	R3375100;
whyleftjob19 = .; if (R3375200	>= 0 & R3375200	<= 50) then	whyleftjob19 =	R3375200;
whyleftjob20 = .; if (R3375300	>= 0 & R3375300	<= 50) then	whyleftjob20 =	R3375300;
whyleftjob21 = .; if (R3375400	>= 0 & R3375400	<= 50) then	whyleftjob21 =	R3375400;
whyleftjob22 = .; if (R3375500	>= 0 & R3375500	<= 50) then	whyleftjob22 =	R3375500;
whyleftjob23 = .; if (R3375600	>= 0 & R3375600	<= 50) then	whyleftjob23 =	R3375600;
whyleftjob24 = .;
whyleftjob25 = .; if (R3375700	>= 0 & R3375700	<= 50) then	whyleftjob25 =	R3375700;

curjob17	= .; if	R3781900	>= 0 &	R3781900	<= 1 then	curjob17	=	R3781900	;
curjob18	= .; if	R3782000	>= 0 &	R3782000	<= 1 then	curjob18	=	R3782000	;
curjob19	= .; if	R3782100	>= 0 &	R3782100	<= 1 then	curjob19	=	R3782100	;
curjob20	= .; if	R3782200	>= 0 &	R3782200	<= 1 then	curjob20	=	R3782200	;
curjob21	= .; if	R3782300	>= 0 &	R3782300	<= 1 then	curjob21	=	R3782300	;
curjob22	= .; if	R3782400	>= 0 &	R3782400	<= 1 then	curjob22	=	R3782400	;
curjob23	= .; if	R3782500	>= 0 &	R3782500	<= 1 then	curjob23	=	R3782500	;
curjob24	= .; if	R3782600	>= 0 &	R3782600	<= 1 then	curjob24	=	R3782600	;
curjob25	= .; if	R3782700	>= 0 &	R3782700	<= 1 then	curjob25	=	R3782700	;

intmo17 = R3890100;
intmo18 = R3890100;
intmo19 = R3890100;
intmo20 = R3890100;
intmo21 = R3890100;
intmo22 = R3890100;
intmo23 = R3890100;
intmo24 = R3890100;
intmo25 = R3890100;

weeksjob17 = .;	if (R3901600 >= 0 &	R3901600 <= 5000) then weeksjob17 =	R3901600;
weeksjob18 = .;	if (R3901700 >= 0 &	R3901700 <= 5000) then weeksjob18 =	R3901700;
weeksjob19 = .;	if (R3901800 >= 0 &	R3901800 <= 5000) then weeksjob19 =	R3901800;
weeksjob20 = .;	if (R3901900 >= 0 &	R3901900 <= 5000) then weeksjob20 =	R3901900;
weeksjob21 = .;	if (R3902000 >= 0 &	R3902000 <= 5000) then weeksjob21 =	R3902000;
weeksjob22 = .;	if (R3902100 >= 0 &	R3902100 <= 5000) then weeksjob22 =	R3902100;
weeksjob23 = .;	if (R3902200 >= 0 &	R3902200 <= 5000) then weeksjob23 =	R3902200;
weeksjob24 = .;	if (R3902300 >= 0 &	R3902300 <= 5000) then weeksjob24 =	R3902300;
weeksjob25 = .;	if (R3902400 >= 0 &	R3902400 <= 5000) then weeksjob25 =	R3902400;

startmojob17 =	.;	if	R3786401	>=	0	&	R3786401	<=	12	then	startmojob17	=	R3786401	;			
startmojob18 =	.;	if	R3786501	>=	0	&	R3786501	<=	12	then	startmojob18	=	R3786501	;			
startmojob19 =	.;	if	R3786601	>=	0	&	R3786601	<=	12	then	startmojob19	=	R3786601	;			
startmojob20 =	.;	if	R3786701	>=	0	&	R3786701	<=	12	then	startmojob20	=	R3786701	;			
startmojob21 =	.;	if	R3786801	>=	0	&	R3786801	<=	12	then	startmojob21	=	R3786801	;			
startmojob22 =	.;	if	R3786901	>=	0	&	R3786901	<=	12	then	startmojob22	=	R3786901	;			
startmojob23 =	.;	if	R3787001	>=	0	&	R3787001	<=	12	then	startmojob23	=	R3787001	;			
startmojob24 =	.;	if	R3787101	>=	0	&	R3787101	<=	12	then	startmojob24	=	R3787101	;			
startmojob25 =	.;	if	R3787201	>=	0	&	R3787201	<=	12	then	startmojob25	=	R3787201	;			
																		
startyrjob17 =	.;	if	R3786402	>=	1980	&	R3786402	<=	2050	then	startyrjob17	=	R3786402	;			
startyrjob18 =	.;	if	R3786502	>=	1980	&	R3786502	<=	2050	then	startyrjob18	=	R3786502	;			
startyrjob19 =	.;	if	R3786602	>=	1980	&	R3786602	<=	2050	then	startyrjob19	=	R3786602	;			
startyrjob20 =	.;	if	R3786702	>=	1980	&	R3786702	<=	2050	then	startyrjob20	=	R3786702	;			
startyrjob21 =	.;	if	R3786802	>=	1980	&	R3786802	<=	2050	then	startyrjob21	=	R3786802	;			
startyrjob22 =	.;	if	R3786902	>=	1980	&	R3786902	<=	2050	then	startyrjob22	=	R3786902	;			
startyrjob23 =	.;	if	R3787002	>=	1980	&	R3787002	<=	2050	then	startyrjob23	=	R3787002	;			
startyrjob24 =	.;	if	R3787102	>=	1980	&	R3787102	<=	2050	then	startyrjob24	=	R3787102	;			
startyrjob25 =	.;	if	R3787202	>=	1980	&	R3787202	<=	2050	then	startyrjob25	=	R3787202	;			
																		
startcontmo17 =	.;	if	startyrjob17	ne	.	&	startmojob17	ne	.	then	startcontmo17	=	((startyrjob17	-1980)*12)	+	startmojob17	;
startcontmo18 =	.;	if	startyrjob18	ne	.	&	startmojob18	ne	.	then	startcontmo18	=	((startyrjob18	-1980)*12)	+	startmojob18	;
startcontmo19 =	.;	if	startyrjob19	ne	.	&	startmojob19	ne	.	then	startcontmo19	=	((startyrjob19	-1980)*12)	+	startmojob19	;
startcontmo20 =	.;	if	startyrjob20	ne	.	&	startmojob20	ne	.	then	startcontmo20	=	((startyrjob20	-1980)*12)	+	startmojob20	;
startcontmo21 =	.;	if	startyrjob21	ne	.	&	startmojob21	ne	.	then	startcontmo21	=	((startyrjob21	-1980)*12)	+	startmojob21	;
startcontmo22 =	.;	if	startyrjob22	ne	.	&	startmojob22	ne	.	then	startcontmo22	=	((startyrjob22	-1980)*12)	+	startmojob22	;
startcontmo23 =	.;	if	startyrjob23	ne	.	&	startmojob23	ne	.	then	startcontmo23	=	((startyrjob23	-1980)*12)	+	startmojob23	;
startcontmo24 =	.;	if	startyrjob24	ne	.	&	startmojob24	ne	.	then	startcontmo24	=	((startyrjob24	-1980)*12)	+	startmojob24	;
startcontmo25 =	.;	if	startyrjob25	ne	.	&	startmojob25	ne	.	then	startcontmo25	=	((startyrjob25	-1980)*12)	+	startmojob25	;

endbyst17	= .; if	R3414200	ge 0 &	R3414200	le 1 then	endbyst17	=	R3414200	;
endbyst18	= .; if	R3414300	ge 0 &	R3414300	le 1 then	endbyst18	=	R3414300	;
endbyst19	= .; if	R3414400	ge 0 &	R3414400	le 1 then	endbyst19	=	R3414400	;
endbyst20	= .; if	R3414500	ge 0 &	R3414500	le 1 then	endbyst20	=	R3414500	;
endbyst21	= .; if	R3414600	ge 0 &	R3414600	le 1 then	endbyst21	=	R3414600	;
endbyst22	= .; if	R3414700	ge 0 &	R3414700	le 1 then	endbyst22	=	R3414700	;
endbyst23	= .; if	R3414800	ge 0 &	R3414800	le 1 then	endbyst23	=	R3414800	;
endbyst24	= .; if	R3414900	ge 0 &	R3414900	le 1 then	endbyst24	=	R3414900	;
endbyst25	= .; if	R3415000	ge 0 &	R3415000	le 1 then	endbyst25	=	R3415000	;

/* No 8/job 24 */

jobsat17	= .;	if	R3388000	>= 1 and	R3388000	<= 5 then 	jobsat17	=	R3388000	;
jobsat18	= .;	if	R3388100	>= 1 and	R3388100	<= 5 then 	jobsat18	=	R3388100	;
jobsat19	= .;	if	R3388200	>= 1 and	R3388200	<= 5 then 	jobsat19	=	R3388200	;
jobsat20	= .;	if	R3388300	>= 1 and	R3388300	<= 5 then 	jobsat20	=	R3388300	;
jobsat21	= .;	if	R3388400	>= 1 and	R3388400	<= 5 then 	jobsat21	=	R3388400	;
jobsat22	= .;	if	R3388500	>= 1 and	R3388500	<= 5 then 	jobsat22	=	R3388500	;
jobsat23	= .;	if	R3388600	>= 1 and	R3388600	<= 5 then 	jobsat23	=	R3388600	;
jobsat24	= .;									;
jobsat25	= .;	if	R3388700	>= 1 and	R3388700	<= 5 then 	jobsat25	=	R3388700	;

union17	= .;	if	R3387200	>= 0 and	R3387200	<= 1 then 	union17	=	R3387200	;
union18	= .;	if	R3387300	>= 0 and	R3387300	<= 1 then 	union18	=	R3387300	;
union19	= .;	if	R3387400	>= 0 and	R3387400	<= 1 then 	union19	=	R3387400	;
union20	= .;	if	R3387500	>= 0 and	R3387500	<= 1 then 	union20	=	R3387500	;
union21	= .;	if	R3387600	>= 0 and	R3387600	<= 1 then 	union21	=	R3387600	;
union22	= .;	if	R3387700	>= 0 and	R3387700	<= 1 then 	union22	=	R3387700	;
union23	= .;	if	R3387800	>= 0 and	R3387800	<= 1 then 	union23	=	R3387800	;
union24	=.;									
union25	= .;	if	R3387900	>= 0 and	R3387900	<= 1 then 	union25	=	R3387900	;

ben_med17	= .;	if	R3381101	>= 0 and	R3381101	<= 1 then 	ben_med17	=	R3381101	;
ben_med18	= .;	if	R3381201	>= 0 and	R3381201	<= 1 then 	ben_med18	=	R3381201	;
ben_med19	= .;	if	R3381301	>= 0 and	R3381301	<= 1 then 	ben_med19	=	R3381301	;
ben_med20	= .;	if	R3381401	>= 0 and	R3381401	<= 1 then 	ben_med20	=	R3381401	;
ben_med21	= .;	if	R3381501	>= 0 and	R3381501	<= 1 then 	ben_med21	=	R3381501	;
ben_med22	= .;	if	R3381601	>= 0 and	R3381601	<= 1 then 	ben_med22	=	R3381601	;
ben_med23	= .;	if	R3381701	>= 0 and	R3381701	<= 1 then 	ben_med23	=	R3381701	;
ben_med24	= .;									
ben_med25	= .;	if	R3381801	>= 0 and	R3381801	<= 1 then 	ben_med25	=	R3381801	;

ben_flex17	= .;	if	R3381107	>= 0 and	R3381107	<= 1 then 	ben_flex17	=	R3381107	;
ben_flex18	= .;	if	R3381207	>= 0 and	R3381207	<= 1 then 	ben_flex18	=	R3381207	;
ben_flex19	= .;	if	R3381307	>= 0 and	R3381307	<= 1 then 	ben_flex19	=	R3381307	;
ben_flex20	= .;	if	R3381407	>= 0 and	R3381407	<= 1 then 	ben_flex20	=	R3381407	;
ben_flex21	= .;	if	R3381507	>= 0 and	R3381507	<= 1 then 	ben_flex21	=	R3381507	;
ben_flex22	= .;	if	R3381607	>= 0 and	R3381607	<= 1 then 	ben_flex22	=	R3381607	;
ben_flex23	= .;	if	R3381707	>= 0 and	R3381707	<= 1 then 	ben_flex23	=	R3381707	;
ben_flex24	= .;									
ben_flex25	= .;	if	R3381807	>= 0 and	R3381807	<= 1 then 	ben_flex25	=	R3381807	;

ben_life17	= .;	if	R3381102	>= 0 and	R3381102	<= 1 then 	ben_life17	=	R3381102	;
ben_life18	= .;	if	R3381202	>= 0 and	R3381202	<= 1 then 	ben_life18	=	R3381202	;
ben_life19	= .;	if	R3381302	>= 0 and	R3381302	<= 1 then 	ben_life19	=	R3381302	;
ben_life20	= .;	if	R3381402	>= 0 and	R3381402	<= 1 then 	ben_life20	=	R3381402	;
ben_life21	= .;	if	R3381502	>= 0 and	R3381502	<= 1 then 	ben_life21	=	R3381502	;
ben_life22	= .;	if	R3381602	>= 0 and	R3381602	<= 1 then 	ben_life22	=	R3381602	;
ben_life23	= .;	if	R3381702	>= 0 and	R3381702	<= 1 then 	ben_life23	=	R3381702	;
ben_life24	= .;									
ben_life25	= .;	if	R3381802	>= 0 and	R3381802	<= 1 then 	ben_life25	=	R3381802	;

ben_dental17	= .;	if	R3381103	>= 0 and	R3381103	<= 1 then 	ben_dental17	=	R3381103	;
ben_dental18	= .;	if	R3381203	>= 0 and	R3381203	<= 1 then 	ben_dental18	=	R3381203	;
ben_dental19	= .;	if	R3381303	>= 0 and	R3381303	<= 1 then 	ben_dental19	=	R3381303	;
ben_dental20	= .;	if	R3381403	>= 0 and	R3381403	<= 1 then 	ben_dental20	=	R3381403	;
ben_dental21	= .;	if	R3381503	>= 0 and	R3381503	<= 1 then 	ben_dental21	=	R3381503	;
ben_dental22	= .;	if	R3381603	>= 0 and	R3381603	<= 1 then 	ben_dental22	=	R3381603	;
ben_dental23	= .;	if	R3381703	>= 0 and	R3381703	<= 1 then 	ben_dental23	=	R3381703	;
ben_dental24	= .;									
ben_dental25	= .;	if	R3381803	>= 0 and	R3381803	<= 1 then 	ben_dental25	=	R3381803	;

ben_pdleave17	= .;	if	R3381104	>= 0 and	R3381104	<= 1 then 	ben_pdleave17	=	R3381104	;
ben_pdleave18	= .;	if	R3381204	>= 0 and	R3381204	<= 1 then 	ben_pdleave18	=	R3381204	;
ben_pdleave19	= .;	if	R3381304	>= 0 and	R3381304	<= 1 then 	ben_pdleave19	=	R3381304	;
ben_pdleave20	= .;	if	R3381404	>= 0 and	R3381404	<= 1 then 	ben_pdleave20	=	R3381404	;
ben_pdleave21	= .;	if	R3381504	>= 0 and	R3381504	<= 1 then 	ben_pdleave21	=	R3381504	;
ben_pdleave22	= .;	if	R3381604	>= 0 and	R3381604	<= 1 then 	ben_pdleave22	=	R3381604	;
ben_pdleave23	= .;	if	R3381704	>= 0 and	R3381704	<= 1 then 	ben_pdleave23	=	R3381704	;
ben_pdleave24	= .;									
ben_pdleave25	= .;	if	R3381804	>= 0 and	R3381804	<= 1 then 	ben_pdleave25	=	R3381804	;

ben_unpdleave17	= .;	if	R3381105	>= 0 and	R3381105	<= 1 then 	ben_unpdleave17	=	R3381105	;
ben_unpdleave18	= .;	if	R3381205	>= 0 and	R3381205	<= 1 then 	ben_unpdleave18	=	R3381205	;
ben_unpdleave19	= .;	if	R3381305	>= 0 and	R3381305	<= 1 then 	ben_unpdleave19	=	R3381305	;
ben_unpdleave20	= .;	if	R3381405	>= 0 and	R3381405	<= 1 then 	ben_unpdleave20	=	R3381405	;
ben_unpdleave21	= .;	if	R3381505	>= 0 and	R3381505	<= 1 then 	ben_unpdleave21	=	R3381505	;
ben_unpdleave22	= .;	if	R3381605	>= 0 and	R3381605	<= 1 then 	ben_unpdleave22	=	R3381605	;
ben_unpdleave23	= .;	if	R3381705	>= 0 and	R3381705	<= 1 then 	ben_unpdleave23	=	R3381705	;
ben_unpdleave24	= .;									
ben_unpdleave25	= .;	if	R3381805	>= 0 and	R3381805	<= 1 then 	ben_unpdleave25	=	R3381805	;

ben_retire17	= .;	if	R3381106	>= 0 and	R3381106	<= 1 then 	ben_retire17	=	R3381106	;
ben_retire18	= .;	if	R3381206	>= 0 and	R3381206	<= 1 then 	ben_retire18	=	R3381206	;
ben_retire19	= .;	if	R3381306	>= 0 and	R3381306	<= 1 then 	ben_retire19	=	R3381306	;
ben_retire20	= .;	if	R3381406	>= 0 and	R3381406	<= 1 then 	ben_retire20	=	R3381406	;
ben_retire21	= .;	if	R3381506	>= 0 and	R3381506	<= 1 then 	ben_retire21	=	R3381506	;
ben_retire22	= .;	if	R3381606	>= 0 and	R3381606	<= 1 then 	ben_retire22	=	R3381606	;
ben_retire23	= .;	if	R3381706	>= 0 and	R3381706	<= 1 then 	ben_retire23	=	R3381706	;
ben_retire24	= .;									
ben_retire25	= .;	if	R3381806	>= 0 and	R3381806	<= 1 then 	ben_retire25	=	R3381806	;

ben_tuition17	= .;	if	R3381108	>= 0 and	R3381108	<= 1 then 	ben_tuition17	=	R3381108	;
ben_tuition18	= .;	if	R3381208	>= 0 and	R3381208	<= 1 then 	ben_tuition18	=	R3381208	;
ben_tuition19	= .;	if	R3381308	>= 0 and	R3381308	<= 1 then 	ben_tuition19	=	R3381308	;
ben_tuition20	= .;	if	R3381408	>= 0 and	R3381408	<= 1 then 	ben_tuition20	=	R3381408	;
ben_tuition21	= .;	if	R3381508	>= 0 and	R3381508	<= 1 then 	ben_tuition21	=	R3381508	;
ben_tuition22	= .;	if	R3381608	>= 0 and	R3381608	<= 1 then 	ben_tuition22	=	R3381608	;
ben_tuition23	= .;	if	R3381708	>= 0 and	R3381708	<= 1 then 	ben_tuition23	=	R3381708	;
ben_tuition24	= .;									
ben_tuition25	= .;	if	R3381808	>= 0 and	R3381808	<= 1 then 	ben_tuition25	=	R3381808	;

ben_child17	= .;	if	R3381109	>= 0 and	R3381109	<= 1 then 	ben_child17	=	R3381109	;
ben_child18	= .;	if	R3381209	>= 0 and	R3381209	<= 1 then 	ben_child18	=	R3381209	;
ben_child19	= .;	if	R3381309	>= 0 and	R3381309	<= 1 then 	ben_child19	=	R3381309	;
ben_child20	= .;	if	R3381409	>= 0 and	R3381409	<= 1 then 	ben_child20	=	R3381409	;
ben_child21	= .;	if	R3381509	>= 0 and	R3381509	<= 1 then 	ben_child21	=	R3381509	;
ben_child22	= .;	if	R3381609	>= 0 and	R3381609	<= 1 then 	ben_child22	=	R3381609	;
ben_child23	= .;	if	R3381709	>= 0 and	R3381709	<= 1 then 	ben_child23	=	R3381709	;
ben_child24	= .;									
ben_child25	= .;	if	R3381809	>= 0 and	R3381809	<= 1 then 	ben_child25	=	R3381809	;

ben_stock17	= .;	if	R3381110	>= 0 and	R3381110	<= 1 then 	ben_stock17	=	R3381110	;
ben_stock18	= .;	if	R3381210	>= 0 and	R3381210	<= 1 then 	ben_stock18	=	R3381210	;
ben_stock19	= .;	if	R3381310	>= 0 and	R3381310	<= 1 then 	ben_stock19	=	R3381310	;
ben_stock20	= .;	if	R3381410	>= 0 and	R3381410	<= 1 then 	ben_stock20	=	R3381410	;
ben_stock21	= .;	if	R3381510	>= 0 and	R3381510	<= 1 then 	ben_stock21	=	R3381510	;
ben_stock22	= .;	if	R3381610	>= 0 and	R3381610	<= 1 then 	ben_stock22	=	R3381610	;
ben_stock23	= .;	if	R3381710	>= 0 and	R3381710	<= 1 then 	ben_stock23	=	R3381710	;
ben_stock24	= .;									
ben_stock25	= .;	if	R3381810	>= 0 and	R3381810	<= 1 then 	ben_stock25	=	R3381810	;

occcode17	= .; if	S3697000	ge 0 and	S3697000	le 9990 then	occcode17	=	S3697000	;
occcode18	= .; if	S3697100	ge 0 and	S3697100	le 9990 then	occcode18	=	S3697100	;
occcode19	= .; if	S3697200	ge 0 and	S3697200	le 9990 then	occcode19	=	S3697200	;
occcode20	= .; if	S3697300	ge 0 and	S3697300	le 9990 then	occcode20	=	S3697300	;
occcode21	= .; if	S3697400	ge 0 and	S3697400	le 9990 then	occcode21	=	S3697400	;
occcode22	= .; if	S3697500	ge 0 and	S3697500	le 9990 then	occcode22	=	S3697500	;
occcode23	= .; if	S3697600	ge 0 and	S3697600	le 9990 then	occcode23	=	S3697600	;
occcode24	= .; if	S3697700	ge 0 and	S3697700	le 9990 then	occcode24	=	S3697700	;
occcode25	= .; if	S3697800	ge 0 and	S3697800	le 9990 then	occcode25	=	S3697800	;

indcode17	= .; if	S3695000	ge 0 and	S3695000	le 9990 then	indcode17	=	S3695000	;
indcode18	= .; if	S3695100	ge 0 and	S3695100	le 9990 then	indcode18	=	S3695100	;
indcode19	= .; if	S3695200	ge 0 and	S3695200	le 9990 then	indcode19	=	S3695200	;
indcode20	= .; if	S3695300	ge 0 and	S3695300	le 9990 then	indcode20	=	S3695300	;
indcode21	= .; if	S3695400	ge 0 and	S3695400	le 9990 then	indcode21	=	S3695400	;
indcode22	= .; if	S3695500	ge 0 and	S3695500	le 9990 then	indcode22	=	S3695500	;
indcode23	= .; if	S3695600	ge 0 and	S3695600	le 9990 then	indcode23	=	S3695600	;
indcode24	= .; if	S3695700	ge 0 and	S3695700	le 9990 then	indcode24	=	S3695700	;
indcode25	= .; if	S3695800	ge 0 and	S3695800	le 9990 then	indcode25	=	S3695800	;

jobtype17	= .; if	R3189000	ge 1 &	R3189000	le 5 then	jobtype17	=	R3189000	;
jobtype18	= .; if	R3189100	ge 1 &	R3189100	le 5 then	jobtype18	=	R3189100	;
jobtype19	= .; if	R3189200	ge 1 &	R3189200	le 5 then	jobtype19	=	R3189200	;
jobtype20	= .; if	R3189300	ge 1 &	R3189300	le 5 then	jobtype20	=	R3189300	;
jobtype21	= .; if	R3189400	ge 1 &	R3189400	le 5 then	jobtype21	=	R3189400	;
jobtype22	= .; if	R3189500	ge 1 &	R3189500	le 5 then	jobtype22	=	R3189500	;
jobtype23	= .; if	R3189600	ge 1 &	R3189600	le 5 then	jobtype23	=	R3189600	;
jobtype24	= .; if	R3189700	ge 1 &	R3189700	le 5 then	jobtype24	=	R3189700	;
jobtype25	= .; if	R3189800	ge 1 &	R3189800	le 5 then	jobtype25	=	R3189800	;

hourswk17	= .; if	R3889701	ge 0 &	R3889701	le 168 then	hourswk17	=	R3889701	;
hourswk18	= .; if	R3889702	ge 0 &	R3889702	le 168 then	hourswk18	=	R3889702	;
hourswk19	= .; if	R3889703	ge 0 &	R3889703	le 168 then	hourswk19	=	R3889703	;
hourswk20	= .; if	R3889704	ge 0 &	R3889704	le 168 then	hourswk20	=	R3889704	;
hourswk21	= .; if	R3889705	ge 0 &	R3889705	le 168 then	hourswk21	=	R3889705	;
hourswk22	= .; if	R3889706	ge 0 &	R3889706	le 168 then	hourswk22	=	R3889706	;
hourswk23	= .; if	R3889707	ge 0 &	R3889707	le 168 then	hourswk23	=	R3889707	;
hourswk24	= .; if	R3889708	ge 0 &	R3889708	le 168 then	hourswk24	=	R3889708	;
hourswk25	= .; if	R3889709	ge 0 &	R3889709	le 168 then	hourswk25	=	R3889709	;

anygap17	= .; if	R3390400	ge -2 &	R3390400	le 0 then	anygap17	=	0	;	if 	R3390400	eq 1 then	anygap17	=	1	;
anygap18	= .; if	R3390500	ge -2 &	R3390500	le 0 then	anygap18	=	0	;	if 	R3390500	eq 1 then	anygap18	=	1	;
anygap19	= .; if	R3390600	ge -2 &	R3390600	le 0 then	anygap19	=	0	;	if 	R3390600	eq 1 then	anygap19	=	1	;
anygap20	= .; if	R3390700	ge -2 &	R3390700	le 0 then	anygap20	=	0	;	if 	R3390700	eq 1 then	anygap20	=	1	;
anygap21	= .; if	R3390800	ge -2 &	R3390800	le 0 then	anygap21	=	0	;	if 	R3390800	eq 1 then	anygap21	=	1	;
anygap22	= .; if	R3390900	ge -2 &	R3390900	le 0 then	anygap22	=	0	;	if 	R3390900	eq 1 then	anygap22	=	1	;
anygap23	= .; if	R3391000	ge -2 &	R3391000	le 0 then	anygap23	=	0	;	if 	R3391000	eq 1 then	anygap23	=	1	;
anygap24	= .; if	R3391100	ge -2 &	R3391100	le 0 then	anygap24	=	0	;	if 	R3391100	eq 1 then	anygap24	=	1	;
anygap25	= .; if	R3391200	ge -2 &	R3391200	le 0 then	anygap25	=	0	;	if 	R3391200	eq 1 then	anygap25	=	1	;

worksched17	= .; if	R3380300	ge 1 &	R3380300	le 9 then	worksched17	=	R3380300	;
worksched18	= .; if	R3380400	ge 1 &	R3380400	le 9 then	worksched18	=	R3380400	;
worksched19	= .; if	R3380500	ge 1 &	R3380500	le 9 then	worksched19	=	R3380500	;
worksched20	= .; if	R3380600	ge 1 &	R3380600	le 9 then	worksched20	=	R3380600	;
worksched21	= .; if	R3380700	ge 1 &	R3380700	le 9 then	worksched21	=	R3380700	;
worksched22	= .; if	R3380800	ge 1 &	R3380800	le 9 then	worksched22	=	R3380800	;
worksched23	= .; if	R3380900	ge 1 &	R3380900	le 9 then	worksched23	=	R3380900	;
worksched24	= .; 						
worksched25	= .; if	R3381000	ge 1 &	R3381000	le 9 then	worksched25	=	R3381000	;

/* 2000: up to 9 ***********************************************************/

idjob26	= .; if (R5313700 >= 0 & R5313700 <= 300000) then idjob26 =	R5313700;
idjob27	= .; if (R5313800 >= 0 & R5313800 <= 300000) then idjob27 =	R5313800;
idjob28	= .; if (R5313900 >= 0 & R5313900 <= 300000) then idjob28 =	R5313900;
idjob29	= .; if (R5314000 >= 0 & R5314000 <= 300000) then idjob29 =	R5314000;
idjob30	= .; if (R5314100 >= 0 & R5314100 <= 300000) then idjob30 =	R5314100;
idjob31	= .; if (R5314200 >= 0 & R5314200 <= 300000) then idjob31 =	R5314200;
idjob32	= .; if (R5314300 >= 0 & R5314300 <= 300000) then idjob32 =	R5314300;
idjob33	= .; if (R5314400 >= 0 & R5314400 <= 300000) then idjob33 =	R5314400;
idjob34	= .; if (R5314500 >= 0 & R5314500 <= 300000) then idjob34 =	R5314500;

whyleftjob26 = .; if (R4751900	>= 0 & R4751900	<= 50) then	whyleftjob26 =	R4751900;
whyleftjob27 = .; if (R4752000	>= 0 & R4752000	<= 50) then	whyleftjob27 =	R4752000;
whyleftjob28 = .; if (R4752100	>= 0 & R4752100	<= 50) then	whyleftjob28 =	R4752100;
whyleftjob29 = .; if (R4752200	>= 0 & R4752200	<= 50) then	whyleftjob29 =	R4752200;
whyleftjob30 = .; if (R4752300	>= 0 & R4752300	<= 50) then	whyleftjob30 =	R4752300;
whyleftjob31 = .; if (R4752400	>= 0 & R4752400	<= 50) then	whyleftjob31 =	R4752400;
whyleftjob32 = .; if (R4752500	>= 0 & R4752500	<= 50) then	whyleftjob32 =	R4752500;
whyleftjob33 = .; if (R4752600	>= 0 & R4752600	<= 50) then	whyleftjob33 =	R4752600;
whyleftjob34 = .; if (R4752700	>= 0 & R4752700	<= 50) then	whyleftjob34 =	R4752700;

curjob26	= .; if	R5304300	>= 0 &	R5304300	<= 1 then	curjob26	=	R5304300	;
curjob27	= .; if	R5304400	>= 0 &	R5304400	<= 1 then	curjob27	=	R5304400	;
curjob28	= .; if	R5304500	>= 0 &	R5304500	<= 1 then	curjob28	=	R5304500	;
curjob29	= .; if	R5304600	>= 0 &	R5304600	<= 1 then	curjob29	=	R5304600	;
curjob30	= .; if	R5304700	>= 0 &	R5304700	<= 1 then	curjob30	=	R5304700	;
curjob31	= .; if	R5304800	>= 0 &	R5304800	<= 1 then	curjob31	=	R5304800	;
curjob32	= .; if	R5304900	>= 0 &	R5304900	<= 1 then	curjob32	=	R5304900	;
curjob33	= .; if	R5305000	>= 0 &	R5305000	<= 1 then	curjob33	=	R5305000	;
curjob34	= .; if	R5305100	>= 0 &	R5305100	<= 1 then	curjob34	=	R5305100	;

intmo26	= R5472200;
intmo27	= R5472200;
intmo28	= R5472200;
intmo29	= R5472200;
intmo30	= R5472200;
intmo31	= R5472200;
intmo32	= R5472200;
intmo33	= R5472200;
intmo34	= R5472200;

weeksjob26 = .;	if (R5484800 >= 0 &	R5484800 <= 5000) then weeksjob26 =	R5484800;
weeksjob27 = .;	if (R5484900 >= 0 &	R5484900 <= 5000) then weeksjob27 =	R5484900;
weeksjob28 = .;	if (R5485000 >= 0 &	R5485000 <= 5000) then weeksjob28 =	R5485000;
weeksjob29 = .;	if (R5485100 >= 0 &	R5485100 <= 5000) then weeksjob29 =	R5485100;
weeksjob30 = .;	if (R5485200 >= 0 &	R5485200 <= 5000) then weeksjob30 =	R5485200;
weeksjob31 = .;	if (R5485300 >= 0 &	R5485300 <= 5000) then weeksjob31 =	R5485300;
weeksjob32 = .;	if (R5485400 >= 0 &	R5485400 <= 5000) then weeksjob32 =	R5485400;
weeksjob33 = .;	if (R5485500 >= 0 &	R5485500 <= 5000) then weeksjob33 =	R5485500;
weeksjob34 = .;	if (R5485600 >= 0 &	R5485600 <= 5000) then weeksjob34 =	R5485600;

startmojob26	=	.;	if	R5310101	>=	0	&	R5310101	<=	12	then	startmojob26	=	R5310101	;			
startmojob27	=	.;	if	R5310201	>=	0	&	R5310201	<=	12	then	startmojob27	=	R5310201	;			
startmojob28	=	.;	if	R5310301	>=	0	&	R5310301	<=	12	then	startmojob28	=	R5310301	;			
startmojob29	=	.;	if	R5310401	>=	0	&	R5310401	<=	12	then	startmojob29	=	R5310401	;			
startmojob30	=	.;	if	R5310501	>=	0	&	R5310501	<=	12	then	startmojob30	=	R5310501	;			
startmojob31	=	.;	if	R5310601	>=	0	&	R5310601	<=	12	then	startmojob31	=	R5310601	;			
startmojob32	=	.;	if	R5310701	>=	0	&	R5310701	<=	12	then	startmojob32	=	R5310701	;			
startmojob33	=	.;	if	R5310801	>=	0	&	R5310801	<=	12	then	startmojob33	=	R5310801	;			
startmojob34	=	.;	if	R5310901	>=	0	&	R5310901	<=	12	then	startmojob34	=	R5310901	;			
																		
startyrjob26	=	.;	if	R5310102	>=	1980	&	R5310102	<=	2050	then	startyrjob26	=	R5310102	;			
startyrjob27	=	.;	if	R5310202	>=	1980	&	R5310202	<=	2050	then	startyrjob27	=	R5310202	;			
startyrjob28	=	.;	if	R5310302	>=	1980	&	R5310302	<=	2050	then	startyrjob28	=	R5310302	;			
startyrjob29	=	.;	if	R5310402	>=	1980	&	R5310402	<=	2050	then	startyrjob29	=	R5310402	;			
startyrjob30	=	.;	if	R5310502	>=	1980	&	R5310502	<=	2050	then	startyrjob30	=	R5310502	;			
startyrjob31	=	.;	if	R5310602	>=	1980	&	R5310602	<=	2050	then	startyrjob31	=	R5310602	;			
startyrjob32	=	.;	if	R5310702	>=	1980	&	R5310702	<=	2050	then	startyrjob32	=	R5310702	;			
startyrjob33	=	.;	if	R5310802	>=	1980	&	R5310802	<=	2050	then	startyrjob33	=	R5310802	;			
startyrjob34	=	.;	if	R5310902	>=	1980	&	R5310902	<=	2050	then	startyrjob34	=	R5310902	;			
																		
startcontmo26	=	.;	if	startyrjob26	ne	.	&	startmojob26	ne	.	then	startcontmo26	=	((startyrjob26	-1980)*12)	+	startmojob26	;
startcontmo27	=	.;	if	startyrjob27	ne	.	&	startmojob27	ne	.	then	startcontmo27	=	((startyrjob27	-1980)*12)	+	startmojob27	;
startcontmo28	=	.;	if	startyrjob28	ne	.	&	startmojob28	ne	.	then	startcontmo28	=	((startyrjob28	-1980)*12)	+	startmojob28	;
startcontmo29	=	.;	if	startyrjob29	ne	.	&	startmojob29	ne	.	then	startcontmo29	=	((startyrjob29	-1980)*12)	+	startmojob29	;
startcontmo30	=	.;	if	startyrjob30	ne	.	&	startmojob30	ne	.	then	startcontmo30	=	((startyrjob30	-1980)*12)	+	startmojob30	;
startcontmo31	=	.;	if	startyrjob31	ne	.	&	startmojob31	ne	.	then	startcontmo31	=	((startyrjob31	-1980)*12)	+	startmojob31	;
startcontmo32	=	.;	if	startyrjob32	ne	.	&	startmojob32	ne	.	then	startcontmo32	=	((startyrjob32	-1980)*12)	+	startmojob32	;
startcontmo33	=	.;	if	startyrjob33	ne	.	&	startmojob33	ne	.	then	startcontmo33	=	((startyrjob33	-1980)*12)	+	startmojob33	;
startcontmo34	=	.;	if	startyrjob34	ne	.	&	startmojob34	ne	.	then	startcontmo34	=	((startyrjob34	-1980)*12)	+	startmojob34	;

endbyst26	= .; if	R4811000	ge 0 &	R4811000	le 1 then	endbyst26	=	R4811000	;
endbyst27	= .; if	R4811100	ge 0 &	R4811100	le 1 then	endbyst27	=	R4811100	;
endbyst28	= .; if	R4811200	ge 0 &	R4811200	le 1 then	endbyst28	=	R4811200	;
endbyst29	= .; if	R4811300	ge 0 &	R4811300	le 1 then	endbyst29	=	R4811300	;
endbyst30	= .; if	R4811400	ge 0 &	R4811400	le 1 then	endbyst30	=	R4811400	;
endbyst31	= .; if	R4811500	ge 0 &	R4811500	le 1 then	endbyst31	=	R4811500	;
endbyst32	= .; if	R4811600	ge 0 &	R4811600	le 1 then	endbyst32	=	R4811600	;
endbyst33	= .; if	R4811700	ge 0 &	R4811700	le 1 then	endbyst33	=	R4811700	;
endbyst34	= .; if	R4811800	ge 0 &	R4811800	le 1 then	endbyst34	=	R4811800	;

jobsat26	= .;	if	R4771900	>= 1 and	R4771900	<= 5 then 	jobsat26	=	R4771900	;
jobsat27	= .;	if	R4772000	>= 1 and	R4772000	<= 5 then 	jobsat27	=	R4772000	;
jobsat28	= .;	if	R4772100	>= 1 and	R4772100	<= 5 then 	jobsat28	=	R4772100	;
jobsat29	= .;	if	R4772200	>= 1 and	R4772200	<= 5 then 	jobsat29	=	R4772200	;
jobsat30	= .;	if	R4772300	>= 1 and	R4772300	<= 5 then 	jobsat30	=	R4772300	;
jobsat31	= .;	if	R4772400	>= 1 and	R4772400	<= 5 then 	jobsat31	=	R4772400	;
jobsat32	= .;	if	R4772500	>= 1 and	R4772500	<= 5 then 	jobsat32	=	R4772500	;
jobsat33	= .;	if	R4772600	>= 1 and	R4772600	<= 5 then 	jobsat33	=	R4772600	;
jobsat34	= .;	if	R4772700	>= 1 and	R4772700	<= 5 then 	jobsat34	=	R4772700	;

union26	= .;	if	R4766800	>= 0 and	R4766800	<= 1 then 	union26	=	R4766800	;
union27	= .;	if	R4766900	>= 0 and	R4766900	<= 1 then 	union27	=	R4766900	;
union28	= .;	if	R4767000	>= 0 and	R4767000	<= 1 then 	union28	=	R4767000	;
union29	= .;	if	R4767100	>= 0 and	R4767100	<= 1 then 	union29	=	R4767100	;
union30	= .;	if	R4767200	>= 0 and	R4767200	<= 1 then 	union30	=	R4767200	;
union31	= .;	if	R4767300	>= 0 and	R4767300	<= 1 then 	union31	=	R4767300	;
union32	= .;	if	R4767400	>= 0 and	R4767400	<= 1 then 	union32	=	R4767400	;
union33	= .;	if	R4767500	>= 0 and	R4767500	<= 1 then 	union33	=	R4767500	;
union34	= .;	if	R4767600	>= 0 and	R4767600	<= 1 then 	union34	=	R4767600	;

ben_med26	= .;	if	R4760101	>= 0 and	R4760101	<= 1 then 	ben_med26	=	R4760101	;
ben_med27	= .;	if	R4760201	>= 0 and	R4760201	<= 1 then 	ben_med27	=	R4760201	;
ben_med28	= .;	if	R4760301	>= 0 and	R4760301	<= 1 then 	ben_med28	=	R4760301	;
ben_med29	= .;	if	R4760401	>= 0 and	R4760401	<= 1 then 	ben_med29	=	R4760401	;
ben_med30	= .;	if	R4760501	>= 0 and	R4760501	<= 1 then 	ben_med30	=	R4760501	;
ben_med31	= .;	if	R4760601	>= 0 and	R4760601	<= 1 then 	ben_med31	=	R4760601	;
ben_med32	= .;	if	R4760701	>= 0 and	R4760701	<= 1 then 	ben_med32	=	R4760701	;
ben_med33	= .;	if	R4760801	>= 0 and	R4760801	<= 1 then 	ben_med33	=	R4760801	;
ben_med34	= .;	if	R4760901	>= 0 and	R4760901	<= 1 then 	ben_med34	=	R4760901	;

ben_flex26	= .;	if	R4760107	>= 0 and	R4760107	<= 1 then 	ben_flex26	=	R4760107	;
ben_flex27	= .;	if	R4760207	>= 0 and	R4760207	<= 1 then 	ben_flex27	=	R4760207	;
ben_flex28	= .;	if	R4760307	>= 0 and	R4760307	<= 1 then 	ben_flex28	=	R4760307	;
ben_flex29	= .;	if	R4760407	>= 0 and	R4760407	<= 1 then 	ben_flex29	=	R4760407	;
ben_flex30	= .;	if	R4760507	>= 0 and	R4760507	<= 1 then 	ben_flex30	=	R4760507	;
ben_flex31	= .;	if	R4760607	>= 0 and	R4760607	<= 1 then 	ben_flex31	=	R4760607	;
ben_flex32	= .;	if	R4760707	>= 0 and	R4760707	<= 1 then 	ben_flex32	=	R4760707	;
ben_flex33	= .;	if	R4760807	>= 0 and	R4760807	<= 1 then 	ben_flex33	=	R4760807	;
ben_flex34	= .;	if	R4760907	>= 0 and	R4760907	<= 1 then 	ben_flex34	=	R4760907	;

ben_life26	= .;	if	R4760102	>= 0 and	R4760102	<= 1 then 	ben_life26	=	R4760102	;
ben_life27	= .;	if	R4760202	>= 0 and	R4760202	<= 1 then 	ben_life27	=	R4760202	;
ben_life28	= .;	if	R4760302	>= 0 and	R4760302	<= 1 then 	ben_life28	=	R4760302	;
ben_life29	= .;	if	R4760402	>= 0 and	R4760402	<= 1 then 	ben_life29	=	R4760402	;
ben_life30	= .;	if	R4760502	>= 0 and	R4760502	<= 1 then 	ben_life30	=	R4760502	;
ben_life31	= .;	if	R4760602	>= 0 and	R4760602	<= 1 then 	ben_life31	=	R4760602	;
ben_life32	= .;	if	R4760702	>= 0 and	R4760702	<= 1 then 	ben_life32	=	R4760702	;
ben_life33	= .;	if	R4760802	>= 0 and	R4760802	<= 1 then 	ben_life33	=	R4760802	;
ben_life34	= .;	if	R4760902	>= 0 and	R4760902	<= 1 then 	ben_life34	=	R4760902	;

ben_dental26	= .;	if	R4760103	>= 0 and	R4760103	<= 1 then 	ben_dental26	=	R4760103	;
ben_dental27	= .;	if	R4760203	>= 0 and	R4760203	<= 1 then 	ben_dental27	=	R4760203	;
ben_dental28	= .;	if	R4760303	>= 0 and	R4760303	<= 1 then 	ben_dental28	=	R4760303	;
ben_dental29	= .;	if	R4760403	>= 0 and	R4760403	<= 1 then 	ben_dental29	=	R4760403	;
ben_dental30	= .;	if	R4760503	>= 0 and	R4760503	<= 1 then 	ben_dental30	=	R4760503	;
ben_dental31	= .;	if	R4760603	>= 0 and	R4760603	<= 1 then 	ben_dental31	=	R4760603	;
ben_dental32	= .;	if	R4760703	>= 0 and	R4760703	<= 1 then 	ben_dental32	=	R4760703	;
ben_dental33	= .;	if	R4760803	>= 0 and	R4760803	<= 1 then 	ben_dental33	=	R4760803	;
ben_dental34	= .;	if	R4760903	>= 0 and	R4760903	<= 1 then 	ben_dental34	=	R4760903	;

ben_pdleave26	= .;	if	R4760104	>= 0 and	R4760104	<= 1 then 	ben_pdleave26	=	R4760104	;
ben_pdleave27	= .;	if	R4760204	>= 0 and	R4760204	<= 1 then 	ben_pdleave27	=	R4760204	;
ben_pdleave28	= .;	if	R4760304	>= 0 and	R4760304	<= 1 then 	ben_pdleave28	=	R4760304	;
ben_pdleave29	= .;	if	R4760404	>= 0 and	R4760404	<= 1 then 	ben_pdleave29	=	R4760404	;
ben_pdleave30	= .;	if	R4760504	>= 0 and	R4760504	<= 1 then 	ben_pdleave30	=	R4760504	;
ben_pdleave31	= .;	if	R4760604	>= 0 and	R4760604	<= 1 then 	ben_pdleave31	=	R4760604	;
ben_pdleave32	= .;	if	R4760704	>= 0 and	R4760704	<= 1 then 	ben_pdleave32	=	R4760704	;
ben_pdleave33	= .;	if	R4760804	>= 0 and	R4760804	<= 1 then 	ben_pdleave33	=	R4760804	;
ben_pdleave34	= .;	if	R4760904	>= 0 and	R4760904	<= 1 then 	ben_pdleave34	=	R4760904	;

ben_unpdleave26	= .;	if	R4760105	>= 0 and	R4760105	<= 1 then 	ben_unpdleave26	=	R4760105	;
ben_unpdleave27	= .;	if	R4760205	>= 0 and	R4760205	<= 1 then 	ben_unpdleave27	=	R4760205	;
ben_unpdleave28	= .;	if	R4760305	>= 0 and	R4760305	<= 1 then 	ben_unpdleave28	=	R4760305	;
ben_unpdleave29	= .;	if	R4760405	>= 0 and	R4760405	<= 1 then 	ben_unpdleave29	=	R4760405	;
ben_unpdleave30	= .;	if	R4760505	>= 0 and	R4760505	<= 1 then 	ben_unpdleave30	=	R4760505	;
ben_unpdleave31	= .;	if	R4760605	>= 0 and	R4760605	<= 1 then 	ben_unpdleave31	=	R4760605	;
ben_unpdleave32	= .;	if	R4760705	>= 0 and	R4760705	<= 1 then 	ben_unpdleave32	=	R4760705	;
ben_unpdleave33	= .;	if	R4760805	>= 0 and	R4760805	<= 1 then 	ben_unpdleave33	=	R4760805	;
ben_unpdleave34	= .;	if	R4760905	>= 0 and	R4760905	<= 1 then 	ben_unpdleave34	=	R4760905	;

ben_retire26	= .;	if	R4760106	>= 0 and	R4760106	<= 1 then 	ben_retire26	=	R4760106	;
ben_retire27	= .;	if	R4760206	>= 0 and	R4760206	<= 1 then 	ben_retire27	=	R4760206	;
ben_retire28	= .;	if	R4760306	>= 0 and	R4760306	<= 1 then 	ben_retire28	=	R4760306	;
ben_retire29	= .;	if	R4760406	>= 0 and	R4760406	<= 1 then 	ben_retire29	=	R4760406	;
ben_retire30	= .;	if	R4760506	>= 0 and	R4760506	<= 1 then 	ben_retire30	=	R4760506	;
ben_retire31	= .;	if	R4760606	>= 0 and	R4760606	<= 1 then 	ben_retire31	=	R4760606	;
ben_retire32	= .;	if	R4760706	>= 0 and	R4760706	<= 1 then 	ben_retire32	=	R4760706	;
ben_retire33	= .;	if	R4760806	>= 0 and	R4760806	<= 1 then 	ben_retire33	=	R4760806	;
ben_retire34	= .;	if	R4760906	>= 0 and	R4760906	<= 1 then 	ben_retire34	=	R4760906	;

ben_tuition26	= .;	if	R4760108	>= 0 and	R4760108	<= 1 then 	ben_tuition26	=	R4760108	;
ben_tuition27	= .;	if	R4760208	>= 0 and	R4760208	<= 1 then 	ben_tuition27	=	R4760208	;
ben_tuition28	= .;	if	R4760308	>= 0 and	R4760308	<= 1 then 	ben_tuition28	=	R4760308	;
ben_tuition29	= .;	if	R4760408	>= 0 and	R4760408	<= 1 then 	ben_tuition29	=	R4760408	;
ben_tuition30	= .;	if	R4760508	>= 0 and	R4760508	<= 1 then 	ben_tuition30	=	R4760508	;
ben_tuition31	= .;	if	R4760608	>= 0 and	R4760608	<= 1 then 	ben_tuition31	=	R4760608	;
ben_tuition32	= .;	if	R4760708	>= 0 and	R4760708	<= 1 then 	ben_tuition32	=	R4760708	;
ben_tuition33	= .;	if	R4760808	>= 0 and	R4760808	<= 1 then 	ben_tuition33	=	R4760808	;
ben_tuition34	= .;	if	R4760908	>= 0 and	R4760908	<= 1 then 	ben_tuition34	=	R4760908	;

ben_child26	= .;	if	R4760109	>= 0 and	R4760109	<= 1 then 	ben_child26	=	R4760109	;
ben_child27	= .;	if	R4760209	>= 0 and	R4760209	<= 1 then 	ben_child27	=	R4760209	;
ben_child28	= .;	if	R4760309	>= 0 and	R4760309	<= 1 then 	ben_child28	=	R4760309	;
ben_child29	= .;	if	R4760409	>= 0 and	R4760409	<= 1 then 	ben_child29	=	R4760409	;
ben_child30	= .;	if	R4760509	>= 0 and	R4760509	<= 1 then 	ben_child30	=	R4760509	;
ben_child31	= .;	if	R4760609	>= 0 and	R4760609	<= 1 then 	ben_child31	=	R4760609	;
ben_child32	= .;	if	R4760709	>= 0 and	R4760709	<= 1 then 	ben_child32	=	R4760709	;
ben_child33	= .;	if	R4760809	>= 0 and	R4760809	<= 1 then 	ben_child33	=	R4760809	;
ben_child34	= .;	if	R4760909	>= 0 and	R4760909	<= 1 then 	ben_child34	=	R4760909	;

ben_stock26	= .;	if	R4760110	>= 0 and	R4760110	<= 1 then 	ben_stock26	=	R4760110	;
ben_stock27	= .;	if	R4760210	>= 0 and	R4760210	<= 1 then 	ben_stock27	=	R4760210	;
ben_stock28	= .;	if	R4760310	>= 0 and	R4760310	<= 1 then 	ben_stock28	=	R4760310	;
ben_stock29	= .;	if	R4760410	>= 0 and	R4760410	<= 1 then 	ben_stock29	=	R4760410	;
ben_stock30	= .;	if	R4760510	>= 0 and	R4760510	<= 1 then 	ben_stock30	=	R4760510	;
ben_stock31	= .;	if	R4760610	>= 0 and	R4760610	<= 1 then 	ben_stock31	=	R4760610	;
ben_stock32	= .;	if	R4760710	>= 0 and	R4760710	<= 1 then 	ben_stock32	=	R4760710	;
ben_stock33	= .;	if	R4760810	>= 0 and	R4760810	<= 1 then 	ben_stock33	=	R4760810	;
ben_stock34	= .;	if	R4760910	>= 0 and	R4760910	<= 1 then 	ben_stock34	=	R4760910	;

occcode26	= .; if	S3713000	ge 0 and	S3713000	le 9990 then	occcode26	=	S3713000	;
occcode27	= .; if	S3713100	ge 0 and	S3713100	le 9990 then	occcode27	=	S3713100	;
occcode28	= .; if	S3713200	ge 0 and	S3713200	le 9990 then	occcode28	=	S3713200	;
occcode29	= .; if	S3713300	ge 0 and	S3713300	le 9990 then	occcode29	=	S3713300	;
occcode30	= .; if	S3713400	ge 0 and	S3713400	le 9990 then	occcode30	=	S3713400	;
occcode31	= .; if	S3713500	ge 0 and	S3713500	le 9990 then	occcode31	=	S3713500	;
occcode32	= .; if	S3713600	ge 0 and	S3713600	le 9990 then	occcode32	=	S3713600	;
occcode33	= .; if	S3713700	ge 0 and	S3713700	le 9990 then	occcode33	=	S3713700	;
occcode34	= .; if	S3713800	ge 0 and	S3713800	le 9990 then	occcode34	=	S3713800	;

indcode26	= .; if	S3711000	ge 0 and	S3711000	le 9990 then	indcode26	=	S3711000	;
indcode27	= .; if	S3711100	ge 0 and	S3711100	le 9990 then	indcode27	=	S3711100	;
indcode28	= .; if	S3711200	ge 0 and	S3711200	le 9990 then	indcode28	=	S3711200	;
indcode29	= .; if	S3711300	ge 0 and	S3711300	le 9990 then	indcode29	=	S3711300	;
indcode30	= .; if	S3711400	ge 0 and	S3711400	le 9990 then	indcode30	=	S3711400	;
indcode31	= .; if	S3711500	ge 0 and	S3711500	le 9990 then	indcode31	=	S3711500	;
indcode32	= .; if	S3711600	ge 0 and	S3711600	le 9990 then	indcode32	=	S3711600	;
indcode33	= .; if	S3711700	ge 0 and	S3711700	le 9990 then	indcode33	=	S3711700	;
indcode34	= .; if	S3711800	ge 0 and	S3711800	le 9990 then	indcode34	=	S3711800	;

jobtype26	= .; if	R4471400	ge 1 &	R4471400	le 5 then	jobtype26	=	R4471400	;
jobtype27	= .; if	R4471500	ge 1 &	R4471500	le 5 then	jobtype27	=	R4471500	;
jobtype28	= .; if	R4471600	ge 1 &	R4471600	le 5 then	jobtype28	=	R4471600	;
jobtype29	= .; if	R4471700	ge 1 &	R4471700	le 5 then	jobtype29	=	R4471700	;
jobtype30	= .; if	R4471800	ge 1 &	R4471800	le 5 then	jobtype30	=	R4471800	;
jobtype31	= .; if	R4471900	ge 1 &	R4471900	le 5 then	jobtype31	=	R4471900	;
jobtype32	= .; if	R4472000	ge 1 &	R4472000	le 5 then	jobtype32	=	R4472000	;
jobtype33	= .; if	R4472100	ge 1 &	R4472100	le 5 then	jobtype33	=	R4472100	;
jobtype34	= .; if	R4472200	ge 1 &	R4472200	le 5 then	jobtype34	=	R4472200	;

hourswk26	= .; if	R5471801	ge 0 &	R5471801	le 168 then	hourswk26	=	R5471801	;
hourswk27	= .; if	R5471802	ge 0 &	R5471802	le 168 then	hourswk27	=	R5471802	;
hourswk28	= .; if	R5471803	ge 0 &	R5471803	le 168 then	hourswk28	=	R5471803	;
hourswk29	= .; if	R5471804	ge 0 &	R5471804	le 168 then	hourswk29	=	R5471804	;
hourswk30	= .; if	R5471805	ge 0 &	R5471805	le 168 then	hourswk30	=	R5471805	;
hourswk31	= .; if	R5471806	ge 0 &	R5471806	le 168 then	hourswk31	=	R5471806	;
hourswk32	= .; if	R5471807	ge 0 &	R5471807	le 168 then	hourswk32	=	R5471807	;
hourswk33	= .; if	R5471808	ge 0 &	R5471808	le 168 then	hourswk33	=	R5471808	;
hourswk34	= .; if	R5471809	ge 0 &	R5471809	le 168 then	hourswk34	=	R5471809	;

anygap26	= .; if	R4776000	ge -2 &	R4776000	le 0 then	anygap26	=	0	;	if 	R4776000	eq 1 then	anygap26	=	1	;
anygap27	= .; if	R4776100	ge -2 &	R4776100	le 0 then	anygap27	=	0	;	if 	R4776100	eq 1 then	anygap27	=	1	;
anygap28	= .; if	R4776200	ge -2 &	R4776200	le 0 then	anygap28	=	0	;	if 	R4776200	eq 1 then	anygap28	=	1	;
anygap29	= .; if	R4776300	ge -2 &	R4776300	le 0 then	anygap29	=	0	;	if 	R4776300	eq 1 then	anygap29	=	1	;
anygap30	= .; if	R4776400	ge -2 &	R4776400	le 0 then	anygap30	=	0	;	if 	R4776400	eq 1 then	anygap30	=	1	;
anygap31	= .; if	R4776500	ge -2 &	R4776500	le 0 then	anygap31	=	0	;	if 	R4776500	eq 1 then	anygap31	=	1	;
anygap32	= .; if	R4776600	ge -2 &	R4776600	le 0 then	anygap32	=	0	;	if 	R4776600	eq 1 then	anygap32	=	1	;
anygap33	= .; if	R4776700	ge -2 &	R4776700	le 0 then	anygap33	=	0	;	if 	R4776700	eq 1 then	anygap33	=	1	;
anygap34	= .; if	R4776800	ge -2 &	R4776800	le 0 then	anygap34	=	0	;	if 	R4776800	eq 1 then	anygap34	=	1	;

worksched26	= .; if	R4759200	ge 1 &	R4759200	le 9 then	worksched26	=	R4759200	;
worksched27	= .; if	R4759300	ge 1 &	R4759300	le 9 then	worksched27	=	R4759300	;
worksched28	= .; if	R4759400	ge 1 &	R4759400	le 9 then	worksched28	=	R4759400	;
worksched29	= .; if	R4759500	ge 1 &	R4759500	le 9 then	worksched29	=	R4759500	;
worksched30	= .; if	R4759600	ge 1 &	R4759600	le 9 then	worksched30	=	R4759600	;
worksched31	= .; if	R4759700	ge 1 &	R4759700	le 9 then	worksched31	=	R4759700	;
worksched32	= .; if	R4759800	ge 1 &	R4759800	le 9 then	worksched32	=	R4759800	;
worksched33	= .; if	R4759900	ge 1 &	R4759900	le 9 then	worksched33	=	R4759900	;
worksched34	= .; if	R4760000	ge 1 &	R4760000	le 9 then	worksched34	=	R4760000	;

/* 2001: up to 8 ***********************************************************/

idjob35	= .; if (R7053500 >= 0 & R7053500 <= 300000) then idjob35 =	R7053500;
idjob36	= .; if (R7053600 >= 0 & R7053600 <= 300000) then idjob36 =	R7053600;
idjob37	= .; if (R7053700 >= 0 & R7053700 <= 300000) then idjob37 =	R7053700;
idjob38	= .; if (R7053800 >= 0 & R7053800 <= 300000) then idjob38 =	R7053800;
idjob39	= .; if (R7053900 >= 0 & R7053900 <= 300000) then idjob39 =	R7053900;
idjob40	= .; if (R7054000 >= 0 & R7054000 <= 300000) then idjob40 =	R7054000;
idjob41	= .; if (R7054100 >= 0 & R7054100 <= 300000) then idjob41 =	R7054100;
idjob42	= .; if (R7054200 >= 0 & R7054200 <= 300000) then idjob42 =	R7054200;

whyleftjob35 = .; if (R6382500	>= 0 & R6382500	<= 50) then	whyleftjob35 =	R6382500;
whyleftjob36 = .; if (R6382600	>= 0 & R6382600	<= 50) then	whyleftjob36 =	R6382600;
whyleftjob37 = .; if (R6382700	>= 0 & R6382700	<= 50) then	whyleftjob37 =	R6382700;
whyleftjob38 = .; if (R6382800	>= 0 & R6382800	<= 50) then	whyleftjob38 =	R6382800;
whyleftjob39 = .; if (R6382900	>= 0 & R6382900	<= 50) then	whyleftjob39 =	R6382900;
whyleftjob40 = .; if (R6383000	>= 0 & R6383000	<= 50) then	whyleftjob40 =	R6383000;
whyleftjob41 = .; if (R6383100	>= 0 & R6383100	<= 50) then	whyleftjob41 =	R6383100;
whyleftjob42 = .; if (R6383200	>= 0 & R6383200	<= 50) then	whyleftjob42 =	R6383200;

curjob35	= .; if	R7046200	>= 0 &	R7046200	<= 1 then	curjob35	=	R7046200	;
curjob36	= .; if	R7046300	>= 0 &	R7046300	<= 1 then	curjob36	=	R7046300	;
curjob37	= .; if	R7046400	>= 0 &	R7046400	<= 1 then	curjob37	=	R7046400	;
curjob38	= .; if	R7046500	>= 0 &	R7046500	<= 1 then	curjob38	=	R7046500	;
curjob39	= .; if	R7046600	>= 0 &	R7046600	<= 1 then	curjob39	=	R7046600	;
curjob40	= .; if	R7046700	>= 0 &	R7046700	<= 1 then	curjob40	=	R7046700	;
curjob41	= .; if	R7046800	>= 0 &	R7046800	<= 1 then	curjob41	=	R7046800	;
curjob42	= .; if	R7046900	>= 0 &	R7046900	<= 1 then	curjob42	=	R7046900	;

intmo35	= R7236000;
intmo36	= R7236000;
intmo37	= R7236000;
intmo38	= R7236000;
intmo39	= R7236000;
intmo40	= R7236000;
intmo41	= R7236000;
intmo42	= R7236000;

weeksjob35 = .;	if (R7249100 >= 0 &	R7249100 <= 5000) then weeksjob35 =	R7249100;
weeksjob36 = .;	if (R7249200 >= 0 &	R7249200 <= 5000) then weeksjob36 =	R7249200;
weeksjob37 = .;	if (R7249300 >= 0 &	R7249300 <= 5000) then weeksjob37 =	R7249300;
weeksjob38 = .;	if (R7249400 >= 0 &	R7249400 <= 5000) then weeksjob38 =	R7249400;
weeksjob39 = .;	if (R7249500 >= 0 &	R7249500 <= 5000) then weeksjob39 =	R7249500;
weeksjob40 = .;	if (R7249600 >= 0 &	R7249600 <= 5000) then weeksjob40 =	R7249600;
weeksjob41 = .;	if (R7249700 >= 0 &	R7249700 <= 5000) then weeksjob41 =	R7249700;
weeksjob42 = .;	if (R7249800 >= 0 &	R7249800 <= 5000) then weeksjob42 =	R7249800;

startmojob35	=	.;	if	R7051101	>=	0	&	R7051101	<=	12	then	startmojob35	=	R7051101	;			
startmojob36	=	.;	if	R7051201	>=	0	&	R7051201	<=	12	then	startmojob36	=	R7051201	;			
startmojob37	=	.;	if	R7051301	>=	0	&	R7051301	<=	12	then	startmojob37	=	R7051301	;			
startmojob38	=	.;	if	R7051401	>=	0	&	R7051401	<=	12	then	startmojob38	=	R7051401	;			
startmojob39	=	.;	if	R7051501	>=	0	&	R7051501	<=	12	then	startmojob39	=	R7051501	;			
startmojob40	=	.;	if	R7051601	>=	0	&	R7051601	<=	12	then	startmojob40	=	R7051601	;			
startmojob41	=	.;	if	R7051701	>=	0	&	R7051701	<=	12	then	startmojob41	=	R7051701	;			
startmojob42	=	.;	if	R7051801	>=	0	&	R7051801	<=	12	then	startmojob42	=	R7051801	;			
																		
startyrjob35	=	.;	if	R7051102	>=	1980	&	R7051102	<=	2050	then	startyrjob35	=	R7051102	;			
startyrjob36	=	.;	if	R7051202	>=	1980	&	R7051202	<=	2050	then	startyrjob36	=	R7051202	;			
startyrjob37	=	.;	if	R7051302	>=	1980	&	R7051302	<=	2050	then	startyrjob37	=	R7051302	;			
startyrjob38	=	.;	if	R7051402	>=	1980	&	R7051402	<=	2050	then	startyrjob38	=	R7051402	;			
startyrjob39	=	.;	if	R7051502	>=	1980	&	R7051502	<=	2050	then	startyrjob39	=	R7051502	;			
startyrjob40	=	.;	if	R7051602	>=	1980	&	R7051602	<=	2050	then	startyrjob40	=	R7051602	;			
startyrjob41	=	.;	if	R7051702	>=	1980	&	R7051702	<=	2050	then	startyrjob41	=	R7051702	;			
startyrjob42	=	.;	if	R7051802	>=	1980	&	R7051802	<=	2050	then	startyrjob42	=	R7051802	;			
																		
startcontmo35	=	.;	if	startyrjob35	ne	.	&	startmojob35	ne	.	then	startcontmo35	=	((startyrjob35	-1980)*12)	+	startmojob35	;
startcontmo36	=	.;	if	startyrjob36	ne	.	&	startmojob36	ne	.	then	startcontmo36	=	((startyrjob36	-1980)*12)	+	startmojob36	;
startcontmo37	=	.;	if	startyrjob37	ne	.	&	startmojob37	ne	.	then	startcontmo37	=	((startyrjob37	-1980)*12)	+	startmojob37	;
startcontmo38	=	.;	if	startyrjob38	ne	.	&	startmojob38	ne	.	then	startcontmo38	=	((startyrjob38	-1980)*12)	+	startmojob38	;
startcontmo39	=	.;	if	startyrjob39	ne	.	&	startmojob39	ne	.	then	startcontmo39	=	((startyrjob39	-1980)*12)	+	startmojob39	;
startcontmo40	=	.;	if	startyrjob40	ne	.	&	startmojob40	ne	.	then	startcontmo40	=	((startyrjob40	-1980)*12)	+	startmojob40	;
startcontmo41	=	.;	if	startyrjob41	ne	.	&	startmojob41	ne	.	then	startcontmo41	=	((startyrjob41	-1980)*12)	+	startmojob41	;
startcontmo42	=	.;	if	startyrjob42	ne	.	&	startmojob42	ne	.	then	startcontmo42	=	((startyrjob42	-1980)*12)	+	startmojob42	;

endbyst35	= .; if	R6434400	ge 0 &	R6434400	le 1 then	endbyst35	=	R6434400	;
endbyst36	= .; if	R6434500	ge 0 &	R6434500	le 1 then	endbyst36	=	R6434500	;
endbyst37	= .; if	R6434600	ge 0 &	R6434600	le 1 then	endbyst37	=	R6434600	;
endbyst38	= .; if	R6434700	ge 0 &	R6434700	le 1 then	endbyst38	=	R6434700	;
endbyst39	= .; if	R6434800	ge 0 &	R6434800	le 1 then	endbyst39	=	R6434800	;
endbyst40	= .; if	R6434900	ge 0 &	R6434900	le 1 then	endbyst40	=	R6434900	;
endbyst41	= .; if	R6435000	ge 0 &	R6435000	le 1 then	endbyst41	=	R6435000	;
endbyst42	= .; if	R6435100	ge 0 &	R6435100	le 1 then	endbyst42	=	R6435100	;

jobsat35	= .;	if	R6401500	>= 1 and	R6401500	<= 5 then 	jobsat35	=	R6401500	;
jobsat36	= .;	if	R6401600	>= 1 and	R6401600	<= 5 then 	jobsat36	=	R6401600	;
jobsat37	= .;	if	R6401700	>= 1 and	R6401700	<= 5 then 	jobsat37	=	R6401700	;
jobsat38	= .;	if	R6401800	>= 1 and	R6401800	<= 5 then 	jobsat38	=	R6401800	;
jobsat39	= .;	if	R6401900	>= 1 and	R6401900	<= 5 then 	jobsat39	=	R6401900	;
jobsat40	= .;	if	R6402000	>= 1 and	R6402000	<= 5 then 	jobsat40	=	R6402000	;
jobsat41	= .;	if	R6402100	>= 1 and	R6402100	<= 5 then 	jobsat41	=	R6402100	;
jobsat42 = .;

union35	= .;	if	R6395500	>= 0 and	R6395500	<= 1 then 	union35	=	R6395500	;
union36	= .;	if	R6395600	>= 0 and	R6395600	<= 1 then 	union36	=	R6395600	;
union37	= .;	if	R6395700	>= 0 and	R6395700	<= 1 then 	union37	=	R6395700	;
union38	= .;	if	R6395800	>= 0 and	R6395800	<= 1 then 	union38	=	R6395800	;
union39	= .;	if	R6395900	>= 0 and	R6395900	<= 1 then 	union39	=	R6395900	;
union40	= .;	if	R6396000	>= 0 and	R6396000	<= 1 then 	union40	=	R6396000	;
union41	= .;	if	R6396100	>= 0 and	R6396100	<= 1 then 	union41	=	R6396100	;
union42 = .;

ben_med35	= .;	if	R6390101	>= 0 and	R6390101	<= 1 then 	ben_med35	=	R6390101	;
ben_med36	= .;	if	R6390201	>= 0 and	R6390201	<= 1 then 	ben_med36	=	R6390201	;
ben_med37	= .;	if	R6390301	>= 0 and	R6390301	<= 1 then 	ben_med37	=	R6390301	;
ben_med38	= .;	if	R6390401	>= 0 and	R6390401	<= 1 then 	ben_med38	=	R6390401	;
ben_med39	= .;	if	R6390501	>= 0 and	R6390501	<= 1 then 	ben_med39	=	R6390501	;
ben_med40	= .;	if	R6390601	>= 0 and	R6390601	<= 1 then 	ben_med40	=	R6390601	;
ben_med41	= .;	if	R6390701	>= 0 and	R6390701	<= 1 then 	ben_med41	=	R6390701	;
ben_med42 = .;

ben_flex35	= .;	if	R6390107	>= 0 and	R6390107	<= 1 then 	ben_flex35	=	R6390107	;
ben_flex36	= .;	if	R6390207	>= 0 and	R6390207	<= 1 then 	ben_flex36	=	R6390207	;
ben_flex37	= .;	if	R6390307	>= 0 and	R6390307	<= 1 then 	ben_flex37	=	R6390307	;
ben_flex38	= .;	if	R6390407	>= 0 and	R6390407	<= 1 then 	ben_flex38	=	R6390407	;
ben_flex39	= .;	if	R6390507	>= 0 and	R6390507	<= 1 then 	ben_flex39	=	R6390507	;
ben_flex40	= .;	if	R6390607	>= 0 and	R6390607	<= 1 then 	ben_flex40	=	R6390607	;
ben_flex41	= .;	if	R6390707	>= 0 and	R6390707	<= 1 then 	ben_flex41	=	R6390707	;
ben_flex42 = .;

ben_life35	= .;	if	R6390102	>= 0 and	R6390102	<= 1 then 	ben_life35	=	R6390102	;
ben_life36	= .;	if	R6390202	>= 0 and	R6390202	<= 1 then 	ben_life36	=	R6390202	;
ben_life37	= .;	if	R6390302	>= 0 and	R6390302	<= 1 then 	ben_life37	=	R6390302	;
ben_life38	= .;	if	R6390402	>= 0 and	R6390402	<= 1 then 	ben_life38	=	R6390402	;
ben_life39	= .;	if	R6390502	>= 0 and	R6390502	<= 1 then 	ben_life39	=	R6390502	;
ben_life40	= .;	if	R6390602	>= 0 and	R6390602	<= 1 then 	ben_life40	=	R6390602	;
ben_life41	= .;	if	R6390702	>= 0 and	R6390702	<= 1 then 	ben_life41	=	R6390702	;
ben_life42 = .;

ben_dental35	= .;	if	R6390103	>= 0 and	R6390103	<= 1 then 	ben_dental35	=	R6390103	;
ben_dental36	= .;	if	R6390203	>= 0 and	R6390203	<= 1 then 	ben_dental36	=	R6390203	;
ben_dental37	= .;	if	R6390303	>= 0 and	R6390303	<= 1 then 	ben_dental37	=	R6390303	;
ben_dental38	= .;	if	R6390403	>= 0 and	R6390403	<= 1 then 	ben_dental38	=	R6390403	;
ben_dental39	= .;	if	R6390503	>= 0 and	R6390503	<= 1 then 	ben_dental39	=	R6390503	;
ben_dental40	= .;	if	R6390603	>= 0 and	R6390603	<= 1 then 	ben_dental40	=	R6390603	;
ben_dental41	= .;	if	R6390703	>= 0 and	R6390703	<= 1 then 	ben_dental41	=	R6390703	;
ben_dental42 = .;

ben_pdleave35	= .;	if	R6390104	>= 0 and	R6390104	<= 1 then 	ben_pdleave35	=	R6390104	;
ben_pdleave36	= .;	if	R6390204	>= 0 and	R6390204	<= 1 then 	ben_pdleave36	=	R6390204	;
ben_pdleave37	= .;	if	R6390304	>= 0 and	R6390304	<= 1 then 	ben_pdleave37	=	R6390304	;
ben_pdleave38	= .;	if	R6390404	>= 0 and	R6390404	<= 1 then 	ben_pdleave38	=	R6390404	;
ben_pdleave39	= .;	if	R6390504	>= 0 and	R6390504	<= 1 then 	ben_pdleave39	=	R6390504	;
ben_pdleave40	= .;	if	R6390604	>= 0 and	R6390604	<= 1 then 	ben_pdleave40	=	R6390604	;
ben_pdleave41	= .;	if	R6390704	>= 0 and	R6390704	<= 1 then 	ben_pdleave41	=	R6390704	;
ben_pdleave42 = .;

ben_unpdleave35	= .;	if	R6390105	>= 0 and	R6390105	<= 1 then 	ben_unpdleave35	=	R6390105	;
ben_unpdleave36	= .;	if	R6390205	>= 0 and	R6390205	<= 1 then 	ben_unpdleave36	=	R6390205	;
ben_unpdleave37	= .;	if	R6390305	>= 0 and	R6390305	<= 1 then 	ben_unpdleave37	=	R6390305	;
ben_unpdleave38	= .;	if	R6390405	>= 0 and	R6390405	<= 1 then 	ben_unpdleave38	=	R6390405	;
ben_unpdleave39	= .;	if	R6390505	>= 0 and	R6390505	<= 1 then 	ben_unpdleave39	=	R6390505	;
ben_unpdleave40	= .;	if	R6390605	>= 0 and	R6390605	<= 1 then 	ben_unpdleave40	=	R6390605	;
ben_unpdleave41	= .;	if	R6390705	>= 0 and	R6390705	<= 1 then 	ben_unpdleave41	=	R6390705	;
ben_unpdleave42 = .;

ben_retire35	= .;	if	R6390106	>= 0 and	R6390106	<= 1 then 	ben_retire35	=	R6390106	;
ben_retire36	= .;	if	R6390206	>= 0 and	R6390206	<= 1 then 	ben_retire36	=	R6390206	;
ben_retire37	= .;	if	R6390306	>= 0 and	R6390306	<= 1 then 	ben_retire37	=	R6390306	;
ben_retire38	= .;	if	R6390406	>= 0 and	R6390406	<= 1 then 	ben_retire38	=	R6390406	;
ben_retire39	= .;	if	R6390506	>= 0 and	R6390506	<= 1 then 	ben_retire39	=	R6390506	;
ben_retire40	= .;	if	R6390606	>= 0 and	R6390606	<= 1 then 	ben_retire40	=	R6390606	;
ben_retire41	= .;	if	R6390706	>= 0 and	R6390706	<= 1 then 	ben_retire41	=	R6390706	;
ben_retire42 = .;

ben_tuition35	= .;	if	R6390108	>= 0 and	R6390108	<= 1 then 	ben_tuition35	=	R6390108	;
ben_tuition36	= .;	if	R6390208	>= 0 and	R6390208	<= 1 then 	ben_tuition36	=	R6390208	;
ben_tuition37	= .;	if	R6390308	>= 0 and	R6390308	<= 1 then 	ben_tuition37	=	R6390308	;
ben_tuition38	= .;	if	R6390408	>= 0 and	R6390408	<= 1 then 	ben_tuition38	=	R6390408	;
ben_tuition39	= .;	if	R6390508	>= 0 and	R6390508	<= 1 then 	ben_tuition39	=	R6390508	;
ben_tuition40	= .;	if	R6390608	>= 0 and	R6390608	<= 1 then 	ben_tuition40	=	R6390608	;
ben_tuition41	= .;	if	R6390708	>= 0 and	R6390708	<= 1 then 	ben_tuition41	=	R6390708	;
ben_tuition42 = .;

ben_child35	= .;	if	R6390109	>= 0 and	R6390109	<= 1 then 	ben_child35	=	R6390109	;
ben_child36	= .;	if	R6390209	>= 0 and	R6390209	<= 1 then 	ben_child36	=	R6390209	;
ben_child37	= .;	if	R6390309	>= 0 and	R6390309	<= 1 then 	ben_child37	=	R6390309	;
ben_child38	= .;	if	R6390409	>= 0 and	R6390409	<= 1 then 	ben_child38	=	R6390409	;
ben_child39	= .;	if	R6390509	>= 0 and	R6390509	<= 1 then 	ben_child39	=	R6390509	;
ben_child40	= .;	if	R6390609	>= 0 and	R6390609	<= 1 then 	ben_child40	=	R6390609	;
ben_child41	= .;	if	R6390709	>= 0 and	R6390709	<= 1 then 	ben_child41	=	R6390709	;
ben_child42 = .;

ben_stock35	= .;	if	R6390110	>= 0 and	R6390110	<= 1 then 	ben_stock35	=	R6390110	;
ben_stock36	= .;	if	R6390210	>= 0 and	R6390210	<= 1 then 	ben_stock36	=	R6390210	;
ben_stock37	= .;	if	R6390310	>= 0 and	R6390310	<= 1 then 	ben_stock37	=	R6390310	;
ben_stock38	= .;	if	R6390410	>= 0 and	R6390410	<= 1 then 	ben_stock38	=	R6390410	;
ben_stock39	= .;	if	R6390510	>= 0 and	R6390510	<= 1 then 	ben_stock39	=	R6390510	;
ben_stock40	= .;	if	R6390610	>= 0 and	R6390610	<= 1 then 	ben_stock40	=	R6390610	;
ben_stock41	= .;	if	R6390710	>= 0 and	R6390710	<= 1 then 	ben_stock41	=	R6390710	;
ben_stock42 = .;

occcode35	= .; if	S3729000	ge 0 and	S3729000	le 9990 then	occcode35	=	S3729000	;
occcode36	= .; if	S3729100	ge 0 and	S3729100	le 9990 then	occcode36	=	S3729100	;
occcode37	= .; if	S3729200	ge 0 and	S3729200	le 9990 then	occcode37	=	S3729200	;
occcode38	= .; if	S3729300	ge 0 and	S3729300	le 9990 then	occcode38	=	S3729300	;
occcode39	= .; if	S3729400	ge 0 and	S3729400	le 9990 then	occcode39	=	S3729400	;
occcode40	= .; if	S3729500	ge 0 and	S3729500	le 9990 then	occcode40	=	S3729500	;
occcode41	= .; if	S3729600	ge 0 and	S3729600	le 9990 then	occcode41	=	S3729600	;
occcode42	= .; if	S3729700	ge 0 and	S3729700	le 9990 then	occcode42	=	S3729700	;

indcode35	= .; if	S3727000	ge 0 and	S3727000	le 9990 then	indcode35	=	S3727000	;
indcode36	= .; if	S3727100	ge 0 and	S3727100	le 9990 then	indcode36	=	S3727100	;
indcode37	= .; if	S3727200	ge 0 and	S3727200	le 9990 then	indcode37	=	S3727200	;
indcode38	= .; if	S3727300	ge 0 and	S3727300	le 9990 then	indcode38	=	S3727300	;
indcode39	= .; if	S3727400	ge 0 and	S3727400	le 9990 then	indcode39	=	S3727400	;
indcode40	= .; if	S3727500	ge 0 and	S3727500	le 9990 then	indcode40	=	S3727500	;
indcode41	= .; if	S3727600	ge 0 and	S3727600	le 9990 then	indcode41	=	S3727600	;
indcode42	= .; if	S3727700	ge 0 and	S3727700	le 9990 then	indcode42	=	S3727700	;

jobtype35	= .; if	R6132100	ge 1 &	R6132100	le 5 then	jobtype35	=	R6132100	;
jobtype36	= .; if	R6132200	ge 1 &	R6132200	le 5 then	jobtype36	=	R6132200	;
jobtype37	= .; if	R6132300	ge 1 &	R6132300	le 5 then	jobtype37	=	R6132300	;
jobtype38	= .; if	R6132400	ge 1 &	R6132400	le 5 then	jobtype38	=	R6132400	;
jobtype39	= .; if	R6132500	ge 1 &	R6132500	le 5 then	jobtype39	=	R6132500	;
jobtype40	= .; if	R6132600	ge 1 &	R6132600	le 5 then	jobtype40	=	R6132600	;
jobtype41	= .; if	R6132700	ge 1 &	R6132700	le 5 then	jobtype41	=	R6132700	;
jobtype42 = .;

hourswk35	= .; if	R7235601	ge 0 &	R7235601	le 168 then	hourswk35	=	R7235601	;
hourswk36	= .; if	R7235602	ge 0 &	R7235602	le 168 then	hourswk36	=	R7235602	;
hourswk37	= .; if	R7235603	ge 0 &	R7235603	le 168 then	hourswk37	=	R7235603	;
hourswk38	= .; if	R7235604	ge 0 &	R7235604	le 168 then	hourswk38	=	R7235604	;
hourswk39	= .; if	R7235605	ge 0 &	R7235605	le 168 then	hourswk39	=	R7235605	;
hourswk40	= .; if	R7235606	ge 0 &	R7235606	le 168 then	hourswk40	=	R7235606	;
hourswk41	= .; if	R7235607	ge 0 &	R7235607	le 168 then	hourswk41	=	R7235607	;
hourswk42	= .; if	R7235608	ge 0 &	R7235608	le 168 then	hourswk42	=	R7235608	;

anygap35	= .; if	R6405000	ge -2 &	R6405000	le 0 then	anygap35	=	0	;	if 	R6405000	eq 1 then	anygap35	=	1	;
anygap36	= .; if	R6405100	ge -2 &	R6405100	le 0 then	anygap36	=	0	;	if 	R6405100	eq 1 then	anygap36	=	1	;
anygap37	= .; if	R6405200	ge -2 &	R6405200	le 0 then	anygap37	=	0	;	if 	R6405200	eq 1 then	anygap37	=	1	;
anygap38	= .; if	R6405300	ge -2 &	R6405300	le 0 then	anygap38	=	0	;	if 	R6405300	eq 1 then	anygap38	=	1	;
anygap39	= .; if	R6405400	ge -2 &	R6405400	le 0 then	anygap39	=	0	;	if 	R6405400	eq 1 then	anygap39	=	1	;
anygap40	= .; if	R6405500	ge -2 &	R6405500	le 0 then	anygap40	=	0	;	if 	R6405500	eq 1 then	anygap40	=	1	;
anygap41	= .; if	R6405600	ge -2 &	R6405600	le 0 then	anygap41	=	0	;	if 	R6405600	eq 1 then	anygap41	=	1	;
anygap42	= .; if	R6405700	ge -2 &	R6405700	le 0 then	anygap42	=	0	;	if 	R6405700	eq 1 then	anygap42	=	1	;

worksched35	= .; if	R6389400	ge 1 &	R6389400	le 9 then	worksched35	=	R6389400	;
worksched36	= .; if	R6389500	ge 1 &	R6389500	le 9 then	worksched36	=	R6389500	;
worksched37	= .; if	R6389600	ge 1 &	R6389600	le 9 then	worksched37	=	R6389600	;
worksched38	= .; if	R6389700	ge 1 &	R6389700	le 9 then	worksched38	=	R6389700	;
worksched39	= .; if	R6389800	ge 1 &	R6389800	le 9 then	worksched39	=	R6389800	;
worksched40	= .; if	R6389900	ge 1 &	R6389900	le 9 then	worksched40	=	R6389900	;
worksched41	= .; if	R6390000	ge 1 &	R6390000	le 9 then	worksched41	=	R6390000	;
worksched42 = .;

/* 2002: up to 11 ***********************************************************/

idjob43	= .; if (S1523200 >= 0 & S1523200 <= 300000) then idjob43 =	S1523200;
idjob44	= .; if (S1523300 >= 0 & S1523300 <= 300000) then idjob44 =	S1523300;
idjob45	= .; if (S1523400 >= 0 & S1523400 <= 300000) then idjob45 =	S1523400;
idjob46	= .; if (S1523500 >= 0 & S1523500 <= 300000) then idjob46 =	S1523500;
idjob47	= .; if (S1523600 >= 0 & S1523600 <= 300000) then idjob47 =	S1523600;
idjob48	= .; if (S1523700 >= 0 & S1523700 <= 300000) then idjob48 =	S1523700;
idjob49	= .; if (S1523800 >= 0 & S1523800 <= 300000) then idjob49 =	S1523800;
idjob50	= .; if (S1523900 >= 0 & S1523900 <= 300000) then idjob50 =	S1523900;
idjob51	= .; if (S1524000 >= 0 & S1524000 <= 300000) then idjob51 =	S1524000;
idjob52	= .; if (S1524100 >= 0 & S1524100 <= 300000) then idjob52 =	S1524100;
idjob53	= .; if (S1524200 >= 0 & S1524200 <= 300000) then idjob53 =	S1524200;

whyleftjob43 = .; if (S0803400	>= 0 & S0803400	<= 50) then	whyleftjob43 =	S0803400;
whyleftjob44 = .; if (S0803500	>= 0 & S0803500	<= 50) then	whyleftjob44 =	S0803500;
whyleftjob45 = .; if (S0803600	>= 0 & S0803600	<= 50) then	whyleftjob45 =	S0803600;
whyleftjob46 = .; if (S0803700	>= 0 & S0803700	<= 50) then	whyleftjob46 =	S0803700;
whyleftjob47 = .; if (S0803800	>= 0 & S0803800	<= 50) then	whyleftjob47 =	S0803800;
whyleftjob48 = .; if (S0803900	>= 0 & S0803900	<= 50) then	whyleftjob48 =	S0803900;
whyleftjob49 = .; if (S0804000	>= 0 & S0804000	<= 50) then	whyleftjob49 =	S0804000;
whyleftjob50 = .; if (S0804100	>= 0 & S0804100	<= 50) then	whyleftjob50 =	S0804100;
whyleftjob51 = .; if (S0804200	>= 0 & S0804200	<= 50) then	whyleftjob51 =	S0804200;
whyleftjob52 = .; if (S0804300	>= 0 & S0804300	<= 50) then	whyleftjob52 =	S0804300;
whyleftjob53 = .; if (S0804400	>= 0 & S0804400	<= 50) then	whyleftjob53 =	S0804400;

curjob43	= .; if	S1512800	>= 0 &	S1512800	<= 1 then	curjob43	=	S1512800	;
curjob44	= .; if	S1512900	>= 0 &	S1512900	<= 1 then	curjob44	=	S1512900	;
curjob45	= .; if	S1513000	>= 0 &	S1513000	<= 1 then	curjob45	=	S1513000	;
curjob46	= .; if	S1513100	>= 0 &	S1513100	<= 1 then	curjob46	=	S1513100	;
curjob47	= .; if	S1513200	>= 0 &	S1513200	<= 1 then	curjob47	=	S1513200	;
curjob48	= .; if	S1513300	>= 0 &	S1513300	<= 1 then	curjob48	=	S1513300	;
curjob49	= .; if	S1513400	>= 0 &	S1513400	<= 1 then	curjob49	=	S1513400	;
curjob50	= .; if	S1513500	>= 0 &	S1513500	<= 1 then	curjob50	=	S1513500	;
curjob51	= .; if	S1513600	>= 0 &	S1513600	<= 1 then	curjob51	=	S1513600	;
curjob52	= .; if	S1513700	>= 0 &	S1513700	<= 1 then	curjob52	=	S1513700	;
curjob53	= .; if	S1513800	>= 0 &	S1513800	<= 1 then	curjob53	=	S1513800	;

intmo43	= S1550800;
intmo44	= S1550800;
intmo45	= S1550800;
intmo46	= S1550800;
intmo47	= S1550800;
intmo48	= S1550800;
intmo49	= S1550800;
intmo50	= S1550800;
intmo51	= S1550800;
intmo52	= S1550800;
intmo53	= S1550800;

weeksjob43 = .;	if (S1565000 >= 0 &	S1565000 <= 5000) then weeksjob43 =	S1565000;
weeksjob44 = .;	if (S1565100 >= 0 &	S1565100 <= 5000) then weeksjob44 =	S1565100;
weeksjob45 = .;	if (S1565200 >= 0 &	S1565200 <= 5000) then weeksjob45 =	S1565200;
weeksjob46 = .;	if (S1565300 >= 0 &	S1565300 <= 5000) then weeksjob46 =	S1565300;
weeksjob47 = .;	if (S1565400 >= 0 &	S1565400 <= 5000) then weeksjob47 =	S1565400;
weeksjob48 = .;	if (S1565500 >= 0 &	S1565500 <= 5000) then weeksjob48 =	S1565500;
weeksjob49 = .;	if (S1565600 >= 0 &	S1565600 <= 5000) then weeksjob49 =	S1565600;
weeksjob50 = .;	if (S1565700 >= 0 &	S1565700 <= 5000) then weeksjob50 =	S1565700;
weeksjob51 = .;	if (S1565800 >= 0 &	S1565800 <= 5000) then weeksjob51 =	S1565800;
weeksjob52 = .;	if (S1565900 >= 0 &	S1565900 <= 5000) then weeksjob52 =	S1565900;
weeksjob53 = .;	if (S1566000 >= 0 &	S1566000 <= 5000) then weeksjob53 =	S1566000;

startmojob43	=	.;	if	 S1521001	>=	0	&	 S1521001	<=	12	then	startmojob43	=	 S1521001	;			
startmojob44	=	.;	if	 S1521101	>=	0	&	 S1521101	<=	12	then	startmojob44	=	 S1521101	;			
startmojob45	=	.;	if	 S1521201	>=	0	&	 S1521201	<=	12	then	startmojob45	=	 S1521201	;			
startmojob46	=	.;	if	 S1521301	>=	0	&	 S1521301	<=	12	then	startmojob46	=	 S1521301	;			
startmojob47	=	.;	if	 S1521401	>=	0	&	 S1521401	<=	12	then	startmojob47	=	 S1521401	;			
startmojob48	=	.;	if	 S1521501	>=	0	&	 S1521501	<=	12	then	startmojob48	=	 S1521501	;			
startmojob49	=	.;	if	 S1521601	>=	0	&	 S1521601	<=	12	then	startmojob49	=	 S1521601	;			
startmojob50	=	.;	if	 S1521701	>=	0	&	 S1521701	<=	12	then	startmojob50	=	 S1521701	;			
startmojob51	=	.;	if	 S1521801	>=	0	&	 S1521801	<=	12	then	startmojob51	=	 S1521801	;			
startmojob52	=	.;	if	 S1521901	>=	0	&	 S1521901	<=	12	then	startmojob52	=	 S1521901	;			
startmojob53	=	.;	if	 S1522001	>=	0	&	 S1522001	<=	12	then	startmojob53	=	 S1522001	;			
																		
startyrjob43	=	.;	if	 S1521002	>=	1980	&	 S1521002	<=	2050	then	startyrjob43	=	 S1521002	;			
startyrjob44	=	.;	if	 S1521102	>=	1980	&	 S1521102	<=	2050	then	startyrjob44	=	 S1521102	;			
startyrjob45	=	.;	if	 S1521202	>=	1980	&	 S1521202	<=	2050	then	startyrjob45	=	 S1521202	;			
startyrjob46	=	.;	if	 S1521302	>=	1980	&	 S1521302	<=	2050	then	startyrjob46	=	 S1521302	;			
startyrjob47	=	.;	if	 S1521402	>=	1980	&	 S1521402	<=	2050	then	startyrjob47	=	 S1521402	;			
startyrjob48	=	.;	if	 S1521502	>=	1980	&	 S1521502	<=	2050	then	startyrjob48	=	 S1521502	;			
startyrjob49	=	.;	if	 S1521602	>=	1980	&	 S1521602	<=	2050	then	startyrjob49	=	 S1521602	;			
startyrjob50	=	.;	if	 S1521702	>=	1980	&	 S1521702	<=	2050	then	startyrjob50	=	 S1521702	;			
startyrjob51	=	.;	if	 S1521802	>=	1980	&	 S1521802	<=	2050	then	startyrjob51	=	 S1521802	;			
startyrjob52	=	.;	if	 S1521902	>=	1980	&	 S1521902	<=	2050	then	startyrjob52	=	 S1521902	;			
startyrjob53	=	.;	if	 S1522002	>=	1980	&	 S1522002	<=	2050	then	startyrjob53	=	 S1522002	;			

startcontmo43	=	.;	if	startyrjob43	ne	.	&	startmojob43	ne	.	then	startcontmo43	=	((startyrjob43	-1980)*12)	+	startmojob43	;
startcontmo44	=	.;	if	startyrjob44	ne	.	&	startmojob44	ne	.	then	startcontmo44	=	((startyrjob44	-1980)*12)	+	startmojob44	;
startcontmo45	=	.;	if	startyrjob45	ne	.	&	startmojob45	ne	.	then	startcontmo45	=	((startyrjob45	-1980)*12)	+	startmojob45	;
startcontmo46	=	.;	if	startyrjob46	ne	.	&	startmojob46	ne	.	then	startcontmo46	=	((startyrjob46	-1980)*12)	+	startmojob46	;
startcontmo47	=	.;	if	startyrjob47	ne	.	&	startmojob47	ne	.	then	startcontmo47	=	((startyrjob47	-1980)*12)	+	startmojob47	;
startcontmo48	=	.;	if	startyrjob48	ne	.	&	startmojob48	ne	.	then	startcontmo48	=	((startyrjob48	-1980)*12)	+	startmojob48	;
startcontmo49	=	.;	if	startyrjob49	ne	.	&	startmojob49	ne	.	then	startcontmo49	=	((startyrjob49	-1980)*12)	+	startmojob49	;
startcontmo50	=	.;	if	startyrjob50	ne	.	&	startmojob50	ne	.	then	startcontmo50	=	((startyrjob50	-1980)*12)	+	startmojob50	;
startcontmo51	=	.;	if	startyrjob51	ne	.	&	startmojob51	ne	.	then	startcontmo51	=	((startyrjob51	-1980)*12)	+	startmojob51	;
startcontmo52	=	.;	if	startyrjob52	ne	.	&	startmojob52	ne	.	then	startcontmo52	=	((startyrjob52	-1980)*12)	+	startmojob52	;
startcontmo53	=	.;	if	startyrjob53	ne	.	&	startmojob53	ne	.	then	startcontmo53	=	((startyrjob53	-1980)*12)	+	startmojob53	;

endbyst43	= .; if	S0865800	ge 0 &	S0865800	le 1 then	endbyst43	=	S0865800	;
endbyst44	= .; if	S0865900	ge 0 &	S0865900	le 1 then	endbyst44	=	S0865900	;
endbyst45	= .; if	S0866000	ge 0 &	S0866000	le 1 then	endbyst45	=	S0866000	;
endbyst46	= .; if	S0866100	ge 0 &	S0866100	le 1 then	endbyst46	=	S0866100	;
endbyst47	= .; if	S0866200	ge 0 &	S0866200	le 1 then	endbyst47	=	S0866200	;
endbyst48	= .; if	S0866300	ge 0 &	S0866300	le 1 then	endbyst48	=	S0866300	;
endbyst49	= .; if	S0866400	ge 0 &	S0866400	le 1 then	endbyst49	=	S0866400	;
endbyst50	= .; if	S0866500	ge 0 &	S0866500	le 1 then	endbyst50	=	S0866500	;
endbyst51	= .; if	S0866600	ge 0 &	S0866600	le 1 then	endbyst51	=	S0866600	;
endbyst52	= .; if	S0866700	ge 0 &	S0866700	le 1 then	endbyst52	=	S0866700	;
endbyst53	= .; if	S0866800	ge 0 &	S0866800	le 1 then	endbyst53	=	S0866800	;

/* No job 10; 52 */

jobsat43	= .;	if	S0829000	>= 1 and	S0829000	<= 5 then 	jobsat43	=	S0829000	;
jobsat44	= .;	if	S0829100	>= 1 and	S0829100	<= 5 then 	jobsat44	=	S0829100	;
jobsat45	= .;	if	S0829200	>= 1 and	S0829200	<= 5 then 	jobsat45	=	S0829200	;
jobsat46	= .;	if	S0829300	>= 1 and	S0829300	<= 5 then 	jobsat46	=	S0829300	;
jobsat47	= .;	if	S0829400	>= 1 and	S0829400	<= 5 then 	jobsat47	=	S0829400	;
jobsat48	= .;	if	S0829500	>= 1 and	S0829500	<= 5 then 	jobsat48	=	S0829500	;
jobsat49	= .;	if	S0829600	>= 1 and	S0829600	<= 5 then 	jobsat49	=	S0829600	;
jobsat50	= .;	if	S0829700	>= 1 and	S0829700	<= 5 then 	jobsat50	=	S0829700	;
jobsat51	= .;	if	S0829800	>= 1 and	S0829800	<= 5 then 	jobsat51	=	S0829800	;
jobsat52	= .;									
jobsat53	= .;	if	S0829900	>= 1 and	S0829900	<= 5 then 	jobsat53	=	S0829900	;

union43	= .;	if	S0822300	>= 0 and	S0822300	<= 1 then 	union43	=	S0822300	;
union44	= .;	if	S0822400	>= 0 and	S0822400	<= 1 then 	union44	=	S0822400	;
union45	= .;	if	S0822500	>= 0 and	S0822500	<= 1 then 	union45	=	S0822500	;
union46	= .;	if	S0822600	>= 0 and	S0822600	<= 1 then 	union46	=	S0822600	;
union47	= .;	if	S0822700	>= 0 and	S0822700	<= 1 then 	union47	=	S0822700	;
union48	= .;	if	S0822800	>= 0 and	S0822800	<= 1 then 	union48	=	S0822800	;
union49	= .;	if	S0822900	>= 0 and	S0822900	<= 1 then 	union49	=	S0822900	;
union50	= .;	if	S0823000	>= 0 and	S0823000	<= 1 then 	union50	=	S0823000	;
union51	= .;	if	S0823100	>= 0 and	S0823100	<= 1 then 	union51	=	S0823100	;
union52	=.;									
union53	= .;	if	S0823200	>= 0 and	S0823200	<= 1 then 	union53	=	S0823200	;

ben_med43	= .;	if	S0814202	>= 0 and	S0814202	<= 1 then 	ben_med43	=	S0814202	;
ben_med44	= .;	if	S0814302	>= 0 and	S0814302	<= 1 then 	ben_med44	=	S0814302	;
ben_med45	= .;	if	S0814402	>= 0 and	S0814402	<= 1 then 	ben_med45	=	S0814402	;
ben_med46	= .;	if	S0814502	>= 0 and	S0814502	<= 1 then 	ben_med46	=	S0814502	;
ben_med47	= .;	if	S0814602	>= 0 and	S0814602	<= 1 then 	ben_med47	=	S0814602	;
ben_med48	= .;	if	S0814702	>= 0 and	S0814702	<= 1 then 	ben_med48	=	S0814702	;
ben_med49	= .;	if	S0814802	>= 0 and	S0814802	<= 1 then 	ben_med49	=	S0814802	;
ben_med50	= .;	if	S0814902	>= 0 and	S0814902	<= 1 then 	ben_med50	=	S0814902	;
ben_med51	= .;	if	S0815002	>= 0 and	S0815002	<= 1 then 	ben_med51	=	S0815002	;
ben_med52	= .;									
ben_med53	= .;	if	S0815102	>= 0 and	S0815102	<= 1 then 	ben_med53	=	S0815102	;

ben_flex43	= .;	if	S0814201	>= 0 and	S0814201	<= 1 then 	ben_flex43	=	S0814201	;
ben_flex44	= .;	if	S0814301	>= 0 and	S0814301	<= 1 then 	ben_flex44	=	S0814301	;
ben_flex45	= .;	if	S0814401	>= 0 and	S0814401	<= 1 then 	ben_flex45	=	S0814401	;
ben_flex46	= .;	if	S0814501	>= 0 and	S0814501	<= 1 then 	ben_flex46	=	S0814501	;
ben_flex47	= .;	if	S0814601	>= 0 and	S0814601	<= 1 then 	ben_flex47	=	S0814601	;
ben_flex48	= .;	if	S0814701	>= 0 and	S0814701	<= 1 then 	ben_flex48	=	S0814701	;
ben_flex49	= .;	if	S0814801	>= 0 and	S0814801	<= 1 then 	ben_flex49	=	S0814801	;
ben_flex50	= .;	if	S0814901	>= 0 and	S0814901	<= 1 then 	ben_flex50	=	S0814901	;
ben_flex51	= .;	if	S0815001	>= 0 and	S0815001	<= 1 then 	ben_flex51	=	S0815001	;
ben_flex52	= .;								
ben_flex53	= .;	if	S0815101	>= 0 and	S0815101	<= 1 then 	ben_flex53	=	S0815101	;

ben_life43	= .;	if	S0814203	>= 0 and	S0814203	<= 1 then 	ben_life43	=	S0814203	;
ben_life44	= .;	if	S0814303	>= 0 and	S0814303	<= 1 then 	ben_life44	=	S0814303	;
ben_life45	= .;	if	S0814403	>= 0 and	S0814403	<= 1 then 	ben_life45	=	S0814403	;
ben_life46	= .;	if	S0814503	>= 0 and	S0814503	<= 1 then 	ben_life46	=	S0814503	;
ben_life47	= .;	if	S0814603	>= 0 and	S0814603	<= 1 then 	ben_life47	=	S0814603	;
ben_life48	= .;	if	S0814703	>= 0 and	S0814703	<= 1 then 	ben_life48	=	S0814703	;
ben_life49	= .;	if	S0814803	>= 0 and	S0814803	<= 1 then 	ben_life49	=	S0814803	;
ben_life50	= .;	if	S0814903	>= 0 and	S0814903	<= 1 then 	ben_life50	=	S0814903	;
ben_life51	= .;	if	S0815003	>= 0 and	S0815003	<= 1 then 	ben_life51	=	S0815003	;
ben_life52	= .;								
ben_life53	= .;	if	S0815103	>= 0 and	S0815103	<= 1 then 	ben_life53	=	S0815103	;

ben_dental43	= .;	if	S0814204	>= 0 and	S0814204	<= 1 then 	ben_dental43	=	S0814204	;
ben_dental44	= .;	if	S0814304	>= 0 and	S0814304	<= 1 then 	ben_dental44	=	S0814304	;
ben_dental45	= .;	if	S0814404	>= 0 and	S0814404	<= 1 then 	ben_dental45	=	S0814404	;
ben_dental46	= .;	if	S0814504	>= 0 and	S0814504	<= 1 then 	ben_dental46	=	S0814504	;
ben_dental47	= .;	if	S0814604	>= 0 and	S0814604	<= 1 then 	ben_dental47	=	S0814604	;
ben_dental48	= .;	if	S0814704	>= 0 and	S0814704	<= 1 then 	ben_dental48	=	S0814704	;
ben_dental49	= .;	if	S0814804	>= 0 and	S0814804	<= 1 then 	ben_dental49	=	S0814804	;
ben_dental50	= .;	if	S0814904	>= 0 and	S0814904	<= 1 then 	ben_dental50	=	S0814904	;
ben_dental51	= .;	if	S0815004	>= 0 and	S0815004	<= 1 then 	ben_dental51	=	S0815004	;
ben_dental52	= .;								
ben_dental53	= .;	if	S0815104	>= 0 and	S0815104	<= 1 then 	ben_dental53	=	S0815104	;

ben_pdleave43	= .;	if	S0814205	>= 0 and	S0814205	<= 1 then 	ben_pdleave43	=	S0814205	;
ben_pdleave44	= .;	if	S0814305	>= 0 and	S0814305	<= 1 then 	ben_pdleave44	=	S0814305	;
ben_pdleave45	= .;	if	S0814405	>= 0 and	S0814405	<= 1 then 	ben_pdleave45	=	S0814405	;
ben_pdleave46	= .;	if	S0814505	>= 0 and	S0814505	<= 1 then 	ben_pdleave46	=	S0814505	;
ben_pdleave47	= .;	if	S0814605	>= 0 and	S0814605	<= 1 then 	ben_pdleave47	=	S0814605	;
ben_pdleave48	= .;	if	S0814705	>= 0 and	S0814705	<= 1 then 	ben_pdleave48	=	S0814705	;
ben_pdleave49	= .;	if	S0814805	>= 0 and	S0814805	<= 1 then 	ben_pdleave49	=	S0814805	;
ben_pdleave50	= .;	if	S0814905	>= 0 and	S0814905	<= 1 then 	ben_pdleave50	=	S0814905	;
ben_pdleave51	= .;	if	S0815005	>= 0 and	S0815005	<= 1 then 	ben_pdleave51	=	S0815005	;
ben_pdleave52	= .;								
ben_pdleave53	= .;	if	S0815105	>= 0 and	S0815105	<= 1 then 	ben_pdleave53	=	S0815105	;

ben_unpdleave43	= .;	if	S0814206	>= 0 and	S0814206	<= 1 then 	ben_unpdleave43	=	S0814206	;
ben_unpdleave44	= .;	if	S0814306	>= 0 and	S0814306	<= 1 then 	ben_unpdleave44	=	S0814306	;
ben_unpdleave45	= .;	if	S0814406	>= 0 and	S0814406	<= 1 then 	ben_unpdleave45	=	S0814406	;
ben_unpdleave46	= .;	if	S0814506	>= 0 and	S0814506	<= 1 then 	ben_unpdleave46	=	S0814506	;
ben_unpdleave47	= .;	if	S0814606	>= 0 and	S0814606	<= 1 then 	ben_unpdleave47	=	S0814606	;
ben_unpdleave48	= .;	if	S0814706	>= 0 and	S0814706	<= 1 then 	ben_unpdleave48	=	S0814706	;
ben_unpdleave49	= .;	if	S0814806	>= 0 and	S0814806	<= 1 then 	ben_unpdleave49	=	S0814806	;
ben_unpdleave50	= .;	if	S0814906	>= 0 and	S0814906	<= 1 then 	ben_unpdleave50	=	S0814906	;
ben_unpdleave51	= .;	if	S0815006	>= 0 and	S0815006	<= 1 then 	ben_unpdleave51	=	S0815006	;
ben_unpdleave52	= .;								
ben_unpdleave53	= .;	if	S0815106	>= 0 and	S0815106	<= 1 then 	ben_unpdleave53	=	S0815106	;

ben_retire43	= .;	if	S0814207	>= 0 and	S0814207	<= 1 then 	ben_retire43	=	S0814207	;
ben_retire44	= .;	if	S0814307	>= 0 and	S0814307	<= 1 then 	ben_retire44	=	S0814307	;
ben_retire45	= .;	if	S0814407	>= 0 and	S0814407	<= 1 then 	ben_retire45	=	S0814407	;
ben_retire46	= .;	if	S0814507	>= 0 and	S0814507	<= 1 then 	ben_retire46	=	S0814507	;
ben_retire47	= .;	if	S0814607	>= 0 and	S0814607	<= 1 then 	ben_retire47	=	S0814607	;
ben_retire48	= .;	if	S0814707	>= 0 and	S0814707	<= 1 then 	ben_retire48	=	S0814707	;
ben_retire49	= .;	if	S0814807	>= 0 and	S0814807	<= 1 then 	ben_retire49	=	S0814807	;
ben_retire50	= .;	if	S0814907	>= 0 and	S0814907	<= 1 then 	ben_retire50	=	S0814907	;
ben_retire51	= .;	if	S0815007	>= 0 and	S0815007	<= 1 then 	ben_retire51	=	S0815007	;
ben_retire52	= .;								
ben_retire53	= .;	if	S0815107	>= 0 and	S0815107	<= 1 then 	ben_retire53	=	S0815107	;

ben_tuition43	= .;	if	S0814208	>= 0 and	S0814208	<= 1 then 	ben_tuition43	=	S0814208	;
ben_tuition44	= .;	if	S0814308	>= 0 and	S0814308	<= 1 then 	ben_tuition44	=	S0814308	;
ben_tuition45	= .;	if	S0814408	>= 0 and	S0814408	<= 1 then 	ben_tuition45	=	S0814408	;
ben_tuition46	= .;	if	S0814508	>= 0 and	S0814508	<= 1 then 	ben_tuition46	=	S0814508	;
ben_tuition47	= .;	if	S0814608	>= 0 and	S0814608	<= 1 then 	ben_tuition47	=	S0814608	;
ben_tuition48	= .;	if	S0814708	>= 0 and	S0814708	<= 1 then 	ben_tuition48	=	S0814708	;
ben_tuition49	= .;	if	S0814808	>= 0 and	S0814808	<= 1 then 	ben_tuition49	=	S0814808	;
ben_tuition50	= .;	if	S0814908	>= 0 and	S0814908	<= 1 then 	ben_tuition50	=	S0814908	;
ben_tuition51	= .;	if	S0815008	>= 0 and	S0815008	<= 1 then 	ben_tuition51	=	S0815008	;
ben_tuition52	= .;								
ben_tuition53	= .;	if	S0815108	>= 0 and	S0815108	<= 1 then 	ben_tuition53	=	S0815108	;

ben_child43	= .;	if	S0814209	>= 0 and	S0814209	<= 1 then 	ben_child43	=	S0814209	;
ben_child44	= .;	if	S0814309	>= 0 and	S0814309	<= 1 then 	ben_child44	=	S0814309	;
ben_child45	= .;	if	S0814409	>= 0 and	S0814409	<= 1 then 	ben_child45	=	S0814409	;
ben_child46	= .;	if	S0814509	>= 0 and	S0814509	<= 1 then 	ben_child46	=	S0814509	;
ben_child47	= .;	if	S0814609	>= 0 and	S0814609	<= 1 then 	ben_child47	=	S0814609	;
ben_child48	= .;	if	S0814709	>= 0 and	S0814709	<= 1 then 	ben_child48	=	S0814709	;
ben_child49	= .;	if	S0814809	>= 0 and	S0814809	<= 1 then 	ben_child49	=	S0814809	;
ben_child50	= .;	if	S0814909	>= 0 and	S0814909	<= 1 then 	ben_child50	=	S0814909	;
ben_child51	= .;	if	S0815009	>= 0 and	S0815009	<= 1 then 	ben_child51	=	S0815009	;
ben_child52	= .;								
ben_child53	= .;	if	S0815109	>= 0 and	S0815109	<= 1 then 	ben_child53	=	S0815109	;

ben_stock43	= .;	if	S0814210	>= 0 and	S0814210	<= 1 then 	ben_stock43	=	S0814210	;
ben_stock44	= .;	if	S0814310	>= 0 and	S0814310	<= 1 then 	ben_stock44	=	S0814310	;
ben_stock45	= .;	if	S0814410	>= 0 and	S0814410	<= 1 then 	ben_stock45	=	S0814410	;
ben_stock46	= .;	if	S0814510	>= 0 and	S0814510	<= 1 then 	ben_stock46	=	S0814510	;
ben_stock47	= .;	if	S0814610	>= 0 and	S0814610	<= 1 then 	ben_stock47	=	S0814610	;
ben_stock48	= .;	if	S0814710	>= 0 and	S0814710	<= 1 then 	ben_stock48	=	S0814710	;
ben_stock49	= .;	if	S0814810	>= 0 and	S0814810	<= 1 then 	ben_stock49	=	S0814810	;
ben_stock50	= .;	if	S0814910	>= 0 and	S0814910	<= 1 then 	ben_stock50	=	S0814910	;
ben_stock51	= .;	if	S0815010	>= 0 and	S0815010	<= 1 then 	ben_stock51	=	S0815010	;
ben_stock52	= .;								
ben_stock53	= .;	if	S0815110	>= 0 and	S0815110	<= 1 then 	ben_stock53	=	S0815110	;

occcode43	= .; if	S1603000	ge 0 and	S1603000	le 9990 then	occcode43	=	S1603000	;
occcode44	= .; if	S1603100	ge 0 and	S1603100	le 9990 then	occcode44	=	S1603100	;
occcode45	= .; if	S1603200	ge 0 and	S1603200	le 9990 then	occcode45	=	S1603200	;
occcode46	= .; if	S1603300	ge 0 and	S1603300	le 9990 then	occcode46	=	S1603300	;
occcode47	= .; if	S1603400	ge 0 and	S1603400	le 9990 then	occcode47	=	S1603400	;
occcode48	= .; if	S1603500	ge 0 and	S1603500	le 9990 then	occcode48	=	S1603500	;
occcode49	= .; if	S1603600	ge 0 and	S1603600	le 9990 then	occcode49	=	S1603600	;
occcode50	= .; if	S1603700	ge 0 and	S1603700	le 9990 then	occcode50	=	S1603700	;
occcode51	= .; if	S1603800	ge 0 and	S1603800	le 9990 then	occcode51	=	S1603800	;
occcode52	= .; if	S1603900	ge 0 and	S1603900	le 9990 then	occcode52	=	S1603900	;
occcode53	= .; if	S1604000	ge 0 and	S1604000	le 9990 then	occcode53	=	S1604000	;

indcode43	= .; if	S1601900	ge 0 and	S1601900	le 9990 then	indcode43	=	S1601900	;
indcode44	= .; if	S1602000	ge 0 and	S1602000	le 9990 then	indcode44	=	S1602000	;
indcode45	= .; if	S1602100	ge 0 and	S1602100	le 9990 then	indcode45	=	S1602100	;
indcode46	= .; if	S1602200	ge 0 and	S1602200	le 9990 then	indcode46	=	S1602200	;
indcode47	= .; if	S1602300	ge 0 and	S1602300	le 9990 then	indcode47	=	S1602300	;
indcode48	= .; if	S1602400	ge 0 and	S1602400	le 9990 then	indcode48	=	S1602400	;
indcode49	= .; if	S1602500	ge 0 and	S1602500	le 9990 then	indcode49	=	S1602500	;
indcode50	= .; if	S1602600	ge 0 and	S1602600	le 9990 then	indcode50	=	S1602600	;
indcode51	= .; if	S1602700	ge 0 and	S1602700	le 9990 then	indcode51	=	S1602700	;
indcode52	= .; if	S1602800	ge 0 and	S1602800	le 9990 then	indcode52	=	S1602800	;
indcode53	= .; if	S1602900	ge 0 and	S1602900	le 9990 then	indcode53	=	S1602900	;

jobtype43	= .; if	S0527800	ge 1 &	S0527800	le 5 then	jobtype43	=	S0527800	;
jobtype44	= .; if	S0527900	ge 1 &	S0527900	le 5 then	jobtype44	=	S0527900	;
jobtype45	= .; if	S0528000	ge 1 &	S0528000	le 5 then	jobtype45	=	S0528000	;
jobtype46	= .; if	S0528100	ge 1 &	S0528100	le 5 then	jobtype46	=	S0528100	;
jobtype47	= .; if	S0528200	ge 1 &	S0528200	le 5 then	jobtype47	=	S0528200	;
jobtype48	= .; if	S0528300	ge 1 &	S0528300	le 5 then	jobtype48	=	S0528300	;
jobtype49	= .; if	S0528400	ge 1 &	S0528400	le 5 then	jobtype49	=	S0528400	;
jobtype50	= .; if	S0528500	ge 1 &	S0528500	le 5 then	jobtype50	=	S0528500	;
jobtype51	= .; if	S0528600	ge 1 &	S0528600	le 5 then	jobtype51	=	S0528600	;
jobtype52	= .; if	S0528700	ge 1 &	S0528700	le 5 then	jobtype52	=	S0528700	;
jobtype53	= .; if	S0528800	ge 1 &	S0528800	le 5 then	jobtype53	=	S0528800	;

hourswk43	= .; if	S1550401	ge 0 &	S1550401	le 168 then	hourswk43	=	S1550401	;
hourswk44	= .; if	S1550402	ge 0 &	S1550402	le 168 then	hourswk44	=	S1550402	;
hourswk45	= .; if	S1550403	ge 0 &	S1550403	le 168 then	hourswk45	=	S1550403	;
hourswk46	= .; if	S1550404	ge 0 &	S1550404	le 168 then	hourswk46	=	S1550404	;
hourswk47	= .; if	S1550405	ge 0 &	S1550405	le 168 then	hourswk47	=	S1550405	;
hourswk48	= .; if	S1550406	ge 0 &	S1550406	le 168 then	hourswk48	=	S1550406	;
hourswk49	= .; if	S1550407	ge 0 &	S1550407	le 168 then	hourswk49	=	S1550407	;
hourswk50	= .; if	S1550408	ge 0 &	S1550408	le 168 then	hourswk50	=	S1550408	;
hourswk51	= .; if	S1550409	ge 0 &	S1550409	le 168 then	hourswk51	=	S1550409	;
hourswk52	= .; if	S1550410	ge 0 &	S1550410	le 168 then	hourswk52	=	S1550410	;
hourswk53	= .; if	S1550411	ge 0 &	S1550411	le 168 then	hourswk53	=	S1550411	;

anygap43	= .; if	S0834400	ge -2 &	S0834400	le 0 then	anygap43	=	0	;	if 	S0834400	eq 1 then	anygap43	=	1	;
anygap44	= .; if	S0834500	ge -2 &	S0834500	le 0 then	anygap44	=	0	;	if 	S0834500	eq 1 then	anygap44	=	1	;
anygap45	= .; if	S0834600	ge -2 &	S0834600	le 0 then	anygap45	=	0	;	if 	S0834600	eq 1 then	anygap45	=	1	;
anygap46	= .; if	S0834700	ge -2 &	S0834700	le 0 then	anygap46	=	0	;	if 	S0834700	eq 1 then	anygap46	=	1	;
anygap47	= .; if	S0834800	ge -2 &	S0834800	le 0 then	anygap47	=	0	;	if 	S0834800	eq 1 then	anygap47	=	1	;
anygap48	= .; if	S0834900	ge -2 &	S0834900	le 0 then	anygap48	=	0	;	if 	S0834900	eq 1 then	anygap48	=	1	;
anygap49	= .; if	S0835000	ge -2 &	S0835000	le 0 then	anygap49	=	0	;	if 	S0835000	eq 1 then	anygap49	=	1	;
anygap50	= .; if	S0835100	ge -2 &	S0835100	le 0 then	anygap50	=	0	;	if 	S0835100	eq 1 then	anygap50	=	1	;
anygap51	= .; if	S0835200	ge -2 &	S0835200	le 0 then	anygap51	=	0	;	if 	S0835200	eq 1 then	anygap51	=	1	;
anygap52	= .; if	S0835300	ge -2 &	S0835300	le 0 then	anygap52	=	0	;	if 	S0835300	eq 1 then	anygap52	=	1	;
anygap53	= .; if	S0835400	ge -2 &	S0835400	le 0 then	anygap53	=	0	;	if 	S0835400	eq 1 then	anygap53	=	1	;

worksched43	= .; if	S0813100	ge 1 &	S0813100	le 9 then	worksched43	=	S0813100	;
worksched44	= .; if	S0813200	ge 1 &	S0813200	le 9 then	worksched44	=	S0813200	;
worksched45	= .; if	S0813300	ge 1 &	S0813300	le 9 then	worksched45	=	S0813300	;
worksched46	= .; if	S0813400	ge 1 &	S0813400	le 9 then	worksched46	=	S0813400	;
worksched47	= .; if	S0813500	ge 1 &	S0813500	le 9 then	worksched47	=	S0813500	;
worksched48	= .; if	S0813600	ge 1 &	S0813600	le 9 then	worksched48	=	S0813600	;
worksched49	= .; if	S0813700	ge 1 &	S0813700	le 9 then	worksched49	=	S0813700	;
worksched50	= .; if	S0813800	ge 1 &	S0813800	le 9 then	worksched50	=	S0813800	;
worksched51	= .; if	S0813900	ge 1 &	S0813900	le 9 then	worksched51	=	S0813900	;
worksched52	= .; 						
worksched53	= .; if	S0814000	ge 1 &	S0814000	le 9 then	worksched53	=	S0814000	;

/* 2003: up to 10 ***********************************************************/

idjob54	= .; if (S3588900 >= 0 & S3588900 <= 300000) then idjob54 =	S3588900;
idjob55	= .; if (S3589000 >= 0 & S3589000 <= 300000) then idjob55 =	S3589000;
idjob56	= .; if (S3589100 >= 0 & S3589100 <= 300000) then idjob56 =	S3589100;
idjob57	= .; if (S3589200 >= 0 & S3589200 <= 300000) then idjob57 =	S3589200;
idjob58	= .; if (S3589300 >= 0 & S3589300 <= 300000) then idjob58 =	S3589300;
idjob59	= .; if (S3589400 >= 0 & S3589400 <= 300000) then idjob59 =	S3589400;
idjob60	= .; if (S3589500 >= 0 & S3589500 <= 300000) then idjob60 =	S3589500;
idjob61	= .; if (S3589600 >= 0 & S3589600 <= 300000) then idjob61 =	S3589600;
idjob62	= .; if (S3589700 >= 0 & S3589700 <= 300000) then idjob62 =	S3589700;
idjob63	= .; if (S3589800 >= 0 & S3589800 <= 300000) then idjob63 =	S3589800;

whyleftjob54 = .; if (S2869500	>= 0 & S2869500	<= 50) then	whyleftjob54 =	S2869500;
whyleftjob55 = .; if (S2869600	>= 0 & S2869600	<= 50) then	whyleftjob55 =	S2869600;
whyleftjob56 = .; if (S2869700	>= 0 & S2869700	<= 50) then	whyleftjob56 =	S2869700;
whyleftjob57 = .; if (S2869800	>= 0 & S2869800	<= 50) then	whyleftjob57 =	S2869800;
whyleftjob58 = .; if (S2869900	>= 0 & S2869900	<= 50) then	whyleftjob58 =	S2869900;
whyleftjob59 = .; if (S2870000	>= 0 & S2870000	<= 50) then	whyleftjob59 =	S2870000;
whyleftjob60 = .; if (S2870100	>= 0 & S2870100	<= 50) then	whyleftjob60 =	S2870100;
whyleftjob61 = .; if (S2870200	>= 0 & S2870200	<= 50) then	whyleftjob61 =	S2870200;
whyleftjob62 = .; if (S2870300	>= 0 & S2870300	<= 50) then	whyleftjob62 =	S2870300;
whyleftjob63 = .; if (S2870400	>= 0 & S2870400	<= 50) then	whyleftjob63 =	S2870400;

curjob54	= .; if	S3579600	>= 0 &	S3579600	<= 1 then	curjob54	=	S3579600	;
curjob55	= .; if	S3579700	>= 0 &	S3579700	<= 1 then	curjob55	=	S3579700	;
curjob56	= .; if	S3579800	>= 0 &	S3579800	<= 1 then	curjob56	=	S3579800	;
curjob57	= .; if	S3579900	>= 0 &	S3579900	<= 1 then	curjob57	=	S3579900	;
curjob58	= .; if	S3580000	>= 0 &	S3580000	<= 1 then	curjob58	=	S3580000	;
curjob59	= .; if	S3580100	>= 0 &	S3580100	<= 1 then	curjob59	=	S3580100	;
curjob60	= .; if	S3580200	>= 0 &	S3580200	<= 1 then	curjob60	=	S3580200	;
curjob61	= .; if	S3580300	>= 0 &	S3580300	<= 1 then	curjob61	=	S3580300	;
curjob62	= .; if	S3580400	>= 0 &	S3580400	<= 1 then	curjob62	=	S3580400	;
curjob63	= .; if	S3580500	>= 0 &	S3580500	<= 1 then	curjob63	=	S3580500	;
									
intmo54	= S2020700;
intmo55	= S2020700;
intmo56	= S2020700;
intmo57	= S2020700;
intmo58	= S2020700;
intmo59	= S2020700;
intmo60	= S2020700;
intmo61	= S2020700;
intmo62	= S2020700;
intmo63	= S2020700;

weeksjob54 = .;	if (S2035100 >= 0 &	S2035100 <= 5000) then weeksjob54 =	S2035100;
weeksjob55 = .;	if (S2035200 >= 0 &	S2035200 <= 5000) then weeksjob55 =	S2035200;
weeksjob56 = .;	if (S2035300 >= 0 &	S2035300 <= 5000) then weeksjob56 =	S2035300;
weeksjob57 = .;	if (S2035400 >= 0 &	S2035400 <= 5000) then weeksjob57 =	S2035400;
weeksjob58 = .;	if (S2035500 >= 0 &	S2035500 <= 5000) then weeksjob58 =	S2035500;
weeksjob59 = .;	if (S2035600 >= 0 &	S2035600 <= 5000) then weeksjob59 =	S2035600;
weeksjob60 = .;	if (S2035700 >= 0 &	S2035700 <= 5000) then weeksjob60 =	S2035700;
weeksjob61 = .;	if (S2035800 >= 0 &	S2035800 <= 5000) then weeksjob61 =	S2035800;
weeksjob62 = .;	if (S2035900 >= 0 &	S2035900 <= 5000) then weeksjob62 =	S2035900;
weeksjob63 = .;	if (S2036000 >= 0 &	S2036000 <= 5000) then weeksjob63 =	S2036000;

startmojob54	=	.;	if	 S3586901	>=	0	&	 S3586901	<=	12	then	startmojob54	=	 S3586901	;			
startmojob55	=	.;	if	 S3587001	>=	0	&	 S3587001	<=	12	then	startmojob55	=	 S3587001	;			
startmojob56	=	.;	if	 S3587101	>=	0	&	 S3587101	<=	12	then	startmojob56	=	 S3587101	;			
startmojob57	=	.;	if	 S3587201	>=	0	&	 S3587201	<=	12	then	startmojob57	=	 S3587201	;			
startmojob58	=	.;	if	 S3587301	>=	0	&	 S3587301	<=	12	then	startmojob58	=	 S3587301	;			
startmojob59	=	.;	if	 S3587401	>=	0	&	 S3587401	<=	12	then	startmojob59	=	 S3587401	;			
startmojob60	=	.;	if	 S3587501	>=	0	&	 S3587501	<=	12	then	startmojob60	=	 S3587501	;			
startmojob61	=	.;	if	 S3587601	>=	0	&	 S3587601	<=	12	then	startmojob61	=	 S3587601	;			
startmojob62	=	.;	if	 S3587701	>=	0	&	 S3587701	<=	12	then	startmojob62	=	 S3587701	;			
startmojob63	=	.;	if	 S3587801	>=	0	&	 S3587801	<=	12	then	startmojob63	=	 S3587801	;			
																	
startyrjob54	=	.;	if	 S3586902	>=	1980	&	 S3586902	<=	2050	then	startyrjob54	=	 S3586902	;			
startyrjob55	=	.;	if	 S3587002	>=	1980	&	 S3587002	<=	2050	then	startyrjob55	=	 S3587002	;			
startyrjob56	=	.;	if	 S3587102	>=	1980	&	 S3587102	<=	2050	then	startyrjob56	=	 S3587102	;			
startyrjob57	=	.;	if	 S3587202	>=	1980	&	 S3587202	<=	2050	then	startyrjob57	=	 S3587202	;			
startyrjob58	=	.;	if	 S3587302	>=	1980	&	 S3587302	<=	2050	then	startyrjob58	=	 S3587302	;			
startyrjob59	=	.;	if	 S3587402	>=	1980	&	 S3587402	<=	2050	then	startyrjob59	=	 S3587402	;			
startyrjob60	=	.;	if	 S3587502	>=	1980	&	 S3587502	<=	2050	then	startyrjob60	=	 S3587502	;			
startyrjob61	=	.;	if	 S3587602	>=	1980	&	 S3587602	<=	2050	then	startyrjob61	=	 S3587602	;			
startyrjob62	=	.;	if	 S3587702	>=	1980	&	 S3587702	<=	2050	then	startyrjob62	=	 S3587702	;			
startyrjob63	=	.;	if	 S3587802	>=	1980	&	 S3587802	<=	2050	then	startyrjob63	=	 S3587802	;			
																		
startcontmo54	=	.;	if	startyrjob54	ne	.	&	startmojob54	ne	.	then	startcontmo54	=	((startyrjob54	-1980)*12)	+	startmojob54	;
startcontmo55	=	.;	if	startyrjob55	ne	.	&	startmojob55	ne	.	then	startcontmo55	=	((startyrjob55	-1980)*12)	+	startmojob55	;
startcontmo56	=	.;	if	startyrjob56	ne	.	&	startmojob56	ne	.	then	startcontmo56	=	((startyrjob56	-1980)*12)	+	startmojob56	;
startcontmo57	=	.;	if	startyrjob57	ne	.	&	startmojob57	ne	.	then	startcontmo57	=	((startyrjob57	-1980)*12)	+	startmojob57	;
startcontmo58	=	.;	if	startyrjob58	ne	.	&	startmojob58	ne	.	then	startcontmo58	=	((startyrjob58	-1980)*12)	+	startmojob58	;
startcontmo59	=	.;	if	startyrjob59	ne	.	&	startmojob59	ne	.	then	startcontmo59	=	((startyrjob59	-1980)*12)	+	startmojob59	;
startcontmo60	=	.;	if	startyrjob60	ne	.	&	startmojob60	ne	.	then	startcontmo60	=	((startyrjob60	-1980)*12)	+	startmojob60	;
startcontmo61	=	.;	if	startyrjob61	ne	.	&	startmojob61	ne	.	then	startcontmo61	=	((startyrjob61	-1980)*12)	+	startmojob61	;
startcontmo62	=	.;	if	startyrjob62	ne	.	&	startmojob62	ne	.	then	startcontmo62	=	((startyrjob62	-1980)*12)	+	startmojob62	;
startcontmo63	=	.;	if	startyrjob63	ne	.	&	startmojob63	ne	.	then	startcontmo63	=	((startyrjob63	-1980)*12)	+	startmojob63	;

endbyst54	= .; if	S2931600	ge 0 &	S2931600	le 1 then	endbyst54	=	S2931600	;
endbyst55	= .; if	S2931700	ge 0 &	S2931700	le 1 then	endbyst55	=	S2931700	;
endbyst56	= .; if	S2931800	ge 0 &	S2931800	le 1 then	endbyst56	=	S2931800	;
endbyst57	= .; if	S2931900	ge 0 &	S2931900	le 1 then	endbyst57	=	S2931900	;
endbyst58	= .; if	S2932000	ge 0 &	S2932000	le 1 then	endbyst58	=	S2932000	;
endbyst59	= .; if	S2932100	ge 0 &	S2932100	le 1 then	endbyst59	=	S2932100	;
endbyst60	= .; if	S2932200	ge 0 &	S2932200	le 1 then	endbyst60	=	S2932200	;
endbyst61	= .; if	S2932300	ge 0 &	S2932300	le 1 then	endbyst61	=	S2932300	;
endbyst62	= .; if	S2932400	ge 0 &	S2932400	le 1 then	endbyst62	=	S2932400	;
endbyst63	= .; if	S2932500	ge 0 &	S2932500	le 1 then	endbyst63	=	S2932500	;

jobsat54	= .;	if	S2894400	>= 1 and	S2894400	<= 5 then 	jobsat54	=	S2894400	;
jobsat55	= .;	if	S2894500	>= 1 and	S2894500	<= 5 then 	jobsat55	=	S2894500	;
jobsat56	= .;	if	S2894600	>= 1 and	S2894600	<= 5 then 	jobsat56	=	S2894600	;
jobsat57	= .;	if	S2894700	>= 1 and	S2894700	<= 5 then 	jobsat57	=	S2894700	;
jobsat58	= .;	if	S2894800	>= 1 and	S2894800	<= 5 then 	jobsat58	=	S2894800	;
jobsat59	= .;	if	S2894900	>= 1 and	S2894900	<= 5 then 	jobsat59	=	S2894900	;
jobsat60	= .;	if	S2895000	>= 1 and	S2895000	<= 5 then 	jobsat60	=	S2895000	;
jobsat61	= .;	if	S2895100	>= 1 and	S2895100	<= 5 then 	jobsat61	=	S2895100	;
jobsat62	= .;	if	S2895200	>= 1 and	S2895200	<= 5 then 	jobsat62	=	S2895200	;
jobsat63	= .;	if	S2895300	>= 1 and	S2895300	<= 5 then 	jobsat63	=	S2895300	;

union54	= .;	if	S2887000	>= 0 and	S2887000	<= 1 then 	union54	=	S2887000	;
union55	= .;	if	S2887100	>= 0 and	S2887100	<= 1 then 	union55	=	S2887100	;
union56	= .;	if	S2887200	>= 0 and	S2887200	<= 1 then 	union56	=	S2887200	;
union57	= .;	if	S2887300	>= 0 and	S2887300	<= 1 then 	union57	=	S2887300	;
union58	= .;	if	S2887400	>= 0 and	S2887400	<= 1 then 	union58	=	S2887400	;
union59	= .;	if	S2887500	>= 0 and	S2887500	<= 1 then 	union59	=	S2887500	;
union60	= .;	if	S2887600	>= 0 and	S2887600	<= 1 then 	union60	=	S2887600	;
union61	= .;	if	S2887700	>= 0 and	S2887700	<= 1 then 	union61	=	S2887700	;
union62	= .;	if	S2887800	>= 0 and	S2887800	<= 1 then 	union62	=	S2887800	;
union63	= .;	if	S2887900	>= 0 and	S2887900	<= 1 then 	union63	=	S2887900	;

ben_med54	= .;	if	S2879602	>= 0 and	S2879602	<= 1 then 	ben_med54	=	S2879602	;
ben_med55	= .;	if	S2879702	>= 0 and	S2879702	<= 1 then 	ben_med55	=	S2879702	;
ben_med56	= .;	if	S2879802	>= 0 and	S2879802	<= 1 then 	ben_med56	=	S2879802	;
ben_med57	= .;	if	S2879902	>= 0 and	S2879902	<= 1 then 	ben_med57	=	S2879902	;
ben_med58	= .;	if	S2880002	>= 0 and	S2880002	<= 1 then 	ben_med58	=	S2880002	;
ben_med59	= .;	if	S2880102	>= 0 and	S2880102	<= 1 then 	ben_med59	=	S2880102	;
ben_med60	= .;	if	S2880202	>= 0 and	S2880202	<= 1 then 	ben_med60	=	S2880202	;
ben_med61	= .;	if	S2880302	>= 0 and	S2880302	<= 1 then 	ben_med61	=	S2880302	;
ben_med62	= .;	if	S2880402	>= 0 and	S2880402	<= 1 then 	ben_med62	=	S2880402	;
ben_med63	= .;	if	S2880502	>= 0 and	S2880502	<= 1 then 	ben_med63	=	S2880502	;

ben_flex54	= .;	if	S2879601	>= 0 and	S2879601	<= 1 then 	ben_flex54	=	S2879601	;
ben_flex55	= .;	if	S2879701	>= 0 and	S2879701	<= 1 then 	ben_flex55	=	S2879701	;
ben_flex56	= .;	if	S2879801	>= 0 and	S2879801	<= 1 then 	ben_flex56	=	S2879801	;
ben_flex57	= .;	if	S2879901	>= 0 and	S2879901	<= 1 then 	ben_flex57	=	S2879901	;
ben_flex58	= .;	if	S2880001	>= 0 and	S2880001	<= 1 then 	ben_flex58	=	S2880001	;
ben_flex59	= .;	if	S2880101	>= 0 and	S2880101	<= 1 then 	ben_flex59	=	S2880101	;
ben_flex60	= .;	if	S2880201	>= 0 and	S2880201	<= 1 then 	ben_flex60	=	S2880201	;
ben_flex61	= .;	if	S2880301	>= 0 and	S2880301	<= 1 then 	ben_flex61	=	S2880301	;
ben_flex62	= .;	if	S2880401	>= 0 and	S2880401	<= 1 then 	ben_flex62	=	S2880401	;
ben_flex63	= .;	if	S2880501	>= 0 and	S2880501	<= 1 then 	ben_flex63	=	S2880501	;

ben_life54	= .;	if	S2879603	>= 0 and	S2879603	<= 1 then 	ben_life54	=	S2879603	;
ben_life55	= .;	if	S2879703	>= 0 and	S2879703	<= 1 then 	ben_life55	=	S2879703	;
ben_life56	= .;	if	S2879803	>= 0 and	S2879803	<= 1 then 	ben_life56	=	S2879803	;
ben_life57	= .;	if	S2879903	>= 0 and	S2879903	<= 1 then 	ben_life57	=	S2879903	;
ben_life58	= .;	if	S2880003	>= 0 and	S2880003	<= 1 then 	ben_life58	=	S2880003	;
ben_life59	= .;	if	S2880103	>= 0 and	S2880103	<= 1 then 	ben_life59	=	S2880103	;
ben_life60	= .;	if	S2880203	>= 0 and	S2880203	<= 1 then 	ben_life60	=	S2880203	;
ben_life61	= .;	if	S2880303	>= 0 and	S2880303	<= 1 then 	ben_life61	=	S2880303	;
ben_life62	= .;	if	S2880403	>= 0 and	S2880403	<= 1 then 	ben_life62	=	S2880403	;
ben_life63	= .;	if	S2880503	>= 0 and	S2880503	<= 1 then 	ben_life63	=	S2880503	;

ben_dental54	= .;	if	S2879604	>= 0 and	S2879604	<= 1 then 	ben_dental54	=	S2879604	;
ben_dental55	= .;	if	S2879704	>= 0 and	S2879704	<= 1 then 	ben_dental55	=	S2879704	;
ben_dental56	= .;	if	S2879804	>= 0 and	S2879804	<= 1 then 	ben_dental56	=	S2879804	;
ben_dental57	= .;	if	S2879904	>= 0 and	S2879904	<= 1 then 	ben_dental57	=	S2879904	;
ben_dental58	= .;	if	S2880004	>= 0 and	S2880004	<= 1 then 	ben_dental58	=	S2880004	;
ben_dental59	= .;	if	S2880104	>= 0 and	S2880104	<= 1 then 	ben_dental59	=	S2880104	;
ben_dental60	= .;	if	S2880204	>= 0 and	S2880204	<= 1 then 	ben_dental60	=	S2880204	;
ben_dental61	= .;	if	S2880304	>= 0 and	S2880304	<= 1 then 	ben_dental61	=	S2880304	;
ben_dental62	= .;	if	S2880404	>= 0 and	S2880404	<= 1 then 	ben_dental62	=	S2880404	;
ben_dental63	= .;	if	S2880504	>= 0 and	S2880504	<= 1 then 	ben_dental63	=	S2880504	;

ben_pdleave54	= .;	if	S2879605	>= 0 and	S2879605	<= 1 then 	ben_pdleave54	=	S2879605	;
ben_pdleave55	= .;	if	S2879705	>= 0 and	S2879705	<= 1 then 	ben_pdleave55	=	S2879705	;
ben_pdleave56	= .;	if	S2879805	>= 0 and	S2879805	<= 1 then 	ben_pdleave56	=	S2879805	;
ben_pdleave57	= .;	if	S2879905	>= 0 and	S2879905	<= 1 then 	ben_pdleave57	=	S2879905	;
ben_pdleave58	= .;	if	S2880005	>= 0 and	S2880005	<= 1 then 	ben_pdleave58	=	S2880005	;
ben_pdleave59	= .;	if	S2880105	>= 0 and	S2880105	<= 1 then 	ben_pdleave59	=	S2880105	;
ben_pdleave60	= .;	if	S2880205	>= 0 and	S2880205	<= 1 then 	ben_pdleave60	=	S2880205	;
ben_pdleave61	= .;	if	S2880305	>= 0 and	S2880305	<= 1 then 	ben_pdleave61	=	S2880305	;
ben_pdleave62	= .;	if	S2880405	>= 0 and	S2880405	<= 1 then 	ben_pdleave62	=	S2880405	;
ben_pdleave63	= .;	if	S2880505	>= 0 and	S2880505	<= 1 then 	ben_pdleave63	=	S2880505	;

ben_unpdleave54	= .;	if	S2879606	>= 0 and	S2879606	<= 1 then 	ben_unpdleave54	=	S2879606	;
ben_unpdleave55	= .;	if	S2879706	>= 0 and	S2879706	<= 1 then 	ben_unpdleave55	=	S2879706	;
ben_unpdleave56	= .;	if	S2879806	>= 0 and	S2879806	<= 1 then 	ben_unpdleave56	=	S2879806	;
ben_unpdleave57	= .;	if	S2879906	>= 0 and	S2879906	<= 1 then 	ben_unpdleave57	=	S2879906	;
ben_unpdleave58	= .;	if	S2880006	>= 0 and	S2880006	<= 1 then 	ben_unpdleave58	=	S2880006	;
ben_unpdleave59	= .;	if	S2880106	>= 0 and	S2880106	<= 1 then 	ben_unpdleave59	=	S2880106	;
ben_unpdleave60	= .;	if	S2880206	>= 0 and	S2880206	<= 1 then 	ben_unpdleave60	=	S2880206	;
ben_unpdleave61	= .;	if	S2880306	>= 0 and	S2880306	<= 1 then 	ben_unpdleave61	=	S2880306	;
ben_unpdleave62	= .;	if	S2880406	>= 0 and	S2880406	<= 1 then 	ben_unpdleave62	=	S2880406	;
ben_unpdleave63	= .;	if	S2880506	>= 0 and	S2880506	<= 1 then 	ben_unpdleave63	=	S2880506	;

ben_retire54	= .;	if	S2879607	>= 0 and	S2879607	<= 1 then 	ben_retire54	=	S2879607	;
ben_retire55	= .;	if	S2879707	>= 0 and	S2879707	<= 1 then 	ben_retire55	=	S2879707	;
ben_retire56	= .;	if	S2879807	>= 0 and	S2879807	<= 1 then 	ben_retire56	=	S2879807	;
ben_retire57	= .;	if	S2879907	>= 0 and	S2879907	<= 1 then 	ben_retire57	=	S2879907	;
ben_retire58	= .;	if	S2880007	>= 0 and	S2880007	<= 1 then 	ben_retire58	=	S2880007	;
ben_retire59	= .;	if	S2880107	>= 0 and	S2880107	<= 1 then 	ben_retire59	=	S2880107	;
ben_retire60	= .;	if	S2880207	>= 0 and	S2880207	<= 1 then 	ben_retire60	=	S2880207	;
ben_retire61	= .;	if	S2880307	>= 0 and	S2880307	<= 1 then 	ben_retire61	=	S2880307	;
ben_retire62	= .;	if	S2880407	>= 0 and	S2880407	<= 1 then 	ben_retire62	=	S2880407	;
ben_retire63	= .;	if	S2880507	>= 0 and	S2880507	<= 1 then 	ben_retire63	=	S2880507	;

ben_tuition54	= .;	if	S2879608	>= 0 and	S2879608	<= 1 then 	ben_tuition54	=	S2879608	;
ben_tuition55	= .;	if	S2879708	>= 0 and	S2879708	<= 1 then 	ben_tuition55	=	S2879708	;
ben_tuition56	= .;	if	S2879808	>= 0 and	S2879808	<= 1 then 	ben_tuition56	=	S2879808	;
ben_tuition57	= .;	if	S2879908	>= 0 and	S2879908	<= 1 then 	ben_tuition57	=	S2879908	;
ben_tuition58	= .;	if	S2880008	>= 0 and	S2880008	<= 1 then 	ben_tuition58	=	S2880008	;
ben_tuition59	= .;	if	S2880108	>= 0 and	S2880108	<= 1 then 	ben_tuition59	=	S2880108	;
ben_tuition60	= .;	if	S2880208	>= 0 and	S2880208	<= 1 then 	ben_tuition60	=	S2880208	;
ben_tuition61	= .;	if	S2880308	>= 0 and	S2880308	<= 1 then 	ben_tuition61	=	S2880308	;
ben_tuition62	= .;	if	S2880408	>= 0 and	S2880408	<= 1 then 	ben_tuition62	=	S2880408	;
ben_tuition63	= .;	if	S2880508	>= 0 and	S2880508	<= 1 then 	ben_tuition63	=	S2880508	;

ben_child54	= .;	if	S2879609	>= 0 and	S2879609	<= 1 then 	ben_child54	=	S2879609	;
ben_child55	= .;	if	S2879709	>= 0 and	S2879709	<= 1 then 	ben_child55	=	S2879709	;
ben_child56	= .;	if	S2879809	>= 0 and	S2879809	<= 1 then 	ben_child56	=	S2879809	;
ben_child57	= .;	if	S2879909	>= 0 and	S2879909	<= 1 then 	ben_child57	=	S2879909	;
ben_child58	= .;	if	S2880009	>= 0 and	S2880009	<= 1 then 	ben_child58	=	S2880009	;
ben_child59	= .;	if	S2880109	>= 0 and	S2880109	<= 1 then 	ben_child59	=	S2880109	;
ben_child60	= .;	if	S2880209	>= 0 and	S2880209	<= 1 then 	ben_child60	=	S2880209	;
ben_child61	= .;	if	S2880309	>= 0 and	S2880309	<= 1 then 	ben_child61	=	S2880309	;
ben_child62	= .;	if	S2880409	>= 0 and	S2880409	<= 1 then 	ben_child62	=	S2880409	;
ben_child63	= .;	if	S2880509	>= 0 and	S2880509	<= 1 then 	ben_child63	=	S2880509	;

ben_stock54	= .;	if	S2879610	>= 0 and	S2879610	<= 1 then 	ben_stock54	=	S2879610	;
ben_stock55	= .;	if	S2879710	>= 0 and	S2879710	<= 1 then 	ben_stock55	=	S2879710	;
ben_stock56	= .;	if	S2879810	>= 0 and	S2879810	<= 1 then 	ben_stock56	=	S2879810	;
ben_stock57	= .;	if	S2879910	>= 0 and	S2879910	<= 1 then 	ben_stock57	=	S2879910	;
ben_stock58	= .;	if	S2880010	>= 0 and	S2880010	<= 1 then 	ben_stock58	=	S2880010	;
ben_stock59	= .;	if	S2880110	>= 0 and	S2880110	<= 1 then 	ben_stock59	=	S2880110	;
ben_stock60	= .;	if	S2880210	>= 0 and	S2880210	<= 1 then 	ben_stock60	=	S2880210	;
ben_stock61	= .;	if	S2880310	>= 0 and	S2880310	<= 1 then 	ben_stock61	=	S2880310	;
ben_stock62	= .;	if	S2880410	>= 0 and	S2880410	<= 1 then 	ben_stock62	=	S2880410	;
ben_stock63	= .;	if	S2880510	>= 0 and	S2880510	<= 1 then 	ben_stock63	=	S2880510	;

occcode54	= .; if	S3757000	ge 0 and	S3757000	le 9990 then	occcode54	=	S3757000	;
occcode55	= .; if	S3757100	ge 0 and	S3757100	le 9990 then	occcode55	=	S3757100	;
occcode56	= .; if	S3757200	ge 0 and	S3757200	le 9990 then	occcode56	=	S3757200	;
occcode57	= .; if	S3757300	ge 0 and	S3757300	le 9990 then	occcode57	=	S3757300	;
occcode58	= .; if	S3757400	ge 0 and	S3757400	le 9990 then	occcode58	=	S3757400	;
occcode59	= .; if	S3757500	ge 0 and	S3757500	le 9990 then	occcode59	=	S3757500	;
occcode60	= .; if	S3757600	ge 0 and	S3757600	le 9990 then	occcode60	=	S3757600	;
occcode61	= .; if	S3757700	ge 0 and	S3757700	le 9990 then	occcode61	=	S3757700	;
occcode62	= .; if	S3757800	ge 0 and	S3757800	le 9990 then	occcode62	=	S3757800	;
occcode63	= .; if	S3757900	ge 0 and	S3757900	le 9990 then	occcode63	=	S3757900	;

indcode54	= .; if	S3755000	ge 0 and	S3755000	le 9990 then	indcode54	=	S3755000	;
indcode55	= .; if	S3755100	ge 0 and	S3755100	le 9990 then	indcode55	=	S3755100	;
indcode56	= .; if	S3755200	ge 0 and	S3755200	le 9990 then	indcode56	=	S3755200	;
indcode57	= .; if	S3755300	ge 0 and	S3755300	le 9990 then	indcode57	=	S3755300	;
indcode58	= .; if	S3755400	ge 0 and	S3755400	le 9990 then	indcode58	=	S3755400	;
indcode59	= .; if	S3755500	ge 0 and	S3755500	le 9990 then	indcode59	=	S3755500	;
indcode60	= .; if	S3755600	ge 0 and	S3755600	le 9990 then	indcode60	=	S3755600	;
indcode61	= .; if	S3755700	ge 0 and	S3755700	le 9990 then	indcode61	=	S3755700	;
indcode62	= .; if	S3755800	ge 0 and	S3755800	le 9990 then	indcode62	=	S3755800	;
indcode63	= .; if	S3755900	ge 0 and	S3755900	le 9990 then	indcode63	=	S3755900	;

jobtype54	= .; if	S2605700	ge 1 &	S2605700	le 5 then	jobtype54	=	S2605700	;
jobtype55	= .; if	S2605800	ge 1 &	S2605800	le 5 then	jobtype55	=	S2605800	;
jobtype56	= .; if	S2605900	ge 1 &	S2605900	le 5 then	jobtype56	=	S2605900	;
jobtype57	= .; if	S2606000	ge 1 &	S2606000	le 5 then	jobtype57	=	S2606000	;
jobtype58	= .; if	S2606100	ge 1 &	S2606100	le 5 then	jobtype58	=	S2606100	;
jobtype59	= .; if	S2606200	ge 1 &	S2606200	le 5 then	jobtype59	=	S2606200	;
jobtype60	= .; if	S2606300	ge 1 &	S2606300	le 5 then	jobtype60	=	S2606300	;
jobtype61	= .; if	S2606400	ge 1 &	S2606400	le 5 then	jobtype61	=	S2606400	;
jobtype62	= .; if	S2606500	ge 1 &	S2606500	le 5 then	jobtype62	=	S2606500	;
jobtype63 = .;

hourswk54	= .; if	S2020301	ge 0 &	S2020301	le 168 then	hourswk54	=	S2020301	;
hourswk55	= .; if	S2020302	ge 0 &	S2020302	le 168 then	hourswk55	=	S2020302	;
hourswk56	= .; if	S2020303	ge 0 &	S2020303	le 168 then	hourswk56	=	S2020303	;
hourswk57	= .; if	S2020304	ge 0 &	S2020304	le 168 then	hourswk57	=	S2020304	;
hourswk58	= .; if	S2020305	ge 0 &	S2020305	le 168 then	hourswk58	=	S2020305	;
hourswk59	= .; if	S2020306	ge 0 &	S2020306	le 168 then	hourswk59	=	S2020306	;
hourswk60	= .; if	S2020307	ge 0 &	S2020307	le 168 then	hourswk60	=	S2020307	;
hourswk61	= .; if	S2020308	ge 0 &	S2020308	le 168 then	hourswk61	=	S2020308	;
hourswk62	= .; if	S2020309	ge 0 &	S2020309	le 168 then	hourswk62	=	S2020309	;
hourswk63	= .; if	S2020310	ge 0 &	S2020310	le 168 then	hourswk63	=	S2020310	;

anygap54	= .; if	S2899300	ge -2 &	S2899300	le 0 then	anygap54	=	0	;	if 	S2899300	eq 1 then	anygap54	=	1	;
anygap55	= .; if	S2899400	ge -2 &	S2899400	le 0 then	anygap55	=	0	;	if 	S2899400	eq 1 then	anygap55	=	1	;
anygap56	= .; if	S2899500	ge -2 &	S2899500	le 0 then	anygap56	=	0	;	if 	S2899500	eq 1 then	anygap56	=	1	;
anygap57	= .; if	S2899600	ge -2 &	S2899600	le 0 then	anygap57	=	0	;	if 	S2899600	eq 1 then	anygap57	=	1	;
anygap58	= .; if	S2899700	ge -2 &	S2899700	le 0 then	anygap58	=	0	;	if 	S2899700	eq 1 then	anygap58	=	1	;
anygap59	= .; if	S2899800	ge -2 &	S2899800	le 0 then	anygap59	=	0	;	if 	S2899800	eq 1 then	anygap59	=	1	;
anygap60	= .; if	S2899900	ge -2 &	S2899900	le 0 then	anygap60	=	0	;	if 	S2899900	eq 1 then	anygap60	=	1	;
anygap61	= .; if	S2900000	ge -2 &	S2900000	le 0 then	anygap61	=	0	;	if 	S2900000	eq 1 then	anygap61	=	1	;
anygap62	= .; if	S2900100	ge -2 &	S2900100	le 0 then	anygap62	=	0	;	if 	S2900100	eq 1 then	anygap62	=	1	;
anygap63	= .; if	S2900200	ge -2 &	S2900200	le 0 then	anygap63	=	0	;	if 	S2900200	eq 1 then	anygap63	=	1	;

worksched54	= .; if	S2878600	ge 1 &	S2878600	le 9 then	worksched54	=	S2878600	;
worksched55	= .; if	S2878700	ge 1 &	S2878700	le 9 then	worksched55	=	S2878700	;
worksched56	= .; if	S2878800	ge 1 &	S2878800	le 9 then	worksched56	=	S2878800	;
worksched57	= .; if	S2878900	ge 1 &	S2878900	le 9 then	worksched57	=	S2878900	;
worksched58	= .; if	S2879000	ge 1 &	S2879000	le 9 then	worksched58	=	S2879000	;
worksched59	= .; if	S2879100	ge 1 &	S2879100	le 9 then	worksched59	=	S2879100	;
worksched60	= .; if	S2879200	ge 1 &	S2879200	le 9 then	worksched60	=	S2879200	;
worksched61	= .; if	S2879300	ge 1 &	S2879300	le 9 then	worksched61	=	S2879300	;
worksched62	= .; if	S2879400	ge 1 &	S2879400	le 9 then	worksched62	=	S2879400	;
worksched63	= .; if	S2879500	ge 1 &	S2879500	le 9 then	worksched63	=	S2879500	;

/* 2004: up to 7 ************************************************************/

idjob64	= .; if (S5146300 >= 0 & S5146300 <= 300000) then idjob64 = S5146300;
idjob65	= .; if (S5146400 >= 0 & S5146400 <= 300000) then idjob65 = S5146400;
idjob66	= .; if (S5146500 >= 0 & S5146500 <= 300000) then idjob66 = S5146500;
idjob67	= .; if (S5146600 >= 0 & S5146600 <= 300000) then idjob67 = S5146600;
idjob68	= .; if (S5146700 >= 0 & S5146700 <= 300000) then idjob68 = S5146700;
idjob69	= .; if (S5146800 >= 0 & S5146800 <= 300000) then idjob69 = S5146800;
idjob70	= .; if (S5146900 >= 0 & S5146900 <= 300000) then idjob70 = S5146900;

whyleftjob64 = .; if (S4584100	>= 0 & S4584100	<= 50) then	whyleftjob64 =	S4584100;
whyleftjob65 = .; if (S4584200	>= 0 & S4584200	<= 50) then	whyleftjob65 =	S4584200;
whyleftjob66 = .; if (S4584300	>= 0 & S4584300	<= 50) then	whyleftjob66 =	S4584300;
whyleftjob67 = .; if (S4584400	>= 0 & S4584400	<= 50) then	whyleftjob67 =	S4584400;
whyleftjob68 = .; if (S4584500	>= 0 & S4584500	<= 50) then	whyleftjob68 =	S4584500;
whyleftjob69 = .; if (S4584600	>= 0 & S4584600	<= 50) then	whyleftjob69 =	S4584600;
whyleftjob70 = .; if (S4584700	>= 0 & S4584700	<= 50) then	whyleftjob70 =	S4584700;

curjob64	= .; if	S5097500	>= 0 &	S5097500	<= 1 then	curjob64	=	S5097500	;
curjob65	= .; if	S5097600	>= 0 &	S5097600	<= 1 then	curjob65	=	S5097600	;
curjob66	= .; if	S5097700	>= 0 &	S5097700	<= 1 then	curjob66	=	S5097700	;
curjob67	= .; if	S5097800	>= 0 &	S5097800	<= 1 then	curjob67	=	S5097800	;
curjob68	= .; if	S5097900	>= 0 &	S5097900	<= 1 then	curjob68	=	S5097900	;
curjob69	= .; if	S5098000	>= 0 &	S5098000	<= 1 then	curjob69	=	S5098000	;
curjob70	= .; if	S5098100	>= 0 &	S5098100	<= 1 then	curjob70	=	S5098100	;

intmo64	= S3821900;
intmo65	= S3821900;
intmo66	= S3821900;
intmo67	= S3821900;
intmo68	= S3821900;
intmo69	= S3821900;
intmo70	= S3821900;

weeksjob64 = .;	if (S3836500 >= 0 &	S3836500 <= 5000) then weeksjob64 =	S3836500;
weeksjob65 = .;	if (S3836600 >= 0 &	S3836600 <= 5000) then weeksjob65 =	S3836600;
weeksjob66 = .;	if (S3836700 >= 0 &	S3836700 <= 5000) then weeksjob66 =	S3836700;
weeksjob67 = .;	if (S3836800 >= 0 &	S3836800 <= 5000) then weeksjob67 =	S3836800;
weeksjob68 = .;	if (S3836900 >= 0 &	S3836900 <= 5000) then weeksjob68 =	S3836900;
weeksjob69 = .;	if (S3837000 >= 0 &	S3837000 <= 5000) then weeksjob69 =	S3837000;
weeksjob70 = .;	if (S3837100 >= 0 &	S3837100 <= 5000) then weeksjob70 =	S3837100;

startmojob64	=	.;	if	S5128901	>=	0	&	S5128901	<=	12	then	startmojob64	=	S5128901	;			
startmojob65	=	.;	if	S5129001	>=	0	&	S5129001	<=	12	then	startmojob65	=	S5129001	;			
startmojob66	=	.;	if	S5129101	>=	0	&	S5129101	<=	12	then	startmojob66	=	S5129101	;			
startmojob67	=	.;	if	S5129201	>=	0	&	S5129201	<=	12	then	startmojob67	=	S5129201	;			
startmojob68	=	.;	if	S5129301	>=	0	&	S5129301	<=	12	then	startmojob68	=	S5129301	;			
startmojob69	=	.;	if	S5129401	>=	0	&	S5129401	<=	12	then	startmojob69	=	S5129401	;			
startmojob70	=	.;	if	S5129501	>=	0	&	S5129501	<=	12	then	startmojob70	=	S5129501	;			
																		
startyrjob64	=	.;	if	S5128902	>=	1980	&	S5128902	<=	2050	then	startyrjob64	=	S5128902	;			
startyrjob65	=	.;	if	S5129002	>=	1980	&	S5129002	<=	2050	then	startyrjob65	=	S5129002	;			
startyrjob66	=	.;	if	S5129102	>=	1980	&	S5129102	<=	2050	then	startyrjob66	=	S5129102	;			
startyrjob67	=	.;	if	S5129202	>=	1980	&	S5129202	<=	2050	then	startyrjob67	=	S5129202	;			
startyrjob68	=	.;	if	S5129302	>=	1980	&	S5129302	<=	2050	then	startyrjob68	=	S5129302	;			
startyrjob69	=	.;	if	S5129402	>=	1980	&	S5129402	<=	2050	then	startyrjob69	=	S5129402	;			
startyrjob70	=	.;	if	S5129502	>=	1980	&	S5129502	<=	2050	then	startyrjob70	=	S5129502	;			
																		
startcontmo64	=	.;	if	startyrjob64	ne	.	&	startmojob64	ne	.	then	startcontmo64	=	((startyrjob64	-1980)*12)	+	startmojob64	;
startcontmo65	=	.;	if	startyrjob65	ne	.	&	startmojob65	ne	.	then	startcontmo65	=	((startyrjob65	-1980)*12)	+	startmojob65	;
startcontmo66	=	.;	if	startyrjob66	ne	.	&	startmojob66	ne	.	then	startcontmo66	=	((startyrjob66	-1980)*12)	+	startmojob66	;
startcontmo67	=	.;	if	startyrjob67	ne	.	&	startmojob67	ne	.	then	startcontmo67	=	((startyrjob67	-1980)*12)	+	startmojob67	;
startcontmo68	=	.;	if	startyrjob68	ne	.	&	startmojob68	ne	.	then	startcontmo68	=	((startyrjob68	-1980)*12)	+	startmojob68	;
startcontmo69	=	.;	if	startyrjob69	ne	.	&	startmojob69	ne	.	then	startcontmo69	=	((startyrjob69	-1980)*12)	+	startmojob69	;
startcontmo70	=	.;	if	startyrjob70	ne	.	&	startmojob70	ne	.	then	startcontmo70	=	((startyrjob70	-1980)*12)	+	startmojob70	;

endbyst64	= .; if	S4635300	ge 0 &	S4635300	le 1 then	endbyst64	=	S4635300	;
endbyst65	= .; if	S4635400	ge 0 &	S4635400	le 1 then	endbyst65	=	S4635400	;
endbyst66	= .; if	S4635500	ge 0 &	S4635500	le 1 then	endbyst66	=	S4635500	;
endbyst67	= .; if	S4635600	ge 0 &	S4635600	le 1 then	endbyst67	=	S4635600	;
endbyst68	= .; if	S4635700	ge 0 &	S4635700	le 1 then	endbyst68	=	S4635700	;
endbyst69	= .; if	S4635800	ge 0 &	S4635800	le 1 then	endbyst69	=	S4635800	;
endbyst70	= .; if	S4635900	ge 0 &	S4635900	le 1 then	endbyst70	=	S4635900	;

jobsat64	= .;	if	S4602900	>= 1 and	S4602900	<= 5 then 	jobsat64	=	S4602900	;
jobsat65	= .;	if	S4603000	>= 1 and	S4603000	<= 5 then 	jobsat65	=	S4603000	;
jobsat66	= .;	if	S4603100	>= 1 and	S4603100	<= 5 then 	jobsat66	=	S4603100	;
jobsat67	= .;	if	S4603200	>= 1 and	S4603200	<= 5 then 	jobsat67	=	S4603200	;
jobsat68	= .;	if	S4603300	>= 1 and	S4603300	<= 5 then 	jobsat68	=	S4603300	;
jobsat69	= .;	if	S4603400	>= 1 and	S4603400	<= 5 then 	jobsat69	=	S4603400	;
jobsat70	= .;	if	S4603500	>= 1 and	S4603500	<= 5 then 	jobsat70	=	S4603500	;

union64	= .;	if	S4597000	>= 0 and	S4597000	<= 1 then 	union64	=	S4597000	;
union65	= .;	if	S4597100	>= 0 and	S4597100	<= 1 then 	union65	=	S4597100	;
union66	= .;	if	S4597200	>= 0 and	S4597200	<= 1 then 	union66	=	S4597200	;
union67	= .;	if	S4597300	>= 0 and	S4597300	<= 1 then 	union67	=	S4597300	;
union68	= .;	if	S4597400	>= 0 and	S4597400	<= 1 then 	union68	=	S4597400	;
union69	= .;	if	S4597500	>= 0 and	S4597500	<= 1 then 	union69	=	S4597500	;
union70	= .;	if	S4597600	>= 0 and	S4597600	<= 1 then 	union70	=	S4597600	;

ben_med64	= .;	if	S4591302	>= 0 and	S4591302	<= 1 then 	ben_med64	=	S4591302	;
ben_med65	= .;	if	S4591402	>= 0 and	S4591402	<= 1 then 	ben_med65	=	S4591402	;
ben_med66	= .;	if	S4591502	>= 0 and	S4591502	<= 1 then 	ben_med66	=	S4591502	;
ben_med67	= .;	if	S4591602	>= 0 and	S4591602	<= 1 then 	ben_med67	=	S4591602	;
ben_med68	= .;	if	S4591702	>= 0 and	S4591702	<= 1 then 	ben_med68	=	S4591702	;
ben_med69	= .;	if	S4591802	>= 0 and	S4591802	<= 1 then 	ben_med69	=	S4591802	;
ben_med70	= .;	if	S4591902	>= 0 and	S4591902	<= 1 then 	ben_med70	=	S4591902	;

ben_flex64	= .;	if	S4591301	>= 0 and	S4591301	<= 1 then 	ben_flex64	=	S4591301	;
ben_flex65	= .;	if	S4591401	>= 0 and	S4591401	<= 1 then 	ben_flex65	=	S4591401	;
ben_flex66	= .;	if	S4591501	>= 0 and	S4591501	<= 1 then 	ben_flex66	=	S4591501	;
ben_flex67	= .;	if	S4591601	>= 0 and	S4591601	<= 1 then 	ben_flex67	=	S4591601	;
ben_flex68	= .;	if	S4591701	>= 0 and	S4591701	<= 1 then 	ben_flex68	=	S4591701	;
ben_flex69	= .;	if	S4591801	>= 0 and	S4591801	<= 1 then 	ben_flex69	=	S4591801	;
ben_flex70	= .;	if	S4591901	>= 0 and	S4591901	<= 1 then 	ben_flex70	=	S4591901	;

ben_life64	= .;	if	S4591303	>= 0 and	S4591303	<= 1 then 	ben_life64	=	S4591303	;
ben_life65	= .;	if	S4591403	>= 0 and	S4591403	<= 1 then 	ben_life65	=	S4591403	;
ben_life66	= .;	if	S4591503	>= 0 and	S4591503	<= 1 then 	ben_life66	=	S4591503	;
ben_life67	= .;	if	S4591603	>= 0 and	S4591603	<= 1 then 	ben_life67	=	S4591603	;
ben_life68	= .;	if	S4591703	>= 0 and	S4591703	<= 1 then 	ben_life68	=	S4591703	;
ben_life69	= .;	if	S4591803	>= 0 and	S4591803	<= 1 then 	ben_life69	=	S4591803	;
ben_life70	= .;	if	S4591903	>= 0 and	S4591903	<= 1 then 	ben_life70	=	S4591903	;

ben_dental64	= .;	if	S4591304	>= 0 and	S4591304	<= 1 then 	ben_dental64	=	S4591304	;
ben_dental65	= .;	if	S4591404	>= 0 and	S4591404	<= 1 then 	ben_dental65	=	S4591404	;
ben_dental66	= .;	if	S4591504	>= 0 and	S4591504	<= 1 then 	ben_dental66	=	S4591504	;
ben_dental67	= .;	if	S4591604	>= 0 and	S4591604	<= 1 then 	ben_dental67	=	S4591604	;
ben_dental68	= .;	if	S4591704	>= 0 and	S4591704	<= 1 then 	ben_dental68	=	S4591704	;
ben_dental69	= .;	if	S4591804	>= 0 and	S4591804	<= 1 then 	ben_dental69	=	S4591804	;
ben_dental70	= .;	if	S4591904	>= 0 and	S4591904	<= 1 then 	ben_dental70	=	S4591904	;

ben_pdleave64	= .;	if	S4591305	>= 0 and	S4591305	<= 1 then 	ben_pdleave64	=	S4591305	;
ben_pdleave65	= .;	if	S4591405	>= 0 and	S4591405	<= 1 then 	ben_pdleave65	=	S4591405	;
ben_pdleave66	= .;	if	S4591505	>= 0 and	S4591505	<= 1 then 	ben_pdleave66	=	S4591505	;
ben_pdleave67	= .;	if	S4591605	>= 0 and	S4591605	<= 1 then 	ben_pdleave67	=	S4591605	;
ben_pdleave68	= .;	if	S4591705	>= 0 and	S4591705	<= 1 then 	ben_pdleave68	=	S4591705	;
ben_pdleave69	= .;	if	S4591805	>= 0 and	S4591805	<= 1 then 	ben_pdleave69	=	S4591805	;
ben_pdleave70	= .;	if	S4591905	>= 0 and	S4591905	<= 1 then 	ben_pdleave70	=	S4591905	;

ben_unpdleave64	= .;	if	S4591306	>= 0 and	S4591306	<= 1 then 	ben_unpdleave64	=	S4591306	;
ben_unpdleave65	= .;	if	S4591406	>= 0 and	S4591406	<= 1 then 	ben_unpdleave65	=	S4591406	;
ben_unpdleave66	= .;	if	S4591506	>= 0 and	S4591506	<= 1 then 	ben_unpdleave66	=	S4591506	;
ben_unpdleave67	= .;	if	S4591606	>= 0 and	S4591606	<= 1 then 	ben_unpdleave67	=	S4591606	;
ben_unpdleave68	= .;	if	S4591706	>= 0 and	S4591706	<= 1 then 	ben_unpdleave68	=	S4591706	;
ben_unpdleave69	= .;	if	S4591806	>= 0 and	S4591806	<= 1 then 	ben_unpdleave69	=	S4591806	;
ben_unpdleave70	= .;	if	S4591906	>= 0 and	S4591906	<= 1 then 	ben_unpdleave70	=	S4591906	;

ben_retire64	= .;	if	S4591307	>= 0 and	S4591307	<= 1 then 	ben_retire64	=	S4591307	;
ben_retire65	= .;	if	S4591407	>= 0 and	S4591407	<= 1 then 	ben_retire65	=	S4591407	;
ben_retire66	= .;	if	S4591507	>= 0 and	S4591507	<= 1 then 	ben_retire66	=	S4591507	;
ben_retire67	= .;	if	S4591607	>= 0 and	S4591607	<= 1 then 	ben_retire67	=	S4591607	;
ben_retire68	= .;	if	S4591707	>= 0 and	S4591707	<= 1 then 	ben_retire68	=	S4591707	;
ben_retire69	= .;	if	S4591807	>= 0 and	S4591807	<= 1 then 	ben_retire69	=	S4591807	;
ben_retire70	= .;	if	S4591907	>= 0 and	S4591907	<= 1 then 	ben_retire70	=	S4591907	;

ben_tuition64	= .;	if	S4591308	>= 0 and	S4591308	<= 1 then 	ben_tuition64	=	S4591308	;
ben_tuition65	= .;	if	S4591408	>= 0 and	S4591408	<= 1 then 	ben_tuition65	=	S4591408	;
ben_tuition66	= .;	if	S4591508	>= 0 and	S4591508	<= 1 then 	ben_tuition66	=	S4591508	;
ben_tuition67	= .;	if	S4591608	>= 0 and	S4591608	<= 1 then 	ben_tuition67	=	S4591608	;
ben_tuition68	= .;	if	S4591708	>= 0 and	S4591708	<= 1 then 	ben_tuition68	=	S4591708	;
ben_tuition69	= .;	if	S4591808	>= 0 and	S4591808	<= 1 then 	ben_tuition69	=	S4591808	;
ben_tuition70	= .;	if	S4591908	>= 0 and	S4591908	<= 1 then 	ben_tuition70	=	S4591908	;

ben_child64	= .;	if	S4591309	>= 0 and	S4591309	<= 1 then 	ben_child64	=	S4591309	;
ben_child65	= .;	if	S4591409	>= 0 and	S4591409	<= 1 then 	ben_child65	=	S4591409	;
ben_child66	= .;	if	S4591509	>= 0 and	S4591509	<= 1 then 	ben_child66	=	S4591509	;
ben_child67	= .;	if	S4591609	>= 0 and	S4591609	<= 1 then 	ben_child67	=	S4591609	;
ben_child68	= .;	if	S4591709	>= 0 and	S4591709	<= 1 then 	ben_child68	=	S4591709	;
ben_child69	= .;	if	S4591809	>= 0 and	S4591809	<= 1 then 	ben_child69	=	S4591809	;
ben_child70	= .;	if	S4591909	>= 0 and	S4591909	<= 1 then 	ben_child70	=	S4591909	;

ben_stock64	= .;	if	S4591310	>= 0 and	S4591310	<= 1 then 	ben_stock64	=	S4591310	;
ben_stock65	= .;	if	S4591410	>= 0 and	S4591410	<= 1 then 	ben_stock65	=	S4591410	;
ben_stock66	= .;	if	S4591510	>= 0 and	S4591510	<= 1 then 	ben_stock66	=	S4591510	;
ben_stock67	= .;	if	S4591610	>= 0 and	S4591610	<= 1 then 	ben_stock67	=	S4591610	;
ben_stock68	= .;	if	S4591710	>= 0 and	S4591710	<= 1 then 	ben_stock68	=	S4591710	;
ben_stock69	= .;	if	S4591810	>= 0 and	S4591810	<= 1 then 	ben_stock69	=	S4591810	;
ben_stock70	= .;	if	S4591910	>= 0 and	S4591910	<= 1 then 	ben_stock70	=	S4591910	;

occcode64	= .; if	S5041700	ge 0 and	S5041700	le 9990 then	occcode64	=	S5041700	;
occcode65	= .; if	S5041800	ge 0 and	S5041800	le 9990 then	occcode65	=	S5041800	;
occcode66	= .; if	S5041900	ge 0 and	S5041900	le 9990 then	occcode66	=	S5041900	;
occcode67	= .; if	S5042000	ge 0 and	S5042000	le 9990 then	occcode67	=	S5042000	;
occcode68	= .; if	S5042100	ge 0 and	S5042100	le 9990 then	occcode68	=	S5042100	;
occcode69	= .; if	S5042200	ge 0 and	S5042200	le 9990 then	occcode69	=	S5042200	;
occcode70	= .; if	S5042300	ge 0 and	S5042300	le 9990 then	occcode70	=	S5042300	;

indcode64	= .; if	S5041000	ge 0 and	S5041000	le 9990 then	indcode64	=	S5041000	;
indcode65	= .; if	S5041100	ge 0 and	S5041100	le 9990 then	indcode65	=	S5041100	;
indcode66	= .; if	S5041200	ge 0 and	S5041200	le 9990 then	indcode66	=	S5041200	;
indcode67	= .; if	S5041300	ge 0 and	S5041300	le 9990 then	indcode67	=	S5041300	;
indcode68	= .; if	S5041400	ge 0 and	S5041400	le 9990 then	indcode68	=	S5041400	;
indcode69	= .; if	S5041500	ge 0 and	S5041500	le 9990 then	indcode69	=	S5041500	;
indcode70	= .; if	S5041600	ge 0 and	S5041600	le 9990 then	indcode70	=	S5041600	;

jobtype64	= .; if	S4340700	ge 1 &	S4340700	le 5 then	jobtype64	=	S4340700	;
jobtype65	= .; if	S4340800	ge 1 &	S4340800	le 5 then	jobtype65	=	S4340800	;
jobtype66	= .; if	S4340900	ge 1 &	S4340900	le 5 then	jobtype66	=	S4340900	;
jobtype67	= .; if	S4341000	ge 1 &	S4341000	le 5 then	jobtype67	=	S4341000	;
jobtype68	= .; if	S4341100	ge 1 &	S4341100	le 5 then	jobtype68	=	S4341100	;
jobtype69	= .; if	S4341200	ge 1 &	S4341200	le 5 then	jobtype69	=	S4341200	;
jobtype70	= .; if	S4341300	ge 1 &	S4341300	le 5 then	jobtype70	=	S4341300	;

hourswk64	= .; if	S3821501	ge 0 &	S3821501	le 168 then	hourswk64	=	S3821501	;
hourswk65	= .; if	S3821502	ge 0 &	S3821502	le 168 then	hourswk65	=	S3821502	;
hourswk66	= .; if	S3821503	ge 0 &	S3821503	le 168 then	hourswk66	=	S3821503	;
hourswk67	= .; if	S3821504	ge 0 &	S3821504	le 168 then	hourswk67	=	S3821504	;
hourswk68	= .; if	S3821505	ge 0 &	S3821505	le 168 then	hourswk68	=	S3821505	;
hourswk69	= .; if	S3821506	ge 0 &	S3821506	le 168 then	hourswk69	=	S3821506	;
hourswk70	= .; if	S3821507	ge 0 &	S3821507	le 168 then	hourswk70	=	S3821507	;

anygap64	= .; if	S4606300	ge -2 &	S4606300	le 0 then	anygap64	=	0	;	if 	S4606300	eq 1 then	anygap64	=	1	;
anygap65	= .; if	S4606400	ge -2 &	S4606400	le 0 then	anygap65	=	0	;	if 	S4606400	eq 1 then	anygap65	=	1	;
anygap66	= .; if	S4606500	ge -2 &	S4606500	le 0 then	anygap66	=	0	;	if 	S4606500	eq 1 then	anygap66	=	1	;
anygap67	= .; if	S4606600	ge -2 &	S4606600	le 0 then	anygap67	=	0	;	if 	S4606600	eq 1 then	anygap67	=	1	;
anygap68	= .; if	S4606700	ge -2 &	S4606700	le 0 then	anygap68	=	0	;	if 	S4606700	eq 1 then	anygap68	=	1	;
anygap69	= .; if	S4606800	ge -2 &	S4606800	le 0 then	anygap69	=	0	;	if 	S4606800	eq 1 then	anygap69	=	1	;
anygap70	= .; if	S4606900	ge -2 &	S4606900	le 0 then	anygap70	=	0	;	if 	S4606900	eq 1 then	anygap70	=	1	;

worksched64	= .; if	S4590600	ge 1 &	S4590600	le 9 then	worksched64	=	S4590600	;	
worksched65	= .; if	S4590700	ge 1 &	S4590700	le 9 then	worksched65	=	S4590700	;	
worksched66	= .; if	S4590800	ge 1 &	S4590800	le 9 then	worksched66	=	S4590800	;	
worksched67	= .; if	S4590900	ge 1 &	S4590900	le 9 then	worksched67	=	S4590900	;	
worksched68	= .; if	S4591000	ge 1 &	S4591000	le 9 then	worksched68	=	S4591000	;	
worksched69	= .; if	S4591100	ge 1 &	S4591100	le 9 then	worksched69	=	S4591100	;	
worksched70	= .; if	S4591200	ge 1 &	S4591200	le 9 then	worksched70	=	S4591200	;	

/* 2005: up to 9 **************************************************************/

idjob71	= .; if (S6912700 >= 0 & S6912700 <= 300000) then idjob71 =	S6912700;
idjob72	= .; if (S6912800 >= 0 & S6912800 <= 300000) then idjob72 =	S6912800;
idjob73	= .; if (S6912900 >= 0 & S6912900 <= 300000) then idjob73 =	S6912900;
idjob74	= .; if (S6913000 >= 0 & S6913000 <= 300000) then idjob74 =	S6913000;
idjob75	= .; if (S6913100 >= 0 & S6913100 <= 300000) then idjob75 =	S6913100;
idjob76	= .; if (S6913200 >= 0 & S6913200 <= 300000) then idjob76 =	S6913200;
idjob77	= .; if (S6913300 >= 0 & S6913300 <= 300000) then idjob77 =	S6913300;
idjob78	= .; if (S6913400 >= 0 & S6913400 <= 300000) then idjob78 =	S6913400;
idjob79	= .; if (S6913500 >= 0 & S6913500 <= 300000) then idjob79 =	S6913500;

whyleftjob71 = .; if (S6185600	>= 0 & S6185600	<= 50) then	whyleftjob71 =	S6185600;
whyleftjob72 = .; if (S6185700	>= 0 & S6185700	<= 50) then	whyleftjob72 =	S6185700;
whyleftjob73 = .; if (S6185800	>= 0 & S6185800	<= 50) then	whyleftjob73 =	S6185800;
whyleftjob74 = .; if (S6185900	>= 0 & S6185900	<= 50) then	whyleftjob74 =	S6185900;
whyleftjob75 = .; if (S6186000	>= 0 & S6186000	<= 50) then	whyleftjob75 =	S6186000;
whyleftjob76 = .; if (S6186100	>= 0 & S6186100	<= 50) then	whyleftjob76 =	S6186100;
whyleftjob77 = .; if (S6186200	>= 0 & S6186200	<= 50) then	whyleftjob77 =	S6186200;
whyleftjob78 = .; if (S6186300	>= 0 & S6186300	<= 50) then	whyleftjob78 =	S6186300;
whyleftjob79 = .; if (S6186400	>= 0 & S6186400	<= 50) then	whyleftjob79 =	S6186400;

curjob71	= .; if	S6846200	>= 0 &	S6846200	<= 1 then	curjob71	=	S6846200	;
curjob72	= .; if	S6846300	>= 0 &	S6846300	<= 1 then	curjob72	=	S6846300	;
curjob73	= .; if	S6846400	>= 0 &	S6846400	<= 1 then	curjob73	=	S6846400	;
curjob74	= .; if	S6846500	>= 0 &	S6846500	<= 1 then	curjob74	=	S6846500	;
curjob75	= .; if	S6846600	>= 0 &	S6846600	<= 1 then	curjob75	=	S6846600	;
curjob76	= .; if	S6846700	>= 0 &	S6846700	<= 1 then	curjob76	=	S6846700	;
curjob77	= .; if	S6846800	>= 0 &	S6846800	<= 1 then	curjob77	=	S6846800	;
curjob78	= .; if	S6846900	>= 0 &	S6846900	<= 1 then	curjob78	=	S6846900	;
curjob79	= .; if	S6847000	>= 0 &	S6847000	<= 1 then	curjob79	=	S6847000	;

intmo71	= S5421900;
intmo72	= S5421900;
intmo73	= S5421900;
intmo74	= S5421900;
intmo75	= S5421900;
intmo76	= S5421900;
intmo77	= S5421900;
intmo78	= S5421900;
intmo79	= S5421900;

weeksjob71 = .;	if (S5437000 >= 0 &	S5437000 <= 5000) then weeksjob71 =	S5437000;
weeksjob72 = .;	if (S5437100 >= 0 &	S5437100 <= 5000) then weeksjob72 =	S5437100;
weeksjob73 = .;	if (S5437200 >= 0 &	S5437200 <= 5000) then weeksjob73 =	S5437200;
weeksjob74 = .;	if (S5437300 >= 0 &	S5437300 <= 5000) then weeksjob74 =	S5437300;
weeksjob75 = .;	if (S5437400 >= 0 &	S5437400 <= 5000) then weeksjob75 =	S5437400;
weeksjob76 = .;	if (S5437500 >= 0 &	S5437500 <= 5000) then weeksjob76 =	S5437500;
weeksjob77 = .;	if (S5437600 >= 0 &	S5437600 <= 5000) then weeksjob77 =	S5437600;
weeksjob78 = .;	if (S5437700 >= 0 &	S5437700 <= 5000) then weeksjob78 =	S5437700;
weeksjob79 = .;	if (S5437800 >= 0 &	S5437800 <= 5000) then weeksjob79 =	S5437800;

startmojob71	=	.;	if	S6880801	>=	0	&	S5128901	<=	12	then	startmojob71	=	S6880801	;			
startmojob72	=	.;	if	S6880901	>=	0	&	S5129001	<=	12	then	startmojob72	=	S6880901	;			
startmojob73	=	.;	if	S6881001	>=	0	&	S5129101	<=	12	then	startmojob73	=	S6881001	;			
startmojob74	=	.;	if	S6881101	>=	0	&	S5129201	<=	12	then	startmojob74	=	S6881101	;			
startmojob75	=	.;	if	S6881201	>=	0	&	S5129301	<=	12	then	startmojob75	=	S6881201	;			
startmojob76	=	.;	if	S6881301	>=	0	&	S5129401	<=	12	then	startmojob76	=	S6881301	;			
startmojob77	=	.;	if	S6881401	>=	0	&	S5129501	<=	12	then	startmojob77	=	S6881401	;			
startmojob78	=	.;	if	S6881501	>=	0	&	S5129401	<=	12	then	startmojob78	=	S6881501	;			
startmojob79	=	.;	if	S6881601	>=	0	&	S5129501	<=	12	then	startmojob79	=	S6881601	;			
																		
startyrjob71	=	.;	if	S6880802	>=	1980	&	S6880802	<=	2050	then	startyrjob71	=	S6880802	;			
startyrjob72	=	.;	if	S6880902	>=	1980	&	S6880902	<=	2050	then	startyrjob72	=	S6880902	;			
startyrjob73	=	.;	if	S6881002	>=	1980	&	S6881002	<=	2050	then	startyrjob73	=	S6881002	;			
startyrjob74	=	.;	if	S6881102	>=	1980	&	S6881102	<=	2050	then	startyrjob74	=	S6881102	;			
startyrjob75	=	.;	if	S6881202	>=	1980	&	S6881202	<=	2050	then	startyrjob75	=	S6881202	;			
startyrjob76	=	.;	if	S6881302	>=	1980	&	S6881302	<=	2050	then	startyrjob76	=	S6881302	;			
startyrjob77	=	.;	if	S6881402	>=	1980	&	S6881402	<=	2050	then	startyrjob77	=	S6881402	;			
startyrjob78	=	.;	if	S6881502	>=	1980	&	S6881502	<=	2050	then	startyrjob78	=	S6881502	;			
startyrjob79	=	.;	if	S6881602	>=	1980	&	S6881602	<=	2050	then	startyrjob79	=	S6881602	;			
																		
startcontmo71	=	.;	if	startyrjob71	ne	.	&	startmojob71	ne	.	then	startcontmo71	=	((startyrjob71	-1980)*12)	+	startmojob71	;
startcontmo72	=	.;	if	startyrjob72	ne	.	&	startmojob72	ne	.	then	startcontmo72	=	((startyrjob72	-1980)*12)	+	startmojob72	;
startcontmo73	=	.;	if	startyrjob73	ne	.	&	startmojob73	ne	.	then	startcontmo73	=	((startyrjob73	-1980)*12)	+	startmojob73	;
startcontmo74	=	.;	if	startyrjob74	ne	.	&	startmojob74	ne	.	then	startcontmo74	=	((startyrjob74	-1980)*12)	+	startmojob74	;
startcontmo75	=	.;	if	startyrjob75	ne	.	&	startmojob75	ne	.	then	startcontmo75	=	((startyrjob75	-1980)*12)	+	startmojob75	;
startcontmo76	=	.;	if	startyrjob76	ne	.	&	startmojob76	ne	.	then	startcontmo76	=	((startyrjob76	-1980)*12)	+	startmojob76	;
startcontmo77	=	.;	if	startyrjob77	ne	.	&	startmojob77	ne	.	then	startcontmo77	=	((startyrjob77	-1980)*12)	+	startmojob77	;
startcontmo78	=	.;	if	startyrjob78	ne	.	&	startmojob78	ne	.	then	startcontmo78	=	((startyrjob78	-1980)*12)	+	startmojob78	;
startcontmo79	=	.;	if	startyrjob79	ne	.	&	startmojob79	ne	.	then	startcontmo79	=	((startyrjob79	-1980)*12)	+	startmojob79	;

endbyst71	= .; if	S6260800	ge 0 &	S6260800	le 1 then	endbyst71	=	S6260800	;
endbyst72	= .; if	S6260900	ge 0 &	S6260900	le 1 then	endbyst72	=	S6260900	;
endbyst73	= .; if	S6261000	ge 0 &	S6261000	le 1 then	endbyst73	=	S6261000	;
endbyst74	= .; if	S6261100	ge 0 &	S6261100	le 1 then	endbyst74	=	S6261100	;
endbyst75	= .; if	S6261200	ge 0 &	S6261200	le 1 then	endbyst75	=	S6261200	;
endbyst76	= .; if	S6261300	ge 0 &	S6261300	le 1 then	endbyst76	=	S6261300	;
endbyst77	= .; if	S6261400	ge 0 &	S6261400	le 1 then	endbyst77	=	S6261400	;
endbyst78	= .; if	S6261500	ge 0 &	S6261500	le 1 then	endbyst78	=	S6261500	;
endbyst79	= .; if	S6261600	ge 0 &	S6261600	le 1 then	endbyst79	=	S6261600	;

jobsat71	= .;	if	S6222100	>= 1 and	S6222100	<= 5 then 	jobsat71	=	S6222100	;
jobsat72	= .;	if	S6222200	>= 1 and	S6222200	<= 5 then 	jobsat72	=	S6222200	;
jobsat73	= .;	if	S6222300	>= 1 and	S6222300	<= 5 then 	jobsat73	=	S6222300	;
jobsat74	= .;	if	S6222400	>= 1 and	S6222400	<= 5 then 	jobsat74	=	S6222400	;
jobsat75	= .;	if	S6222500	>= 1 and	S6222500	<= 5 then 	jobsat75	=	S6222500	;
jobsat76	= .;	if	S6222600	>= 1 and	S6222600	<= 5 then 	jobsat76	=	S6222600	;
jobsat77	= .;	if	S6222700	>= 1 and	S6222700	<= 5 then 	jobsat77	=	S6222700	;
jobsat78	= .;	if	S6222800	>= 1 and	S6222800	<= 5 then 	jobsat78	=	S6222800	;
jobsat79	= .;	if	S6222900	>= 1 and	S6222900	<= 5 then 	jobsat79	=	S6222900	;

union71	= .;	if	S6209000	>= 0 and	S6209000	<= 1 then 	union71	=	S6209000	;
union72	= .;	if	S6209100	>= 0 and	S6209100	<= 1 then 	union72	=	S6209100	;
union73	= .;	if	S6209200	>= 0 and	S6209200	<= 1 then 	union73	=	S6209200	;
union74	= .;	if	S6209300	>= 0 and	S6209300	<= 1 then 	union74	=	S6209300	;
union75	= .;	if	S6209400	>= 0 and	S6209400	<= 1 then 	union75	=	S6209400	;
union76	= .;	if	S6209500	>= 0 and	S6209500	<= 1 then 	union76	=	S6209500	;
union77	= .;	if	S6209600	>= 0 and	S6209600	<= 1 then 	union77	=	S6209600	;
union78	= .;	if	S6209700	>= 0 and	S6209700	<= 1 then 	union78	=	S6209700	;
union79	= .;	if	S6209800	>= 0 and	S6209800	<= 1 then 	union79	=	S6209800	;

ben_med71	= .;	if	S6198502	>= 0 and	S6198502	<= 1 then 	ben_med71	=	S6198502	;
ben_med72	= .;	if	S6198602	>= 0 and	S6198602	<= 1 then 	ben_med72	=	S6198602	;
ben_med73	= .;	if	S6198702	>= 0 and	S6198702	<= 1 then 	ben_med73	=	S6198702	;
ben_med74	= .;	if	S6198802	>= 0 and	S6198802	<= 1 then 	ben_med74	=	S6198802	;
ben_med75	= .;	if	S6198902	>= 0 and	S6198902	<= 1 then 	ben_med75	=	S6198902	;
ben_med76	= .;	if	S6199002	>= 0 and	S6199002	<= 1 then 	ben_med76	=	S6199002	;
ben_med77	= .;	if	S6199102	>= 0 and	S6199102	<= 1 then 	ben_med77	=	S6199102	;
ben_med78	= .;	if	S6199202	>= 0 and	S6199202	<= 1 then 	ben_med78	=	S6199202	;
ben_med79	= .;	if	S6199302	>= 0 and	S6199302	<= 1 then 	ben_med79	=	S6199302	;

ben_flex71	= .;	if	S6198501	>= 0 and	S6198501	<= 1 then 	ben_flex71	=	S6198501	;
ben_flex72	= .;	if	S6198601	>= 0 and	S6198601	<= 1 then 	ben_flex72	=	S6198601	;
ben_flex73	= .;	if	S6198701	>= 0 and	S6198701	<= 1 then 	ben_flex73	=	S6198701	;
ben_flex74	= .;	if	S6198801	>= 0 and	S6198801	<= 1 then 	ben_flex74	=	S6198801	;
ben_flex75	= .;	if	S6198901	>= 0 and	S6198901	<= 1 then 	ben_flex75	=	S6198901	;
ben_flex76	= .;	if	S6199001	>= 0 and	S6199001	<= 1 then 	ben_flex76	=	S6199001	;
ben_flex77	= .;	if	S6199101	>= 0 and	S6199101	<= 1 then 	ben_flex77	=	S6199101	;
ben_flex78	= .;	if	S6199201	>= 0 and	S6199201	<= 1 then 	ben_flex78	=	S6199201	;
ben_flex79	= .;	if	S6199301	>= 0 and	S6199301	<= 1 then 	ben_flex79	=	S6199301	;

ben_life71	= .;	if	S6198503	>= 0 and	S6198503	<= 1 then 	ben_life71	=	S6198503	;
ben_life72	= .;	if	S6198603	>= 0 and	S6198603	<= 1 then 	ben_life72	=	S6198603	;
ben_life73	= .;	if	S6198703	>= 0 and	S6198703	<= 1 then 	ben_life73	=	S6198703	;
ben_life74	= .;	if	S6198803	>= 0 and	S6198803	<= 1 then 	ben_life74	=	S6198803	;
ben_life75	= .;	if	S6198903	>= 0 and	S6198903	<= 1 then 	ben_life75	=	S6198903	;
ben_life76	= .;	if	S6199003	>= 0 and	S6199003	<= 1 then 	ben_life76	=	S6199003	;
ben_life77	= .;	if	S6199103	>= 0 and	S6199103	<= 1 then 	ben_life77	=	S6199103	;
ben_life78	= .;	if	S6199203	>= 0 and	S6199203	<= 1 then 	ben_life78	=	S6199203	;
ben_life79	= .;	if	S6199303	>= 0 and	S6199303	<= 1 then 	ben_life79	=	S6199303	;

ben_dental71	= .;	if	S6198504	>= 0 and	S6198504	<= 1 then 	ben_dental71	=	S6198504	;
ben_dental72	= .;	if	S6198604	>= 0 and	S6198604	<= 1 then 	ben_dental72	=	S6198604	;
ben_dental73	= .;	if	S6198704	>= 0 and	S6198704	<= 1 then 	ben_dental73	=	S6198704	;
ben_dental74	= .;	if	S6198804	>= 0 and	S6198804	<= 1 then 	ben_dental74	=	S6198804	;
ben_dental75	= .;	if	S6198904	>= 0 and	S6198904	<= 1 then 	ben_dental75	=	S6198904	;
ben_dental76	= .;	if	S6199004	>= 0 and	S6199004	<= 1 then 	ben_dental76	=	S6199004	;
ben_dental77	= .;	if	S6199104	>= 0 and	S6199104	<= 1 then 	ben_dental77	=	S6199104	;
ben_dental78	= .;	if	S6199204	>= 0 and	S6199204	<= 1 then 	ben_dental78	=	S6199204	;
ben_dental79	= .;	if	S6199304	>= 0 and	S6199304	<= 1 then 	ben_dental79	=	S6199304	;

ben_pdleave71	= .;	if	S6198505	>= 0 and	S6198505	<= 1 then 	ben_pdleave71	=	S6198505	;
ben_pdleave72	= .;	if	S6198605	>= 0 and	S6198605	<= 1 then 	ben_pdleave72	=	S6198605	;
ben_pdleave73	= .;	if	S6198705	>= 0 and	S6198705	<= 1 then 	ben_pdleave73	=	S6198705	;
ben_pdleave74	= .;	if	S6198805	>= 0 and	S6198805	<= 1 then 	ben_pdleave74	=	S6198805	;
ben_pdleave75	= .;	if	S6198905	>= 0 and	S6198905	<= 1 then 	ben_pdleave75	=	S6198905	;
ben_pdleave76	= .;	if	S6199005	>= 0 and	S6199005	<= 1 then 	ben_pdleave76	=	S6199005	;
ben_pdleave77	= .;	if	S6199105	>= 0 and	S6199105	<= 1 then 	ben_pdleave77	=	S6199105	;
ben_pdleave78	= .;	if	S6199205	>= 0 and	S6199205	<= 1 then 	ben_pdleave78	=	S6199205	;
ben_pdleave79	= .;	if	S6199305	>= 0 and	S6199305	<= 1 then 	ben_pdleave79	=	S6199305	;

ben_unpdleave71	= .;	if	S6198506	>= 0 and	S6198506	<= 1 then 	ben_unpdleave71	=	S6198506	;
ben_unpdleave72	= .;	if	S6198606	>= 0 and	S6198606	<= 1 then 	ben_unpdleave72	=	S6198606	;
ben_unpdleave73	= .;	if	S6198706	>= 0 and	S6198706	<= 1 then 	ben_unpdleave73	=	S6198706	;
ben_unpdleave74	= .;	if	S6198806	>= 0 and	S6198806	<= 1 then 	ben_unpdleave74	=	S6198806	;
ben_unpdleave75	= .;	if	S6198906	>= 0 and	S6198906	<= 1 then 	ben_unpdleave75	=	S6198906	;
ben_unpdleave76	= .;	if	S6199006	>= 0 and	S6199006	<= 1 then 	ben_unpdleave76	=	S6199006	;
ben_unpdleave77	= .;	if	S6199106	>= 0 and	S6199106	<= 1 then 	ben_unpdleave77	=	S6199106	;
ben_unpdleave78	= .;	if	S6199206	>= 0 and	S6199206	<= 1 then 	ben_unpdleave78	=	S6199206	;
ben_unpdleave79	= .;	if	S6199306	>= 0 and	S6199306	<= 1 then 	ben_unpdleave79	=	S6199306	;

ben_retire71	= .;	if	S6198507	>= 0 and	S6198507	<= 1 then 	ben_retire71	=	S6198507	;
ben_retire72	= .;	if	S6198607	>= 0 and	S6198607	<= 1 then 	ben_retire72	=	S6198607	;
ben_retire73	= .;	if	S6198707	>= 0 and	S6198707	<= 1 then 	ben_retire73	=	S6198707	;
ben_retire74	= .;	if	S6198807	>= 0 and	S6198807	<= 1 then 	ben_retire74	=	S6198807	;
ben_retire75	= .;	if	S6198907	>= 0 and	S6198907	<= 1 then 	ben_retire75	=	S6198907	;
ben_retire76	= .;	if	S6199007	>= 0 and	S6199007	<= 1 then 	ben_retire76	=	S6199007	;
ben_retire77	= .;	if	S6199107	>= 0 and	S6199107	<= 1 then 	ben_retire77	=	S6199107	;
ben_retire78	= .;	if	S6199207	>= 0 and	S6199207	<= 1 then 	ben_retire78	=	S6199207	;
ben_retire79	= .;	if	S6199307	>= 0 and	S6199307	<= 1 then 	ben_retire79	=	S6199307	;

ben_tuition71	= .;	if	S6198508	>= 0 and	S6198508	<= 1 then 	ben_tuition71	=	S6198508	;
ben_tuition72	= .;	if	S6198608	>= 0 and	S6198608	<= 1 then 	ben_tuition72	=	S6198608	;
ben_tuition73	= .;	if	S6198708	>= 0 and	S6198708	<= 1 then 	ben_tuition73	=	S6198708	;
ben_tuition74	= .;	if	S6198808	>= 0 and	S6198808	<= 1 then 	ben_tuition74	=	S6198808	;
ben_tuition75	= .;	if	S6198908	>= 0 and	S6198908	<= 1 then 	ben_tuition75	=	S6198908	;
ben_tuition76	= .;	if	S6199008	>= 0 and	S6199008	<= 1 then 	ben_tuition76	=	S6199008	;
ben_tuition77	= .;	if	S6199108	>= 0 and	S6199108	<= 1 then 	ben_tuition77	=	S6199108	;
ben_tuition78	= .;	if	S6199208	>= 0 and	S6199208	<= 1 then 	ben_tuition78	=	S6199208	;
ben_tuition79	= .;	if	S6199308	>= 0 and	S6199308	<= 1 then 	ben_tuition79	=	S6199308	;

ben_child71	= .;	if	S6198509	>= 0 and	S6198509	<= 1 then 	ben_child71	=	S6198509	;
ben_child72	= .;	if	S6198609	>= 0 and	S6198609	<= 1 then 	ben_child72	=	S6198609	;
ben_child73	= .;	if	S6198709	>= 0 and	S6198709	<= 1 then 	ben_child73	=	S6198709	;
ben_child74	= .;	if	S6198809	>= 0 and	S6198809	<= 1 then 	ben_child74	=	S6198809	;
ben_child75	= .;	if	S6198909	>= 0 and	S6198909	<= 1 then 	ben_child75	=	S6198909	;
ben_child76	= .;	if	S6199009	>= 0 and	S6199009	<= 1 then 	ben_child76	=	S6199009	;
ben_child77	= .;	if	S6199109	>= 0 and	S6199109	<= 1 then 	ben_child77	=	S6199109	;
ben_child78	= .;	if	S6199209	>= 0 and	S6199209	<= 1 then 	ben_child78	=	S6199209	;
ben_child79	= .;	if	S6199309	>= 0 and	S6199309	<= 1 then 	ben_child79	=	S6199309	;

ben_stock71	= .;	if	S6198510	>= 0 and	S6198510	<= 1 then 	ben_stock71	=	S6198510	;
ben_stock72	= .;	if	S6198610	>= 0 and	S6198610	<= 1 then 	ben_stock72	=	S6198610	;
ben_stock73	= .;	if	S6198710	>= 0 and	S6198710	<= 1 then 	ben_stock73	=	S6198710	;
ben_stock74	= .;	if	S6198810	>= 0 and	S6198810	<= 1 then 	ben_stock74	=	S6198810	;
ben_stock75	= .;	if	S6198910	>= 0 and	S6198910	<= 1 then 	ben_stock75	=	S6198910	;
ben_stock76	= .;	if	S6199010	>= 0 and	S6199010	<= 1 then 	ben_stock76	=	S6199010	;
ben_stock77	= .;	if	S6199110	>= 0 and	S6199110	<= 1 then 	ben_stock77	=	S6199110	;
ben_stock78	= .;	if	S6199210	>= 0 and	S6199210	<= 1 then 	ben_stock78	=	S6199210	;
ben_stock79	= .;	if	S6199310	>= 0 and	S6199310	<= 1 then 	ben_stock79	=	S6199310	;

occcode71	= .; if	S6783100	ge 0 and	S6783100	le 9990 then	occcode71	=	S6783100	;
occcode72	= .; if	S6783200	ge 0 and	S6783200	le 9990 then	occcode72	=	S6783200	;
occcode73	= .; if	S6783300	ge 0 and	S6783300	le 9990 then	occcode73	=	S6783300	;
occcode74	= .; if	S6783400	ge 0 and	S6783400	le 9990 then	occcode74	=	S6783400	;
occcode75	= .; if	S6783500	ge 0 and	S6783500	le 9990 then	occcode75	=	S6783500	;
occcode76	= .; if	S6783600	ge 0 and	S6783600	le 9990 then	occcode76	=	S6783600	;
occcode77	= .; if	S6783700	ge 0 and	S6783700	le 9990 then	occcode77	=	S6783700	;
occcode78	= .; if	S6783800	ge 0 and	S6783800	le 9990 then	occcode78	=	S6783800	;
occcode79	= .; if	S6783900	ge 0 and	S6783900	le 9990 then	occcode79	=	S6783900	;

indcode71	= .; if	S6782200	ge 0 and	S6782200	le 9990 then	indcode71	=	S6782200	;
indcode72	= .; if	S6782300	ge 0 and	S6782300	le 9990 then	indcode72	=	S6782300	;
indcode73	= .; if	S6782400	ge 0 and	S6782400	le 9990 then	indcode73	=	S6782400	;
indcode74	= .; if	S6782500	ge 0 and	S6782500	le 9990 then	indcode74	=	S6782500	;
indcode75	= .; if	S6782600	ge 0 and	S6782600	le 9990 then	indcode75	=	S6782600	;
indcode76	= .; if	S6782700	ge 0 and	S6782700	le 9990 then	indcode76	=	S6782700	;
indcode77	= .; if	S6782800	ge 0 and	S6782800	le 9990 then	indcode77	=	S6782800	;
indcode78	= .; if	S6782900	ge 0 and	S6782900	le 9990 then	indcode78	=	S6782900	;
indcode79	= .; if	S6783000	ge 0 and	S6783000	le 9990 then	indcode79	=	S6783000	;

jobtype71	= .; if	S5931500	ge 1 &	S5931500	le 5 then	jobtype71	=	S5931500	;
jobtype72	= .; if	S5931600	ge 1 &	S5931600	le 5 then	jobtype72	=	S5931600	;
jobtype73	= .; if	S5931700	ge 1 &	S5931700	le 5 then	jobtype73	=	S5931700	;
jobtype74	= .; if	S5931800	ge 1 &	S5931800	le 5 then	jobtype74	=	S5931800	;
jobtype75	= .; if	S5931900	ge 1 &	S5931900	le 5 then	jobtype75	=	S5931900	;
jobtype76	= .; if	S5932000	ge 1 &	S5932000	le 5 then	jobtype76	=	S5932000	;
jobtype77	= .; if	S5932100	ge 1 &	S5932100	le 5 then	jobtype77	=	S5932100	;
jobtype78	= .; if	S5932200	ge 1 &	S5932200	le 5 then	jobtype78	=	S5932200	;
jobtype79 = .;

hourswk71	= .; if	S5421801	ge 0 &	S5421801	le 168 then	hourswk71	=	S5421801	;
hourswk72	= .; if	S5421802	ge 0 &	S5421802	le 168 then	hourswk72	=	S5421802	;
hourswk73	= .; if	S5421803	ge 0 &	S5421803	le 168 then	hourswk73	=	S5421803	;
hourswk74	= .; if	S5421804	ge 0 &	S5421804	le 168 then	hourswk74	=	S5421804	;
hourswk75	= .; if	S5421805	ge 0 &	S5421805	le 168 then	hourswk75	=	S5421805	;
hourswk76	= .; if	S5421806	ge 0 &	S5421806	le 168 then	hourswk76	=	S5421806	;
hourswk77	= .; if	S5421807	ge 0 &	S5421807	le 168 then	hourswk77	=	S5421807	;
hourswk78	= .; if	S5421808	ge 0 &	S5421808	le 168 then	hourswk78	=	S5421808	;
hourswk79	= .; if	S5421809	ge 0 &	S5421809	le 168 then	hourswk79	=	S5421809	;

anygap71	= .; if	S6227500	ge -2 &	S6227500	le 0 then	anygap71	=	0	;	if 	S6227500	eq 1 then	anygap71	=	1	;
anygap72	= .; if	S6227600	ge -2 &	S6227600	le 0 then	anygap72	=	0	;	if 	S6227600	eq 1 then	anygap72	=	1	;
anygap73	= .; if	S6227700	ge -2 &	S6227700	le 0 then	anygap73	=	0	;	if 	S6227700	eq 1 then	anygap73	=	1	;
anygap74	= .; if	S6227800	ge -2 &	S6227800	le 0 then	anygap74	=	0	;	if 	S6227800	eq 1 then	anygap74	=	1	;
anygap75	= .; if	S6227900	ge -2 &	S6227900	le 0 then	anygap75	=	0	;	if 	S6227900	eq 1 then	anygap75	=	1	;
anygap76	= .; if	S6228000	ge -2 &	S6228000	le 0 then	anygap76	=	0	;	if 	S6228000	eq 1 then	anygap76	=	1	;
anygap77	= .; if	S6228100	ge -2 &	S6228100	le 0 then	anygap77	=	0	;	if 	S6228100	eq 1 then	anygap77	=	1	;
anygap78	= .; if	S6228200	ge -2 &	S6228200	le 0 then	anygap78	=	0	;	if 	S6228200	eq 1 then	anygap78	=	1	;
anygap79	= .; if	S6228300	ge -2 &	S6228300	le 0 then	anygap79	=	0	;	if 	S6228300	eq 1 then	anygap79	=	1	;

worksched71	= .; if	S6197600	ge 1 &	S6197600	le 9 then	worksched71	=	S6197600	;
worksched72	= .; if	S6197700	ge 1 &	S6197700	le 9 then	worksched72	=	S6197700	;
worksched73	= .; if	S6197800	ge 1 &	S6197800	le 9 then	worksched73	=	S6197800	;
worksched74	= .; if	S6197900	ge 1 &	S6197900	le 9 then	worksched74	=	S6197900	;
worksched75	= .; if	S6198000	ge 1 &	S6198000	le 9 then	worksched75	=	S6198000	;
worksched76	= .; if	S6198100	ge 1 &	S6198100	le 9 then	worksched76	=	S6198100	;
worksched77	= .; if	S6198200	ge 1 &	S6198200	le 9 then	worksched77	=	S6198200	;
worksched78	= .; if	S6198300	ge 1 &	S6198300	le 9 then	worksched78	=	S6198300	;
worksched79	= .; if	S6198400	ge 1 &	S6198400	le 9 then	worksched79	=	S6198400	;

/* 2006: up to 9 ************************************************************/

idjob80	= .; if (S8890800 >= 0 & S8890800 <= 300000) then idjob80 =	S8890800;
idjob81	= .; if (S8890900 >= 0 & S8890900 <= 300000) then idjob81 =	S8890900;
idjob82	= .; if (S8891000 >= 0 & S8891000 <= 300000) then idjob82 =	S8891000;
idjob83	= .; if (S8891100 >= 0 & S8891100 <= 300000) then idjob83 =	S8891100;
idjob84	= .; if (S8891200 >= 0 & S8891200 <= 300000) then idjob84 =	S8891200;
idjob85	= .; if (S8891300 >= 0 & S8891300 <= 300000) then idjob85 =	S8891300;
idjob86	= .; if (S8891400 >= 0 & S8891400 <= 300000) then idjob86 =	S8891400;
idjob87	= .; if (S8891500 >= 0 & S8891500 <= 300000) then idjob87 =	S8891500;
idjob88	= .; if (S8891600 >= 0 & S8891600 <= 300000) then idjob88 =	S8891600;

whyleftjob80 = .; if (S8209100	>= 0 & S8209100	<= 50) then	whyleftjob80 =	S8209100;
whyleftjob81 = .; if (S8209200	>= 0 & S8209200	<= 50) then	whyleftjob81 =	S8209200;
whyleftjob82 = .; if (S8209300	>= 0 & S8209300	<= 50) then	whyleftjob82 =	S8209300;
whyleftjob83 = .; if (S8209400	>= 0 & S8209400	<= 50) then	whyleftjob83 =	S8209400;
whyleftjob84 = .; if (S8209500	>= 0 & S8209500	<= 50) then	whyleftjob84 =	S8209500;
whyleftjob85 = .; if (S8209600	>= 0 & S8209600	<= 50) then	whyleftjob85 =	S8209600;
whyleftjob86 = .; if (S8209700	>= 0 & S8209700	<= 50) then	whyleftjob86 =	S8209700;
whyleftjob87 = .; if (S8209800	>= 0 & S8209800	<= 50) then	whyleftjob87 =	S8209800;
whyleftjob88 = .; if (S8209900	>= 0 & S8209900	<= 50) then	whyleftjob88 =	S8209900;

curjob80	= .; if	S8828200	>= 0 &	S8828200	<= 1 then	curjob80	=	S8828200	;
curjob81	= .; if	S8828300	>= 0 &	S8828300	<= 1 then	curjob81	=	S8828300	;
curjob82	= .; if	S8828400	>= 0 &	S8828400	<= 1 then	curjob82	=	S8828400	;
curjob83	= .; if	S8828500	>= 0 &	S8828500	<= 1 then	curjob83	=	S8828500	;
curjob84	= .; if	S8828600	>= 0 &	S8828600	<= 1 then	curjob84	=	S8828600	;
curjob85	= .; if	S8828700	>= 0 &	S8828700	<= 1 then	curjob85	=	S8828700	;
curjob86	= .; if	S8828800	>= 0 &	S8828800	<= 1 then	curjob86	=	S8828800	;
curjob87	= .; if	S8828900	>= 0 &	S8828900	<= 1 then	curjob87	=	S8828900	;
curjob88	= .; if	S8829000	>= 0 &	S8829000	<= 1 then	curjob88	=	S8829000	;

intmo80	= S7524000;
intmo81	= S7524000;
intmo82	= S7524000;
intmo83	= S7524000;
intmo84	= S7524000;
intmo85	= S7524000;
intmo86	= S7524000;
intmo87	= S7524000;
intmo88	= S7524000;

weeksjob80 = .;	if (S7537800 >= 0 &	S7537800 <= 5000) then weeksjob80 =	S7537800;
weeksjob81 = .;	if (S7537900 >= 0 &	S7537900 <= 5000) then weeksjob81 =	S7537900;
weeksjob82 = .;	if (S7538000 >= 0 &	S7538000 <= 5000) then weeksjob82 =	S7538000;
weeksjob83 = .;	if (S7538100 >= 0 &	S7538100 <= 5000) then weeksjob83 =	S7538100;
weeksjob84 = .;	if (S7538200 >= 0 &	S7538200 <= 5000) then weeksjob84 =	S7538200;
weeksjob85 = .;	if (S7538300 >= 0 &	S7538300 <= 5000) then weeksjob85 =	S7538300;
weeksjob86 = .;	if (S7538400 >= 0 &	S7538400 <= 5000) then weeksjob86 =	S7538400;
weeksjob87 = .;	if (S7538500 >= 0 &	S7538500 <= 5000) then weeksjob87 =	S7538500;
weeksjob88 = .;	if (S7538600 >= 0 &	S7538600 <= 5000) then weeksjob88 =	S7538600;

startmojob80	=	.;	if	S8862201	>=	0	&	S8862201	<=	12	then	startmojob80	=	S8862201	;			
startmojob81	=	.;	if	S8862301	>=	0	&	S8862301	<=	12	then	startmojob81	=	S8862301	;			
startmojob82	=	.;	if	S8862401	>=	0	&	S8862401	<=	12	then	startmojob82	=	S8862401	;			
startmojob83	=	.;	if	S8862501	>=	0	&	S8862501	<=	12	then	startmojob83	=	S8862501	;			
startmojob84	=	.;	if	S8862601	>=	0	&	S8862601	<=	12	then	startmojob84	=	S8862601	;			
startmojob85	=	.;	if	S8862701	>=	0	&	S8862701	<=	12	then	startmojob85	=	S8862701	;			
startmojob86	=	.;	if	S8862801	>=	0	&	S8862801	<=	12	then	startmojob86	=	S8862801	;			
startmojob87	=	.;	if	S8862901	>=	0	&	S8862901	<=	12	then	startmojob87	=	S8862901	;			
startmojob88	=	.;	if	S8863001	>=	0	&	S8863001	<=	12	then	startmojob88	=	S8863001	;			
																		
startyrjob80	=	.;	if	S8862202	>=	1980	&	S8862202	<=	2050	then	startyrjob80	=	S8862202	;			
startyrjob81	=	.;	if	S8862302	>=	1980	&	S8862302	<=	2050	then	startyrjob81	=	S8862302	;			
startyrjob82	=	.;	if	S8862402	>=	1980	&	S8862402	<=	2050	then	startyrjob82	=	S8862402	;			
startyrjob83	=	.;	if	S8862502	>=	1980	&	S8862502	<=	2050	then	startyrjob83	=	S8862502	;			
startyrjob84	=	.;	if	S8862602	>=	1980	&	S8862602	<=	2050	then	startyrjob84	=	S8862602	;			
startyrjob85	=	.;	if	S8862702	>=	1980	&	S8862702	<=	2050	then	startyrjob85	=	S8862702	;			
startyrjob86	=	.;	if	S8862802	>=	1980	&	S8862802	<=	2050	then	startyrjob86	=	S8862802	;			
startyrjob87	=	.;	if	S8862902	>=	1980	&	S8862902	<=	2050	then	startyrjob87	=	S8862902	;			
startyrjob88	=	.;	if	S8863002	>=	1980	&	S8863002	<=	2050	then	startyrjob88	=	S8863002	;			
																		
startcontmo80	=	.;	if	startyrjob80	ne	.	&	startmojob80	ne	.	then	startcontmo80	=	((startyrjob80	-1980)*12)	+	startmojob80	;
startcontmo81	=	.;	if	startyrjob81	ne	.	&	startmojob81	ne	.	then	startcontmo81	=	((startyrjob81	-1980)*12)	+	startmojob81	;
startcontmo82	=	.;	if	startyrjob82	ne	.	&	startmojob82	ne	.	then	startcontmo82	=	((startyrjob82	-1980)*12)	+	startmojob82	;
startcontmo83	=	.;	if	startyrjob83	ne	.	&	startmojob83	ne	.	then	startcontmo83	=	((startyrjob83	-1980)*12)	+	startmojob83	;
startcontmo84	=	.;	if	startyrjob84	ne	.	&	startmojob84	ne	.	then	startcontmo84	=	((startyrjob84	-1980)*12)	+	startmojob84	;
startcontmo85	=	.;	if	startyrjob85	ne	.	&	startmojob85	ne	.	then	startcontmo85	=	((startyrjob85	-1980)*12)	+	startmojob85	;
startcontmo86	=	.;	if	startyrjob86	ne	.	&	startmojob86	ne	.	then	startcontmo86	=	((startyrjob86	-1980)*12)	+	startmojob86	;
startcontmo87	=	.;	if	startyrjob87	ne	.	&	startmojob87	ne	.	then	startcontmo87	=	((startyrjob87	-1980)*12)	+	startmojob87	;
startcontmo88	=	.;	if	startyrjob88	ne	.	&	startmojob88	ne	.	then	startcontmo88	=	((startyrjob88	-1980)*12)	+	startmojob88	;

endbyst80	= .; if	S8278100	ge 0 &	S8278100	le 1 then	endbyst80	=	S8278100	;
endbyst81	= .; if	S8278200	ge 0 &	S8278200	le 1 then	endbyst81	=	S8278200	;
endbyst82	= .; if	S8278300	ge 0 &	S8278300	le 1 then	endbyst82	=	S8278300	;
endbyst83	= .; if	S8278400	ge 0 &	S8278400	le 1 then	endbyst83	=	S8278400	;
endbyst84	= .; if	S8278500	ge 0 &	S8278500	le 1 then	endbyst84	=	S8278500	;
endbyst85	= .; if	S8278600	ge 0 &	S8278600	le 1 then	endbyst85	=	S8278600	;
endbyst86	= .; if	S8278700	ge 0 &	S8278700	le 1 then	endbyst86	=	S8278700	;
endbyst87	= .; if	S8278800	ge 0 &	S8278800	le 1 then	endbyst87	=	S8278800	;
endbyst88	= .; if	S8278900	ge 0 &	S8278900	le 1 then	endbyst88	=	S8278900	;

/* No employer 8 - job 87 */

jobsat80	= .;	if	S8241400	>= 1 and	S8241400	<= 5 then 	jobsat80	=	S8241400	;
jobsat81	= .;	if	S8241500	>= 1 and	S8241500	<= 5 then 	jobsat81	=	S8241500	;
jobsat82	= .;	if	S8241600	>= 1 and	S8241600	<= 5 then 	jobsat82	=	S8241600	;
jobsat83	= .;	if	S8241700	>= 1 and	S8241700	<= 5 then 	jobsat83	=	S8241700	;
jobsat84	= .;	if	S8241800	>= 1 and	S8241800	<= 5 then 	jobsat84	=	S8241800	;
jobsat85	= .;	if	S8241900	>= 1 and	S8241900	<= 5 then 	jobsat85	=	S8241900	;
jobsat86	= .;	if	S8242000	>= 1 and	S8242000	<= 5 then 	jobsat86	=	S8242000	;
jobsat87	= .;									
jobsat88	= .;	if	S8242100	>= 1 and	S8242100	<= 5 then 	jobsat88	=	S8242100	;

union80	= .;	if	S8231400	>= 0 and	S8231400	<= 1 then 	union80	=	S8231400	;
union81	= .;	if	S8231500	>= 0 and	S8231500	<= 1 then 	union81	=	S8231500	;
union82	= .;	if	S8231600	>= 0 and	S8231600	<= 1 then 	union82	=	S8231600	;
union83	= .;	if	S8231700	>= 0 and	S8231700	<= 1 then 	union83	=	S8231700	;
union84	= .;	if	S8231800	>= 0 and	S8231800	<= 1 then 	union84	=	S8231800	;
union85	= .;	if	S8231900	>= 0 and	S8231900	<= 1 then 	union85	=	S8231900	;
union86	= .;	if	S8232000	>= 0 and	S8232000	<= 1 then 	union86	=	S8232000	;
union87	= .;									
union88	= .;	if	S8232100	>= 0 and	S8232100	<= 1 then 	union88	=	S8232100	;

ben_med80	= .;	if	S8222202	>= 0 and	S8222202	<= 1 then 	ben_med80	=	S8222202	;
ben_med81	= .;	if	S8222302	>= 0 and	S8222302	<= 1 then 	ben_med81	=	S8222302	;
ben_med82	= .;	if	S8222402	>= 0 and	S8222402	<= 1 then 	ben_med82	=	S8222402	;
ben_med83	= .;	if	S8222502	>= 0 and	S8222502	<= 1 then 	ben_med83	=	S8222502	;
ben_med84	= .;	if	S8222602	>= 0 and	S8222602	<= 1 then 	ben_med84	=	S8222602	;
ben_med85	= .;	if	S8222702	>= 0 and	S8222702	<= 1 then 	ben_med85	=	S8222702	;
ben_med86	= .;	if	S8222802	>= 0 and	S8222802	<= 1 then 	ben_med86	=	S8222802	;
ben_med87	= .;		
ben_med88	= .;	if	S8222902	>= 0 and	S8222902	<= 1 then 	ben_flex88	=	S8222902	;

ben_flex80	= .;	if	S8222201	>= 0 and	S8222201	<= 1 then 	ben_flex80	=	S8222201	;
ben_flex81	= .;	if	S8222301	>= 0 and	S8222301	<= 1 then 	ben_flex81	=	S8222301	;
ben_flex82	= .;	if	S8222401	>= 0 and	S8222401	<= 1 then 	ben_flex82	=	S8222401	;
ben_flex83	= .;	if	S8222501	>= 0 and	S8222501	<= 1 then 	ben_flex83	=	S8222501	;
ben_flex84	= .;	if	S8222601	>= 0 and	S8222601	<= 1 then 	ben_flex84	=	S8222601	;
ben_flex85	= .;	if	S8222701	>= 0 and	S8222701	<= 1 then 	ben_flex85	=	S8222701	;
ben_flex86	= .;	if	S8222801	>= 0 and	S8222801	<= 1 then 	ben_flex86	=	S8222801	;
ben_flex87	= .;									
ben_flex88	= .;	if	S8222901	>= 0 and	S8222901	<= 1 then 	ben_flex88	=	S8222901	;

ben_life80	= .;	if	S8222203	>= 0 and	S8222203	<= 1 then 	ben_life80	=	S8222203	;
ben_life81	= .;	if	S8222303	>= 0 and	S8222303	<= 1 then 	ben_life81	=	S8222303	;
ben_life82	= .;	if	S8222403	>= 0 and	S8222403	<= 1 then 	ben_life82	=	S8222403	;
ben_life83	= .;	if	S8222503	>= 0 and	S8222503	<= 1 then 	ben_life83	=	S8222503	;
ben_life84	= .;	if	S8222603	>= 0 and	S8222603	<= 1 then 	ben_life84	=	S8222603	;
ben_life85	= .;	if	S8222703	>= 0 and	S8222703	<= 1 then 	ben_life85	=	S8222703	;
ben_life86	= .;	if	S8222803	>= 0 and	S8222803	<= 1 then 	ben_life86	=	S8222803	;
ben_life87	= .;									
ben_life88	= .;	if	S8222903	>= 0 and	S8222903	<= 1 then 	ben_life88	=	S8222903	;

ben_dental80	= .;	if	S8222204	>= 0 and	S8222204	<= 1 then 	ben_dental80	=	S8222204	;
ben_dental81	= .;	if	S8222304	>= 0 and	S8222304	<= 1 then 	ben_dental81	=	S8222304	;
ben_dental82	= .;	if	S8222404	>= 0 and	S8222404	<= 1 then 	ben_dental82	=	S8222404	;
ben_dental83	= .;	if	S8222504	>= 0 and	S8222504	<= 1 then 	ben_dental83	=	S8222504	;
ben_dental84	= .;	if	S8222604	>= 0 and	S8222604	<= 1 then 	ben_dental84	=	S8222604	;
ben_dental85	= .;	if	S8222704	>= 0 and	S8222704	<= 1 then 	ben_dental85	=	S8222704	;
ben_dental86	= .;	if	S8222804	>= 0 and	S8222804	<= 1 then 	ben_dental86	=	S8222804	;
ben_dental87	= .;									
ben_dental88	= .;	if	S8222904	>= 0 and	S8222904	<= 1 then 	ben_dental88	=	S8222904	;

ben_pdleave80	= .;	if	S8222205	>= 0 and	S8222205	<= 1 then 	ben_pdleave80	=	S8222205	;
ben_pdleave81	= .;	if	S8222305	>= 0 and	S8222305	<= 1 then 	ben_pdleave81	=	S8222305	;
ben_pdleave82	= .;	if	S8222405	>= 0 and	S8222405	<= 1 then 	ben_pdleave82	=	S8222405	;
ben_pdleave83	= .;	if	S8222505	>= 0 and	S8222505	<= 1 then 	ben_pdleave83	=	S8222505	;
ben_pdleave84	= .;	if	S8222605	>= 0 and	S8222605	<= 1 then 	ben_pdleave84	=	S8222605	;
ben_pdleave85	= .;	if	S8222705	>= 0 and	S8222705	<= 1 then 	ben_pdleave85	=	S8222705	;
ben_pdleave86	= .;	if	S8222805	>= 0 and	S8222805	<= 1 then 	ben_pdleave86	=	S8222805	;
ben_pdleave87	= .;									
ben_pdleave88	= .;	if	S8222905	>= 0 and	S8222905	<= 1 then 	ben_pdleave88	=	S8222905	;

ben_unpdleave80	= .;	if	S8222206	>= 0 and	S8222206	<= 1 then 	ben_unpdleave80	=	S8222206	;
ben_unpdleave81	= .;	if	S8222306	>= 0 and	S8222306	<= 1 then 	ben_unpdleave81	=	S8222306	;
ben_unpdleave82	= .;	if	S8222406	>= 0 and	S8222406	<= 1 then 	ben_unpdleave82	=	S8222406	;
ben_unpdleave83	= .;	if	S8222506	>= 0 and	S8222506	<= 1 then 	ben_unpdleave83	=	S8222506	;
ben_unpdleave84	= .;	if	S8222606	>= 0 and	S8222606	<= 1 then 	ben_unpdleave84	=	S8222606	;
ben_unpdleave85	= .;	if	S8222706	>= 0 and	S8222706	<= 1 then 	ben_unpdleave85	=	S8222706	;
ben_unpdleave86	= .;	if	S8222806	>= 0 and	S8222806	<= 1 then 	ben_unpdleave86	=	S8222806	;
ben_unpdleave87	= .;									
ben_unpdleave88	= .;	if	S8222906	>= 0 and	S8222906	<= 1 then 	ben_unpdleave88	=	S8222906	;

ben_retire80	= .;	if	S8222207	>= 0 and	S8222207	<= 1 then 	ben_retire80	=	S8222207	;
ben_retire81	= .;	if	S8222307	>= 0 and	S8222307	<= 1 then 	ben_retire81	=	S8222307	;
ben_retire82	= .;	if	S8222407	>= 0 and	S8222407	<= 1 then 	ben_retire82	=	S8222407	;
ben_retire83	= .;	if	S8222507	>= 0 and	S8222507	<= 1 then 	ben_retire83	=	S8222507	;
ben_retire84	= .;	if	S8222607	>= 0 and	S8222607	<= 1 then 	ben_retire84	=	S8222607	;
ben_retire85	= .;	if	S8222707	>= 0 and	S8222707	<= 1 then 	ben_retire85	=	S8222707	;
ben_retire86	= .;	if	S8222807	>= 0 and	S8222807	<= 1 then 	ben_retire86	=	S8222807	;
ben_retire87	= .;									
ben_retire88	= .;	if	S8222907	>= 0 and	S8222907	<= 1 then 	ben_retire88	=	S8222907	;

ben_tuition80	= .;	if	S8222208	>= 0 and	S8222208	<= 1 then 	ben_tuition80	=	S8222208	;
ben_tuition81	= .;	if	S8222308	>= 0 and	S8222308	<= 1 then 	ben_tuition81	=	S8222308	;
ben_tuition82	= .;	if	S8222408	>= 0 and	S8222408	<= 1 then 	ben_tuition82	=	S8222408	;
ben_tuition83	= .;	if	S8222508	>= 0 and	S8222508	<= 1 then 	ben_tuition83	=	S8222508	;
ben_tuition84	= .;	if	S8222608	>= 0 and	S8222608	<= 1 then 	ben_tuition84	=	S8222608	;
ben_tuition85	= .;	if	S8222708	>= 0 and	S8222708	<= 1 then 	ben_tuition85	=	S8222708	;
ben_tuition86	= .;	if	S8222808	>= 0 and	S8222808	<= 1 then 	ben_tuition86	=	S8222808	;
ben_tuition87	= .;								
ben_tuition88	= .;	if	S8222908	>= 0 and	S8222908	<= 1 then 	ben_tuition88	=	S8222908	;

ben_child80	= .;	if	S8222209	>= 0 and	S8222209	<= 1 then 	ben_child80	=	S8222209	;
ben_child81	= .;	if	S8222309	>= 0 and	S8222309	<= 1 then 	ben_child81	=	S8222309	;
ben_child82	= .;	if	S8222409	>= 0 and	S8222409	<= 1 then 	ben_child82	=	S8222409	;
ben_child83	= .;	if	S8222509	>= 0 and	S8222509	<= 1 then 	ben_child83	=	S8222509	;
ben_child84	= .;	if	S8222609	>= 0 and	S8222609	<= 1 then 	ben_child84	=	S8222609	;
ben_child85	= .;	if	S8222709	>= 0 and	S8222709	<= 1 then 	ben_child85	=	S8222709	;
ben_child86	= .;	if	S8222809	>= 0 and	S8222809	<= 1 then 	ben_child86	=	S8222809	;
ben_child87	= .;								
ben_child88	= .;	if	S8222909	>= 0 and	S8222909	<= 1 then 	ben_child88	=	S8222909	;

ben_stock80	= .;	if	S8222210	>= 0 and	S8222210	<= 1 then 	ben_stock80	=	S8222210	;
ben_stock81	= .;	if	S8222310	>= 0 and	S8222310	<= 1 then 	ben_stock81	=	S8222310	;
ben_stock82	= .;	if	S8222410	>= 0 and	S8222410	<= 1 then 	ben_stock82	=	S8222410	;
ben_stock83	= .;	if	S8222510	>= 0 and	S8222510	<= 1 then 	ben_stock83	=	S8222510	;
ben_stock84	= .;	if	S8222610	>= 0 and	S8222610	<= 1 then 	ben_stock84	=	S8222610	;
ben_stock85	= .;	if	S8222710	>= 0 and	S8222710	<= 1 then 	ben_stock85	=	S8222710	;
ben_stock86	= .;	if	S8222810	>= 0 and	S8222810	<= 1 then 	ben_stock86	=	S8222810	;
ben_stock87	= .;								
ben_stock88	= .;	if	S8222910	>= 0 and	S8222910	<= 1 then 	ben_stock88	=	S8222910	;

occcode80	= .; if	S8689700	ge 0 and	S8689700	le 9990 then	occcode80	=	S8689700	;
occcode81	= .; if	S8689800	ge 0 and	S8689800	le 9990 then	occcode81	=	S8689800	;
occcode82	= .; if	S8689900	ge 0 and	S8689900	le 9990 then	occcode82	=	S8689900	;
occcode83	= .; if	S8690000	ge 0 and	S8690000	le 9990 then	occcode83	=	S8690000	;
occcode84	= .; if	S8690100	ge 0 and	S8690100	le 9990 then	occcode84	=	S8690100	;
occcode85	= .; if	S8690200	ge 0 and	S8690200	le 9990 then	occcode85	=	S8690200	;
occcode86	= .; if	S8690300	ge 0 and	S8690300	le 9990 then	occcode86	=	S8690300	;
occcode87	= .; if	S8690400	ge 0 and	S8690400	le 9990 then	occcode87	=	S8690400	;
occcode88	= .; if	S8690500	ge 0 and	S8690500	le 9990 then	occcode88	=	S8690500	;

indcode80	= .; if	S8688800	ge 0 and	S8688800	le 9990 then	indcode80	=	S8688800	;
indcode81	= .; if	S8688900	ge 0 and	S8688900	le 9990 then	indcode81	=	S8688900	;
indcode82	= .; if	S8689000	ge 0 and	S8689000	le 9990 then	indcode82	=	S8689000	;
indcode83	= .; if	S8689100	ge 0 and	S8689100	le 9990 then	indcode83	=	S8689100	;
indcode84	= .; if	S8689200	ge 0 and	S8689200	le 9990 then	indcode84	=	S8689200	;
indcode85	= .; if	S8689300	ge 0 and	S8689300	le 9990 then	indcode85	=	S8689300	;
indcode86	= .; if	S8689400	ge 0 and	S8689400	le 9990 then	indcode86	=	S8689400	;
indcode87	= .; if	S8689500	ge 0 and	S8689500	le 9990 then	indcode87	=	S8689500	;
indcode88	= .; if	S8689600	ge 0 and	S8689600	le 9990 then	indcode88	=	S8689600	;

jobtype80	= .; if	S8009500	ge 1 &	S8009500	le 5 then	jobtype80	=	S8009500	;
jobtype81	= .; if	S8009600	ge 1 &	S8009600	le 5 then	jobtype81	=	S8009600	;
jobtype82	= .; if	S8009700	ge 1 &	S8009700	le 5 then	jobtype82	=	S8009700	;
jobtype83	= .; if	S8009800	ge 1 &	S8009800	le 5 then	jobtype83	=	S8009800	;
jobtype84	= .; if	S8009900	ge 1 &	S8009900	le 5 then	jobtype84	=	S8009900	;
jobtype85	= .; if	S8010000	ge 1 &	S8010000	le 5 then	jobtype85	=	S8010000	;
jobtype86	= .; if	S8010100	ge 1 &	S8010100	le 5 then	jobtype86	=	S8010100	;
jobtype87	= .; if	S8010200	ge 1 &	S8010200	le 5 then	jobtype87	=	S8010200	;
jobtype88	= .; if	S8010300	ge 1 &	S8010300	le 5 then	jobtype88	=	S8010300	;

hourswk80	= .; if	S7523100	ge 0 &	S7523100	le 168 then	hourswk80	=	S7523100	;
hourswk81	= .; if	S7523200	ge 0 &	S7523200	le 168 then	hourswk81	=	S7523200	;
hourswk82	= .; if	S7523300	ge 0 &	S7523300	le 168 then	hourswk82	=	S7523300	;
hourswk83	= .; if	S7523400	ge 0 &	S7523400	le 168 then	hourswk83	=	S7523400	;
hourswk84	= .; if	S7523500	ge 0 &	S7523500	le 168 then	hourswk84	=	S7523500	;
hourswk85	= .; if	S7523600	ge 0 &	S7523600	le 168 then	hourswk85	=	S7523600	;
hourswk86	= .; if	S7523700	ge 0 &	S7523700	le 168 then	hourswk86	=	S7523700	;
hourswk87	= .; if	S7523800	ge 0 &	S7523800	le 168 then	hourswk87	=	S7523800	;
hourswk88	= .; if	S7523900	ge 0 &	S7523900	le 168 then	hourswk88	=	S7523900	;

anygap80	= .; if	S8246200	ge -2 &	S8246200	le 0 then	anygap80	=	0	;	if 	S8246200	eq 1 then	anygap80	=	1	;
anygap81	= .; if	S8246300	ge -2 &	S8246300	le 0 then	anygap81	=	0	;	if 	S8246300	eq 1 then	anygap81	=	1	;
anygap82	= .; if	S8246400	ge -2 &	S8246400	le 0 then	anygap82	=	0	;	if 	S8246400	eq 1 then	anygap82	=	1	;
anygap83	= .; if	S8246500	ge -2 &	S8246500	le 0 then	anygap83	=	0	;	if 	S8246500	eq 1 then	anygap83	=	1	;
anygap84	= .; if	S8246600	ge -2 &	S8246600	le 0 then	anygap84	=	0	;	if 	S8246600	eq 1 then	anygap84	=	1	;
anygap85	= .; if	S8246700	ge -2 &	S8246700	le 0 then	anygap85	=	0	;	if 	S8246700	eq 1 then	anygap85	=	1	;
anygap86	= .; if	S8246800	ge -2 &	S8246800	le 0 then	anygap86	=	0	;	if 	S8246800	eq 1 then	anygap86	=	1	;
anygap87	= .; if	S8246900	ge -2 &	S8246900	le 0 then	anygap87	=	0	;	if 	S8246900	eq 1 then	anygap87	=	1	;
anygap88	= .; if	S8247000	ge -2 &	S8247000	le 0 then	anygap88	=	0	;	if 	S8247000	eq 1 then	anygap88	=	1	;

worksched80	= .; if	S8221400	ge 1 &	S8221400	le 9 then	worksched80	=	S8221400	;
worksched81	= .; if	S8221500	ge 1 &	S8221500	le 9 then	worksched81	=	S8221500	;
worksched82	= .; if	S8221600	ge 1 &	S8221600	le 9 then	worksched82	=	S8221600	;
worksched83	= .; if	S8221700	ge 1 &	S8221700	le 9 then	worksched83	=	S8221700	;
worksched84	= .; if	S8221800	ge 1 &	S8221800	le 9 then	worksched84	=	S8221800	;
worksched85	= .; if	S8221900	ge 1 &	S8221900	le 9 then	worksched85	=	S8221900	;
worksched86	= .; if	S8222000	ge 1 &	S8222000	le 9 then	worksched86	=	S8222000	;
worksched87	= .; 			
worksched88	= .; if	S8222100	ge 1 &	S8222100	le 9 then	worksched88	=	S8222100	;

/* 2007: up to 8 ***********************************************************/

idjob89	= .; if (T1305300 >= 0 & T1305300 <= 300000) then idjob89 =	T1305300;
idjob90	= .; if (T1305400 >= 0 & T1305400 <= 300000) then idjob90 =	T1305400;
idjob91	= .; if (T1305500 >= 0 & T1305500 <= 300000) then idjob91 =	T1305500;
idjob92	= .; if (T1305600 >= 0 & T1305600 <= 300000) then idjob92 =	T1305600;
idjob93	= .; if (T1305700 >= 0 & T1305700 <= 300000) then idjob93 =	T1305700;
idjob94	= .; if (T1305800 >= 0 & T1305800 <= 300000) then idjob94 =	T1305800;
idjob95	= .; if (T1305900 >= 0 & T1305900 <= 300000) then idjob95 =	T1305900;
idjob96	= .; if (T1306000 >= 0 & T1306000 <= 300000) then idjob96 =	T1306000;

whyleftjob89 = .; if (T0616100	>= 0 & T0616100	<= 50) then	whyleftjob89 =	T0616100;
whyleftjob90 = .; if (T0616200	>= 0 & T0616200	<= 50) then	whyleftjob90 =	T0616200;
whyleftjob91 = .; if (T0616300	>= 0 & T0616300	<= 50) then	whyleftjob91 =	T0616300;
whyleftjob92 = .; if (T0616400	>= 0 & T0616400	<= 50) then	whyleftjob92 =	T0616400;
whyleftjob93 = .; if (T0616500	>= 0 & T0616500	<= 50) then	whyleftjob93 =	T0616500;
whyleftjob94 = .; if (T0616600	>= 0 & T0616600	<= 50) then	whyleftjob94 =	T0616600;
whyleftjob95 = .; if (T0616700	>= 0 & T0616700	<= 50) then	whyleftjob95 =	T0616700;
whyleftjob96 = .; if (T0616800	>= 0 & T0616800	<= 50) then	whyleftjob96 =	T0616800;

curjob89	= .; if	T1244500	>= 0 &	T1244500	<= 1 then	curjob89	=	T1244500	;
curjob90	= .; if	T1244600	>= 0 &	T1244600	<= 1 then	curjob90	=	T1244600	;
curjob91	= .; if	T1244700	>= 0 &	T1244700	<= 1 then	curjob91	=	T1244700	;
curjob92	= .; if	T1244800	>= 0 &	T1244800	<= 1 then	curjob92	=	T1244800	;
curjob93	= .; if	T1244900	>= 0 &	T1244900	<= 1 then	curjob93	=	T1244900	;
curjob94	= .; if	T1245000	>= 0 &	T1245000	<= 1 then	curjob94	=	T1245000	;
curjob95	= .; if	T1245100	>= 0 &	T1245100	<= 1 then	curjob95	=	T1245100	;
curjob96	= .; if	T1245200	>= 0 &	T1245200	<= 1 then	curjob96	=	T1245200	;

intmo89	= T0024400;
intmo90	= T0024400;
intmo91	= T0024400;
intmo92	= T0024400;
intmo93	= T0024400;
intmo94	= T0024400;
intmo95	= T0024400;
intmo96	= T0024400;

weeksjob89 = .;	if (T0034400 >= 0 &	T0034400 <= 5000) then weeksjob89 =	T0034400;
weeksjob90 = .;	if (T0034500 >= 0 &	T0034500 <= 5000) then weeksjob90 =	T0034500;
weeksjob91 = .;	if (T0034600 >= 0 &	T0034600 <= 5000) then weeksjob91 =	T0034600;
weeksjob92 = .;	if (T0034700 >= 0 &	T0034700 <= 5000) then weeksjob92 =	T0034700;
weeksjob93 = .;	if (T0034800 >= 0 &	T0034800 <= 5000) then weeksjob93 =	T0034800;
weeksjob94 = .;	if (T0034900 >= 0 &	T0034900 <= 5000) then weeksjob94 =	T0034900;
weeksjob95 = .;	if (T0035000 >= 0 &	T0035000 <= 5000) then weeksjob95 =	T0035000;
weeksjob96 = .;	if (T0035100 >= 0 &	T0035100 <= 5000) then weeksjob96 =	T0035100;

startmojob89	=	.;	if	T1277401	>=	0	&	T1277401	<=	12	then	startmojob89	=	T1277401	;			
startmojob90	=	.;	if	T1277501	>=	0	&	T1277501	<=	12	then	startmojob90	=	T1277501	;			
startmojob91	=	.;	if	T1277601	>=	0	&	T1277601	<=	12	then	startmojob91	=	T1277601	;			
startmojob92	=	.;	if	T1277701	>=	0	&	T1277701	<=	12	then	startmojob92	=	T1277701	;			
startmojob93	=	.;	if	T1277801	>=	0	&	T1277801	<=	12	then	startmojob93	=	T1277801	;			
startmojob94	=	.;	if	T1277901	>=	0	&	T1277901	<=	12	then	startmojob94	=	T1277901	;			
startmojob95	=	.;	if	T1278001	>=	0	&	T1278001	<=	12	then	startmojob95	=	T1278001	;			
startmojob96	=	.;	if	T1278101	>=	0	&	T1278101	<=	12	then	startmojob96	=	T1278101	;			
																		
startyrjob89	=	.;	if	T1277402	>=	1980	&	T1277402	<=	2050	then	startyrjob89	=	T1277402	;			
startyrjob90	=	.;	if	T1277502	>=	1980	&	T1277502	<=	2050	then	startyrjob90	=	T1277502	;			
startyrjob91	=	.;	if	T1277602	>=	1980	&	T1277602	<=	2050	then	startyrjob91	=	T1277602	;			
startyrjob92	=	.;	if	T1277702	>=	1980	&	T1277702	<=	2050	then	startyrjob92	=	T1277702	;			
startyrjob93	=	.;	if	T1277802	>=	1980	&	T1277802	<=	2050	then	startyrjob93	=	T1277802	;			
startyrjob94	=	.;	if	T1277902	>=	1980	&	T1277902	<=	2050	then	startyrjob94	=	T1277902	;			
startyrjob95	=	.;	if	T1278002	>=	1980	&	T1278002	<=	2050	then	startyrjob95	=	T1278002	;			
startyrjob96	=	.;	if	T1278102	>=	1980	&	T1278102	<=	2050	then	startyrjob96	=	T1278102	;			
																		
startcontmo89	=	.;	if	startyrjob89	ne	.	&	startmojob89	ne	.	then	startcontmo89	=	((startyrjob89	-1980)*12)	+	startmojob89	;
startcontmo90	=	.;	if	startyrjob90	ne	.	&	startmojob90	ne	.	then	startcontmo90	=	((startyrjob90	-1980)*12)	+	startmojob90	;
startcontmo91	=	.;	if	startyrjob91	ne	.	&	startmojob91	ne	.	then	startcontmo91	=	((startyrjob91	-1980)*12)	+	startmojob91	;
startcontmo92	=	.;	if	startyrjob92	ne	.	&	startmojob92	ne	.	then	startcontmo92	=	((startyrjob92	-1980)*12)	+	startmojob92	;
startcontmo93	=	.;	if	startyrjob93	ne	.	&	startmojob93	ne	.	then	startcontmo93	=	((startyrjob93	-1980)*12)	+	startmojob93	;
startcontmo94	=	.;	if	startyrjob94	ne	.	&	startmojob94	ne	.	then	startcontmo94	=	((startyrjob94	-1980)*12)	+	startmojob94	;
startcontmo95	=	.;	if	startyrjob95	ne	.	&	startmojob95	ne	.	then	startcontmo95	=	((startyrjob95	-1980)*12)	+	startmojob95	;
startcontmo96	=	.;	if	startyrjob96	ne	.	&	startmojob96	ne	.	then	startcontmo96	=	((startyrjob96	-1980)*12)	+	startmojob96	;

endbyst89	= .; if	T0691600	ge 0 &	T0691600	le 1 then	endbyst89	=	T0691600	;
endbyst90	= .; if	T0691700	ge 0 &	T0691700	le 1 then	endbyst90	=	T0691700	;
endbyst91	= .; if	T0691800	ge 0 &	T0691800	le 1 then	endbyst91	=	T0691800	;
endbyst92	= .; if	T0691900	ge 0 &	T0691900	le 1 then	endbyst92	=	T0691900	;
endbyst93	= .; if	T0692000	ge 0 &	T0692000	le 1 then	endbyst93	=	T0692000	;
endbyst94	= .; if	T0692100	ge 0 &	T0692100	le 1 then	endbyst94	=	T0692100	;
endbyst95	= .; if	T0692200	ge 0 &	T0692200	le 1 then	endbyst95	=	T0692200	;
endbyst96	= .; if	T0692300	ge 0 &	T0692300	le 1 then	endbyst96	=	T0692300	;

jobsat89	= .;	if	T0653200	>= 1 and	T0653200	<= 5 then 	jobsat89	=	T0653200	;
jobsat90	= .;	if	T0653300	>= 1 and	T0653300	<= 5 then 	jobsat90	=	T0653300	;
jobsat91	= .;	if	T0653400	>= 1 and	T0653400	<= 5 then 	jobsat91	=	T0653400	;
jobsat92	= .;	if	T0653500	>= 1 and	T0653500	<= 5 then 	jobsat92	=	T0653500	;
jobsat93	= .;	if	T0653600	>= 1 and	T0653600	<= 5 then 	jobsat93	=	T0653600	;
jobsat94	= .;	if	T0653700	>= 1 and	T0653700	<= 5 then 	jobsat94	=	T0653700	;
jobsat95	= .;	if	T0653800	>= 1 and	T0653800	<= 5 then 	jobsat95	=	T0653800	;
jobsat96	= .;	if	T0653900	>= 1 and	T0653900	<= 5 then 	jobsat96	=	T0653900	;

union89	= .;	if	T0639200	>= 0 and	T0639200	<= 1 then 	union89	=	T0639200	;
union90	= .;	if	T0639300	>= 0 and	T0639300	<= 1 then 	union90	=	T0639300	;
union91	= .;	if	T0639400	>= 0 and	T0639400	<= 1 then 	union91	=	T0639400	;
union92	= .;	if	T0639500	>= 0 and	T0639500	<= 1 then 	union92	=	T0639500	;
union93	= .;	if	T0639600	>= 0 and	T0639600	<= 1 then 	union93	=	T0639600	;
union94	= .;	if	T0639700	>= 0 and	T0639700	<= 1 then 	union94	=	T0639700	;
union95	= .;	if	T0639800	>= 0 and	T0639800	<= 1 then 	union95	=	T0639800	;
union96	= .;	if	T0639900	>= 0 and	T0639900	<= 1 then 	union96	=	T0639900	;

ben_med89	= .;	if	T0629602	>= 0 and	T0629602	<= 1 then 	ben_med89	=	T0629602	;
ben_med90	= .;	if	T0629702	>= 0 and	T0629702	<= 1 then 	ben_med90	=	T0629702	;
ben_med91	= .;	if	T0629802	>= 0 and	T0629802	<= 1 then 	ben_med91	=	T0629802	;
ben_med92	= .;	if	T0629902	>= 0 and	T0629902	<= 1 then 	ben_med92	=	T0629902	;
ben_med93	= .;	if	T0630002	>= 0 and	T0630002	<= 1 then 	ben_med93	=	T0630002	;
ben_med94	= .;	if	T0630102	>= 0 and	T0630102	<= 1 then 	ben_med94	=	T0630102	;
ben_med95	= .;	if	T0630202	>= 0 and	T0630202	<= 1 then 	ben_med95	=	T0630202	;
ben_med96	= .;	if	T0630302	>= 0 and	T0630302	<= 1 then 	ben_med96	=	T0630302	;

ben_flex89	= .;	if	T0629601	>= 0 and	T0629601	<= 1 then 	ben_flex89	=	T0629601	;
ben_flex90	= .;	if	T0629701	>= 0 and	T0629701	<= 1 then 	ben_flex90	=	T0629701	;
ben_flex91	= .;	if	T0629801	>= 0 and	T0629801	<= 1 then 	ben_flex91	=	T0629801	;
ben_flex92	= .;	if	T0629901	>= 0 and	T0629901	<= 1 then 	ben_flex92	=	T0629901	;
ben_flex93	= .;	if	T0630001	>= 0 and	T0630001	<= 1 then 	ben_flex93	=	T0630001	;
ben_flex94	= .;	if	T0630101	>= 0 and	T0630101	<= 1 then 	ben_flex94	=	T0630101	;
ben_flex95	= .;	if	T0630201	>= 0 and	T0630201	<= 1 then 	ben_flex95	=	T0630201	;
ben_flex96	= .;	if	T0630301	>= 0 and	T0630301	<= 1 then 	ben_flex96	=	T0630301	;

ben_life89	= .;	if	T0629603	>= 0 and	T0629603	<= 1 then 	ben_life89	=	T0629603	;
ben_life90	= .;	if	T0629703	>= 0 and	T0629703	<= 1 then 	ben_life90	=	T0629703	;
ben_life91	= .;	if	T0629803	>= 0 and	T0629803	<= 1 then 	ben_life91	=	T0629803	;
ben_life92	= .;	if	T0629903	>= 0 and	T0629903	<= 1 then 	ben_life92	=	T0629903	;
ben_life93	= .;	if	T0630003	>= 0 and	T0630003	<= 1 then 	ben_life93	=	T0630003	;
ben_life94	= .;	if	T0630103	>= 0 and	T0630103	<= 1 then 	ben_life94	=	T0630103	;
ben_life95	= .;	if	T0630203	>= 0 and	T0630203	<= 1 then 	ben_life95	=	T0630203	;
ben_life96	= .;	if	T0630303	>= 0 and	T0630303	<= 1 then 	ben_life96	=	T0630303	;

ben_dental89	= .;	if	T0629604	>= 0 and	T0629604	<= 1 then 	ben_dental89	=	T0629604	;
ben_dental90	= .;	if	T0629704	>= 0 and	T0629704	<= 1 then 	ben_dental90	=	T0629704	;
ben_dental91	= .;	if	T0629804	>= 0 and	T0629804	<= 1 then 	ben_dental91	=	T0629804	;
ben_dental92	= .;	if	T0629904	>= 0 and	T0629904	<= 1 then 	ben_dental92	=	T0629904	;
ben_dental93	= .;	if	T0630004	>= 0 and	T0630004	<= 1 then 	ben_dental93	=	T0630004	;
ben_dental94	= .;	if	T0630104	>= 0 and	T0630104	<= 1 then 	ben_dental94	=	T0630104	;
ben_dental95	= .;	if	T0630204	>= 0 and	T0630204	<= 1 then 	ben_dental95	=	T0630204	;
ben_dental96	= .;	if	T0630304	>= 0 and	T0630304	<= 1 then 	ben_dental96	=	T0630304	;

ben_pdleave89	= .;	if	T0629605	>= 0 and	T0629605	<= 1 then 	ben_pdleave89	=	T0629605	;
ben_pdleave90	= .;	if	T0629705	>= 0 and	T0629705	<= 1 then 	ben_pdleave90	=	T0629705	;
ben_pdleave91	= .;	if	T0629805	>= 0 and	T0629805	<= 1 then 	ben_pdleave91	=	T0629805	;
ben_pdleave92	= .;	if	T0629905	>= 0 and	T0629905	<= 1 then 	ben_pdleave92	=	T0629905	;
ben_pdleave93	= .;	if	T0630005	>= 0 and	T0630005	<= 1 then 	ben_pdleave93	=	T0630005	;
ben_pdleave94	= .;	if	T0630105	>= 0 and	T0630105	<= 1 then 	ben_pdleave94	=	T0630105	;
ben_pdleave95	= .;	if	T0630205	>= 0 and	T0630205	<= 1 then 	ben_pdleave95	=	T0630205	;
ben_pdleave96	= .;	if	T0630305	>= 0 and	T0630305	<= 1 then 	ben_pdleave96	=	T0630305	;

ben_unpdleave89	= .;	if	T0629606	>= 0 and	T0629606	<= 1 then 	ben_unpdleave89	=	T0629606	;
ben_unpdleave90	= .;	if	T0629706	>= 0 and	T0629706	<= 1 then 	ben_unpdleave90	=	T0629706	;
ben_unpdleave91	= .;	if	T0629806	>= 0 and	T0629806	<= 1 then 	ben_unpdleave91	=	T0629806	;
ben_unpdleave92	= .;	if	T0629906	>= 0 and	T0629906	<= 1 then 	ben_unpdleave92	=	T0629906	;
ben_unpdleave93	= .;	if	T0630006	>= 0 and	T0630006	<= 1 then 	ben_unpdleave93	=	T0630006	;
ben_unpdleave94	= .;	if	T0630106	>= 0 and	T0630106	<= 1 then 	ben_unpdleave94	=	T0630106	;
ben_unpdleave95	= .;	if	T0630206	>= 0 and	T0630206	<= 1 then 	ben_unpdleave95	=	T0630206	;
ben_unpdleave96	= .;	if	T0630306	>= 0 and	T0630306	<= 1 then 	ben_unpdleave96	=	T0630306	;

ben_retire89	= .;	if	T0629607	>= 0 and	T0629607	<= 1 then 	ben_retire89	=	T0629607	;
ben_retire90	= .;	if	T0629707	>= 0 and	T0629707	<= 1 then 	ben_retire90	=	T0629707	;
ben_retire91	= .;	if	T0629807	>= 0 and	T0629807	<= 1 then 	ben_retire91	=	T0629807	;
ben_retire92	= .;	if	T0629907	>= 0 and	T0629907	<= 1 then 	ben_retire92	=	T0629907	;
ben_retire93	= .;	if	T0630007	>= 0 and	T0630007	<= 1 then 	ben_retire93	=	T0630007	;
ben_retire94	= .;	if	T0630107	>= 0 and	T0630107	<= 1 then 	ben_retire94	=	T0630107	;
ben_retire95	= .;	if	T0630207	>= 0 and	T0630207	<= 1 then 	ben_retire95	=	T0630207	;
ben_retire96	= .;	if	T0630307	>= 0 and	T0630307	<= 1 then 	ben_retire96	=	T0630307	;

ben_tuition89	= .;	if	T0629608	>= 0 and	T0629608	<= 1 then 	ben_tuition89	=	T0629608	;
ben_tuition90	= .;	if	T0629708	>= 0 and	T0629708	<= 1 then 	ben_tuition90	=	T0629708	;
ben_tuition91	= .;	if	T0629808	>= 0 and	T0629808	<= 1 then 	ben_tuition91	=	T0629808	;
ben_tuition92	= .;	if	T0629908	>= 0 and	T0629908	<= 1 then 	ben_tuition92	=	T0629908	;
ben_tuition93	= .;	if	T0630008	>= 0 and	T0630008	<= 1 then 	ben_tuition93	=	T0630008	;
ben_tuition94	= .;	if	T0630108	>= 0 and	T0630108	<= 1 then 	ben_tuition94	=	T0630108	;
ben_tuition95	= .;	if	T0630208	>= 0 and	T0630208	<= 1 then 	ben_tuition95	=	T0630208	;
ben_tuition96	= .;	if	T0630308	>= 0 and	T0630308	<= 1 then 	ben_tuition96	=	T0630308	;

ben_child89	= .;	if	T0629609	>= 0 and	T0629609	<= 1 then 	ben_child89	=	T0629609	;
ben_child90	= .;	if	T0629709	>= 0 and	T0629709	<= 1 then 	ben_child90	=	T0629709	;
ben_child91	= .;	if	T0629809	>= 0 and	T0629809	<= 1 then 	ben_child91	=	T0629809	;
ben_child92	= .;	if	T0629909	>= 0 and	T0629909	<= 1 then 	ben_child92	=	T0629909	;
ben_child93	= .;	if	T0630009	>= 0 and	T0630009	<= 1 then 	ben_child93	=	T0630009	;
ben_child94	= .;	if	T0630109	>= 0 and	T0630109	<= 1 then 	ben_child94	=	T0630109	;
ben_child95	= .;	if	T0630209	>= 0 and	T0630209	<= 1 then 	ben_child95	=	T0630209	;
ben_child96	= .;	if	T0630309	>= 0 and	T0630309	<= 1 then 	ben_child96	=	T0630309	;

ben_stock89	= .;	if	T0629610	>= 0 and	T0629610	<= 1 then 	ben_stock89	=	T0629610	;
ben_stock90	= .;	if	T0629710	>= 0 and	T0629710	<= 1 then 	ben_stock90	=	T0629710	;
ben_stock91	= .;	if	T0629810	>= 0 and	T0629810	<= 1 then 	ben_stock91	=	T0629810	;
ben_stock92	= .;	if	T0629910	>= 0 and	T0629910	<= 1 then 	ben_stock92	=	T0629910	;
ben_stock93	= .;	if	T0630010	>= 0 and	T0630010	<= 1 then 	ben_stock93	=	T0630010	;
ben_stock94	= .;	if	T0630110	>= 0 and	T0630110	<= 1 then 	ben_stock94	=	T0630110	;
ben_stock95	= .;	if	T0630210	>= 0 and	T0630210	<= 1 then 	ben_stock95	=	T0630210	;
ben_stock96	= .;	if	T0630310	>= 0 and	T0630310	<= 1 then 	ben_stock96	=	T0630310	;

occcode89	= .; if	T1109400	ge 0 and	T1109400	le 9990 then	occcode89	=	T1109400	;
occcode90	= .; if	T1109500	ge 0 and	T1109500	le 9990 then	occcode90	=	T1109500	;
occcode91	= .; if	T1109600	ge 0 and	T1109600	le 9990 then	occcode91	=	T1109600	;
occcode92	= .; if	T1109700	ge 0 and	T1109700	le 9990 then	occcode92	=	T1109700	;
occcode93	= .; if	T1109800	ge 0 and	T1109800	le 9990 then	occcode93	=	T1109800	;
occcode94	= .; if	T1109900	ge 0 and	T1109900	le 9990 then	occcode94	=	T1109900	;
occcode95	= .; if	T1110000	ge 0 and	T1110000	le 9990 then	occcode95	=	T1110000	;
occcode96	= .; if	T1110100	ge 0 and	T1110100	le 9990 then	occcode96	=	T1110100	;

indcode89	= .; if	T1108600	ge 0 and	T1108600	le 9990 then	indcode89	=	T1108600	;
indcode90	= .; if	T1108700	ge 0 and	T1108700	le 9990 then	indcode90	=	T1108700	;
indcode91	= .; if	T1108800	ge 0 and	T1108800	le 9990 then	indcode91	=	T1108800	;
indcode92	= .; if	T1108900	ge 0 and	T1108900	le 9990 then	indcode92	=	T1108900	;
indcode93	= .; if	T1109000	ge 0 and	T1109000	le 9990 then	indcode93	=	T1109000	;
indcode94	= .; if	T1109100	ge 0 and	T1109100	le 9990 then	indcode94	=	T1109100	;
indcode95	= .; if	T1109200	ge 0 and	T1109200	le 9990 then	indcode95	=	T1109200	;
indcode96	= .; if	T1109300	ge 0 and	T1109300	le 9990 then	indcode96	=	T1109300	;

jobtype89	= .; if	T0411500	ge 1 &	T0411500	le 5 then	jobtype89	=	T0411500	;
jobtype90	= .; if	T0411600	ge 1 &	T0411600	le 5 then	jobtype90	=	T0411600	;
jobtype91	= .; if	T0411700	ge 1 &	T0411700	le 5 then	jobtype91	=	T0411700	;
jobtype92	= .; if	T0411800	ge 1 &	T0411800	le 5 then	jobtype92	=	T0411800	;
jobtype93	= .; if	T0411900	ge 1 &	T0411900	le 5 then	jobtype93	=	T0411900	;
jobtype94	= .; if	T0412000	ge 1 &	T0412000	le 5 then	jobtype94	=	T0412000	;
jobtype95	= .; if	T0412100	ge 1 &	T0412100	le 5 then	jobtype95	=	T0412100	;
jobtype96	= .; if	T0412200	ge 1 &	T0412200	le 5 then	jobtype96	=	T0412200	;

hourswk89	= .; if	T0023600	ge 0 &	T0023600	le 168 then	hourswk89	=	T0023600	;
hourswk90	= .; if	T0023700	ge 0 &	T0023700	le 168 then	hourswk90	=	T0023700	;
hourswk91	= .; if	T0023800	ge 0 &	T0023800	le 168 then	hourswk91	=	T0023800	;
hourswk92	= .; if	T0023900	ge 0 &	T0023900	le 168 then	hourswk92	=	T0023900	;
hourswk93	= .; if	T0024000	ge 0 &	T0024000	le 168 then	hourswk93	=	T0024000	;
hourswk94	= .; if	T0024100	ge 0 &	T0024100	le 168 then	hourswk94	=	T0024100	;
hourswk95	= .; if	T0024200	ge 0 &	T0024200	le 168 then	hourswk95	=	T0024200	;
hourswk96	= .; if	T0024300	ge 0 &	T0024300	le 168 then	hourswk96	=	T0024300	;

anygap89	= .; if	T0658000	ge -2 &	T0658000	le 0 then	anygap89	=	0	;	if 	T0658000	eq 1 then	anygap89	=	1	;
anygap90	= .; if	T0658100	ge -2 &	T0658100	le 0 then	anygap90	=	0	;	if 	T0658100	eq 1 then	anygap90	=	1	;
anygap91	= .; if	T0658200	ge -2 &	T0658200	le 0 then	anygap91	=	0	;	if 	T0658200	eq 1 then	anygap91	=	1	;
anygap92	= .; if	T0658300	ge -2 &	T0658300	le 0 then	anygap92	=	0	;	if 	T0658300	eq 1 then	anygap92	=	1	;
anygap93	= .; if	T0658400	ge -2 &	T0658400	le 0 then	anygap93	=	0	;	if 	T0658400	eq 1 then	anygap93	=	1	;
anygap94	= .; if	T0658500	ge -2 &	T0658500	le 0 then	anygap94	=	0	;	if 	T0658500	eq 1 then	anygap94	=	1	;
anygap95	= .; if	T0658600	ge -2 &	T0658600	le 0 then	anygap95	=	0	;	if 	T0658600	eq 1 then	anygap95	=	1	;
anygap96	= .; if	T0658700	ge -2 &	T0658700	le 0 then	anygap96	=	0	;	if 	T0658700	eq 1 then	anygap96	=	1	;

worksched89	= .; if	T0628800	ge 1 &	T0628800	le 9 then	worksched89	=	T0628800	;	
worksched90	= .; if	T0628900	ge 1 &	T0628900	le 9 then	worksched90	=	T0628900	;	
worksched91	= .; if	T0629000	ge 1 &	T0629000	le 9 then	worksched91	=	T0629000	;	
worksched92	= .; if	T0629100	ge 1 &	T0629100	le 9 then	worksched92	=	T0629100	;	
worksched93	= .; if	T0629200	ge 1 &	T0629200	le 9 then	worksched93	=	T0629200	;	
worksched94	= .; if	T0629300	ge 1 &	T0629300	le 9 then	worksched94	=	T0629300	;	
worksched95	= .; if	T0629400	ge 1 &	T0629400	le 9 then	worksched95	=	T0629400	;	
worksched96	= .; if	T0629500	ge 1 &	T0629500	le 9 then	worksched96	=	T0629500	;	

/* 2008: up to 8 ***********************************************************/

idjob97	= .; if (T3394500 >= 0 & T3394500 <= 300000) then idjob97 = T3394500;
idjob98	= .; if (T3394600 >= 0 & T3394600 <= 300000) then idjob98 = T3394600;
idjob99	= .; if (T3394700 >= 0 & T3394700 <= 300000) then idjob99 = T3394700;
idjob100= .; if (T3394800 >= 0 & T3394800 <= 300000) then idjob100 = T3394800;
idjob101 = .; if (T3394900 >= 0 & T3394900 <= 300000) then idjob101	= T3394900;
idjob102 = .; if (T3395000 >= 0 & T3395000 <= 300000) then idjob102	= T3395000;
idjob103 = .; if (T3395100 >= 0 & T3395100 <= 300000) then idjob103	= T3395100;
idjob104 = .; if (T3395200 >= 0 & T3395200 <= 300000) then idjob104	= T3395200;

whyleftjob97 = .; if (T2657200 >= 0 & T2657200 <= 50) then whyleftjob97 = T2657200;
whyleftjob98 = .; if (T2657300 >= 0 & T2657300 <= 50) then whyleftjob98 = T2657300;
whyleftjob99 = .; if (T2657400 >= 0 & T2657400 <= 50) then whyleftjob99 = T2657400;
whyleftjob100 = .; if (T2657500 >= 0 & T2657500 <= 50) then whyleftjob100 = T2657500;
whyleftjob101 = .; if (T2657600 >= 0 & T2657600 <= 50) then whyleftjob101 = T2657600;
whyleftjob102 = .; if (T2657700 >= 0 & T2657700 <= 50) then whyleftjob102 = T2657700;
whyleftjob103 = .; if (T2657800 >= 0 & T2657800 <= 50) then whyleftjob103 = T2657800;
whyleftjob104 = .; if (T2657900 >= 0 & T2657900 <= 50) then whyleftjob104 = T2657900;

curjob97	= .; if	T3330100	>= 0 &	T3330100	<= 1 then	curjob97	=	T3330100	;
curjob98	= .; if	T3330200	>= 0 &	T3330200	<= 1 then	curjob98	=	T3330200	;
curjob99	= .; if	T3330300	>= 0 &	T3330300	<= 1 then	curjob99	=	T3330300	;
curjob100	= .; if	T3330400	>= 0 &	T3330400	<= 1 then	curjob100	=	T3330400	;
curjob101	= .; if	T3330500	>= 0 &	T3330500	<= 1 then	curjob101	=	T3330500	;
curjob102	= .; if	T3330600	>= 0 &	T3330600	<= 1 then	curjob102	=	T3330600	;
curjob103	= .; if	T3330700	>= 0 &	T3330700	<= 1 then	curjob103	=	T3330700	;
curjob104	= .; if	T3330800	>= 0 &	T3330800	<= 1 then	curjob104	=	T3330800	;

intmo97	= T2019300;
intmo98	= T2019300;
intmo99	= T2019300;
intmo100 = T2019300;
intmo101 = T2019300;
intmo102 = T2019300;
intmo103 = T2019300;
intmo104 = T2019300;

weeksjob97 = .;	if (T2021700 >= 0 &	T2021700 <= 5000) then weeksjob97 = T2021700;
weeksjob98 = .;	if (T2021800 >= 0 &	T2021800 <= 5000) then weeksjob98 = T2021800;
weeksjob99 = .;	if (T2021900 >= 0 &	T2021900 <= 5000) then weeksjob99 = T2021900;
weeksjob100	= .; if (T2022000 >= 0 & T2022000 <= 5000) then	weeksjob100	= T2022000;
weeksjob101	= .; if (T2022100 >= 0 & T2022100 <= 5000) then	weeksjob101	= T2022100;
weeksjob102	= .; if (T2022200 >= 0 & T2022200 <= 5000) then	weeksjob102	= T2022200;
weeksjob103	= .; if (T2022300 >= 0 & T2022300 <= 5000) then	weeksjob103	= T2022300;
weeksjob104	= .; if (T2022400 >= 0 & T2022400 <= 5000) then	weeksjob104	= T2022400;

startmojob97	=	.;	if	T3364901	>=	0	&	T3364901	<=	12	then	startmojob97	=	T3364901	;			
startmojob98	=	.;	if	T3365001	>=	0	&	T3365001	<=	12	then	startmojob98	=	T3365001	;			
startmojob99	=	.;	if	T3365101	>=	0	&	T3365101	<=	12	then	startmojob99	=	T3365101	;			
startmojob100	=	.;	if	T3365201	>=	0	&	T3365201	<=	12	then	startmojob100	=	T3365201	;			
startmojob101	=	.;	if	T3365301	>=	0	&	T3365301	<=	12	then	startmojob101	=	T3365301	;			
startmojob102	=	.;	if	T3365401	>=	0	&	T3365401	<=	12	then	startmojob102	=	T3365401	;			
startmojob103	=	.;	if	T3365501	>=	0	&	T3365501	<=	12	then	startmojob103	=	T3365501	;			
startmojob104	=	.;	if	T3365601	>=	0	&	T3365601	<=	12	then	startmojob104	=	T3365601	;			
																		
startyrjob97	=	.;	if	T3364902	>=	1980	&	T3364902	<=	2050	then	startyrjob97	=	T3364902	;			
startyrjob98	=	.;	if	T3365002	>=	1980	&	T3365002	<=	2050	then	startyrjob98	=	T3365002	;			
startyrjob99	=	.;	if	T3365102	>=	1980	&	T3365102	<=	2050	then	startyrjob99	=	T3365102	;			
startyrjob100	=	.;	if	T3365202	>=	1980	&	T3365202	<=	2050	then	startyrjob100	=	T3365202	;			
startyrjob101	=	.;	if	T3365302	>=	1980	&	T3365302	<=	2050	then	startyrjob101	=	T3365302	;			
startyrjob102	=	.;	if	T3365402	>=	1980	&	T3365402	<=	2050	then	startyrjob102	=	T3365402	;			
startyrjob103	=	.;	if	T3365502	>=	1980	&	T3365502	<=	2050	then	startyrjob103	=	T3365502	;			
startyrjob104	=	.;	if	T3365602	>=	1980	&	T3365602	<=	2050	then	startyrjob104	=	T3365602	;			
																		
startcontmo97	=	.;	if	startyrjob97	ne	.	&	startmojob97	ne	.	then	startcontmo97	=	((startyrjob97	-1980)*12)	+	startmojob97	;
startcontmo98	=	.;	if	startyrjob98	ne	.	&	startmojob98	ne	.	then	startcontmo98	=	((startyrjob98	-1980)*12)	+	startmojob98	;
startcontmo99	=	.;	if	startyrjob99	ne	.	&	startmojob99	ne	.	then	startcontmo99	=	((startyrjob99	-1980)*12)	+	startmojob99	;
startcontmo100	=	.;	if	startyrjob100	ne	.	&	startmojob100	ne	.	then	startcontmo100	=	((startyrjob100	-1980)*12)	+	startmojob100	;
startcontmo101	=	.;	if	startyrjob101	ne	.	&	startmojob101	ne	.	then	startcontmo101	=	((startyrjob101	-1980)*12)	+	startmojob101	;
startcontmo102	=	.;	if	startyrjob102	ne	.	&	startmojob102	ne	.	then	startcontmo102	=	((startyrjob102	-1980)*12)	+	startmojob102	;
startcontmo103	=	.;	if	startyrjob103	ne	.	&	startmojob103	ne	.	then	startcontmo103	=	((startyrjob103	-1980)*12)	+	startmojob103	;
startcontmo104	=	.;	if	startyrjob104	ne	.	&	startmojob104	ne	.	then	startcontmo104	=	((startyrjob104	-1980)*12)	+	startmojob104	;

endbyst97	= .; if	T2741300	ge 0 &	T2741300	le 1 then	endbyst97	=	T2741300	;
endbyst98	= .; if	T2741400	ge 0 &	T2741400	le 1 then	endbyst98	=	T2741400	;
endbyst99	= .; if	T2741500	ge 0 &	T2741500	le 1 then	endbyst99	=	T2741500	;
endbyst100	= .; if	T2741600	ge 0 &	T2741600	le 1 then	endbyst100	=	T2741600	;
endbyst101	= .; if	T2741700	ge 0 &	T2741700	le 1 then	endbyst101	=	T2741700	;
endbyst102	= .; if	T2741800	ge 0 &	T2741800	le 1 then	endbyst102	=	T2741800	;
endbyst103	= .; if	T2741900	ge 0 &	T2741900	le 1 then	endbyst103	=	T2741900	;
endbyst104	= .; if	T2742000	ge 0 &	T2742000	le 1 then	endbyst104	=	T2742000	;

jobsat97	= .;	if	T2692700	>= 1 and	T2692700	<= 5 then 	jobsat97	=	T2692700	;
jobsat98	= .;	if	T2692800	>= 1 and	T2692800	<= 5 then 	jobsat98	=	T2692800	;
jobsat99	= .;	if	T2692900	>= 1 and	T2692900	<= 5 then 	jobsat99	=	T2692900	;
jobsat100	= .;	if	T2693000	>= 1 and	T2693000	<= 5 then 	jobsat100	=	T2693000	;
jobsat101	= .;	if	T2693100	>= 1 and	T2693100	<= 5 then 	jobsat101	=	T2693100	;
jobsat102	= .;	if	T2693200	>= 1 and	T2693200	<= 5 then 	jobsat102	=	T2693200	;
jobsat103	= .;	if	T2693300	>= 1 and	T2693300	<= 5 then 	jobsat103	=	T2693300	;
jobsat104	= .;	if	T2693400	>= 1 and	T2693400	<= 5 then 	jobsat104	=	T2693400	;

union97	= .;	if	T2680200	>= 0 and	T2680200	<= 1 then 	union97	=	T2680200	;
union98	= .;	if	T2680300	>= 0 and	T2680300	<= 1 then 	union98	=	T2680300	;
union99	= .;	if	T2680400	>= 0 and	T2680400	<= 1 then 	union99	=	T2680400	;
union100	= .;	if	T2680500	>= 0 and	T2680500	<= 1 then 	union100	=	T2680500	;
union101	= .;	if	T2680600	>= 0 and	T2680600	<= 1 then 	union101	=	T2680600	;
union102	= .;	if	T2680700	>= 0 and	T2680700	<= 1 then 	union102	=	T2680700	;
union103	= .;	if	T2680800	>= 0 and	T2680800	<= 1 then 	union103	=	T2680800	;
union104	= .;	if	T2680900	>= 0 and	T2680900	<= 1 then 	union104	=	T2680900	;

ben_med97	= .;	if	T2670802	>= 0 and	T2670802	<= 1 then 	ben_med97	=	T2670802	;
ben_med98	= .;	if	T2670902	>= 0 and	T2670902	<= 1 then 	ben_med98	=	T2670902	;
ben_med99	= .;	if	T2671002	>= 0 and	T2671002	<= 1 then 	ben_med99	=	T2671002	;
ben_med100	= .;	if	T2671102	>= 0 and	T2671102	<= 1 then 	ben_med100	=	T2671102	;
ben_med101	= .;	if	T2671202	>= 0 and	T2671202	<= 1 then 	ben_med101	=	T2671202	;
ben_med102	= .;	if	T2671302	>= 0 and	T2671302	<= 1 then 	ben_med102	=	T2671302	;
ben_med103	= .;	if	T2671402	>= 0 and	T2671402	<= 1 then 	ben_med103	=	T2671402	;
ben_med104	= .;	if	T2671502	>= 0 and	T2671502	<= 1 then 	ben_med104	=	T2671502	;

ben_flex97	= .;	if	T2670801	>= 0 and	T2670801	<= 1 then 	ben_flex97	=	T2670801	;
ben_flex98	= .;	if	T2670901	>= 0 and	T2670901	<= 1 then 	ben_flex98	=	T2670901	;
ben_flex99	= .;	if	T2671001	>= 0 and	T2671001	<= 1 then 	ben_flex99	=	T2671001	;
ben_flex100	= .;	if	T2671101	>= 0 and	T2671101	<= 1 then 	ben_flex100	=	T2671101	;
ben_flex101	= .;	if	T2671201	>= 0 and	T2671201	<= 1 then 	ben_flex101	=	T2671201	;
ben_flex102	= .;	if	T2671301	>= 0 and	T2671301	<= 1 then 	ben_flex102	=	T2671301	;
ben_flex103	= .;	if	T2671401	>= 0 and	T2671401	<= 1 then 	ben_flex103	=	T2671401	;
ben_flex104	= .;	if	T2671501	>= 0 and	T2671501	<= 1 then 	ben_flex104	=	T2671501	;

ben_life97	= .;	if	T2670803	>= 0 and	T2670803	<= 1 then 	ben_life97	=	T2670803	;
ben_life98	= .;	if	T2670903	>= 0 and	T2670903	<= 1 then 	ben_life98	=	T2670903	;
ben_life99	= .;	if	T2671003	>= 0 and	T2671003	<= 1 then 	ben_life99	=	T2671003	;
ben_life100	= .;	if	T2671103	>= 0 and	T2671103	<= 1 then 	ben_life100	=	T2671103	;
ben_life101	= .;	if	T2671203	>= 0 and	T2671203	<= 1 then 	ben_life101	=	T2671203	;
ben_life102	= .;	if	T2671303	>= 0 and	T2671303	<= 1 then 	ben_life102	=	T2671303	;
ben_life103	= .;	if	T2671403	>= 0 and	T2671403	<= 1 then 	ben_life103	=	T2671403	;
ben_life104	= .;	if	T2671503	>= 0 and	T2671503	<= 1 then 	ben_life104	=	T2671503	;

ben_dental97	= .;	if	T2670804	>= 0 and	T2670804	<= 1 then 	ben_dental97	=	T2670804	;
ben_dental98	= .;	if	T2670904	>= 0 and	T2670904	<= 1 then 	ben_dental98	=	T2670904	;
ben_dental99	= .;	if	T2671004	>= 0 and	T2671004	<= 1 then 	ben_dental99	=	T2671004	;
ben_dental100	= .;	if	T2671104	>= 0 and	T2671104	<= 1 then 	ben_dental100	=	T2671104	;
ben_dental101	= .;	if	T2671204	>= 0 and	T2671204	<= 1 then 	ben_dental101	=	T2671204	;
ben_dental102	= .;	if	T2671304	>= 0 and	T2671304	<= 1 then 	ben_dental102	=	T2671304	;
ben_dental103	= .;	if	T2671404	>= 0 and	T2671404	<= 1 then 	ben_dental103	=	T2671404	;
ben_dental104	= .;	if	T2671504	>= 0 and	T2671504	<= 1 then 	ben_dental104	=	T2671504	;

ben_pdleave97	= .;	if	T2670805	>= 0 and	T2670805	<= 1 then 	ben_pdleave97	=	T2670805	;
ben_pdleave98	= .;	if	T2670905	>= 0 and	T2670905	<= 1 then 	ben_pdleave98	=	T2670905	;
ben_pdleave99	= .;	if	T2671005	>= 0 and	T2671005	<= 1 then 	ben_pdleave99	=	T2671005	;
ben_pdleave100	= .;	if	T2671105	>= 0 and	T2671105	<= 1 then 	ben_pdleave100	=	T2671105	;
ben_pdleave101	= .;	if	T2671205	>= 0 and	T2671205	<= 1 then 	ben_pdleave101	=	T2671205	;
ben_pdleave102	= .;	if	T2671305	>= 0 and	T2671305	<= 1 then 	ben_pdleave102	=	T2671305	;
ben_pdleave103	= .;	if	T2671405	>= 0 and	T2671405	<= 1 then 	ben_pdleave103	=	T2671405	;
ben_pdleave104	= .;	if	T2671505	>= 0 and	T2671505	<= 1 then 	ben_pdleave104	=	T2671505	;

ben_unpdleave97	= .;	if	T2670806	>= 0 and	T2670806	<= 1 then 	ben_unpdleave97	=	T2670806	;
ben_unpdleave98	= .;	if	T2670906	>= 0 and	T2670906	<= 1 then 	ben_unpdleave98	=	T2670906	;
ben_unpdleave99	= .;	if	T2671006	>= 0 and	T2671006	<= 1 then 	ben_unpdleave99	=	T2671006	;
ben_unpdleave100	= .;	if	T2671106	>= 0 and	T2671106	<= 1 then 	ben_unpdleave100	=	T2671106	;
ben_unpdleave101	= .;	if	T2671206	>= 0 and	T2671206	<= 1 then 	ben_unpdleave101	=	T2671206	;
ben_unpdleave102	= .;	if	T2671306	>= 0 and	T2671306	<= 1 then 	ben_unpdleave102	=	T2671306	;
ben_unpdleave103	= .;	if	T2671406	>= 0 and	T2671406	<= 1 then 	ben_unpdleave103	=	T2671406	;
ben_unpdleave104	= .;	if	T2671506	>= 0 and	T2671506	<= 1 then 	ben_unpdleave104	=	T2671506	;

ben_retire97	= .;	if	T2670807	>= 0 and	T2670807	<= 1 then 	ben_retire97	=	T2670807	;
ben_retire98	= .;	if	T2670907	>= 0 and	T2670907	<= 1 then 	ben_retire98	=	T2670907	;
ben_retire99	= .;	if	T2671007	>= 0 and	T2671007	<= 1 then 	ben_retire99	=	T2671007	;
ben_retire100	= .;	if	T2671107	>= 0 and	T2671107	<= 1 then 	ben_retire100	=	T2671107	;
ben_retire101	= .;	if	T2671207	>= 0 and	T2671207	<= 1 then 	ben_retire101	=	T2671207	;
ben_retire102	= .;	if	T2671307	>= 0 and	T2671307	<= 1 then 	ben_retire102	=	T2671307	;
ben_retire103	= .;	if	T2671407	>= 0 and	T2671407	<= 1 then 	ben_retire103	=	T2671407	;
ben_retire104	= .;	if	T2671507	>= 0 and	T2671507	<= 1 then 	ben_retire104	=	T2671507	;

ben_tuition97	= .;	if	T2670808	>= 0 and	T2670808	<= 1 then 	ben_tuition97	=	T2670808	;
ben_tuition98	= .;	if	T2670908	>= 0 and	T2670908	<= 1 then 	ben_tuition98	=	T2670908	;
ben_tuition99	= .;	if	T2671008	>= 0 and	T2671008	<= 1 then 	ben_tuition99	=	T2671008	;
ben_tuition100	= .;	if	T2671108	>= 0 and	T2671108	<= 1 then 	ben_tuition100	=	T2671108	;
ben_tuition101	= .;	if	T2671208	>= 0 and	T2671208	<= 1 then 	ben_tuition101	=	T2671208	;
ben_tuition102	= .;	if	T2671308	>= 0 and	T2671308	<= 1 then 	ben_tuition102	=	T2671308	;
ben_tuition103	= .;	if	T2671408	>= 0 and	T2671408	<= 1 then 	ben_tuition103	=	T2671408	;
ben_tuition104	= .;	if	T2671508	>= 0 and	T2671508	<= 1 then 	ben_tuition104	=	T2671508	;

ben_child97	= .;	if	T2670809	>= 0 and	T2670809	<= 1 then 	ben_child97	=	T2670809	;
ben_child98	= .;	if	T2670909	>= 0 and	T2670909	<= 1 then 	ben_child98	=	T2670909	;
ben_child99	= .;	if	T2671009	>= 0 and	T2671009	<= 1 then 	ben_child99	=	T2671009	;
ben_child100	= .;	if	T2671109	>= 0 and	T2671109	<= 1 then 	ben_child100	=	T2671109	;
ben_child101	= .;	if	T2671209	>= 0 and	T2671209	<= 1 then 	ben_child101	=	T2671209	;
ben_child102	= .;	if	T2671309	>= 0 and	T2671309	<= 1 then 	ben_child102	=	T2671309	;
ben_child103	= .;	if	T2671409	>= 0 and	T2671409	<= 1 then 	ben_child103	=	T2671409	;
ben_child104	= .;	if	T2671509	>= 0 and	T2671509	<= 1 then 	ben_child104	=	T2671509	;

ben_stock97	= .;	if	T2670810	>= 0 and	T2670810	<= 1 then 	ben_stock97	=	T2670810	;
ben_stock98	= .;	if	T2670910	>= 0 and	T2670910	<= 1 then 	ben_stock98	=	T2670910	;
ben_stock99	= .;	if	T2671010	>= 0 and	T2671010	<= 1 then 	ben_stock99	=	T2671010	;
ben_stock100	= .;	if	T2671110	>= 0 and	T2671110	<= 1 then 	ben_stock100	=	T2671110	;
ben_stock101	= .;	if	T2671210	>= 0 and	T2671210	<= 1 then 	ben_stock101	=	T2671210	;
ben_stock102	= .;	if	T2671310	>= 0 and	T2671310	<= 1 then 	ben_stock102	=	T2671310	;
ben_stock103	= .;	if	T2671410	>= 0 and	T2671410	<= 1 then 	ben_stock103	=	T2671410	;
ben_stock104	= .;	if	T2671510	>= 0 and	T2671510	<= 1 then 	ben_stock104	=	T2671510	;

occcode97	= .; if	T3186900	ge 0 and	T3186900	le 9990 then	occcode97	=	T3186900	;
occcode98	= .; if	T3187000	ge 0 and	T3187000	le 9990 then	occcode98	=	T3187000	;
occcode99	= .; if	T3187100	ge 0 and	T3187100	le 9990 then	occcode99	=	T3187100	;
occcode100	= .; if	T3187200	ge 0 and	T3187200	le 9990 then	occcode100	=	T3187200	;
occcode101	= .; if	T3187300	ge 0 and	T3187300	le 9990 then	occcode101	=	T3187300	;
occcode102	= .; if	T3187400	ge 0 and	T3187400	le 9990 then	occcode102	=	T3187400	;
occcode103	= .; if	T3187500	ge 0 and	T3187500	le 9990 then	occcode103	=	T3187500	;
occcode104	= .; if	T3187600	ge 0 and	T3187600	le 9990 then	occcode104	=	T3187600	;

indcode97	= .; if	T3186000	ge 0 and	T3186000	le 9990 then	indcode89	=	T3186000	;
indcode98	= .; if	T3186100	ge 0 and	T3186100	le 9990 then	indcode90	=	T3186100	;
indcode99	= .; if	T3186200	ge 0 and	T3186200	le 9990 then	indcode91	=	T3186200	;
indcode100	= .; if	T3186300	ge 0 and	T3186300	le 9990 then	indcode92	=	T3186300	;
indcode101	= .; if	T3186400	ge 0 and	T3186400	le 9990 then	indcode93	=	T3186400	;
indcode102	= .; if	T3186500	ge 0 and	T3186500	le 9990 then	indcode94	=	T3186500	;
indcode103	= .; if	T3186600	ge 0 and	T3186600	le 9990 then	indcode95	=	T3186600	;
indcode104	= .; if	T3186700	ge 0 and	T3186700	le 9990 then	indcode96	=	T3186700	;

jobtype97	= .; if	T2440600	ge 1 &	T2440600	le 5 then	jobtype97	=	T2440600	;
jobtype98	= .; if	T2440700	ge 1 &	T2440700	le 5 then	jobtype98	=	T2440700	;
jobtype99	= .; if	T2440800	ge 1 &	T2440800	le 5 then	jobtype99	=	T2440800	;
jobtype100	= .; if	T2440900	ge 1 &	T2440900	le 5 then	jobtype100	=	T2440900	;
jobtype101	= .; if	T2441000	ge 1 &	T2441000	le 5 then	jobtype101	=	T2441000	;
jobtype102	= .; if	T2441100	ge 1 &	T2441100	le 5 then	jobtype102	=	T2441100	;
jobtype103	= .; if	T2441200	ge 1 &	T2441200	le 5 then	jobtype103	=	T2441200	;
jobtype104	= .; if	T2441300	ge 1 &	T2441300	le 5 then	jobtype104	=	T2441300	;

hourswk97	= .; if	T2018500	ge 0 &	T2018500	le 168 then	hourswk97	=	T2018500	;
hourswk98	= .; if	T2018600	ge 0 &	T2018600	le 168 then	hourswk98	=	T2018600	;
hourswk99	= .; if	T2018700	ge 0 &	T2018700	le 168 then	hourswk99	=	T2018700	;
hourswk100	= .; if	T2018800	ge 0 &	T2018800	le 168 then	hourswk100	=	T2018800	;
hourswk101	= .; if	T2018900	ge 0 &	T2018900	le 168 then	hourswk101	=	T2018900	;
hourswk102	= .; if	T2019000	ge 0 &	T2019000	le 168 then	hourswk102	=	T2019000	;
hourswk103	= .; if	T2019100	ge 0 &	T2019100	le 168 then	hourswk103	=	T2019100	;
hourswk104	= .; if	T2019200	ge 0 &	T2019200	le 168 then	hourswk104	=	T2019200	;

anygap97	= .; if	T2699400	ge -2 &	T2699400	le 0 then	anygap97	=	0	;	if 	T2699400	eq 1 then	anygap97	=	1	;
anygap98	= .; if	T2699500	ge -2 &	T2699500	le 0 then	anygap98	=	0	;	if 	T2699500	eq 1 then	anygap98	=	1	;
anygap99	= .; if	T2699600	ge -2 &	T2699600	le 0 then	anygap99	=	0	;	if 	T2699600	eq 1 then	anygap99	=	1	;
anygap100	= .; if	T2699700	ge -2 &	T2699700	le 0 then	anygap100	=	0	;	if 	T2699700	eq 1 then	anygap100	=	1	;
anygap101	= .; if	T2699800	ge -2 &	T2699800	le 0 then	anygap101	=	0	;	if 	T2699800	eq 1 then	anygap101	=	1	;
anygap102	= .; if	T2699900	ge -2 &	T2699900	le 0 then	anygap102	=	0	;	if 	T2699900	eq 1 then	anygap102	=	1	;
anygap103	= .; if	T2700000	ge -2 &	T2700000	le 0 then	anygap103	=	0	;	if 	T2700000	eq 1 then	anygap103	=	1	;
anygap104	= .; if	T2700100	ge -2 &	T2700100	le 0 then	anygap104	=	0	;	if 	T2700100	eq 1 then	anygap104	=	1	;

worksched97	= .; if	T2670000	ge 1 &	T2670000	le 9 then	worksched97	=	T2670000	;
worksched98	= .; if	T2670100	ge 1 &	T2670100	le 9 then	worksched98	=	T2670100	;
worksched99	= .; if	T2670200	ge 1 &	T2670200	le 9 then	worksched99	=	T2670200	;
worksched100	= .; if	T2670300	ge 1 &	T2670300	le 9 then	worksched100	=	T2670300	;
worksched101	= .; if	T2670400	ge 1 &	T2670400	le 9 then	worksched101	=	T2670400	;
worksched102	= .; if	T2670500	ge 1 &	T2670500	le 9 then	worksched102	=	T2670500	;
worksched103	= .; if	T2670600	ge 1 &	T2670600	le 9 then	worksched103	=	T2670600	;
worksched104	= .; if	T2670700	ge 1 &	T2670700	le 9 then	worksched104	=	T2670700	;

/* 2009: up to 9 *************************************************************/

idjob105 = .; if (T4814600 >= 0 & T4814600 <= 300000) then idjob105	= T4814600;
idjob106 = .; if (T4814700 >= 0 & T4814700 <= 300000) then idjob106	= T4814700;
idjob107 = .; if (T4814800 >= 0 & T4814800 <= 300000) then idjob107	= T4814800;
idjob108 = .; if (T4814900 >= 0 & T4814900 <= 300000) then idjob108	= T4814900;
idjob109 = .; if (T4815000 >= 0 & T4815000 <= 300000) then idjob109	= T4815000;
idjob110 = .; if (T4815100 >= 0 & T4815100 <= 300000) then idjob110	= T4815100;
idjob111 = .; if (T4815200 >= 0 & T4815200 <= 300000) then idjob111	= T4815200;
idjob112 = .; if (T4815300 >= 0 & T4815300 <= 300000) then idjob112	= T4815300;
idjob113 = .; if (T4815400 >= 0 & T4815400 <= 300000) then idjob113	= T4815400;

whyleftjob105 = .;	if (T4146500 >= 0 &	T4146500 <= 50) then whyleftjob105	= T4146500;
whyleftjob106 = .;	if (T4146600 >= 0 &	T4146600 <= 50) then whyleftjob106	= T4146600;
whyleftjob107 = .;	if (T4146700 >= 0 &	T4146700 <= 50) then whyleftjob107	= T4146700;
whyleftjob108 = .;	if (T4146800 >= 0 &	T4146800 <= 50) then whyleftjob108	= T4146800;
whyleftjob109 = .;	if (T4146900 >= 0 &	T4146900 <= 50) then whyleftjob109	= T4146900;
whyleftjob110 = .;	if (T4147000 >= 0 &	T4147000 <= 50) then whyleftjob110	= T4147000;
whyleftjob111 = .;	if (T4147100 >= 0 &	T4147100 <= 50) then whyleftjob111	= T4147100;
whyleftjob112 = .;	if (T4147200 >= 0 &	T4147200 <= 50) then whyleftjob112	= T4147200;
whyleftjob113 = .;	if (T4147300 >= 0 &	T4147300 <= 50) then whyleftjob113	= T4147300;

curjob105	= .; if	T4746100	>= 0 &	T4746100	<= 1 then	curjob105	=	T4746100	;
curjob106	= .; if	T4746200	>= 0 &	T4746200	<= 1 then	curjob106	=	T4746200	;
curjob107	= .; if	T4746300	>= 0 &	T4746300	<= 1 then	curjob107	=	T4746300	;
curjob108	= .; if	T4746400	>= 0 &	T4746400	<= 1 then	curjob108	=	T4746400	;
curjob109	= .; if	T4746500	>= 0 &	T4746500	<= 1 then	curjob109	=	T4746500	;
curjob110	= .; if	T4746600	>= 0 &	T4746600	<= 1 then	curjob110	=	T4746600	;
curjob111	= .; if	T4746700	>= 0 &	T4746700	<= 1 then	curjob111	=	T4746700	;
curjob112	= .; if	T4746800	>= 0 &	T4746800	<= 1 then	curjob112	=	T4746800	;
curjob113	= .; if	T4746900	>= 0 &	T4746900	<= 1 then	curjob113	=	T4746900	;

intmo105 = T3609900;
intmo106 = T3609900;
intmo107 = T3609900;
intmo108 = T3609900;
intmo109 = T3609900;
intmo110 = T3609900;
intmo111 = T3609900;
intmo112 = T3609900;
intmo113 = T3609900;

weeksjob105	= .; if (T3612400 >= 0 & T3612400 <= 5000) then	weeksjob105	= T3612400;
weeksjob106	= .; if (T3612500 >= 0 & T3612500 <= 5000) then	weeksjob106	= T3612500;
weeksjob107	= .; if (T3612600 >= 0 & T3612600 <= 5000) then	weeksjob107	= T3612600;
weeksjob108	= .; if (T3612700 >= 0 & T3612700 <= 5000) then	weeksjob108	= T3612700;
weeksjob109	= .; if (T3612800 >= 0 & T3612800 <= 5000) then	weeksjob109	= T3612800;
weeksjob110	= .; if (T3612900 >= 0 & T3612900 <= 5000) then	weeksjob110	= T3612900;
weeksjob111	= .; if (T3613000 >= 0 & T3613000 <= 5000) then	weeksjob111	= T3613000;
weeksjob112	= .; if (T3613100 >= 0 & T3613100 <= 5000) then	weeksjob112	= T3613100;
weeksjob113	= .; if (T3613200 >= 0 & T3613200 <= 5000) then	weeksjob113	= T3613200;

startmojob105	=	.;	if	T4782201	>=	0	&	T4782201	<=	12	then	startmojob105	=	T4782201	;			
startmojob106	=	.;	if	T4782301	>=	0	&	T4782301	<=	12	then	startmojob106	=	T4782301	;			
startmojob107	=	.;	if	T4782401	>=	0	&	T4782401	<=	12	then	startmojob107	=	T4782401	;			
startmojob108	=	.;	if	T4782501	>=	0	&	T4782501	<=	12	then	startmojob108	=	T4782501	;			
startmojob109	=	.;	if	T4782601	>=	0	&	T4782601	<=	12	then	startmojob109	=	T4782601	;			
startmojob110	=	.;	if	T4782701	>=	0	&	T4782701	<=	12	then	startmojob110	=	T4782701	;			
startmojob111	=	.;	if	T4782801	>=	0	&	T4782801	<=	12	then	startmojob111	=	T4782801	;			
startmojob112	=	.;	if	T4782901	>=	0	&	T4782901	<=	12	then	startmojob112	=	T4782901	;			
startmojob113	=	.;	if	T4783001	>=	0	&	T4783001	<=	12	then	startmojob113	=	T4783001	;			
																		
startyrjob105	=	.;	if	T4782202	>=	1980	&	T4782202	<=	2050	then	startyrjob105	=	T4782202	;			
startyrjob106	=	.;	if	T4782302	>=	1980	&	T4782302	<=	2050	then	startyrjob106	=	T4782302	;			
startyrjob107	=	.;	if	T4782402	>=	1980	&	T4782402	<=	2050	then	startyrjob107	=	T4782402	;			
startyrjob108	=	.;	if	T4782502	>=	1980	&	T4782502	<=	2050	then	startyrjob108	=	T4782502	;			
startyrjob109	=	.;	if	T4782602	>=	1980	&	T4782602	<=	2050	then	startyrjob109	=	T4782602	;			
startyrjob110	=	.;	if	T4782702	>=	1980	&	T4782702	<=	2050	then	startyrjob110	=	T4782702	;			
startyrjob111	=	.;	if	T4782802	>=	1980	&	T4782802	<=	2050	then	startyrjob111	=	T4782802	;			
startyrjob112	=	.;	if	T4782902	>=	1980	&	T4782902	<=	2050	then	startyrjob112	=	T4782902	;			
startyrjob113	=	.;	if	T4783002	>=	1980	&	T4783002	<=	2050	then	startyrjob113	=	T4783002	;			
																		
startcontmo105	=	.;	if	startyrjob105	ne	.	&	startmojob105	ne	.	then	startcontmo105	=	((startyrjob105	-1980)*12)	+	startmojob105	;
startcontmo106	=	.;	if	startyrjob106	ne	.	&	startmojob106	ne	.	then	startcontmo106	=	((startyrjob106	-1980)*12)	+	startmojob106	;
startcontmo107	=	.;	if	startyrjob107	ne	.	&	startmojob107	ne	.	then	startcontmo107	=	((startyrjob107	-1980)*12)	+	startmojob107	;
startcontmo108	=	.;	if	startyrjob108	ne	.	&	startmojob108	ne	.	then	startcontmo108	=	((startyrjob108	-1980)*12)	+	startmojob108	;
startcontmo109	=	.;	if	startyrjob109	ne	.	&	startmojob109	ne	.	then	startcontmo109	=	((startyrjob109	-1980)*12)	+	startmojob109	;
startcontmo110	=	.;	if	startyrjob110	ne	.	&	startmojob110	ne	.	then	startcontmo110	=	((startyrjob110	-1980)*12)	+	startmojob110	;
startcontmo111	=	.;	if	startyrjob111	ne	.	&	startmojob111	ne	.	then	startcontmo111	=	((startyrjob111	-1980)*12)	+	startmojob111	;
startcontmo112	=	.;	if	startyrjob112	ne	.	&	startmojob112	ne	.	then	startcontmo112	=	((startyrjob112	-1980)*12)	+	startmojob112	;
startcontmo113	=	.;	if	startyrjob113	ne	.	&	startmojob113	ne	.	then	startcontmo113	=	((startyrjob113	-1980)*12)	+	startmojob113	;

endbyst105	= .; if	T4225200	ge 0 &	T4225200	le 1 then	endbyst105	=	T4225200	;
endbyst106	= .; if	T4225300	ge 0 &	T4225300	le 1 then	endbyst106	=	T4225300	;
endbyst107	= .; if	T4225400	ge 0 &	T4225400	le 1 then	endbyst107	=	T4225400	;
endbyst108	= .; if	T4225500	ge 0 &	T4225500	le 1 then	endbyst108	=	T4225500	;
endbyst109	= .; if	T4225600	ge 0 &	T4225600	le 1 then	endbyst109	=	T4225600	;
endbyst110	= .; if	T4225700	ge 0 &	T4225700	le 1 then	endbyst110	=	T4225700	;
endbyst111	= .; if	T4225800	ge 0 &	T4225800	le 1 then	endbyst111	=	T4225800	;
endbyst112	= .; if	T4225900	ge 0 &	T4225900	le 1 then	endbyst112	=	T4225900	;
endbyst113	= .; if	T4226000	ge 0 &	T4226000	le 1 then	endbyst113	=	T4226000	;

jobsat105	= .;	if	T4178700	>= 1 and	T4178700	<= 5 then 	jobsat105	=	T4178700	;
jobsat106	= .;	if	T4178800	>= 1 and	T4178800	<= 5 then 	jobsat106	=	T4178800	;
jobsat107	= .;	if	T4178900	>= 1 and	T4178900	<= 5 then 	jobsat107	=	T4178900	;
jobsat108	= .;	if	T4179000	>= 1 and	T4179000	<= 5 then 	jobsat108	=	T4179000	;
jobsat109	= .;	if	T4179100	>= 1 and	T4179100	<= 5 then 	jobsat109	=	T4179100	;
jobsat110	= .;	if	T4179200	>= 1 and	T4179200	<= 5 then 	jobsat110	=	T4179200	;
jobsat111	= .;	if	T4179300	>= 1 and	T4179300	<= 5 then 	jobsat111	=	T4179300	;
jobsat112	= .;	if	T4179400	>= 1 and	T4179400	<= 5 then 	jobsat112	=	T4179400	;
jobsat113	= .;	if	T4179500	>= 1 and	T4179500	<= 5 then 	jobsat113	=	T4179500	;

union105	= .;	if	T4164900	>= 0 and	T4164900	<= 1 then 	union105	=	T4164900	;
union106	= .;	if	T4165000	>= 0 and	T4165000	<= 1 then 	union106	=	T4165000	;
union107	= .;	if	T4165100	>= 0 and	T4165100	<= 1 then 	union107	=	T4165100	;
union108	= .;	if	T4165200	>= 0 and	T4165200	<= 1 then 	union108	=	T4165200	;
union109	= .;	if	T4165300	>= 0 and	T4165300	<= 1 then 	union109	=	T4165300	;
union110	= .;	if	T4165400	>= 0 and	T4165400	<= 1 then 	union110	=	T4165400	;
union111	= .;	if	T4165500	>= 0 and	T4165500	<= 1 then 	union111	=	T4165500	;
union112	= .;	if	T4165600	>= 0 and	T4165600	<= 1 then 	union112	=	T4165600	;
union113	= .;	if	T4165700	>= 0 and	T4165700	<= 1 then 	union113	=	T4165700	;

ben_med105	= .;	if	T4154402	>= 0 and	T4154402	<= 1 then 	ben_med105	=	T4154402	;
ben_med106	= .;	if	T4154502	>= 0 and	T4154502	<= 1 then 	ben_med106	=	T4154502	;
ben_med107	= .;	if	T4154602	>= 0 and	T4154602	<= 1 then 	ben_med107	=	T4154602	;
ben_med108	= .;	if	T4154702	>= 0 and	T4154702	<= 1 then 	ben_med108	=	T4154702	;
ben_med109	= .;	if	T4154802	>= 0 and	T4154802	<= 1 then 	ben_med109	=	T4154802	;
ben_med110	= .;	if	T4154902	>= 0 and	T4154902	<= 1 then 	ben_med110	=	T4154902	;
ben_med111	= .;	if	T4155002	>= 0 and	T4155002	<= 1 then 	ben_med111	=	T4155002	;
ben_med112	= .;	if	T4155102	>= 0 and	T4155102	<= 1 then 	ben_med112	=	T4155102	;
ben_med113	= .;	if	T4155202	>= 0 and	T4155202	<= 1 then 	ben_med113	=	T4155202	;

ben_flex105	= .;	if	T4154401	>= 0 and	T4154401	<= 1 then 	ben_flex105	=	T4154401	;
ben_flex106	= .;	if	T4154501	>= 0 and	T4154501	<= 1 then 	ben_flex106	=	T4154501	;
ben_flex107	= .;	if	T4154601	>= 0 and	T4154601	<= 1 then 	ben_flex107	=	T4154601	;
ben_flex108	= .;	if	T4154701	>= 0 and	T4154701	<= 1 then 	ben_flex108	=	T4154701	;
ben_flex109	= .;	if	T4154801	>= 0 and	T4154801	<= 1 then 	ben_flex109	=	T4154801	;
ben_flex110	= .;	if	T4154901	>= 0 and	T4154901	<= 1 then 	ben_flex110	=	T4154901	;
ben_flex111	= .;	if	T4155001	>= 0 and	T4155001	<= 1 then 	ben_flex111	=	T4155001	;
ben_flex112	= .;	if	T4155101	>= 0 and	T4155101	<= 1 then 	ben_flex112	=	T4155101	;
ben_flex113	= .;	if	T4155201	>= 0 and	T4155201	<= 1 then 	ben_flex113	=	T4155201	;

ben_life105	= .;	if	T4154403	>= 0 and	T4154403	<= 1 then 	ben_life105	=	T4154403	;
ben_life106	= .;	if	T4154503	>= 0 and	T4154503	<= 1 then 	ben_life106	=	T4154503	;
ben_life107	= .;	if	T4154603	>= 0 and	T4154603	<= 1 then 	ben_life107	=	T4154603	;
ben_life108	= .;	if	T4154703	>= 0 and	T4154703	<= 1 then 	ben_life108	=	T4154703	;
ben_life109	= .;	if	T4154803	>= 0 and	T4154803	<= 1 then 	ben_life109	=	T4154803	;
ben_life110	= .;	if	T4154903	>= 0 and	T4154903	<= 1 then 	ben_life110	=	T4154903	;
ben_life111	= .;	if	T4155003	>= 0 and	T4155003	<= 1 then 	ben_life111	=	T4155003	;
ben_life112	= .;	if	T4155103	>= 0 and	T4155103	<= 1 then 	ben_life112	=	T4155103	;
ben_life113	= .;	if	T4155203	>= 0 and	T4155203	<= 1 then 	ben_life113	=	T4155203	;

ben_dental105	= .;	if	T4154404	>= 0 and	T4154404	<= 1 then 	ben_dental105	=	T4154404	;
ben_dental106	= .;	if	T4154504	>= 0 and	T4154504	<= 1 then 	ben_dental106	=	T4154504	;
ben_dental107	= .;	if	T4154604	>= 0 and	T4154604	<= 1 then 	ben_dental107	=	T4154604	;
ben_dental108	= .;	if	T4154704	>= 0 and	T4154704	<= 1 then 	ben_dental108	=	T4154704	;
ben_dental109	= .;	if	T4154804	>= 0 and	T4154804	<= 1 then 	ben_dental109	=	T4154804	;
ben_dental110	= .;	if	T4154904	>= 0 and	T4154904	<= 1 then 	ben_dental110	=	T4154904	;
ben_dental111	= .;	if	T4155004	>= 0 and	T4155004	<= 1 then 	ben_dental111	=	T4155004	;
ben_dental112	= .;	if	T4155104	>= 0 and	T4155104	<= 1 then 	ben_dental112	=	T4155104	;
ben_dental113	= .;	if	T4155204	>= 0 and	T4155204	<= 1 then 	ben_dental113	=	T4155204	;

ben_pdleave105	= .;	if	T4154405	>= 0 and	T4154405	<= 1 then 	ben_pdleave105	=	T4154405	;
ben_pdleave106	= .;	if	T4154505	>= 0 and	T4154505	<= 1 then 	ben_pdleave106	=	T4154505	;
ben_pdleave107	= .;	if	T4154605	>= 0 and	T4154605	<= 1 then 	ben_pdleave107	=	T4154605	;
ben_pdleave108	= .;	if	T4154705	>= 0 and	T4154705	<= 1 then 	ben_pdleave108	=	T4154705	;
ben_pdleave109	= .;	if	T4154805	>= 0 and	T4154805	<= 1 then 	ben_pdleave109	=	T4154805	;
ben_pdleave110	= .;	if	T4154905	>= 0 and	T4154905	<= 1 then 	ben_pdleave110	=	T4154905	;
ben_pdleave111	= .;	if	T4155005	>= 0 and	T4155005	<= 1 then 	ben_pdleave111	=	T4155005	;
ben_pdleave112	= .;	if	T4155105	>= 0 and	T4155105	<= 1 then 	ben_pdleave112	=	T4155105	;
ben_pdleave113	= .;	if	T4155205	>= 0 and	T4155205	<= 1 then 	ben_pdleave113	=	T4155205	;

ben_unpdleave105	= .;	if	T4154406	>= 0 and	T4154406	<= 1 then 	ben_unpdleave105	=	T4154406	;
ben_unpdleave106	= .;	if	T4154506	>= 0 and	T4154506	<= 1 then 	ben_unpdleave106	=	T4154506	;
ben_unpdleave107	= .;	if	T4154606	>= 0 and	T4154606	<= 1 then 	ben_unpdleave107	=	T4154606	;
ben_unpdleave108	= .;	if	T4154706	>= 0 and	T4154706	<= 1 then 	ben_unpdleave108	=	T4154706	;
ben_unpdleave109	= .;	if	T4154806	>= 0 and	T4154806	<= 1 then 	ben_unpdleave109	=	T4154806	;
ben_unpdleave110	= .;	if	T4154906	>= 0 and	T4154906	<= 1 then 	ben_unpdleave110	=	T4154906	;
ben_unpdleave111	= .;	if	T4155006	>= 0 and	T4155006	<= 1 then 	ben_unpdleave111	=	T4155006	;
ben_unpdleave112	= .;	if	T4155106	>= 0 and	T4155106	<= 1 then 	ben_unpdleave112	=	T4155106	;
ben_unpdleave113	= .;	if	T4155206	>= 0 and	T4155206	<= 1 then 	ben_unpdleave113	=	T4155206	;

ben_retire105	= .;	if	T4154407	>= 0 and	T4154407	<= 1 then 	ben_retire105	=	T4154407	;
ben_retire106	= .;	if	T4154507	>= 0 and	T4154507	<= 1 then 	ben_retire106	=	T4154507	;
ben_retire107	= .;	if	T4154607	>= 0 and	T4154607	<= 1 then 	ben_retire107	=	T4154607	;
ben_retire108	= .;	if	T4154707	>= 0 and	T4154707	<= 1 then 	ben_retire108	=	T4154707	;
ben_retire109	= .;	if	T4154807	>= 0 and	T4154807	<= 1 then 	ben_retire109	=	T4154807	;
ben_retire110	= .;	if	T4154907	>= 0 and	T4154907	<= 1 then 	ben_retire110	=	T4154907	;
ben_retire111	= .;	if	T4155007	>= 0 and	T4155007	<= 1 then 	ben_retire111	=	T4155007	;
ben_retire112	= .;	if	T4155107	>= 0 and	T4155107	<= 1 then 	ben_retire112	=	T4155107	;
ben_retire113	= .;	if	T4155207	>= 0 and	T4155207	<= 1 then 	ben_retire113	=	T4155207	;

ben_tuition105	= .;	if	T4154408	>= 0 and	T4154408	<= 1 then 	ben_tuition105	=	T4154408	;
ben_tuition106	= .;	if	T4154508	>= 0 and	T4154508	<= 1 then 	ben_tuition106	=	T4154508;
ben_tuition107	= .;	if	T4154608	>= 0 and	T4154608	<= 1 then 	ben_tuition107	=	T4154608	;
ben_tuition108	= .;	if	T4154708	>= 0 and	T4154708	<= 1 then 	ben_tuition108	=	T4154708	;
ben_tuition109	= .;	if	T4154808	>= 0 and	T4154808	<= 1 then 	ben_tuition109	=	T4154808	;
ben_tuition110	= .;	if	T4154908	>= 0 and	T4154908	<= 1 then 	ben_tuition110	=	T4154908	;
ben_tuition111	= .;	if	T4155008	>= 0 and	T4155008	<= 1 then 	ben_tuition111	=	T4155008	;
ben_tuition112	= .;	if	T4155108	>= 0 and	T4155108	<= 1 then 	ben_tuition112	=	T4155108	;
ben_tuition113	= .;	if	T4155208	>= 0 and	T4155208	<= 1 then 	ben_tuition113	=	T4155208	;

ben_child105	= .;	if	T4154409	>= 0 and	T4154409	<= 1 then 	ben_child105	=	T4154409	;
ben_child106	= .;	if	T4154509	>= 0 and	T4154509	<= 1 then 	ben_child106	=	T4154509;
ben_child107	= .;	if	T4154609	>= 0 and	T4154609	<= 1 then 	ben_child107	=	T4154609	;
ben_child108	= .;	if	T4154709	>= 0 and	T4154709	<= 1 then 	ben_child108	=	T4154709	;
ben_child109	= .;	if	T4154809	>= 0 and	T4154809	<= 1 then 	ben_child109	=	T4154809	;
ben_child110	= .;	if	T4154909	>= 0 and	T4154909	<= 1 then 	ben_child110	=	T4154909	;
ben_child111	= .;	if	T4155009	>= 0 and	T4155009	<= 1 then 	ben_child111	=	T4155009	;
ben_child112	= .;	if	T4155109	>= 0 and	T4155109	<= 1 then 	ben_child112	=	T4155109	;
ben_child113	= .;	if	T4155209	>= 0 and	T4155209	<= 1 then 	ben_child113	=	T4155209	;

ben_stock105	= .;	if	T4154410	>= 0 and	T4154410	<= 1 then 	ben_stock105	=	T4154410	;
ben_stock106	= .;	if	T4154510	>= 0 and	T4154510	<= 1 then 	ben_stock106	=	T4154510;
ben_stock107	= .;	if	T4154610	>= 0 and	T4154610	<= 1 then 	ben_stock107	=	T4154610	;
ben_stock108	= .;	if	T4154710	>= 0 and	T4154710	<= 1 then 	ben_stock108	=	T4154710	;
ben_stock109	= .;	if	T4154810	>= 0 and	T4154810	<= 1 then 	ben_stock109	=	T4154810	;
ben_stock110	= .;	if	T4154910	>= 0 and	T4154910	<= 1 then 	ben_stock110	=	T4154910	;
ben_stock111	= .;	if	T4155010	>= 0 and	T4155010	<= 1 then 	ben_stock111	=	T4155010	;
ben_stock112	= .;	if	T4155110	>= 0 and	T4155110	<= 1 then 	ben_stock112	=	T4155110	;
ben_stock113	= .;	if	T4155210	>= 0 and	T4155210	<= 1 then 	ben_stock113	=	T4155210	;

occcode105	= .; if	T4597800	ge 0 and	T4597800	le 9990 then	occcode105	=	T4597800	;
occcode106	= .; if	T4597900	ge 0 and	T4597900	le 9990 then	occcode106	=	T4597900	;
occcode107	= .; if	T4598000	ge 0 and	T4598000	le 9990 then	occcode107	=	T4598000	;
occcode108	= .; if	T4598100	ge 0 and	T4598100	le 9990 then	occcode108	=	T4598100	;
occcode109	= .; if	T4598200	ge 0 and	T4598200	le 9990 then	occcode109	=	T4598200	;
occcode110	= .; if	T4598300	ge 0 and	T4598300	le 9990 then	occcode110	=	T4598300	;
occcode111	= .; if	T4598400	ge 0 and	T4598400	le 9990 then	occcode111	=	T4598400	;
occcode112	= .; if	T4598500	ge 0 and	T4598500	le 9990 then	occcode112	=	T4598500	;
occcode113	= .; if	T4598600	ge 0 and	T4598600	le 9990 then	occcode113	=	T4598600	;

indcode105	= .; if	T4596900	ge 0 and	T4596900	le 9990 then	indcode105	=	T4596900	;
indcode106	= .; if	T4597000	ge 0 and	T4597000	le 9990 then	indcode106	=	T4597000	;
indcode107	= .; if	T4597100	ge 0 and	T4597100	le 9990 then	indcode107	=	T4597100	;
indcode108	= .; if	T4597200	ge 0 and	T4597200	le 9990 then	indcode108	=	T4597200	;
indcode109	= .; if	T4597300	ge 0 and	T4597300	le 9990 then	indcode109	=	T4597300	;
indcode110	= .; if	T4597400	ge 0 and	T4597400	le 9990 then	indcode110	=	T4597400	;
indcode111	= .; if	T4597500	ge 0 and	T4597500	le 9990 then	indcode111	=	T4597500	;
indcode112	= .; if	T4597600	ge 0 and	T4597600	le 9990 then	indcode112	=	T4597600	;
indcode113	= .; if	T4597700	ge 0 and	T4597700	le 9990 then	indcode113	=	T4597700	;

jobtype105	= .; if	T3945500	ge 1 &	T3945500	le 5 then	jobtype105	=	T3945500	;
jobtype106	= .; if	T3945600	ge 1 &	T3945600	le 5 then	jobtype106	=	T3945600	;
jobtype107	= .; if	T3945700	ge 1 &	T3945700	le 5 then	jobtype107	=	T3945700	;
jobtype108	= .; if	T3945800	ge 1 &	T3945800	le 5 then	jobtype108	=	T3945800	;
jobtype109	= .; if	T3945900	ge 1 &	T3945900	le 5 then	jobtype109	=	T3945900	;
jobtype110	= .; if	T3946000	ge 1 &	T3946000	le 5 then	jobtype110	=	T3946000	;
jobtype111	= .; if	T3946100	ge 1 &	T3946100	le 5 then	jobtype111	=	T3946100	;
jobtype112	= .; if	T3946200	ge 1 &	T3946200	le 5 then	jobtype112	=	T3946200	;
jobtype113 = .;

hourswk105	= .; if	T3609000	ge 0 &	T3609000	le 168 then	hourswk105	=	T3609000	;
hourswk106	= .; if	T3609100	ge 0 &	T3609100	le 168 then	hourswk106	=	T3609100	;
hourswk107	= .; if	T3609200	ge 0 &	T3609200	le 168 then	hourswk107	=	T3609200	;
hourswk108	= .; if	T3609300	ge 0 &	T3609300	le 168 then	hourswk108	=	T3609300	;
hourswk109	= .; if	T3609400	ge 0 &	T3609400	le 168 then	hourswk109	=	T3609400	;
hourswk110	= .; if	T3609500	ge 0 &	T3609500	le 168 then	hourswk110	=	T3609500	;
hourswk111	= .; if	T3609600	ge 0 &	T3609600	le 168 then	hourswk111	=	T3609600	;
hourswk112	= .; if	T3609700	ge 0 &	T3609700	le 168 then	hourswk112	=	T3609700	;
hourswk113	= .; if	T3609800	ge 0 &	T3609800	le 168 then	hourswk113	=	T3609800	;

anygap105	= .; if	T4186100	ge -2 &	T4186100	le 0 then	anygap105	=	0	;	if 	T4186100	eq 1 then	anygap105	=	1	;
anygap106	= .; if	T4186200	ge -2 &	T4186200	le 0 then	anygap106	=	0	;	if 	T4186200	eq 1 then	anygap106	=	1	;
anygap107	= .; if	T4186300	ge -2 &	T4186300	le 0 then	anygap107	=	0	;	if 	T4186300	eq 1 then	anygap107	=	1	;
anygap108	= .; if	T4186400	ge -2 &	T4186400	le 0 then	anygap108	=	0	;	if 	T4186400	eq 1 then	anygap108	=	1	;
anygap109	= .; if	T4186500	ge -2 &	T4186500	le 0 then	anygap109	=	0	;	if 	T4186500	eq 1 then	anygap109	=	1	;
anygap110	= .; if	T4186600	ge -2 &	T4186600	le 0 then	anygap110	=	0	;	if 	T4186600	eq 1 then	anygap110	=	1	;
anygap111	= .; if	T4186700	ge -2 &	T4186700	le 0 then	anygap111	=	0	;	if 	T4186700	eq 1 then	anygap111	=	1	;
anygap112	= .; if	T4186800	ge -2 &	T4186800	le 0 then	anygap112	=	0	;	if 	T4186800	eq 1 then	anygap112	=	1	;
anygap113	= .; if	T4186900	ge -2 &	T4186900	le 0 then	anygap113	=	0	;	if 	T4186900	eq 1 then	anygap113	=	1	;

worksched105	= .; if	T4153500	ge 1 &	T4153500	le 9 then	worksched105	=	T4153500	;
worksched106	= .; if	T4153600	ge 1 &	T4153600	le 9 then	worksched106	=	T4153600	;
worksched107	= .; if	T4153700	ge 1 &	T4153700	le 9 then	worksched107	=	T4153700	;
worksched108	= .; if	T4153800	ge 1 &	T4153800	le 9 then	worksched108	=	T4153800	;
worksched109	= .; if	T4153900	ge 1 &	T4153900	le 9 then	worksched109	=	T4153900	;
worksched110	= .; if	T4154000	ge 1 &	T4154000	le 9 then	worksched110	=	T4154000	;
worksched111	= .; if	T4154100	ge 1 &	T4154100	le 9 then	worksched111	=	T4154100	;
worksched112	= .; if	T4154200	ge 1 &	T4154200	le 9 then	worksched112	=	T4154200	;
worksched113	= .; if	T4154300	ge 1 &	T4154300	le 9 then	worksched113	=	T4154300	;

/* 2010: up to 9 **************************************************************/

idjob114 = .; if (T6460000 >= 0 & T6460000 <= 300000) then idjob114	= T6460000;
idjob115 = .; if (T6460100 >= 0 & T6460100 <= 300000) then idjob115	= T6460100;
idjob116 = .; if (T6460200 >= 0 & T6460200 <= 300000) then idjob116	= T6460200;
idjob117 = .; if (T6460300 >= 0 & T6460300 <= 300000) then idjob117	= T6460300;
idjob118 = .; if (T6460400 >= 0 & T6460400 <= 300000) then idjob118	= T6460400;
idjob119 = .; if (T6460500 >= 0 & T6460500 <= 300000) then idjob119	= T6460500;
idjob120 = .; if (T6460600 >= 0 & T6460600 <= 300000) then idjob120	= T6460600;
idjob121 = .; if (T6460700 >= 0 & T6460700 <= 300000) then idjob121	= T6460700;
idjob122 = .; if (T6460800 >= 0 & T6460800 <= 300000) then idjob122	= T6460800;

whyleftjob114 = .; if (T5778800 >= 0 &	T5778800 <= 50) then whyleftjob114	= T5778800;
whyleftjob115 = .; if (T5778900 >= 0 &	T5778900 <= 50) then whyleftjob115	= T5778900;
whyleftjob116 = .; if (T5779000 >= 0 &	T5779000 <= 50) then whyleftjob116	= T5779000;
whyleftjob117 = .; if (T5779100 >= 0 &	T5779100 <= 50) then whyleftjob117	= T5779100;
whyleftjob118 = .; if (T5779200 >= 0 &	T5779200 <= 50) then whyleftjob118	= T5779200;
whyleftjob119 = .; if (T5779300 >= 0 &	T5779300 <= 50) then whyleftjob119	= T5779300;
whyleftjob120 = .; if (T5779400 >= 0 &	T5779400 <= 50) then whyleftjob120	= T5779400;
whyleftjob121 = .; if (T5779500 >= 0 &	T5779500 <= 50) then whyleftjob121	= T5779500;
whyleftjob122 = .; if (T5779600 >= 0 &	T5779600 <= 50) then whyleftjob122	= T5779600;

curjob114	= .; if	T6387100	>= 0 &	T6387100	<= 1 then	curjob114	=	T6387100	;
curjob115	= .; if	T6387200	>= 0 &	T6387200	<= 1 then	curjob115	=	T6387200	;
curjob116	= .; if	T6387300	>= 0 &	T6387300	<= 1 then	curjob116	=	T6387300	;
curjob117	= .; if	T6387400	>= 0 &	T6387400	<= 1 then	curjob117	=	T6387400	;
curjob118	= .; if	T6387500	>= 0 &	T6387500	<= 1 then	curjob118	=	T6387500	;
curjob119	= .; if	T6387600	>= 0 &	T6387600	<= 1 then	curjob119	=	T6387600	;
curjob120	= .; if	T6387700	>= 0 &	T6387700	<= 1 then	curjob120	=	T6387700	;
curjob121	= .; if	T6387800	>= 0 &	T6387800	<= 1 then	curjob121	=	T6387800	;
curjob122	= .; if	T6387900	>= 0 &	T6387900	<= 1 then	curjob122	=	T6387900	;

intmo114	= T5210300;
intmo115	= T5210300;
intmo116	= T5210300;
intmo117	= T5210300;
intmo118	= T5210300;
intmo119	= T5210300;
intmo120	= T5210300;
intmo121	= T5210300;
intmo122	= T5210300;

weeksjob114	= .; if (T5212300 >= 0 & T5212300 <= 5000) then	weeksjob114	= T5212300;
weeksjob115	= .; if (T5212400 >= 0 & T5212400 <= 5000) then	weeksjob115	= T5212400;
weeksjob116	= .; if (T5212500 >= 0 & T5212500 <= 5000) then	weeksjob116	= T5212500;
weeksjob117	= .; if (T5212600 >= 0 & T5212600 <= 5000) then	weeksjob117	= T5212600;
weeksjob118	= .; if (T5212700 >= 0 & T5212700 <= 5000) then	weeksjob118	= T5212700;
weeksjob119	= .; if (T5212800 >= 0 & T5212800 <= 5000) then	weeksjob119	= T5212800;
weeksjob120	= .; if (T5212900 >= 0 & T5212900 <= 5000) then	weeksjob120	= T5212900;
weeksjob121	= .; if (T5213000 >= 0 & T5213000 <= 5000) then	weeksjob121	= T5213000;
weeksjob122	= .; if (T5213100 >= 0 & T5213100 <= 5000) then	weeksjob122	= T5213100;

startmojob114	=	.;	if	T6424701	>=	0	&	T6424701	<=	12	then	startmojob114	=	T6424701	;			
startmojob115	=	.;	if	T6424801	>=	0	&	T6424801	<=	12	then	startmojob115	=	T6424801	;			
startmojob116	=	.;	if	T6424901	>=	0	&	T6424901	<=	12	then	startmojob116	=	T6424901	;			
startmojob117	=	.;	if	T6425001	>=	0	&	T6425001	<=	12	then	startmojob117	=	T6425001	;			
startmojob118	=	.;	if	T6425101	>=	0	&	T6425101	<=	12	then	startmojob118	=	T6425101	;			
startmojob119	=	.;	if	T6425201	>=	0	&	T6425201	<=	12	then	startmojob119	=	T6425201	;			
startmojob120	=	.;	if	T6425301	>=	0	&	T6425301	<=	12	then	startmojob120	=	T6425301	;			
startmojob121	=	.;	if	T6425401	>=	0	&	T6425401	<=	12	then	startmojob121	=	T6425401	;			
startmojob122	=	.;	if	T6425501	>=	0	&	T6425501	<=	12	then	startmojob122	=	T6425501	;			
																		
startyrjob114	=	.;	if	T6424702	>=	1980	&	T6424702	<=	2050	then	startyrjob114	=	T6424702	;			
startyrjob115	=	.;	if	T6424802	>=	1980	&	T6424802	<=	2050	then	startyrjob115	=	T6424802	;			
startyrjob116	=	.;	if	T6424902	>=	1980	&	T6424902	<=	2050	then	startyrjob116	=	T6424902	;			
startyrjob117	=	.;	if	T6425002	>=	1980	&	T6425002	<=	2050	then	startyrjob117	=	T6425002	;			
startyrjob118	=	.;	if	T6425102	>=	1980	&	T6425102	<=	2050	then	startyrjob118	=	T6425102	;			
startyrjob119	=	.;	if	T6425202	>=	1980	&	T6425202	<=	2050	then	startyrjob119	=	T6425202	;			
startyrjob120	=	.;	if	T6425302	>=	1980	&	T6425302	<=	2050	then	startyrjob120	=	T6425302	;			
startyrjob121	=	.;	if	T6425402	>=	1980	&	T6425402	<=	2050	then	startyrjob121	=	T6425402	;			
startyrjob122	=	.;	if	T6425502	>=	1980	&	T6425502	<=	2050	then	startyrjob122	=	T6425502	;			
																		
startcontmo114	=	.;	if	startyrjob114	ne	.	&	startmojob114	ne	.	then	startcontmo114	=	((startyrjob114	-1980)*12)	+	startmojob114	;
startcontmo115	=	.;	if	startyrjob115	ne	.	&	startmojob115	ne	.	then	startcontmo115	=	((startyrjob115	-1980)*12)	+	startmojob115	;
startcontmo116	=	.;	if	startyrjob116	ne	.	&	startmojob116	ne	.	then	startcontmo116	=	((startyrjob116	-1980)*12)	+	startmojob116	;
startcontmo117	=	.;	if	startyrjob117	ne	.	&	startmojob117	ne	.	then	startcontmo117	=	((startyrjob117	-1980)*12)	+	startmojob117	;
startcontmo118	=	.;	if	startyrjob118	ne	.	&	startmojob118	ne	.	then	startcontmo118	=	((startyrjob118	-1980)*12)	+	startmojob118	;
startcontmo119	=	.;	if	startyrjob119	ne	.	&	startmojob119	ne	.	then	startcontmo119	=	((startyrjob119	-1980)*12)	+	startmojob119	;
startcontmo120	=	.;	if	startyrjob120	ne	.	&	startmojob120	ne	.	then	startcontmo120	=	((startyrjob120	-1980)*12)	+	startmojob120	;
startcontmo121	=	.;	if	startyrjob121	ne	.	&	startmojob121	ne	.	then	startcontmo121	=	((startyrjob121	-1980)*12)	+	startmojob121	;
startcontmo122	=	.;	if	startyrjob122	ne	.	&	startmojob122	ne	.	then	startcontmo122	=	((startyrjob122	-1980)*12)	+	startmojob122	;

endbyst114	= .; if	T5864700	ge 0 &	T5864700	le 1 then	endbyst114	=	T5864700	;
endbyst115	= .; if	T5864800	ge 0 &	T5864800	le 1 then	endbyst115	=	T5864800	;
endbyst116	= .; if	T5864900	ge 0 &	T5864900	le 1 then	endbyst116	=	T5864900	;
endbyst117	= .; if	T5865000	ge 0 &	T5865000	le 1 then	endbyst117	=	T5865000	;
endbyst118	= .; if	T5865100	ge 0 &	T5865100	le 1 then	endbyst118	=	T5865100	;
endbyst119	= .; if	T5865200	ge 0 &	T5865200	le 1 then	endbyst119	=	T5865200	;
endbyst120	= .; if	T5865300	ge 0 &	T5865300	le 1 then	endbyst120	=	T5865300	;
endbyst121	= .; if	T5865400	ge 0 &	T5865400	le 1 then	endbyst121	=	T5865400	;
endbyst122	= .; if	T5865500	ge 0 &	T5865500	le 1 then	endbyst122	=	T5865500	;

jobsat114	= .;	if	T5808400	>= 1 and	T5808400	<= 5 then 	jobsat114	=	T5808400	;
jobsat115	= .;	if	T5808500	>= 1 and	T5808500	<= 5 then 	jobsat115	=	T5808500	;
jobsat116	= .;	if	T5808600	>= 1 and	T5808600	<= 5 then 	jobsat116	=	T5808600	;
jobsat117	= .;	if	T5808700	>= 1 and	T5808700	<= 5 then 	jobsat117	=	T5808700	;
jobsat118	= .;	if	T5808800	>= 1 and	T5808800	<= 5 then 	jobsat118	=	T5808800	;
jobsat119	= .;	if	T5808900	>= 1 and	T5808900	<= 5 then 	jobsat119	=	T5808900	;
jobsat120	= .;	if	T5809000	>= 1 and	T5809000	<= 5 then 	jobsat120	=	T5809000	;
jobsat121	= .;	if	T5809100	>= 1 and	T5809100	<= 5 then 	jobsat121	=	T5809100	;
jobsat122	= .;	if	T5809200	>= 1 and	T5809200	<= 5 then 	jobsat122	=	T5809200	;

union114	= .;	if	T5797300	>= 0 and	T5797300	<= 1 then 	union114	=	T5797300	;
union115	= .;	if	T5797400	>= 0 and	T5797400	<= 1 then 	union115	=	T5797400	;
union116	= .;	if	T5797500	>= 0 and	T5797500	<= 1 then 	union116	=	T5797500	;
union117	= .;	if	T5797600	>= 0 and	T5797600	<= 1 then 	union117	=	T5797600	;
union118	= .;	if	T5797700	>= 0 and	T5797700	<= 1 then 	union118	=	T5797700	;
union119	= .;	if	T5797800	>= 0 and	T5797800	<= 1 then 	union119	=	T5797800	;
union120	= .;	if	T5797900	>= 0 and	T5797900	<= 1 then 	union120	=	T5797900	;
union121	= .;	if	T5798000	>= 0 and	T5798000	<= 1 then 	union121	=	T5798000	;
union122	= .;	if	T5798100	>= 0 and	T5798100	<= 1 then 	union122	=	T5798100	;

ben_med114	= .;	if	T5786702	>= 0 and	T5786702	<= 1 then 	ben_med114	=	T5786702	;
ben_med115	= .;	if	T5786802	>= 0 and	T5786802	<= 1 then 	ben_med115	=	T5786802	;
ben_med116	= .;	if	T5786902	>= 0 and	T5786902	<= 1 then 	ben_med116	=	T5786902	;
ben_med117	= .;	if	T5787002	>= 0 and	T5787002	<= 1 then 	ben_med117	=	T5787002	;
ben_med118	= .;	if	T5787102	>= 0 and	T5787102	<= 1 then 	ben_med118	=	T5787102	;
ben_med119	= .;	if	T5787202	>= 0 and	T5787202	<= 1 then 	ben_med119	=	T5787202	;
ben_med120	= .;	if	T5787302	>= 0 and	T5787302	<= 1 then 	ben_med120	=	T5787302	;
ben_med121	= .;	if	T5787402	>= 0 and	T5787402	<= 1 then 	ben_med121	=	T5787402	;
ben_med122	= .;	if	T5787502	>= 0 and	T5787502	<= 1 then 	ben_med122	=	T5787502	;

ben_flex114	= .;	if	T5786701	>= 0 and	T5786701	<= 1 then 	ben_flex114	=	T5786701	;
ben_flex115	= .;	if	T5786801	>= 0 and	T5786801	<= 1 then 	ben_flex115	=	T5786801	;
ben_flex116	= .;	if	T5786901	>= 0 and	T5786901	<= 1 then 	ben_flex116	=	T5786901	;
ben_flex117	= .;	if	T5787001	>= 0 and	T5787001	<= 1 then 	ben_flex117	=	T5787001	;
ben_flex118	= .;	if	T5787101	>= 0 and	T5787101	<= 1 then 	ben_flex118	=	T5787101	;
ben_flex119	= .;	if	T5787201	>= 0 and	T5787201	<= 1 then 	ben_flex119	=	T5787201	;
ben_flex120	= .;	if	T5787301	>= 0 and	T5787301	<= 1 then 	ben_flex120	=	T5787301	;
ben_flex121	= .;	if	T5787401	>= 0 and	T5787401	<= 1 then 	ben_flex121	=	T5787401	;
ben_flex122	= .;	if	T5787501	>= 0 and	T5787501	<= 1 then 	ben_flex122	=	T5787501	;

ben_life114	= .;	if	T5786703	>= 0 and	T5786703	<= 1 then 	ben_life114	=	T5786703	;
ben_life115	= .;	if	T5786803	>= 0 and	T5786803	<= 1 then 	ben_life115	=	T5786803	;
ben_life116	= .;	if	T5786903	>= 0 and	T5786903	<= 1 then 	ben_life116	=	T5786903	;
ben_life117	= .;	if	T5787003	>= 0 and	T5787003	<= 1 then 	ben_life117	=	T5787003	;
ben_life118	= .;	if	T5787103	>= 0 and	T5787103	<= 1 then 	ben_life118	=	T5787103	;
ben_life119	= .;	if	T5787203	>= 0 and	T5787203	<= 1 then 	ben_life119	=	T5787203	;
ben_life120	= .;	if	T5787303	>= 0 and	T5787303	<= 1 then 	ben_life120	=	T5787303	;
ben_life121	= .;	if	T5787403	>= 0 and	T5787403	<= 1 then 	ben_life121	=	T5787403	;
ben_life122	= .;	if	T5787503	>= 0 and	T5787503	<= 1 then 	ben_life122	=	T5787503	;

ben_dental114	= .;	if	T5786704	>= 0 and	T5786704	<= 1 then 	ben_dental114	=	T5786704	;
ben_dental115	= .;	if	T5786804	>= 0 and	T5786804	<= 1 then 	ben_dental115	=	T5786804	;
ben_dental116	= .;	if	T5786904	>= 0 and	T5786904	<= 1 then 	ben_dental116	=	T5786904	;
ben_dental117	= .;	if	T5787004	>= 0 and	T5787004	<= 1 then 	ben_dental117	=	T5787004	;
ben_dental118	= .;	if	T5787104	>= 0 and	T5787104	<= 1 then 	ben_dental118	=	T5787104	;
ben_dental119	= .;	if	T5787204	>= 0 and	T5787204	<= 1 then 	ben_dental119	=	T5787204	;
ben_dental120	= .;	if	T5787304	>= 0 and	T5787304	<= 1 then 	ben_dental120	=	T5787304	;
ben_dental121	= .;	if	T5787404	>= 0 and	T5787404	<= 1 then 	ben_dental121	=	T5787404	;
ben_dental122	= .;	if	T5787504	>= 0 and	T5787504	<= 1 then 	ben_dental122	=	T5787504	;

ben_pdleave114	= .;	if	T5786705	>= 0 and	T5786705	<= 1 then 	ben_pdleave114	=	T5786705	;
ben_pdleave115	= .;	if	T5786805	>= 0 and	T5786805	<= 1 then 	ben_pdleave115	=	T5786805	;
ben_pdleave116	= .;	if	T5786905	>= 0 and	T5786905	<= 1 then 	ben_pdleave116	=	T5786905	;
ben_pdleave117	= .;	if	T5787005	>= 0 and	T5787005	<= 1 then 	ben_pdleave117	=	T5787005	;
ben_pdleave118	= .;	if	T5787105	>= 0 and	T5787105	<= 1 then 	ben_pdleave118	=	T5787105	;
ben_pdleave119	= .;	if	T5787205	>= 0 and	T5787205	<= 1 then 	ben_pdleave119	=	T5787205	;
ben_pdleave120	= .;	if	T5787305	>= 0 and	T5787305	<= 1 then 	ben_pdleave120	=	T5787305	;
ben_pdleave121	= .;	if	T5787405	>= 0 and	T5787405	<= 1 then 	ben_pdleave121	=	T5787405	;
ben_pdleave122	= .;	if	T5787505	>= 0 and	T5787505	<= 1 then 	ben_pdleave122	=	T5787505	;

ben_unpdleave114	= .;	if	T5786706	>= 0 and	T5786706	<= 1 then 	ben_unpdleave114	=	T5786706	;
ben_unpdleave115	= .;	if	T5786806	>= 0 and	T5786806	<= 1 then 	ben_unpdleave115	=	T5786806	;
ben_unpdleave116	= .;	if	T5786906	>= 0 and	T5786906	<= 1 then 	ben_unpdleave116	=	T5786906	;
ben_unpdleave117	= .;	if	T5787006	>= 0 and	T5787006	<= 1 then 	ben_unpdleave117	=	T5787006	;
ben_unpdleave118	= .;	if	T5787106	>= 0 and	T5787106	<= 1 then 	ben_unpdleave118	=	T5787106	;
ben_unpdleave119	= .;	if	T5787206	>= 0 and	T5787206	<= 1 then 	ben_unpdleave119	=	T5787206	;
ben_unpdleave120	= .;	if	T5787306	>= 0 and	T5787306	<= 1 then 	ben_unpdleave120	=	T5787306	;
ben_unpdleave121	= .;	if	T5787406	>= 0 and	T5787406	<= 1 then 	ben_unpdleave121	=	T5787406	;
ben_unpdleave122	= .;	if	T5787506	>= 0 and	T5787506	<= 1 then 	ben_unpdleave122	=	T5787506	;

ben_retire114	= .;	if	T5786707	>= 0 and	T5786707	<= 1 then 	ben_retire114	=	T5786707	;
ben_retire115	= .;	if	T5786807	>= 0 and	T5786807	<= 1 then 	ben_retire115	=	T5786807	;
ben_retire116	= .;	if	T5786907	>= 0 and	T5786907	<= 1 then 	ben_retire116	=	T5786907	;
ben_retire117	= .;	if	T5787007	>= 0 and	T5787007	<= 1 then 	ben_retire117	=	T5787007	;
ben_retire118	= .;	if	T5787107	>= 0 and	T5787107	<= 1 then 	ben_retire118	=	T5787107	;
ben_retire119	= .;	if	T5787207	>= 0 and	T5787207	<= 1 then 	ben_retire119	=	T5787207	;
ben_retire120	= .;	if	T5787307	>= 0 and	T5787307	<= 1 then 	ben_retire120	=	T5787307	;
ben_retire121	= .;	if	T5787407	>= 0 and	T5787407	<= 1 then 	ben_retire121	=	T5787407	;
ben_retire122	= .;	if	T5787507	>= 0 and	T5787507	<= 1 then 	ben_retire122	=	T5787507	;

ben_tuition114	= .;	if	T5786708	>= 0 and	T5786708	<= 1 then 	ben_tuition114	=	T5786708	;
ben_tuition115	= .;	if	T5786808	>= 0 and	T5786808	<= 1 then 	ben_tuition115	=	T5786808	;
ben_tuition116	= .;	if	T5786908	>= 0 and	T5786908	<= 1 then 	ben_tuition116	=	T5786908	;
ben_tuition117	= .;	if	T5787008	>= 0 and	T5787008	<= 1 then 	ben_tuition117	=	T5787008	;
ben_tuition118	= .;	if	T5787108	>= 0 and	T5787108	<= 1 then 	ben_tuition118	=	T5787108	;
ben_tuition119	= .;	if	T5787208	>= 0 and	T5787208	<= 1 then 	ben_tuition119	=	T5787208	;
ben_tuition120	= .;	if	T5787308	>= 0 and	T5787308	<= 1 then 	ben_tuition120	=	T5787308	;
ben_tuition121	= .;	if	T5787408	>= 0 and	T5787408	<= 1 then 	ben_tuition121	=	T5787408	;
ben_tuition122	= .;	if	T5787508	>= 0 and	T5787508	<= 1 then 	ben_tuition122	=	T5787508	;

ben_child114	= .;	if	T5786709	>= 0 and	T5786709	<= 1 then 	ben_child114	=	T5786709	;
ben_child115	= .;	if	T5786809	>= 0 and	T5786809	<= 1 then 	ben_child115	=	T5786809	;
ben_child116	= .;	if	T5786909	>= 0 and	T5786909	<= 1 then 	ben_child116	=	T5786909	;
ben_child117	= .;	if	T5787009	>= 0 and	T5787009	<= 1 then 	ben_child117	=	T5787009	;
ben_child118	= .;	if	T5787109	>= 0 and	T5787109	<= 1 then 	ben_child118	=	T5787109	;
ben_child119	= .;	if	T5787209	>= 0 and	T5787209	<= 1 then 	ben_child119	=	T5787209	;
ben_child120	= .;	if	T5787309	>= 0 and	T5787309	<= 1 then 	ben_child120	=	T5787309	;
ben_child121	= .;	if	T5787409	>= 0 and	T5787409	<= 1 then 	ben_child121	=	T5787409	;
ben_child122	= .;	if	T5787509	>= 0 and	T5787509	<= 1 then 	ben_child122	=	T5787509	;

ben_stock114	= .;	if	T5786710	>= 0 and	T5786710	<= 1 then 	ben_stock114	=	T5786710	;
ben_stock115	= .;	if	T5786810	>= 0 and	T5786810	<= 1 then 	ben_stock115	=	T5786810	;
ben_stock116	= .;	if	T5786910	>= 0 and	T5786910	<= 1 then 	ben_stock116	=	T5786910	;
ben_stock117	= .;	if	T5787010	>= 0 and	T5787010	<= 1 then 	ben_stock117	=	T5787010	;
ben_stock118	= .;	if	T5787110	>= 0 and	T5787110	<= 1 then 	ben_stock118	=	T5787110	;
ben_stock119	= .;	if	T5787210	>= 0 and	T5787210	<= 1 then 	ben_stock119	=	T5787210	;
ben_stock120	= .;	if	T5787310	>= 0 and	T5787310	<= 1 then 	ben_stock120	=	T5787310	;
ben_stock121	= .;	if	T5787410	>= 0 and	T5787410	<= 1 then 	ben_stock121	=	T5787410	;
ben_stock122	= .;	if	T5787510	>= 0 and	T5787510	<= 1 then 	ben_stock122	=	T5787510	;

occcode114	= .; if	T6231000	ge 0 and	T6231000	le 9990 then	occcode114	=	T6231000	;
occcode115	= .; if	T6231100	ge 0 and	T6231100	le 9990 then	occcode115	=	T6231100	;
occcode116	= .; if	T6231200	ge 0 and	T6231200	le 9990 then	occcode116	=	T6231200	;
occcode117	= .; if	T6231300	ge 0 and	T6231300	le 9990 then	occcode117	=	T6231300	;
occcode118	= .; if	T6231400	ge 0 and	T6231400	le 9990 then	occcode118	=	T6231400	;
occcode119	= .; if	T6231500	ge 0 and	T6231500	le 9990 then	occcode119	=	T6231500	;
occcode120	= .; if	T6231600	ge 0 and	T6231600	le 9990 then	occcode120	=	T6231600	;
occcode121	= .; if	T6231700	ge 0 and	T6231700	le 9990 then	occcode121	=	T6231700	;
occcode122	= .; if	T6231800	ge 0 and	T6231800	le 9990 then	occcode122	=	T6231800	;

indcode114	= .; if	T6230100	ge 0 and	T6230100	le 9990 then	indcode114	=	T6230100	;
indcode115	= .; if	T6230200	ge 0 and	T6230200	le 9990 then	indcode115	=	T6230200	;
indcode116	= .; if	T6230300	ge 0 and	T6230300	le 9990 then	indcode116	=	T6230300	;
indcode117	= .; if	T6230400	ge 0 and	T6230400	le 9990 then	indcode117	=	T6230400	;
indcode118	= .; if	T6230500	ge 0 and	T6230500	le 9990 then	indcode118	=	T6230500	;
indcode119	= .; if	T6230600	ge 0 and	T6230600	le 9990 then	indcode119	=	T6230600	;
indcode120	= .; if	T6230700	ge 0 and	T6230700	le 9990 then	indcode120	=	T6230700	;
indcode121	= .; if	T6230800	ge 0 and	T6230800	le 9990 then	indcode121	=	T6230800	;
indcode122	= .; if	T6230900	ge 0 and	T6230900	le 9990 then	indcode122	=	T6230900	;

jobtype114	= .; if	T5583900	ge 1 &	T5583900	le 5 then	jobtype114	=	T5583900	;
jobtype115	= .; if	T5584000	ge 1 &	T5584000	le 5 then	jobtype115	=	T5584000	;
jobtype116	= .; if	T5584100	ge 1 &	T5584100	le 5 then	jobtype116	=	T5584100	;
jobtype117	= .; if	T5584200	ge 1 &	T5584200	le 5 then	jobtype117	=	T5584200	;
jobtype118	= .; if	T5584300	ge 1 &	T5584300	le 5 then	jobtype118	=	T5584300	;
jobtype119	= .; if	T5584400	ge 1 &	T5584400	le 5 then	jobtype119	=	T5584400	;
jobtype120	= .; if	T5584500	ge 1 &	T5584500	le 5 then	jobtype120	=	T5584500	;
jobtype121	= .; if	T5584600	ge 1 &	T5584600	le 5 then	jobtype121	=	T5584600	;
jobtype122 = .;

hourswk114	= .; if	T5209400	ge 0 &	T5209400	le 168 then	hourswk114	=	T5209400	;
hourswk115	= .; if	T5209500	ge 0 &	T5209500	le 168 then	hourswk115	=	T5209500	;
hourswk116	= .; if	T5209600	ge 0 &	T5209600	le 168 then	hourswk116	=	T5209600	;
hourswk117	= .; if	T5209700	ge 0 &	T5209700	le 168 then	hourswk117	=	T5209700	;
hourswk118	= .; if	T5209800	ge 0 &	T5209800	le 168 then	hourswk118	=	T5209800	;
hourswk119	= .; if	T5209900	ge 0 &	T5209900	le 168 then	hourswk119	=	T5209900	;
hourswk120	= .; if	T5210000	ge 0 &	T5210000	le 168 then	hourswk120	=	T5210000	;
hourswk121	= .; if	T5210100	ge 0 &	T5210100	le 168 then	hourswk121	=	T5210100	;
hourswk122	= .; if	T5210200	ge 0 &	T5210200	le 168 then	hourswk122	=	T5210200	;

anygap114	= .; if	T5816200	ge -2 &	T5816200	le 0 then	anygap114	=	0	;	if 	T5816200	eq 1 then	anygap114	=	1	;
anygap115	= .; if	T5816300	ge -2 &	T5816300	le 0 then	anygap115	=	0	;	if 	T5816300	eq 1 then	anygap115	=	1	;
anygap116	= .; if	T5816400	ge -2 &	T5816400	le 0 then	anygap116	=	0	;	if 	T5816400	eq 1 then	anygap116	=	1	;
anygap117	= .; if	T5816500	ge -2 &	T5816500	le 0 then	anygap117	=	0	;	if 	T5816500	eq 1 then	anygap117	=	1	;
anygap118	= .; if	T5816600	ge -2 &	T5816600	le 0 then	anygap118	=	0	;	if 	T5816600	eq 1 then	anygap118	=	1	;
anygap119	= .; if	T5816700	ge -2 &	T5816700	le 0 then	anygap119	=	0	;	if 	T5816700	eq 1 then	anygap119	=	1	;
anygap120	= .; if	T5816800	ge -2 &	T5816800	le 0 then	anygap120	=	0	;	if 	T5816800	eq 1 then	anygap120	=	1	;
anygap121	= .; if	T5816900	ge -2 &	T5816900	le 0 then	anygap121	=	0	;	if 	T5816900	eq 1 then	anygap121	=	1	;
anygap122	= .; if	T5817000	ge -2 &	T5817000	le 0 then	anygap122	=	0	;	if 	T5817000	eq 1 then	anygap122	=	1	;

worksched114	= .; if	T5785800	ge 1 &	T5785800	le 9 then	worksched114	=	T5785800	;
worksched115	= .; if	T5785900	ge 1 &	T5785900	le 9 then	worksched115	=	T5785900	;
worksched116	= .; if	T5786000	ge 1 &	T5786000	le 9 then	worksched116	=	T5786000	;
worksched117	= .; if	T5786100	ge 1 &	T5786100	le 9 then	worksched117	=	T5786100	;
worksched118	= .; if	T5786200	ge 1 &	T5786200	le 9 then	worksched118	=	T5786200	;
worksched119	= .; if	T5786300	ge 1 &	T5786300	le 9 then	worksched119	=	T5786300	;
worksched120	= .; if	T5786400	ge 1 &	T5786400	le 9 then	worksched120	=	T5786400	;
worksched121	= .; if	T5786500	ge 1 &	T5786500	le 9 then	worksched121	=	T5786500	;
worksched122	= .; if	T5786600	ge 1 &	T5786600	le 9 then	worksched122	=	T5786600	;

/* 2011: up to 13 *************************************************************/

idjob123 = .; if (T7961200 >= 0 & T7961200 <= 300000) then idjob123	= T7961200;
idjob124 = .; if (T7961300 >= 0 & T7961300 <= 300000) then idjob124	= T7961300;
idjob125 = .; if (T7961400 >= 0 & T7961400 <= 300000) then idjob125	= T7961400;
idjob126 = .; if (T7961500 >= 0 & T7961500 <= 300000) then idjob126	= T7961500;
idjob127 = .; if (T7961600 >= 0 & T7961600 <= 300000) then idjob127	= T7961600;
idjob128 = .; if (T7961700 >= 0 & T7961700 <= 300000) then idjob128	= T7961700;
idjob129 = .; if (T7961800 >= 0 & T7961800 <= 300000) then idjob129	= T7961800;
idjob130 = .; if (T7961900 >= 0 & T7961900 <= 300000) then idjob130	= T7961900;
idjob131 = .; if (T7962000 >= 0 & T7962000 <= 300000) then idjob131	= T7962000;
idjob132 = .; if (T7962100 >= 0 & T7962100 <= 300000) then idjob132	= T7962100;
idjob133 = .; if (T7962200 >= 0 & T7962200 <= 300000) then idjob133	= T7962200;
idjob134 = .; if (T7962300 >= 0 & T7962300 <= 300000) then idjob134	= T7962300;
idjob135 = .; if (T7962400 >= 0 & T7962400 <= 300000) then idjob135	= T7962400;

/* Only 12 (no 13) */

whyleftjob123 = .;	if (T7207400 >= 0 &	T7207400 <= 50) then whyleftjob123	= T7207400;
whyleftjob124 = .;	if (T7207500 >= 0 &	T7207500 <= 50) then whyleftjob124	= T7207500;
whyleftjob125 = .;	if (T7207600 >= 0 &	T7207600 <= 50) then whyleftjob125	= T7207600;
whyleftjob126 = .;	if (T7207700 >= 0 &	T7207700 <= 50) then whyleftjob126	= T7207700;
whyleftjob127 = .;	if (T7207800 >= 0 &	T7207800 <= 50) then whyleftjob127	= T7207800;
whyleftjob128 = .;	if (T7207900 >= 0 &	T7207900 <= 50) then whyleftjob128	= T7207900;
whyleftjob129 = .;	if (T7208000 >= 0 &	T7208000 <= 50) then whyleftjob129	= T7208000;
whyleftjob130 = .;	if (T7208100 >= 0 &	T7208100 <= 50) then whyleftjob130	= T7208100;
whyleftjob131 = .;	if (T7208200 >= 0 &	T7208200 <= 50) then whyleftjob131	= T7208200;
whyleftjob132 = .;	if (T7208300 >= 0 &	T7208300 <= 50) then whyleftjob132	= T7208300;
whyleftjob133 = .;	if (T7208400 >= 0 &	T7208400 <= 50) then whyleftjob133	= T7208400;
whyleftjob134 = .;	if (T7208500 >= 0 &	T7208500 <= 50) then whyleftjob134	= T7208500;
whyleftjob135 = .;

curjob123	= .; if	T7887400	>= 0 &	T7887400	<= 1 then	curjob123	=	T7887400	;
curjob124	= .; if	T7887500	>= 0 &	T7887500	<= 1 then	curjob124	=	T7887500	;
curjob125	= .; if	T7887600	>= 0 &	T7887600	<= 1 then	curjob125	=	T7887600	;
curjob126	= .; if	T7887700	>= 0 &	T7887700	<= 1 then	curjob126	=	T7887700	;
curjob127	= .; if	T7887800	>= 0 &	T7887800	<= 1 then	curjob127	=	T7887800	;
curjob128	= .; if	T7887900	>= 0 &	T7887900	<= 1 then	curjob128	=	T7887900	;
curjob129	= .; if	T7888000	>= 0 &	T7888000	<= 1 then	curjob129	=	T7888000	;
curjob130	= .; if	T7888100	>= 0 &	T7888100	<= 1 then	curjob130	=	T7888100	;
curjob131	= .; if	T7888200	>= 0 &	T7888200	<= 1 then	curjob131	=	T7888200	;
curjob132	= .; if	T7888300	>= 0 &	T7888300	<= 1 then	curjob132	=	T7888300	;
curjob133	= .; if	T7888400	>= 0 &	T7888400	<= 1 then	curjob133	=	T7888400	;
curjob134	= .; if	T7888500	>= 0 &	T7888500	<= 1 then	curjob134	=	T7888500	;
curjob135	= .; if	T7888600	>= 0 &	T7888600	<= 1 then	curjob135	=	T7888600	;

intmo123 = T6661300;
intmo124 = T6661300;
intmo125 = T6661300;
intmo126 = T6661300;
intmo127 = T6661300;
intmo128 = T6661300;
intmo129 = T6661300;
intmo130 = T6661300;
intmo131 = T6661300;
intmo132 = T6661300;
intmo133 = T6661300;
intmo134 = T6661300;
intmo135 = T6661300;

weeksjob123	= .; if (T6663700 >= 0 & T6663700 <= 5000) then	weeksjob123	= T6663700;
weeksjob124	= .; if (T6663800 >= 0 & T6663800 <= 5000) then	weeksjob124	= T6663800;
weeksjob125	= .; if (T6663900 >= 0 & T6663900 <= 5000) then	weeksjob125	= T6663900;
weeksjob126	= .; if (T6664000 >= 0 & T6664000 <= 5000) then	weeksjob126	= T6664000;
weeksjob127	= .; if (T6664100 >= 0 & T6664100 <= 5000) then	weeksjob127	= T6664100;
weeksjob128	= .; if (T6664200 >= 0 & T6664200 <= 5000) then	weeksjob128	= T6664200;
weeksjob129	= .; if (T6664300 >= 0 & T6664300 <= 5000) then	weeksjob129	= T6664300;
weeksjob130	= .; if (T6664400 >= 0 & T6664400 <= 5000) then	weeksjob130	= T6664400;
weeksjob131	= .; if (T6664500 >= 0 & T6664500 <= 5000) then	weeksjob131	= T6664500;
weeksjob132	= .; if (T6664600 >= 0 & T6664600 <= 5000) then	weeksjob132	= T6664600;
weeksjob133	= .; if (T6664700 >= 0 & T6664700 <= 5000) then	weeksjob133	= T6664700;
weeksjob134	= .; if (T6664800 >= 0 & T6664800 <= 5000) then	weeksjob134	= T6664800;
weeksjob135	= .; if (T6664900 >= 0 & T6664900 <= 5000) then	weeksjob135	= T6664900;

startmojob123	=	.;	if	T7925601	>=	0	&	T7925601	<=	12	then	startmojob123	=	T7925601	;			
startmojob124	=	.;	if	T7925701	>=	0	&	T7925701	<=	12	then	startmojob124	=	T7925701	;			
startmojob125	=	.;	if	T7925801	>=	0	&	T7925801	<=	12	then	startmojob125	=	T7925801	;			
startmojob126	=	.;	if	T7925901	>=	0	&	T7925901	<=	12	then	startmojob126	=	T7925901	;			
startmojob127	=	.;	if	T7926001	>=	0	&	T7926001	<=	12	then	startmojob127	=	T7926001	;			
startmojob128	=	.;	if	T7926101	>=	0	&	T7926101	<=	12	then	startmojob128	=	T7926101	;			
startmojob129	=	.;	if	T7926201	>=	0	&	T7926201	<=	12	then	startmojob129	=	T7926201	;			
startmojob130	=	.;	if	T7926301	>=	0	&	T7926301	<=	12	then	startmojob130	=	T7926301	;			
startmojob131	=	.;	if	T7926401	>=	0	&	T7926401	<=	12	then	startmojob131	=	T7926401	;			
startmojob132	=	.;	if	T7926501	>=	0	&	T7926501	<=	12	then	startmojob132	=	T7926501	;			
startmojob133	=	.;	if	T7926601	>=	0	&	T7926601	<=	12	then	startmojob133	=	T7926601	;			
startmojob134	=	.;	if	T7926701	>=	0	&	T7926701	<=	12	then	startmojob134	=	T7926701	;			
startmojob135	=	.;	if	T7926801	>=	0	&	T7926801	<=	12	then	startmojob135	=	T7926801	;			
																		
startyrjob123	=	.;	if	T7925602	>=	1980	&	T7925602	<=	2050	then	startyrjob123	=	T7925602	;			
startyrjob124	=	.;	if	T7925702	>=	1980	&	T7925702	<=	2050	then	startyrjob124	=	T7925702	;			
startyrjob125	=	.;	if	T7925802	>=	1980	&	T7925802	<=	2050	then	startyrjob125	=	T7925802	;			
startyrjob126	=	.;	if	T7925902	>=	1980	&	T7925902	<=	2050	then	startyrjob126	=	T7925902	;			
startyrjob127	=	.;	if	T7926002	>=	1980	&	T7926002	<=	2050	then	startyrjob127	=	T7926002	;			
startyrjob128	=	.;	if	T7926102	>=	1980	&	T7926102	<=	2050	then	startyrjob128	=	T7926102	;			
startyrjob129	=	.;	if	T7926202	>=	1980	&	T7926202	<=	2050	then	startyrjob129	=	T7926202	;			
startyrjob130	=	.;	if	T7926302	>=	1980	&	T7926302	<=	2050	then	startyrjob130	=	T7926302	;			
startyrjob131	=	.;	if	T7926402	>=	1980	&	T7926402	<=	2050	then	startyrjob131	=	T7926402	;			
startyrjob132	=	.;	if	T7926502	>=	1980	&	T7926502	<=	2050	then	startyrjob132	=	T7926502	;			
startyrjob133	=	.;	if	T7926602	>=	1980	&	T7926602	<=	2050	then	startyrjob133	=	T7926602	;			
startyrjob134	=	.;	if	T7926702	>=	1980	&	T7926702	<=	2050	then	startyrjob134	=	T7926702	;			
startyrjob135	=	.;	if	T7926802	>=	1980	&	T7926802	<=	2050	then	startyrjob135	=	T7926802	;			
																		
startcontmo123	=	.;	if	startyrjob123	ne	.	&	startmojob123	ne	.	then	startcontmo123	=	((startyrjob123	-1980)*12)	+	startmojob123	;
startcontmo124	=	.;	if	startyrjob124	ne	.	&	startmojob124	ne	.	then	startcontmo124	=	((startyrjob124	-1980)*12)	+	startmojob124	;
startcontmo125	=	.;	if	startyrjob125	ne	.	&	startmojob125	ne	.	then	startcontmo125	=	((startyrjob125	-1980)*12)	+	startmojob125	;
startcontmo126	=	.;	if	startyrjob126	ne	.	&	startmojob126	ne	.	then	startcontmo126	=	((startyrjob126	-1980)*12)	+	startmojob126	;
startcontmo127	=	.;	if	startyrjob127	ne	.	&	startmojob127	ne	.	then	startcontmo127	=	((startyrjob127	-1980)*12)	+	startmojob127	;
startcontmo128	=	.;	if	startyrjob128	ne	.	&	startmojob128	ne	.	then	startcontmo128	=	((startyrjob128	-1980)*12)	+	startmojob128	;
startcontmo129	=	.;	if	startyrjob129	ne	.	&	startmojob129	ne	.	then	startcontmo129	=	((startyrjob129	-1980)*12)	+	startmojob129	;
startcontmo130	=	.;	if	startyrjob130	ne	.	&	startmojob130	ne	.	then	startcontmo130	=	((startyrjob130	-1980)*12)	+	startmojob130	;
startcontmo131	=	.;	if	startyrjob131	ne	.	&	startmojob131	ne	.	then	startcontmo131	=	((startyrjob131	-1980)*12)	+	startmojob131	;
startcontmo132	=	.;	if	startyrjob132	ne	.	&	startmojob132	ne	.	then	startcontmo132	=	((startyrjob132	-1980)*12)	+	startmojob132	;
startcontmo133	=	.;	if	startyrjob133	ne	.	&	startmojob133	ne	.	then	startcontmo133	=	((startyrjob133	-1980)*12)	+	startmojob133	;
startcontmo134	=	.;	if	startyrjob134	ne	.	&	startmojob134	ne	.	then	startcontmo134	=	((startyrjob134	-1980)*12)	+	startmojob134	;
startcontmo135	=	.;	if	startyrjob135	ne	.	&	startmojob135	ne	.	then	startcontmo135	=	((startyrjob135	-1980)*12)	+	startmojob135	;

endbyst123	= .; if	T7288200	ge 0 &	T7288200	le 1 then	endbyst123	=	T7288200	;
endbyst124	= .; if	T7288300	ge 0 &	T7288300	le 1 then	endbyst124	=	T7288300	;
endbyst125	= .; if	T7288400	ge 0 &	T7288400	le 1 then	endbyst125	=	T7288400	;
endbyst126	= .; if	T7288500	ge 0 &	T7288500	le 1 then	endbyst126	=	T7288500	;
endbyst127	= .; if	T7288600	ge 0 &	T7288600	le 1 then	endbyst127	=	T7288600	;
endbyst128	= .; if	T7288700	ge 0 &	T7288700	le 1 then	endbyst128	=	T7288700	;
endbyst129	= .; if	T7288800	ge 0 &	T7288800	le 1 then	endbyst129	=	T7288800	;
endbyst130	= .; if	T7288900	ge 0 &	T7288900	le 1 then	endbyst130	=	T7288900	;
endbyst131	= .; if	T7289000	ge 0 &	T7289000	le 1 then	endbyst131	=	T7289000	;
endbyst132	= .; if	T7289100	ge 0 &	T7289100	le 1 then	endbyst132	=	T7289100	;
endbyst133	= .; if	T7289200	ge 0 &	T7289200	le 1 then	endbyst133	=	T7289200	;
endbyst134	= .; if	T7289300	ge 0 &	T7289300	le 1 then	endbyst134	=	T7289300	;
endbyst135	= .; if	T7289400	ge 0 &	T7289400	le 1 then	endbyst135	=	T7289400	;

jobsat123	= .;	if	T7242300	>= 1 and	T7242300	<= 5 then 	jobsat123	=	T7242300	;
jobsat124	= .;	if	T7242400	>= 1 and	T7242400	<= 5 then 	jobsat124	=	T7242400	;
jobsat125	= .;	if	T7242500	>= 1 and	T7242500	<= 5 then 	jobsat125	=	T7242500	;
jobsat126	= .;	if	T7242600	>= 1 and	T7242600	<= 5 then 	jobsat126	=	T7242600	;
jobsat127	= .;	if	T7242700	>= 1 and	T7242700	<= 5 then 	jobsat127	=	T7242700	;
jobsat128	= .;	if	T7242800	>= 1 and	T7242800	<= 5 then 	jobsat128	=	T7242800	;
jobsat129	= .;	if	T7242900	>= 1 and	T7242900	<= 5 then 	jobsat129	=	T7242900	;
jobsat130	= .;	if	T7243000	>= 1 and	T7243000	<= 5 then 	jobsat130	=	T7243000	;
jobsat131	= .;	if	T7243100	>= 1 and	T7243100	<= 5 then 	jobsat131	=	T7243100	;
jobsat132	= .;	if	T7243200	>= 1 and	T7243200	<= 5 then 	jobsat132	=	T7243200	;
jobsat133	= .;	if	T7243300	>= 1 and	T7243300	<= 5 then 	jobsat133	=	T7243300	;
jobsat134	= .;	if	T7243400	>= 1 and	T7243400	<= 5 then 	jobsat134	=	T7243400	;
jobsat135	= .;	if	T7243500	>= 1 and	T7243500	<= 5 then 	jobsat135	=	T7243500	;

union123	= .;	if	T7231400	>= 0 and	T7231400	<= 1 then 	union123	=	T7231400	;
union124	= .;	if	T7231500	>= 0 and	T7231500	<= 1 then 	union124	=	T7231500	;
union125	= .;	if	T7231600	>= 0 and	T7231600	<= 1 then 	union125	=	T7231600	;
union126	= .;	if	T7231700	>= 0 and	T7231700	<= 1 then 	union126	=	T7231700	;
union127	= .;	if	T7231800	>= 0 and	T7231800	<= 1 then 	union127	=	T7231800	;
union128	= .;	if	T7231900	>= 0 and	T7231900	<= 1 then 	union128	=	T7231900	;
union129	= .;	if	T7232000	>= 0 and	T7232000	<= 1 then 	union129	=	T7232000	;
union130	= .;	if	T7232100	>= 0 and	T7232100	<= 1 then 	union130	=	T7232100	;
union131	= .;	if	T7232200	>= 0 and	T7232200	<= 1 then 	union131	=	T7232200	;
union132	= .;	if	T7232300	>= 0 and	T7232300	<= 1 then 	union132	=	T7232300	;
union133	= .;	if	T7232400	>= 0 and	T7232400	<= 1 then 	union133	=	T7232400	;
union134	= .;	if	T7232500	>= 0 and	T7232500	<= 1 then 	union134	=	T7232500	;
union135 = .;

ben_med123	= .;	if	T7218602	>= 0 and	T7218602	<= 1 then 	ben_med123	=	T7218602	;
ben_med124	= .;	if	T7218702	>= 0 and	T7218702	<= 1 then 	ben_med124	=	T7218702	;
ben_med125	= .;	if	T7218802	>= 0 and	T7218802	<= 1 then 	ben_med125	=	T7218802	;
ben_med126	= .;	if	T7218902	>= 0 and	T7218902	<= 1 then 	ben_med126	=	T7218902	;
ben_med127	= .;	if	T7219002	>= 0 and	T7219002	<= 1 then 	ben_med127	=	T7219002	;
ben_med128	= .;	if	T7219102	>= 0 and	T7219102	<= 1 then 	ben_med128	=	T7219102	;
ben_med129	= .;	if	T7219202	>= 0 and	T7219202	<= 1 then 	ben_med129	=	T7219202	;
ben_med130	= .;	if	T7219302	>= 0 and	T7219302	<= 1 then 	ben_med130	=	T7219302	;
ben_med131	= .;	if	T7219402	>= 0 and	T7219402	<= 1 then 	ben_med131	=	T7219402	;
ben_med132	= .;	if	T7219502	>= 0 and	T7219502	<= 1 then 	ben_med132	=	T7219502	;
ben_med133	= .;	if	T7219602	>= 0 and	T7219602	<= 1 then 	ben_med133	=	T7219602	;
ben_med134	= .;	if	T7219702	>= 0 and	T7219702	<= 1 then 	ben_med134	=	T7219702	;
ben_med135 = .;

ben_flex123	= .;	if	T7218601	>= 0 and	T7218601	<= 1 then 	ben_flex123	=	T7218601	;
ben_flex124	= .;	if	T7218701	>= 0 and	T7218701	<= 1 then 	ben_flex124	=	T7218701	;
ben_flex125	= .;	if	T7218801	>= 0 and	T7218801	<= 1 then 	ben_flex125	=	T7218801	;
ben_flex126	= .;	if	T7218901	>= 0 and	T7218901	<= 1 then 	ben_flex126	=	T7218901	;
ben_flex127	= .;	if	T7219001	>= 0 and	T7219001	<= 1 then 	ben_flex127	=	T7219001	;
ben_flex128	= .;	if	T7219101	>= 0 and	T7219101	<= 1 then 	ben_flex128	=	T7219101	;
ben_flex129	= .;	if	T7219201	>= 0 and	T7219201	<= 1 then 	ben_flex129	=	T7219201	;
ben_flex130	= .;	if	T7219301	>= 0 and	T7219301	<= 1 then 	ben_flex130	=	T7219301	;
ben_flex131	= .;	if	T7219401	>= 0 and	T7219401	<= 1 then 	ben_flex131	=	T7219401	;
ben_flex132	= .;	if	T7219501	>= 0 and	T7219501	<= 1 then 	ben_flex132	=	T7219501	;
ben_flex133	= .;	if	T7219601	>= 0 and	T7219601	<= 1 then 	ben_flex133	=	T7219601	;
ben_flex134	= .;	if	T7219701	>= 0 and	T7219701	<= 1 then 	ben_flex134	=	T7219701	;
ben_flex135 = .;

ben_life123	= .;	if	T7218603	>= 0 and	T7218603	<= 1 then 	ben_life123	=	T7218603	;
ben_life124	= .;	if	T7218703	>= 0 and	T7218703	<= 1 then 	ben_life124	=	T7218703	;
ben_life125	= .;	if	T7218803	>= 0 and	T7218803	<= 1 then 	ben_life125	=	T7218803	;
ben_life126	= .;	if	T7218903	>= 0 and	T7218903	<= 1 then 	ben_life126	=	T7218903	;
ben_life127	= .;	if	T7219003	>= 0 and	T7219003	<= 1 then 	ben_life127	=	T7219003	;
ben_life128	= .;	if	T7219103	>= 0 and	T7219103	<= 1 then 	ben_life128	=	T7219103	;
ben_life129	= .;	if	T7219203	>= 0 and	T7219203	<= 1 then 	ben_life129	=	T7219203	;
ben_life130	= .;	if	T7219303	>= 0 and	T7219303	<= 1 then 	ben_life130	=	T7219303	;
ben_life131	= .;	if	T7219403	>= 0 and	T7219403	<= 1 then 	ben_life131	=	T7219403	;
ben_life132	= .;	if	T7219503	>= 0 and	T7219503	<= 1 then 	ben_life132	=	T7219503	;
ben_life133	= .;	if	T7219603	>= 0 and	T7219603	<= 1 then 	ben_life133	=	T7219603	;
ben_life134	= .;	if	T7219703	>= 0 and	T7219703	<= 1 then 	ben_life134	=	T7219703	;
ben_life135 = .;

ben_dental123	= .;	if	T7218604	>= 0 and	T7218604	<= 1 then 	ben_dental123	=	T7218604	;
ben_dental124	= .;	if	T7218704	>= 0 and	T7218704	<= 1 then 	ben_dental124	=	T7218704	;
ben_dental125	= .;	if	T7218804	>= 0 and	T7218804	<= 1 then 	ben_dental125	=	T7218804	;
ben_dental126	= .;	if	T7218904	>= 0 and	T7218904	<= 1 then 	ben_dental126	=	T7218904	;
ben_dental127	= .;	if	T7219004	>= 0 and	T7219004	<= 1 then 	ben_dental127	=	T7219004	;
ben_dental128	= .;	if	T7219104	>= 0 and	T7219104	<= 1 then 	ben_dental128	=	T7219104	;
ben_dental129	= .;	if	T7219204	>= 0 and	T7219204	<= 1 then 	ben_dental129	=	T7219204	;
ben_dental130	= .;	if	T7219304	>= 0 and	T7219304	<= 1 then 	ben_dental130	=	T7219304	;
ben_dental131	= .;	if	T7219404	>= 0 and	T7219404	<= 1 then 	ben_dental131	=	T7219404	;
ben_dental132	= .;	if	T7219504	>= 0 and	T7219504	<= 1 then 	ben_dental132	=	T7219504	;
ben_dental133	= .;	if	T7219604	>= 0 and	T7219604	<= 1 then 	ben_dental133	=	T7219604	;
ben_dental134	= .;	if	T7219704	>= 0 and	T7219704	<= 1 then 	ben_dental134	=	T7219704	;
ben_dental135 = .;

ben_pdleave123	= .;	if	T7218605	>= 0 and	T7218605	<= 1 then 	ben_pdleave123	=	T7218605	;
ben_pdleave124	= .;	if	T7218705	>= 0 and	T7218705	<= 1 then 	ben_pdleave124	=	T7218705	;
ben_pdleave125	= .;	if	T7218805	>= 0 and	T7218805	<= 1 then 	ben_pdleave125	=	T7218805	;
ben_pdleave126	= .;	if	T7218905	>= 0 and	T7218905	<= 1 then 	ben_pdleave126	=	T7218905	;
ben_pdleave127	= .;	if	T7219005	>= 0 and	T7219005	<= 1 then 	ben_pdleave127	=	T7219005	;
ben_pdleave128	= .;	if	T7219105	>= 0 and	T7219105	<= 1 then 	ben_pdleave128	=	T7219105	;
ben_pdleave129	= .;	if	T7219205	>= 0 and	T7219205	<= 1 then 	ben_pdleave129	=	T7219205	;
ben_pdleave130	= .;	if	T7219305	>= 0 and	T7219305	<= 1 then 	ben_pdleave130	=	T7219305	;
ben_pdleave131	= .;	if	T7219405	>= 0 and	T7219405	<= 1 then 	ben_pdleave131	=	T7219405	;
ben_pdleave132	= .;	if	T7219505	>= 0 and	T7219505	<= 1 then 	ben_pdleave132	=	T7219505	;
ben_pdleave133	= .;	if	T7219605	>= 0 and	T7219605	<= 1 then 	ben_pdleave133	=	T7219605	;
ben_pdleave134	= .;	if	T7219705	>= 0 and	T7219705	<= 1 then 	ben_pdleave134	=	T7219705	;
ben_pdleave135 = .;

ben_unpdleave123	= .;	if	T7218606	>= 0 and	T7218606	<= 1 then 	ben_unpdleave123	=	T7218606	;
ben_unpdleave124	= .;	if	T7218706	>= 0 and	T7218706	<= 1 then 	ben_unpdleave124	=	T7218706	;
ben_unpdleave125	= .;	if	T7218806	>= 0 and	T7218806	<= 1 then 	ben_unpdleave125	=	T7218806	;
ben_unpdleave126	= .;	if	T7218906	>= 0 and	T7218906	<= 1 then 	ben_unpdleave126	=	T7218906	;
ben_unpdleave127	= .;	if	T7219006	>= 0 and	T7219006	<= 1 then 	ben_unpdleave127	=	T7219006	;
ben_unpdleave128	= .;	if	T7219106	>= 0 and	T7219106	<= 1 then 	ben_unpdleave128	=	T7219106	;
ben_unpdleave129	= .;	if	T7219206	>= 0 and	T7219206	<= 1 then 	ben_unpdleave129	=	T7219206	;
ben_unpdleave130	= .;	if	T7219306	>= 0 and	T7219306	<= 1 then 	ben_unpdleave130	=	T7219306	;
ben_unpdleave131	= .;	if	T7219406	>= 0 and	T7219406	<= 1 then 	ben_unpdleave131	=	T7219406	;
ben_unpdleave132	= .;	if	T7219506	>= 0 and	T7219506	<= 1 then 	ben_unpdleave132	=	T7219506	;
ben_unpdleave133	= .;	if	T7219606	>= 0 and	T7219606	<= 1 then 	ben_unpdleave133	=	T7219606	;
ben_unpdleave134	= .;	if	T7219706	>= 0 and	T7219706	<= 1 then 	ben_unpdleave134	=	T7219706	;
ben_unpdleave135 = .;

ben_retire123	= .;	if	T7218607	>= 0 and	T7218607	<= 1 then 	ben_retire123	=	T7218607	;
ben_retire124	= .;	if	T7218707	>= 0 and	T7218707	<= 1 then 	ben_retire124	=	T7218707	;
ben_retire125	= .;	if	T7218807	>= 0 and	T7218807	<= 1 then 	ben_retire125	=	T7218807	;
ben_retire126	= .;	if	T7218907	>= 0 and	T7218907	<= 1 then 	ben_retire126	=	T7218907	;
ben_retire127	= .;	if	T7219007	>= 0 and	T7219007	<= 1 then 	ben_retire127	=	T7219007	;
ben_retire128	= .;	if	T7219107	>= 0 and	T7219107	<= 1 then 	ben_retire128	=	T7219107	;
ben_retire129	= .;	if	T7219207	>= 0 and	T7219207	<= 1 then 	ben_retire129	=	T7219207	;
ben_retire130	= .;	if	T7219307	>= 0 and	T7219307	<= 1 then 	ben_retire130	=	T7219307	;
ben_retire131	= .;	if	T7219407	>= 0 and	T7219407	<= 1 then 	ben_retire131	=	T7219407	;
ben_retire132	= .;	if	T7219507	>= 0 and	T7219507	<= 1 then 	ben_retire132	=	T7219507	;
ben_retire133	= .;	if	T7219607	>= 0 and	T7219607	<= 1 then 	ben_retire133	=	T7219607	;
ben_retire134	= .;	if	T7219707	>= 0 and	T7219707	<= 1 then 	ben_retire134	=	T7219707	;
ben_retire135 = .;

ben_tuition123	= .;	if	T7218608	>= 0 and	T7218608	<= 1 then 	ben_tuition123	=	T7218608	;
ben_tuition124	= .;	if	T7218708	>= 0 and	T7218708	<= 1 then 	ben_tuition124	=	T7218708	;
ben_tuition125	= .;	if	T7218808	>= 0 and	T7218808	<= 1 then 	ben_tuition125	=	T7218808	;
ben_tuition126	= .;	if	T7218908	>= 0 and	T7218908	<= 1 then 	ben_tuition126	=	T7218908	;
ben_tuition127	= .;	if	T7219008	>= 0 and	T7219008	<= 1 then 	ben_tuition127	=	T7219008	;
ben_tuition128	= .;	if	T7219108	>= 0 and	T7219108	<= 1 then 	ben_tuition128	=	T7219108	;
ben_tuition129	= .;	if	T7219208	>= 0 and	T7219208	<= 1 then 	ben_tuition129	=	T7219208	;
ben_tuition130	= .;	if	T7219308	>= 0 and	T7219308	<= 1 then 	ben_tuition130	=	T7219308	;
ben_tuition131	= .;	if	T7219408	>= 0 and	T7219408	<= 1 then 	ben_tuition131	=	T7219408	;
ben_tuition132	= .;	if	T7219508	>= 0 and	T7219508	<= 1 then 	ben_tuition132	=	T7219508	;
ben_tuition133	= .;	if	T7219608	>= 0 and	T7219608	<= 1 then 	ben_tuition133	=	T7219608	;
ben_tuition134	= .;	if	T7219708	>= 0 and	T7219708	<= 1 then 	ben_tuition134	=	T7219708	;
ben_tuition135 = .;

ben_child123	= .;	if	T7218609	>= 0 and	T7218609	<= 1 then 	ben_child123	=	T7218609	;
ben_child124	= .;	if	T7218709	>= 0 and	T7218709	<= 1 then 	ben_child124	=	T7218709	;
ben_child125	= .;	if	T7218809	>= 0 and	T7218809	<= 1 then 	ben_child125	=	T7218809	;
ben_child126	= .;	if	T7218909	>= 0 and	T7218909	<= 1 then 	ben_child126	=	T7218909	;
ben_child127	= .;	if	T7219009	>= 0 and	T7219009	<= 1 then 	ben_child127	=	T7219009	;
ben_child128	= .;	if	T7219109	>= 0 and	T7219109	<= 1 then 	ben_child128	=	T7219109	;
ben_child129	= .;	if	T7219209	>= 0 and	T7219209	<= 1 then 	ben_child129	=	T7219209	;
ben_child130	= .;	if	T7219309	>= 0 and	T7219309	<= 1 then 	ben_child130	=	T7219309	;
ben_child131	= .;	if	T7219409	>= 0 and	T7219409	<= 1 then 	ben_child131	=	T7219409	;
ben_child132	= .;	if	T7219509	>= 0 and	T7219509	<= 1 then 	ben_child132	=	T7219509	;
ben_child133	= .;	if	T7219609	>= 0 and	T7219609	<= 1 then 	ben_child133	=	T7219609	;
ben_child134	= .;	if	T7219709	>= 0 and	T7219709	<= 1 then 	ben_child134	=	T7219709	;
ben_child135 = .;

ben_stock123	= .;	if	T7218610	>= 0 and	T7218610	<= 1 then 	ben_stock123	=	T7218610	;
ben_stock124	= .;	if	T7218710	>= 0 and	T7218710	<= 1 then 	ben_stock124	=	T7218710	;
ben_stock125	= .;	if	T7218810	>= 0 and	T7218810	<= 1 then 	ben_stock125	=	T7218810	;
ben_stock126	= .;	if	T7218910	>= 0 and	T7218910	<= 1 then 	ben_stock126	=	T7218910	;
ben_stock127	= .;	if	T7219010	>= 0 and	T7219010	<= 1 then 	ben_stock127	=	T7219010	;
ben_stock128	= .;	if	T7219110	>= 0 and	T7219110	<= 1 then 	ben_stock128	=	T7219110	;
ben_stock129	= .;	if	T7219210	>= 0 and	T7219210	<= 1 then 	ben_stock129	=	T7219210	;
ben_stock130	= .;	if	T7219310	>= 0 and	T7219310	<= 1 then 	ben_stock130	=	T7219310	;
ben_stock131	= .;	if	T7219410	>= 0 and	T7219410	<= 1 then 	ben_stock131	=	T7219410	;
ben_stock132	= .;	if	T7219510	>= 0 and	T7219510	<= 1 then 	ben_stock132	=	T7219510	;
ben_stock133	= .;	if	T7219610	>= 0 and	T7219610	<= 1 then 	ben_stock133	=	T7219610	;
ben_stock134	= .;	if	T7219710	>= 0 and	T7219710	<= 1 then 	ben_stock134	=	T7219710	;
ben_stock135 = .;

occcode123	= .; if	T7732100	ge 0 and	T7732100	le 9990 then	occcode123	=	T7732100	;
occcode124	= .; if	T7732200	ge 0 and	T7732200	le 9990 then	occcode124	=	T7732200	;
occcode125	= .; if	T7732300	ge 0 and	T7732300	le 9990 then	occcode125	=	T7732300	;
occcode126	= .; if	T7732400	ge 0 and	T7732400	le 9990 then	occcode126	=	T7732400	;
occcode127	= .; if	T7732500	ge 0 and	T7732500	le 9990 then	occcode127	=	T7732500	;
occcode128	= .; if	T7732600	ge 0 and	T7732600	le 9990 then	occcode128	=	T7732600	;
occcode129	= .; if	T7732700	ge 0 and	T7732700	le 9990 then	occcode129	=	T7732700	;
occcode130	= .; if	T7732800	ge 0 and	T7732800	le 9990 then	occcode130	=	T7732800	;
occcode131	= .; if	T7732900	ge 0 and	T7732900	le 9990 then	occcode131	=	T7732900	;
occcode132	=.;								
occcode133	=.;								
occcode134	=.;								
occcode135	= .; if	T7733000	ge 0 and	T7733000	le 9990 then	occcode135	=	T7733000	;

indcode123	= .; if	T7731100	ge 0 and	T7731100	le 9990 then	indcode123	=	T7731100	;
indcode124	= .; if	T7731200	ge 0 and	T7731200	le 9990 then	indcode124	=	T7731200	;
indcode125	= .; if	T7731300	ge 0 and	T7731300	le 9990 then	indcode125	=	T7731300	;
indcode126	= .; if	T7731400	ge 0 and	T7731400	le 9990 then	indcode126	=	T7731400	;
indcode127	= .; if	T7731500	ge 0 and	T7731500	le 9990 then	indcode127	=	T7731500	;
indcode128	= .; if	T7731600	ge 0 and	T7731600	le 9990 then	indcode128	=	T7731600	;
indcode129	= .; if	T7731700	ge 0 and	T7731700	le 9990 then	indcode129	=	T7731700	;
indcode130	= .; if	T7731800	ge 0 and	T7731800	le 9990 then	indcode130	=	T7731800	;
indcode131	= .; if	T7731900	ge 0 and	T7731900	le 9990 then	indcode131	=	T7731900	;
indcode132 = .;
indcode133 = .;
indcode134 = .;
indcode135	= .; if	T7732000	ge 0 and	T7732000	le 9990 then	indcode135	=	T7732000	;

jobtype123	= .; if	T6983800	ge 1 &	T6983800	le 5 then	jobtype123	=	T6983800	;
jobtype124	= .; if	T6983900	ge 1 &	T6983900	le 5 then	jobtype124	=	T6983900	;
jobtype125	= .; if	T6984000	ge 1 &	T6984000	le 5 then	jobtype125	=	T6984000	;
jobtype126	= .; if	T6984100	ge 1 &	T6984100	le 5 then	jobtype126	=	T6984100	;
jobtype127	= .; if	T6984200	ge 1 &	T6984200	le 5 then	jobtype127	=	T6984200	;
jobtype128	= .; if	T6984300	ge 1 &	T6984300	le 5 then	jobtype128	=	T6984300	;
jobtype129	= .; if	T6984400	ge 1 &	T6984400	le 5 then	jobtype129	=	T6984400	;
jobtype130	= .; if	T6984500	ge 1 &	T6984500	le 5 then	jobtype130	=	T6984500	;
jobtype131	= .; if	T6984600	ge 1 &	T6984600	le 5 then	jobtype131	=	T6984600	;
jobtype132	= .; if	T6984700	ge 1 &	T6984700	le 5 then	jobtype132	=	T6984700	;
jobtype133	= .; if	T6984800	ge 1 &	T6984800	le 5 then	jobtype133	=	T6984800	;
jobtype134	= .; if	T6984900	ge 1 &	T6984900	le 5 then	jobtype134	=	T6984900	;
jobtype135 = .;

hourswk123	= .; if	T6660000	ge 0 &	T6660000	le 168 then	hourswk123	=	T6660000	;
hourswk124	= .; if	T6660100	ge 0 &	T6660100	le 168 then	hourswk124	=	T6660100	;
hourswk125	= .; if	T6660200	ge 0 &	T6660200	le 168 then	hourswk125	=	T6660200	;
hourswk126	= .; if	T6660300	ge 0 &	T6660300	le 168 then	hourswk126	=	T6660300	;
hourswk127	= .; if	T6660400	ge 0 &	T6660400	le 168 then	hourswk127	=	T6660400	;
hourswk128	= .; if	T6660500	ge 0 &	T6660500	le 168 then	hourswk128	=	T6660500	;
hourswk129	= .; if	T6660600	ge 0 &	T6660600	le 168 then	hourswk129	=	T6660600	;
hourswk130	= .; if	T6660700	ge 0 &	T6660700	le 168 then	hourswk130	=	T6660700	;
hourswk131	= .; if	T6660800	ge 0 &	T6660800	le 168 then	hourswk131	=	T6660800	;
hourswk132	= .; if	T6660900	ge 0 &	T6660900	le 168 then	hourswk132	=	T6660900	;
hourswk133	= .; if	T6661000	ge 0 &	T6661000	le 168 then	hourswk133	=	T6661000	;
hourswk134	= .; if	T6661100	ge 0 &	T6661100	le 168 then	hourswk134	=	T6661100	;
hourswk135	= .; if	T6661200	ge 0 &	T6661200	le 168 then	hourswk135	=	T6661200	;

anygap123	= .; if	T7253000	ge -2 &	T7253000	le 0 then	anygap123	=	0	;	if 	T7253000	eq 1 then	anygap123	=	1	;
anygap124	= .; if	T7253100	ge -2 &	T7253100	le 0 then	anygap124	=	0	;	if 	T7253100	eq 1 then	anygap124	=	1	;
anygap125	= .; if	T7253200	ge -2 &	T7253200	le 0 then	anygap125	=	0	;	if 	T7253200	eq 1 then	anygap125	=	1	;
anygap126	= .; if	T7253300	ge -2 &	T7253300	le 0 then	anygap126	=	0	;	if 	T7253300	eq 1 then	anygap126	=	1	;
anygap127	= .; if	T7253400	ge -2 &	T7253400	le 0 then	anygap127	=	0	;	if 	T7253400	eq 1 then	anygap127	=	1	;
anygap128	= .; if	T7253500	ge -2 &	T7253500	le 0 then	anygap128	=	0	;	if 	T7253500	eq 1 then	anygap128	=	1	;
anygap129	= .; if	T7253600	ge -2 &	T7253600	le 0 then	anygap129	=	0	;	if 	T7253600	eq 1 then	anygap129	=	1	;
anygap130	= .; if	T7253700	ge -2 &	T7253700	le 0 then	anygap130	=	0	;	if 	T7253700	eq 1 then	anygap130	=	1	;
anygap131	= .; if	T7253800	ge -2 &	T7253800	le 0 then	anygap131	=	0	;	if 	T7253800	eq 1 then	anygap131	=	1	;
anygap132	= .; if	T7253900	ge -2 &	T7253900	le 0 then	anygap132	=	0	;	if 	T7253900	eq 1 then	anygap132	=	1	;
anygap133	= .; if	T7254000	ge -2 &	T7254000	le 0 then	anygap133	=	0	;	if 	T7254000	eq 1 then	anygap133	=	1	;
anygap134	= .; if	T7254100	ge -2 &	T7254100	le 0 then	anygap134	=	0	;	if 	T7254100	eq 1 then	anygap134	=	1	;
anygap135 = .;

worksched123	= .; if	T7217400	ge 1 &	T7217400	le 9 then	worksched123	=	T7217400	;
worksched124	= .; if	T7217500	ge 1 &	T7217500	le 9 then	worksched124	=	T7217500	;
worksched125	= .; if	T7217600	ge 1 &	T7217600	le 9 then	worksched125	=	T7217600	;
worksched126	= .; if	T7217700	ge 1 &	T7217700	le 9 then	worksched126	=	T7217700	;
worksched127	= .; if	T7217800	ge 1 &	T7217800	le 9 then	worksched127	=	T7217800	;
worksched128	= .; if	T7217900	ge 1 &	T7217900	le 9 then	worksched128	=	T7217900	;
worksched129	= .; if	T7218000	ge 1 &	T7218000	le 9 then	worksched129	=	T7218000	;
worksched130	= .; if	T7218100	ge 1 &	T7218100	le 9 then	worksched130	=	T7218100	;
worksched131	= .; if	T7218200	ge 1 &	T7218200	le 9 then	worksched131	=	T7218200	;
worksched132	= .; if	T7218300	ge 1 &	T7218300	le 9 then	worksched132	=	T7218300	;
worksched133	= .; if	T7218400	ge 1 &	T7218400	le 9 then	worksched133	=	T7218400	;
worksched134	= .; if	T7218500	ge 1 &	T7218500	le 9 then	worksched134	=	T7218500	;
worksched135	= .; 

/* 2013: up to 10 *************************************************************/

idjob136 = .; if (T9331000 >= 0 & T9331000 <= 300000) then idjob136	= T9331000;
idjob137 = .; if (T9331100 >= 0 & T9331100 <= 300000) then idjob137	= T9331100;
idjob138 = .; if (T9331200 >= 0 & T9331200 <= 300000) then idjob138	= T9331200;
idjob139 = .; if (T9331300 >= 0 & T9331300 <= 300000) then idjob139	= T9331300;
idjob140 = .; if (T9331400 >= 0 & T9331400 <= 300000) then idjob140	= T9331400;
idjob141 = .; if (T9331500 >= 0 & T9331500 <= 300000) then idjob141	= T9331500;
idjob142 = .; if (T9331600 >= 0 & T9331600 <= 300000) then idjob142	= T9331600;
idjob143 = .; if (T9331700 >= 0 & T9331700 <= 300000) then idjob143	= T9331700;
idjob144 = .; if (T9331800 >= 0 & T9331800 <= 300000) then idjob144	= T9331800;
idjob145 = .; if (T9331900 >= 0 & T9331900 <= 300000) then idjob145	= T9331900;

/* Only 9 (no 10) */

whyleftjob136 = .;	if (T8705500 >= 0 &	T8705500 <= 50) then whyleftjob136	= T8705500;
whyleftjob137 = .;	if (T8705600 >= 0 &	T8705600 <= 50) then whyleftjob137	= T8705600;
whyleftjob138 = .;	if (T8705700 >= 0 &	T8705700 <= 50) then whyleftjob138	= T8705700;
whyleftjob139 = .;	if (T8705800 >= 0 &	T8705800 <= 50) then whyleftjob139	= T8705800;
whyleftjob140 = .;	if (T8705900 >= 0 &	T8705900 <= 50) then whyleftjob140	= T8705900;
whyleftjob141 = .;	if (T8706000 >= 0 &	T8706000 <= 50) then whyleftjob141	= T8706000;
whyleftjob142 = .;	if (T8706100 >= 0 &	T8706100 <= 50) then whyleftjob142	= T8706100;
whyleftjob143 = .;	if (T8706200 >= 0 &	T8706200 <= 50) then whyleftjob143	= T8706200;
whyleftjob144 = .;	if (T8706300 >= 0 &	T8706300 <= 50) then whyleftjob144	= T8706300;
whyleftjob145 = .;

curjob136	= .; if	T9328000	>= 0 &	T9328000	<= 1 then	curjob136	=	T9328000	;
curjob137	= .; if	T9328100	>= 0 &	T9328100	<= 1 then	curjob137	=	T9328100	;
curjob138	= .; if	T9328200	>= 0 &	T9328200	<= 1 then	curjob138	=	T9328200	;
curjob139	= .; if	T9328300	>= 0 &	T9328300	<= 1 then	curjob139	=	T9328300	;
curjob140	= .; if	T9328400	>= 0 &	T9328400	<= 1 then	curjob140	=	T9328400	;
curjob141	= .; if	T9328500	>= 0 &	T9328500	<= 1 then	curjob141	=	T9328500	;
curjob142	= .; if	T9328600	>= 0 &	T9328600	<= 1 then	curjob142	=	T9328600	;
curjob143	= .; if	T9328700	>= 0 &	T9328700	<= 1 then	curjob143	=	T9328700	;
curjob144	= .; if	T9328800	>= 0 &	T9328800	<= 1 then	curjob144	=	T9328800	;
curjob145	= .; if	T9328900	>= 0 &	T9328900	<= 1 then	curjob145	=	T9328900	;

intmo136 = T8132800;
intmo137 = T8132800;
intmo138 = T8132800;
intmo139 = T8132800;
intmo140 = T8132800;
intmo141 = T8132800;
intmo142 = T8132800;
intmo143 = T8132800;
intmo144 = T8132800;
intmo145 = T8132800;

weeksjob136	= .; if (T8134900 >= 0 & T8134900 <= 5000) then	weeksjob136	= T8134900;
weeksjob137	= .; if (T8135000 >= 0 & T8135000 <= 5000) then	weeksjob137	= T8135000;
weeksjob138	= .; if (T8135100 >= 0 & T8135100 <= 5000) then	weeksjob138	= T8135100;
weeksjob139	= .; if (T8135200 >= 0 & T8135200 <= 5000) then	weeksjob139	= T8135200;
weeksjob140	= .; if (T8135300 >= 0 & T8135300 <= 5000) then	weeksjob140	= T8135300;
weeksjob141	= .; if (T8135400 >= 0 & T8135400 <= 5000) then	weeksjob141	= T8135400;
weeksjob142	= .; if (T8135500 >= 0 & T8135500 <= 5000) then	weeksjob142	= T8135500;
weeksjob143	= .; if (T8135600 >= 0 & T8135600 <= 5000) then	weeksjob143	= T8135600;
weeksjob144	= .; if (T8135700 >= 0 & T8135700 <= 5000) then	weeksjob144	= T8135700;
weeksjob145	= .; if (T8135800 >= 0 & T8135800 <= 5000) then	weeksjob145	= T8135800;

startmojob136	=	.;	if	T9330001	>=	0	&	T9330001	<=	12	then	startmojob136	=	T9330001	;			
startmojob137	=	.;	if	T9330101	>=	0	&	T9330101	<=	12	then	startmojob137	=	T9330101	;			
startmojob138	=	.;	if	T9330201	>=	0	&	T9330201	<=	12	then	startmojob138	=	T9330201	;			
startmojob139	=	.;	if	T9330301	>=	0	&	T9330301	<=	12	then	startmojob139	=	T9330301	;			
startmojob140	=	.;	if	T9330401	>=	0	&	T9330401	<=	12	then	startmojob140	=	T9330401	;			
startmojob141	=	.;	if	T9330501	>=	0	&	T9330501	<=	12	then	startmojob141	=	T9330501	;			
startmojob142	=	.;	if	T9330601	>=	0	&	T9330601	<=	12	then	startmojob142	=	T9330601	;			
startmojob143	=	.;	if	T9330701	>=	0	&	T9330701	<=	12	then	startmojob143	=	T9330701	;			
startmojob144	=	.;	if	T9330801	>=	0	&	T9330801	<=	12	then	startmojob144	=	T9330801	;			
startmojob145	=	.;	if	T9330901	>=	0	&	T9330901	<=	12	then	startmojob145	=	T9330901	;			
																		
startyrjob136	=	.;	if	T9330002	>=	1980	&	T9330002	<=	2050	then	startyrjob136	=	T9330002	;			
startyrjob137	=	.;	if	T9330102	>=	1980	&	T9330102	<=	2050	then	startyrjob137	=	T9330102	;			
startyrjob138	=	.;	if	T9330202	>=	1980	&	T9330202	<=	2050	then	startyrjob138	=	T9330202	;			
startyrjob139	=	.;	if	T9330302	>=	1980	&	T9330302	<=	2050	then	startyrjob139	=	T9330302	;			
startyrjob140	=	.;	if	T9330402	>=	1980	&	T9330402	<=	2050	then	startyrjob140	=	T9330402	;			
startyrjob141	=	.;	if	T9330502	>=	1980	&	T9330502	<=	2050	then	startyrjob141	=	T9330502	;			
startyrjob142	=	.;	if	T9330602	>=	1980	&	T9330602	<=	2050	then	startyrjob142	=	T9330602	;			
startyrjob143	=	.;	if	T9330702	>=	1980	&	T9330702	<=	2050	then	startyrjob143	=	T9330702	;			
startyrjob144	=	.;	if	T9330802	>=	1980	&	T9330802	<=	2050	then	startyrjob144	=	T9330802	;			
startyrjob145	=	.;	if	T9330902	>=	1980	&	T9330902	<=	2050	then	startyrjob145	=	T9330902	;			
																		
startcontmo136	=	.;	if	startyrjob136	ne	.	&	startmojob136	ne	.	then	startcontmo136	=	((startyrjob136	-1980)*12)	+	startmojob136	;
startcontmo137	=	.;	if	startyrjob137	ne	.	&	startmojob137	ne	.	then	startcontmo137	=	((startyrjob137	-1980)*12)	+	startmojob137	;
startcontmo138	=	.;	if	startyrjob138	ne	.	&	startmojob138	ne	.	then	startcontmo138	=	((startyrjob138	-1980)*12)	+	startmojob138	;
startcontmo139	=	.;	if	startyrjob139	ne	.	&	startmojob139	ne	.	then	startcontmo139	=	((startyrjob139	-1980)*12)	+	startmojob139	;
startcontmo140	=	.;	if	startyrjob140	ne	.	&	startmojob140	ne	.	then	startcontmo140	=	((startyrjob140	-1980)*12)	+	startmojob140	;
startcontmo141	=	.;	if	startyrjob141	ne	.	&	startmojob141	ne	.	then	startcontmo141	=	((startyrjob141	-1980)*12)	+	startmojob141	;
startcontmo142	=	.;	if	startyrjob142	ne	.	&	startmojob142	ne	.	then	startcontmo142	=	((startyrjob142	-1980)*12)	+	startmojob142	;
startcontmo143	=	.;	if	startyrjob143	ne	.	&	startmojob143	ne	.	then	startcontmo143	=	((startyrjob143	-1980)*12)	+	startmojob143	;
startcontmo144	=	.;	if	startyrjob144	ne	.	&	startmojob144	ne	.	then	startcontmo144	=	((startyrjob144	-1980)*12)	+	startmojob144	;
startcontmo145	=	.;	if	startyrjob145	ne	.	&	startmojob145	ne	.	then	startcontmo145	=	((startyrjob145	-1980)*12)	+	startmojob145	;

endbyst136	= .; if	T8793600	ge 0 &	T8793600	le 1 then	endbyst136	=	T8793600	;
endbyst137	= .; if	T8793700	ge 0 &	T8793700	le 1 then	endbyst137	=	T8793700	;
endbyst138	= .; if	T8793800	ge 0 &	T8793800	le 1 then	endbyst138	=	T8793800	;
endbyst139	= .; if	T8793900	ge 0 &	T8793900	le 1 then	endbyst139	=	T8793900	;
endbyst140	= .; if	T8794000	ge 0 &	T8794000	le 1 then	endbyst140	=	T8794000	;
endbyst141	= .; if	T8794100	ge 0 &	T8794100	le 1 then	endbyst141	=	T8794100	;
endbyst142	= .; if	T8794200	ge 0 &	T8794200	le 1 then	endbyst142	=	T8794200	;
endbyst143	= .; if	T8794300	ge 0 &	T8794300	le 1 then	endbyst143	=	T8794300	;
endbyst144	= .; if	T8794400	ge 0 &	T8794400	le 1 then	endbyst144	=	T8794400	;
endbyst145	= .; if	T8794500	ge 0 &	T8794500	le 1 then	endbyst145	=	T8794500	;

/* No 10th job 145 */

jobsat136	= .;	if	T8735000	>= 1 and	T8735000	<= 5 then 	jobsat136	=	T8735000	;
jobsat137	= .;	if	T8735100	>= 1 and	T8735100	<= 5 then 	jobsat137	=	T8735100	;
jobsat138	= .;	if	T8735200	>= 1 and	T8735200	<= 5 then 	jobsat138	=	T8735200	;
jobsat139	= .;	if	T8735300	>= 1 and	T8735300	<= 5 then 	jobsat139	=	T8735300	;
jobsat140	= .;	if	T8735400	>= 1 and	T8735400	<= 5 then 	jobsat140	=	T8735400	;
jobsat141	= .;	if	T8735500	>= 1 and	T8735500	<= 5 then 	jobsat141	=	T8735500	;
jobsat142	= .;	if	T8735600	>= 1 and	T8735600	<= 5 then 	jobsat142	=	T8735600	;
jobsat143	= .;	if	T8735700	>= 1 and	T8735700	<= 5 then 	jobsat143	=	T8735700	;
jobsat144	= .;	if	T8735800	>= 1 and	T8735800	<= 5 then 	jobsat144	=	T8735800	;
jobsat145 = .;

union136	= .;	if	T8723400	>= 0 and	T8723400	<= 1 then 	union136	=	T8723400	;
union137	= .;	if	T8723500	>= 0 and	T8723500	<= 1 then 	union137	=	T8723500	;
union138	= .;	if	T8723600	>= 0 and	T8723600	<= 1 then 	union138	=	T8723600	;
union139	= .;	if	T8723700	>= 0 and	T8723700	<= 1 then 	union139	=	T8723700	;
union140	= .;	if	T8723800	>= 0 and	T8723800	<= 1 then 	union140	=	T8723800	;
union141	= .;	if	T8723900	>= 0 and	T8723900	<= 1 then 	union141	=	T8723900	;
union142	= .;	if	T8724000	>= 0 and	T8724000	<= 1 then 	union142	=	T8724000	;
union143	= .;	if	T8724100	>= 0 and	T8724100	<= 1 then 	union143	=	T8724100	;
union144	= .;	if	T8724200	>= 0 and	T8724200	<= 1 then 	union144	=	T8724200	;
union145 = .;

ben_med136	= .;	if	T8714202	>= 0 and	T8714202	<= 1 then 	ben_med136	=	T8714202	;
ben_med137	= .;	if	T8714302	>= 0 and	T8714302	<= 1 then 	ben_med137	=	T8714302	;
ben_med138	= .;	if	T8714402	>= 0 and	T8714402	<= 1 then 	ben_med138	=	T8714402	;
ben_med139	= .;	if	T8714502	>= 0 and	T8714502	<= 1 then 	ben_med139	=	T8714502	;
ben_med140	= .;	if	T8714602	>= 0 and	T8714602	<= 1 then 	ben_med140	=	T8714602	;
ben_med141	= .;	if	T8714702	>= 0 and	T8714702	<= 1 then 	ben_med141	=	T8714702	;
ben_med142	= .;	if	T8714802	>= 0 and	T8714802	<= 1 then 	ben_med142	=	T8714802	;
ben_med143	= .;	if	T8714902	>= 0 and	T8714902	<= 1 then 	ben_med143	=	T8714902	;
ben_med144	= .;	if	T8715002	>= 0 and	T8715002	<= 1 then 	ben_med144	=	T8715002	;
ben_med145 = .;

ben_flex136	= .;	if	T8714201	>= 0 and	T8714201	<= 1 then 	ben_flex136	=	T8714201	;
ben_flex137	= .;	if	T8714301	>= 0 and	T8714301	<= 1 then 	ben_flex137	=	T8714301	;
ben_flex138	= .;	if	T8714401	>= 0 and	T8714401	<= 1 then 	ben_flex138	=	T8714401	;
ben_flex139	= .;	if	T8714501	>= 0 and	T8714501	<= 1 then 	ben_flex139	=	T8714501	;
ben_flex140	= .;	if	T8714601	>= 0 and	T8714601	<= 1 then 	ben_flex140	=	T8714601	;
ben_flex141	= .;	if	T8714701	>= 0 and	T8714701	<= 1 then 	ben_flex141	=	T8714701	;
ben_flex142	= .;	if	T8714801	>= 0 and	T8714801	<= 1 then 	ben_flex142	=	T8714801	;
ben_flex143	= .;	if	T8714901	>= 0 and	T8714901	<= 1 then 	ben_flex143	=	T8714901	;
ben_flex144	= .;	if	T8715001	>= 0 and	T8715001	<= 1 then 	ben_flex144	=	T8715001	;
ben_flex145 = .;

ben_life136	= .;	if	T8714203	>= 0 and	T8714203	<= 1 then 	ben_life136	=	T8714203	;
ben_life137	= .;	if	T8714303	>= 0 and	T8714303	<= 1 then 	ben_life137	=	T8714303	;
ben_life138	= .;	if	T8714403	>= 0 and	T8714403	<= 1 then 	ben_life138	=	T8714403	;
ben_life139	= .;	if	T8714503	>= 0 and	T8714503	<= 1 then 	ben_life139	=	T8714503	;
ben_life140	= .;	if	T8714603	>= 0 and	T8714603	<= 1 then 	ben_life140	=	T8714603	;
ben_life141	= .;	if	T8714703	>= 0 and	T8714703	<= 1 then 	ben_life141	=	T8714703	;
ben_life142	= .;	if	T8714803	>= 0 and	T8714803	<= 1 then 	ben_life142	=	T8714803	;
ben_life143	= .;	if	T8714903	>= 0 and	T8714903	<= 1 then 	ben_life143	=	T8714903	;
ben_life144	= .;	if	T8715003	>= 0 and	T8715003	<= 1 then 	ben_life144	=	T8715003	;
ben_life145 = .;

ben_dental136	= .;	if	T8714204	>= 0 and	T8714204	<= 1 then 	ben_dental136	=	T8714204	;
ben_dental137	= .;	if	T8714304	>= 0 and	T8714304	<= 1 then 	ben_dental137	=	T8714304	;
ben_dental138	= .;	if	T8714404	>= 0 and	T8714404	<= 1 then 	ben_dental138	=	T8714404	;
ben_dental139	= .;	if	T8714504	>= 0 and	T8714504	<= 1 then 	ben_dental139	=	T8714504	;
ben_dental140	= .;	if	T8714604	>= 0 and	T8714604	<= 1 then 	ben_dental140	=	T8714604	;
ben_dental141	= .;	if	T8714704	>= 0 and	T8714704	<= 1 then 	ben_dental141	=	T8714704	;
ben_dental142	= .;	if	T8714804	>= 0 and	T8714804	<= 1 then 	ben_dental142	=	T8714804	;
ben_dental143	= .;	if	T8714904	>= 0 and	T8714904	<= 1 then 	ben_dental143	=	T8714904	;
ben_dental144	= .;	if	T8715004	>= 0 and	T8715004	<= 1 then 	ben_dental144	=	T8715004	;
ben_dental145 = .;

ben_pdleave136	= .;	if	T8714205	>= 0 and	T8714205	<= 1 then 	ben_pdleave136	=	T8714205	;
ben_pdleave137	= .;	if	T8714305	>= 0 and	T8714305	<= 1 then 	ben_pdleave137	=	T8714305	;
ben_pdleave138	= .;	if	T8714405	>= 0 and	T8714405	<= 1 then 	ben_pdleave138	=	T8714405	;
ben_pdleave139	= .;	if	T8714505	>= 0 and	T8714505	<= 1 then 	ben_pdleave139	=	T8714505	;
ben_pdleave140	= .;	if	T8714605	>= 0 and	T8714605	<= 1 then 	ben_pdleave140	=	T8714605	;
ben_pdleave141	= .;	if	T8714705	>= 0 and	T8714705	<= 1 then 	ben_pdleave141	=	T8714705	;
ben_pdleave142	= .;	if	T8714805	>= 0 and	T8714805	<= 1 then 	ben_pdleave142	=	T8714805	;
ben_pdleave143	= .;	if	T8714905	>= 0 and	T8714905	<= 1 then 	ben_pdleave143	=	T8714905	;
ben_pdleave144	= .;	if	T8715005	>= 0 and	T8715005	<= 1 then 	ben_pdleave144	=	T8715005	;
ben_pdleave145 = .;

ben_unpdleave136	= .;	if	T8714206	>= 0 and	T8714206	<= 1 then 	ben_unpdleave136	=	T8714206	;
ben_unpdleave137	= .;	if	T8714306	>= 0 and	T8714306	<= 1 then 	ben_unpdleave137	=	T8714306	;
ben_unpdleave138	= .;	if	T8714406	>= 0 and	T8714406	<= 1 then 	ben_unpdleave138	=	T8714406	;
ben_unpdleave139	= .;	if	T8714506	>= 0 and	T8714506	<= 1 then 	ben_unpdleave139	=	T8714506	;
ben_unpdleave140	= .;	if	T8714606	>= 0 and	T8714606	<= 1 then 	ben_unpdleave140	=	T8714606	;
ben_unpdleave141	= .;	if	T8714706	>= 0 and	T8714706	<= 1 then 	ben_unpdleave141	=	T8714706	;
ben_unpdleave142	= .;	if	T8714806	>= 0 and	T8714806	<= 1 then 	ben_unpdleave142	=	T8714806	;
ben_unpdleave143	= .;	if	T8714906	>= 0 and	T8714906	<= 1 then 	ben_unpdleave143	=	T8714906	;
ben_unpdleave144	= .;	if	T8715006	>= 0 and	T8715006	<= 1 then 	ben_unpdleave144	=	T8715006	;
ben_unpdleave145 = .;

ben_retire136	= .;	if	T8714207	>= 0 and	T8714207	<= 1 then 	ben_retire136	=	T8714207	;
ben_retire137	= .;	if	T8714307	>= 0 and	T8714307	<= 1 then 	ben_retire137	=	T8714307	;
ben_retire138	= .;	if	T8714407	>= 0 and	T8714407	<= 1 then 	ben_retire138	=	T8714407	;
ben_retire139	= .;	if	T8714507	>= 0 and	T8714507	<= 1 then 	ben_retire139	=	T8714507	;
ben_retire140	= .;	if	T8714607	>= 0 and	T8714607	<= 1 then 	ben_retire140	=	T8714607	;
ben_retire141	= .;	if	T8714707	>= 0 and	T8714707	<= 1 then 	ben_retire141	=	T8714707	;
ben_retire142	= .;	if	T8714807	>= 0 and	T8714807	<= 1 then 	ben_retire142	=	T8714807	;
ben_retire143	= .;	if	T8714907	>= 0 and	T8714907	<= 1 then 	ben_retire143	=	T8714907	;
ben_retire144	= .;	if	T8715007	>= 0 and	T8715007	<= 1 then 	ben_retire144	=	T8715007	;
ben_retire145 = .;

ben_tuition136	= .;	if	T8714208	>= 0 and	T8714208	<= 1 then 	ben_tuition136	=	T8714208	;
ben_tuition137	= .;	if	T8714308	>= 0 and	T8714308	<= 1 then 	ben_tuition137	=	T8714308	;
ben_tuition138	= .;	if	T8714408	>= 0 and	T8714408	<= 1 then 	ben_tuition138	=	T8714408	;
ben_tuition139	= .;	if	T8714508	>= 0 and	T8714508	<= 1 then 	ben_tuition139	=	T8714508	;
ben_tuition140	= .;	if	T8714608	>= 0 and	T8714608	<= 1 then 	ben_tuition140	=	T8714608	;
ben_tuition141	= .;	if	T8714708	>= 0 and	T8714708	<= 1 then 	ben_tuition141	=	T8714708	;
ben_tuition142	= .;	if	T8714808	>= 0 and	T8714808	<= 1 then 	ben_tuition142	=	T8714808	;
ben_tuition143	= .;	if	T8714908	>= 0 and	T8714908	<= 1 then 	ben_tuition143	=	T8714908	;
ben_tuition144	= .;	if	T8715008	>= 0 and	T8715008	<= 1 then 	ben_tuition144	=	T8715008	;
ben_tuition145 = .;

ben_child136	= .;	if	T8714209	>= 0 and	T8714209	<= 1 then 	ben_child136	=	T8714209	;
ben_child137	= .;	if	T8714309	>= 0 and	T8714309	<= 1 then 	ben_child137	=	T8714309	;
ben_child138	= .;	if	T8714409	>= 0 and	T8714409	<= 1 then 	ben_child138	=	T8714409	;
ben_child139	= .;	if	T8714509	>= 0 and	T8714509	<= 1 then 	ben_child139	=	T8714509	;
ben_child140	= .;	if	T8714609	>= 0 and	T8714609	<= 1 then 	ben_child140	=	T8714609	;
ben_child141	= .;	if	T8714709	>= 0 and	T8714709	<= 1 then 	ben_child141	=	T8714709	;
ben_child142	= .;	if	T8714809	>= 0 and	T8714809	<= 1 then 	ben_child142	=	T8714809	;
ben_child143	= .;	if	T8714909	>= 0 and	T8714909	<= 1 then 	ben_child143	=	T8714909	;
ben_child144	= .;	if	T8715009	>= 0 and	T8715009	<= 1 then 	ben_child144	=	T8715009	;
ben_child145 = .;

ben_stock136	= .;	if	T8714210	>= 0 and	T8714210	<= 1 then 	ben_stock136	=	T8714210	;
ben_stock137	= .;	if	T8714310	>= 0 and	T8714310	<= 1 then 	ben_stock137	=	T8714310	;
ben_stock138	= .;	if	T8714410	>= 0 and	T8714410	<= 1 then 	ben_stock138	=	T8714410	;
ben_stock139	= .;	if	T8714510	>= 0 and	T8714510	<= 1 then 	ben_stock139	=	T8714510	;
ben_stock140	= .;	if	T8714610	>= 0 and	T8714610	<= 1 then 	ben_stock140	=	T8714610	;
ben_stock141	= .;	if	T8714710	>= 0 and	T8714710	<= 1 then 	ben_stock141	=	T8714710	;
ben_stock142	= .;	if	T8714810	>= 0 and	T8714810	<= 1 then 	ben_stock142	=	T8714810	;
ben_stock143	= .;	if	T8714910	>= 0 and	T8714910	<= 1 then 	ben_stock143	=	T8714910	;
ben_stock144	= .;	if	T8715010	>= 0 and	T8715010	<= 1 then 	ben_stock144	=	T8715010	;
ben_stock145 = .;

occcode136	= .; if	T9133500	ge 0 and	T9133500	le 9990 then	occcode136	=	T9133500;
occcode137	= .; if	T9133600	ge 0 and	T9133600	le 9990 then	occcode137	=	T9133600;
occcode138	= .; if	T9133700	ge 0 and	T9133700	le 9990 then	occcode138	=	T9133700;
occcode139	= .; if	T9133800	ge 0 and	T9133800	le 9990 then	occcode139	=	T9133800;
occcode140	= .; if	T9133900	ge 0 and	T9133900	le 9990 then	occcode140	=	T9133900;
occcode141	= .; if	T9134000	ge 0 and	T9134000	le 9990 then	occcode141	=	T9134000;
occcode142	= .; if	T9134100	ge 0 and	T9134100	le 9990 then	occcode142	=	T9134100;
occcode143	= .; if	T9134200	ge 0 and	T9134200	le 9990 then	occcode143	=	T9134200;
occcode144	= .; if	T9134300	ge 0 and	T9134300	le 9990 then	occcode144	=	T9134300;
occcode145	=.;							

indcode136	= .; if	T9132600	ge 0 and	T9132600	le 9990 then	indcode136	=	T9132600	;
indcode137	= .; if	T9132700	ge 0 and	T9132700	le 9990 then	indcode137	=	T9132700	;
indcode138	= .; if	T9132800	ge 0 and	T9132800	le 9990 then	indcode138	=	T9132800	;
indcode139	= .; if	T9132900	ge 0 and	T9132900	le 9990 then	indcode139	=	T9132900	;
indcode140	= .; if	T9133000	ge 0 and	T9133000	le 9990 then	indcode140	=	T9133000	;
indcode141	= .; if	T9133100	ge 0 and	T9133100	le 9990 then	indcode141	=	T9133100	;
indcode142	= .; if	T9133200	ge 0 and	T9133200	le 9990 then	indcode142	=	T9133200	;
indcode143	= .; if	T9133300	ge 0 and	T9133300	le 9990 then	indcode143	=	T9133300	;
indcode144	= .; if	T9133400	ge 0 and	T9133400	le 9990 then	indcode144	=	T9133400	;
indcode145 = .;

jobtype136	= .; if	T8467200	ge 1 &	T8467200	le 5 then	jobtype136	=	T8467200	;
jobtype137	= .; if	T8467300	ge 1 &	T8467300	le 5 then	jobtype137	=	T8467300	;
jobtype138	= .; if	T8467400	ge 1 &	T8467400	le 5 then	jobtype138	=	T8467400	;
jobtype139	= .; if	T8467500	ge 1 &	T8467500	le 5 then	jobtype139	=	T8467500	;
jobtype140	= .; if	T8467600	ge 1 &	T8467600	le 5 then	jobtype140	=	T8467600	;
jobtype141	= .; if	T8467700	ge 1 &	T8467700	le 5 then	jobtype141	=	T8467700	;
jobtype142	= .; if	T8467800	ge 1 &	T8467800	le 5 then	jobtype142	=	T8467800	;
jobtype143	= .; if	T8467900	ge 1 &	T8467900	le 5 then	jobtype143	=	T8467900	;
jobtype144	= .; if	T8468000	ge 1 &	T8468000	le 5 then	jobtype144	=	T8468000	;
jobtype145	= .; if	T8468100	ge 1 &	T8468100	le 5 then	jobtype145	=	T8468100	;

hourswk136	= .; if	T8131800	ge 0 &	T8131800	le 168 then	hourswk136	=	T8131800	;
hourswk137	= .; if	T8131900	ge 0 &	T8131900	le 168 then	hourswk137	=	T8131900	;
hourswk138	= .; if	T8132000	ge 0 &	T8132000	le 168 then	hourswk138	=	T8132000	;
hourswk139	= .; if	T8132100	ge 0 &	T8132100	le 168 then	hourswk139	=	T8132100	;
hourswk140	= .; if	T8132200	ge 0 &	T8132200	le 168 then	hourswk140	=	T8132200	;
hourswk141	= .; if	T8132300	ge 0 &	T8132300	le 168 then	hourswk141	=	T8132300	;
hourswk142	= .; if	T8132400	ge 0 &	T8132400	le 168 then	hourswk142	=	T8132400	;
hourswk143	= .; if	T8132500	ge 0 &	T8132500	le 168 then	hourswk143	=	T8132500	;
hourswk144	= .; if	T8132600	ge 0 &	T8132600	le 168 then	hourswk144	=	T8132600	;
hourswk145	= .; if	T8132700	ge 0 &	T8132700	le 168 then	hourswk145	=	T8132700	;

anygap136	= .; if	T8743000	ge -2 &	T8743000	le 0 then	anygap136	=	0	;	if 	T8743000	eq 1 then	anygap136	=	1	;
anygap137	= .; if	T8743100	ge -2 &	T8743100	le 0 then	anygap137	=	0	;	if 	T8743100	eq 1 then	anygap137	=	1	;
anygap138	= .; if	T8743200	ge -2 &	T8743200	le 0 then	anygap138	=	0	;	if 	T8743200	eq 1 then	anygap138	=	1	;
anygap139	= .; if	T8743300	ge -2 &	T8743300	le 0 then	anygap139	=	0	;	if 	T8743300	eq 1 then	anygap139	=	1	;
anygap140	= .; if	T8743400	ge -2 &	T8743400	le 0 then	anygap140	=	0	;	if 	T8743400	eq 1 then	anygap140	=	1	;
anygap141	= .; if	T8743500	ge -2 &	T8743500	le 0 then	anygap141	=	0	;	if 	T8743500	eq 1 then	anygap141	=	1	;
anygap142	= .; if	T8743600	ge -2 &	T8743600	le 0 then	anygap142	=	0	;	if 	T8743600	eq 1 then	anygap142	=	1	;
anygap143	= .; if	T8743700	ge -2 &	T8743700	le 0 then	anygap143	=	0	;	if 	T8743700	eq 1 then	anygap143	=	1	;
anygap144	= .; if	T8743800	ge -2 &	T8743800	le 0 then	anygap144	=	0	;	if 	T8743800	eq 1 then	anygap144	=	1	;
anygap145	= .; if	T8743900	ge -2 &	T8743900	le 0 then	anygap145	=	0	;	if 	T8743900	eq 1 then	anygap145	=	1	;

worksched136	= .; if	T8713300	ge 1 &	T8713300	le 9 then	worksched136	=	T8713300	;
worksched137	= .; if	T8713400	ge 1 &	T8713400	le 9 then	worksched137	=	T8713400	;
worksched138	= .; if	T8713500	ge 1 &	T8713500	le 9 then	worksched138	=	T8713500	;
worksched139	= .; if	T8713600	ge 1 &	T8713600	le 9 then	worksched139	=	T8713600	;
worksched140	= .; if	T8713700	ge 1 &	T8713700	le 9 then	worksched140	=	T8713700	;
worksched141	= .; if	T8713800	ge 1 &	T8713800	le 9 then	worksched141	=	T8713800	;
worksched142	= .; if	T8713900	ge 1 &	T8713900	le 9 then	worksched142	=	T8713900	;
worksched143	= .; if	T8714000	ge 1 &	T8714000	le 9 then	worksched143	=	T8714000	;
worksched144	= .; if	T8714100	ge 1 &	T8714100	le 9 then	worksched144	=	T8714100	;
worksched145 = .;

/* 2015: up to 12 *************************************************************/

idjob146 = .; if (U1344700 >= 0 & U1344700 <= 300000) then idjob146	= U1344700;
idjob147 = .; if (U1344800 >= 0 & U1344800 <= 300000) then idjob147	= U1344800;
idjob148 = .; if (U1344900 >= 0 & U1344900 <= 300000) then idjob148	= U1344900;
idjob149 = .; if (U1345000 >= 0 & U1345000 <= 300000) then idjob149	= U1345000;
idjob150 = .; if (U1345100 >= 0 & U1345100 <= 300000) then idjob150	= U1345100;
idjob151 = .; if (U1345200 >= 0 & U1345200 <= 300000) then idjob151	= U1345200;
idjob152 = .; if (U1345300 >= 0 & U1345300 <= 300000) then idjob152	= U1345300;
idjob153 = .; if (U1345400 >= 0 & U1345400 <= 300000) then idjob153	= U1345400;
idjob154 = .; if (U1345500 >= 0 & U1345500 <= 300000) then idjob154	= U1345500;
idjob155 = .; if (U1345600 >= 0 & U1345600 <= 300000) then idjob155	= U1345600;
idjob156 = .; if (U1345700 >= 0 & U1345700 <= 300000) then idjob156	= U1345700;
idjob157 = .; if (U1345800 >= 0 & U1345800 <= 300000) then idjob157	= U1345800;

whyleftjob146 = .;	if (U0618900 >= 0 &	U0618900 <= 50) then whyleftjob146	= U0618900;
whyleftjob147 = .;	if (U0619000 >= 0 &	U0619000 <= 50) then whyleftjob147	= U0619000;
whyleftjob148 = .;	if (U0619100 >= 0 &	U0619100 <= 50) then whyleftjob148	= U0619100;
whyleftjob149 = .;	if (U0619200 >= 0 &	U0619200 <= 50) then whyleftjob149	= U0619200;
whyleftjob150 = .;	if (U0619300 >= 0 &	U0619300 <= 50) then whyleftjob150	= U0619300;
whyleftjob151 = .;	if (U0619400 >= 0 &	U0619400 <= 50) then whyleftjob151	= U0619400;
whyleftjob152 = .;	if (U0619500 >= 0 &	U0619500 <= 50) then whyleftjob152	= U0619500;
whyleftjob153 = .;	if (U0619600 >= 0 &	U0619600 <= 50) then whyleftjob153	= U0619600;
whyleftjob154 = .;	if (U0619700 >= 0 &	U0619700 <= 50) then whyleftjob154	= U0619700;
whyleftjob155 = .;	if (U0619800 >= 0 &	U0619800 <= 50) then whyleftjob155	= U0619800;
whyleftjob156 = .;	if (U0619900 >= 0 &	U0619900 <= 50) then whyleftjob156	= U0619900;
whyleftjob157 = .;	if (U0620000 >= 0 &	U0620000 <= 50) then whyleftjob157	= U0620000;

curjob146	= .; if	U1341100	>= 0 &	U1341100	<= 1 then	curjob146	=	U1341100	;
curjob147	= .; if	U1341200	>= 0 &	U1341200	<= 1 then	curjob147	=	U1341200	;
curjob148	= .; if	U1341300	>= 0 &	U1341300	<= 1 then	curjob148	=	U1341300	;
curjob149	= .; if	U1341400	>= 0 &	U1341400	<= 1 then	curjob149	=	U1341400	;
curjob150	= .; if	U1341500	>= 0 &	U1341500	<= 1 then	curjob150	=	U1341500	;
curjob151	= .; if	U1341600	>= 0 &	U1341600	<= 1 then	curjob151	=	U1341600	;
curjob152	= .; if	U1341700	>= 0 &	U1341700	<= 1 then	curjob152	=	U1341700	;
curjob153	= .; if	U1341800	>= 0 &	U1341800	<= 1 then	curjob153	=	U1341800	;
curjob154	= .; if	U1341900	>= 0 &	U1341900	<= 1 then	curjob154	=	U1341900	;
curjob155	= .; if	U1342000	>= 0 &	U1342000	<= 1 then	curjob155	=	U1342000	;
curjob156	= .; if	U1342100	>= 0 &	U1342100	<= 1 then	curjob156	=	U1342100	;
curjob157	= .; if	U1342200	>= 0 &	U1342200	<= 1 then	curjob157	=	U1342200	;

intmo146 = U0013100;
intmo147 = U0013100;
intmo148 = U0013100;
intmo149 = U0013100;
intmo150 = U0013100;
intmo151 = U0013100;
intmo152 = U0013100;
intmo153 = U0013100;
intmo154 = U0013100;
intmo155 = U0013100;
intmo156 = U0013100;
intmo157 = U0013100;

weeksjob146	= .; if (U0015400 >= 0 & U0015400 <= 5000) then	weeksjob146	= U0015400;
weeksjob147	= .; if (U0015500 >= 0 & U0015500 <= 5000) then	weeksjob147	= U0015500;
weeksjob148	= .; if (U0015600 >= 0 & U0015600 <= 5000) then	weeksjob148	= U0015600;
weeksjob149	= .; if (U0015700 >= 0 & U0015700 <= 5000) then	weeksjob149	= U0015700;
weeksjob150	= .; if (U0015800 >= 0 & U0015800 <= 5000) then	weeksjob150	= U0015800;
weeksjob151	= .; if (U0015900 >= 0 & U0015900 <= 5000) then	weeksjob151	= U0015900;
weeksjob152	= .; if (U0016000 >= 0 & U0016000 <= 5000) then	weeksjob152	= U0016000;
weeksjob153	= .; if (U0016100 >= 0 & U0016100 <= 5000) then	weeksjob153	= U0016100;
weeksjob154	= .; if (U0016200 >= 0 & U0016200 <= 5000) then	weeksjob154	= U0016200;
weeksjob155	= .; if (U0016300 >= 0 & U0016300 <= 5000) then	weeksjob155	= U0016300;
weeksjob156	= .; if (U0016400 >= 0 & U0016400 <= 5000) then	weeksjob156	= U0016400;
weeksjob157	= .; if (U0016500 >= 0 & U0016500 <= 5000) then	weeksjob157	= U0016500;

startmojob146	=	.;	if	U1343501	>=	0	&	U1343501	<=	12	then	startmojob146	=	U1343501	;			
startmojob147	=	.;	if	U1343601	>=	0	&	U1343601	<=	12	then	startmojob147	=	U1343601	;			
startmojob148	=	.;	if	U1343701	>=	0	&	U1343701	<=	12	then	startmojob148	=	U1343701	;			
startmojob149	=	.;	if	U1343801	>=	0	&	U1343801	<=	12	then	startmojob149	=	U1343801	;			
startmojob150	=	.;	if	U1343901	>=	0	&	U1343901	<=	12	then	startmojob150	=	U1343901	;			
startmojob151	=	.;	if	U1344001	>=	0	&	U1344001	<=	12	then	startmojob151	=	U1344001	;			
startmojob152	=	.;	if	U1344101	>=	0	&	U1344101	<=	12	then	startmojob152	=	U1344101	;			
startmojob153	=	.;	if	U1344201	>=	0	&	U1344201	<=	12	then	startmojob153	=	U1344201	;			
startmojob154	=	.;	if	U1344301	>=	0	&	U1344301	<=	12	then	startmojob154	=	U1344301	;			
startmojob155	=	.;	if	U1344401	>=	0	&	U1344401	<=	12	then	startmojob155	=	U1344401	;			
startmojob156	=	.;	if	U1344501	>=	0	&	U1344501	<=	12	then	startmojob156	=	U1344501	;			
startmojob157	=	.;	if	U1344601	>=	0	&	U1344601	<=	12	then	startmojob157	=	U1344601	;			
																		
startyrjob146	=	.;	if	U1343502	>=	1980	&	U1343502	<=	2050	then	startyrjob146	=	U1343502	;			
startyrjob147	=	.;	if	U1343602	>=	1980	&	U1343602	<=	2050	then	startyrjob147	=	U1343602	;			
startyrjob148	=	.;	if	U1343702	>=	1980	&	U1343702	<=	2050	then	startyrjob148	=	U1343702	;			
startyrjob149	=	.;	if	U1343802	>=	1980	&	U1343802	<=	2050	then	startyrjob149	=	U1343802	;			
startyrjob150	=	.;	if	U1343902	>=	1980	&	U1343902	<=	2050	then	startyrjob150	=	U1343902	;			
startyrjob151	=	.;	if	U1344002	>=	1980	&	U1344002	<=	2050	then	startyrjob151	=	U1344002	;			
startyrjob152	=	.;	if	U1344102	>=	1980	&	U1344102	<=	2050	then	startyrjob152	=	U1344102	;			
startyrjob153	=	.;	if	U1344202	>=	1980	&	U1344202	<=	2050	then	startyrjob153	=	U1344202	;			
startyrjob154	=	.;	if	U1344302	>=	1980	&	U1344302	<=	2050	then	startyrjob154	=	U1344302	;			
startyrjob155	=	.;	if	U1344402	>=	1980	&	U1344402	<=	2050	then	startyrjob155	=	U1344402	;			
startyrjob156	=	.;	if	U1344502	>=	1980	&	U1344502	<=	2050	then	startyrjob156	=	U1344502	;			
startyrjob157	=	.;	if	U1344602	>=	1980	&	U1344602	<=	2050	then	startyrjob157	=	U1344602	;			
																		
startcontmo146	=	.;	if	startyrjob146	ne	.	&	startmojob146	ne	.	then	startcontmo146	=	((startyrjob146	-1980)*12)	+	startmojob146	;
startcontmo147	=	.;	if	startyrjob147	ne	.	&	startmojob147	ne	.	then	startcontmo147	=	((startyrjob147	-1980)*12)	+	startmojob147	;
startcontmo148	=	.;	if	startyrjob148	ne	.	&	startmojob148	ne	.	then	startcontmo148	=	((startyrjob148	-1980)*12)	+	startmojob148	;
startcontmo149	=	.;	if	startyrjob149	ne	.	&	startmojob149	ne	.	then	startcontmo149	=	((startyrjob149	-1980)*12)	+	startmojob149	;
startcontmo150	=	.;	if	startyrjob150	ne	.	&	startmojob150	ne	.	then	startcontmo150	=	((startyrjob150	-1980)*12)	+	startmojob150	;
startcontmo151	=	.;	if	startyrjob151	ne	.	&	startmojob151	ne	.	then	startcontmo151	=	((startyrjob151	-1980)*12)	+	startmojob151	;
startcontmo152	=	.;	if	startyrjob152	ne	.	&	startmojob152	ne	.	then	startcontmo152	=	((startyrjob152	-1980)*12)	+	startmojob152	;
startcontmo153	=	.;	if	startyrjob153	ne	.	&	startmojob153	ne	.	then	startcontmo153	=	((startyrjob153	-1980)*12)	+	startmojob153	;
startcontmo154	=	.;	if	startyrjob154	ne	.	&	startmojob154	ne	.	then	startcontmo154	=	((startyrjob154	-1980)*12)	+	startmojob154	;
startcontmo155	=	.;	if	startyrjob155	ne	.	&	startmojob155	ne	.	then	startcontmo155	=	((startyrjob155	-1980)*12)	+	startmojob155	;
startcontmo156	=	.;	if	startyrjob156	ne	.	&	startmojob156	ne	.	then	startcontmo156	=	((startyrjob156	-1980)*12)	+	startmojob156	;
startcontmo157	=	.;	if	startyrjob157	ne	.	&	startmojob157	ne	.	then	startcontmo157	=	((startyrjob157	-1980)*12)	+	startmojob157	;

endbyst146	= .; if	U0714600	ge 0 &	U0714600	le 1 then	endbyst146	=	U0714600	;
endbyst147	= .; if	U0714700	ge 0 &	U0714700	le 1 then	endbyst147	=	U0714700	;
endbyst148	= .; if	U0714800	ge 0 &	U0714800	le 1 then	endbyst148	=	U0714800	;
endbyst149	= .; if	U0714900	ge 0 &	U0714900	le 1 then	endbyst149	=	U0714900	;
endbyst150	= .; if	U0715000	ge 0 &	U0715000	le 1 then	endbyst150	=	U0715000	;
endbyst151	= .; if	U0715100	ge 0 &	U0715100	le 1 then	endbyst151	=	U0715100	;
endbyst152	= .; if	U0715200	ge 0 &	U0715200	le 1 then	endbyst152	=	U0715200	;
endbyst153	= .; if	U0715300	ge 0 &	U0715300	le 1 then	endbyst153	=	U0715300	;
endbyst154	= .; if	U0715400	ge 0 &	U0715400	le 1 then	endbyst154	=	U0715400	;
endbyst155	= .; if	U0715500	ge 0 &	U0715500	le 1 then	endbyst155	=	U0715500	;
endbyst156	= .; if	U0715600	ge 0 &	U0715600	le 1 then	endbyst156	=	U0715600	;
endbyst157	= .; if	U0715700	ge 0 &	U0715700	le 1 then	endbyst157	=	U0715700	;

jobsat146	= .;	if	U0654900	>= 1 and	U0654900	<= 5 then 	jobsat146	=	U0654900	;
jobsat147	= .;	if	U0655000	>= 1 and	U0655000	<= 5 then 	jobsat147	=	U0655000	;
jobsat148	= .;	if	U0655100	>= 1 and	U0655100	<= 5 then 	jobsat148	=	U0655100	;
jobsat149	= .;	if	U0655200	>= 1 and	U0655200	<= 5 then 	jobsat149	=	U0655200	;
jobsat150	= .;	if	U0655300	>= 1 and	U0655300	<= 5 then 	jobsat150	=	U0655300	;
jobsat151	= .;	if	U0655400	>= 1 and	U0655400	<= 5 then 	jobsat151	=	U0655400	;
jobsat152	= .;	if	U0655500	>= 1 and	U0655500	<= 5 then 	jobsat152	=	U0655500	;
jobsat153	= .;	if	U0655600	>= 1 and	U0655600	<= 5 then 	jobsat153	=	U0655600	;
jobsat154	= .;	if	U0655700	>= 1 and	U0655700	<= 5 then 	jobsat154	=	U0655700	;
jobsat155	= .;	if	U0655800	>= 1 and	U0655800	<= 5 then 	jobsat155	=	U0655800	;
jobsat156	= .;	if	U0655900	>= 1 and	U0655900	<= 5 then 	jobsat156	=	U0655900	;
jobsat157 = .;

union146	= .;	if	U0641000	>= 0 and	U0641000	<= 1 then 	union146	=	U0641000	;
union147	= .;	if	U0641100	>= 0 and	U0641100	<= 1 then 	union147	=	U0641100	;
union148	= .;	if	U0641200	>= 0 and	U0641200	<= 1 then 	union148	=	U0641200	;
union149	= .;	if	U0641300	>= 0 and	U0641300	<= 1 then 	union149	=	U0641300	;
union150	= .;	if	U0641400	>= 0 and	U0641400	<= 1 then 	union150	=	U0641400	;
union151	= .;	if	U0641500	>= 0 and	U0641500	<= 1 then 	union151	=	U0641500	;
union152	= .;	if	U0641600	>= 0 and	U0641600	<= 1 then 	union152	=	U0641600	;
union153	= .;	if	U0641700	>= 0 and	U0641700	<= 1 then 	union153	=	U0641700	;
union154	= .;	if	U0641800	>= 0 and	U0641800	<= 1 then 	union154	=	U0641800	;
union155	= .;	if	U0641900	>= 0 and	U0641900	<= 1 then 	union155	=	U0641900	;
union156	= .;	if	U0642000	>= 0 and	U0642000	<= 1 then 	union156	=	U0642000	;
union157 = .;

ben_med146	= .;	if	U0630502	>= 0 and	U0630502	<= 1 then 	ben_med146	=	U0630502	;
ben_med147	= .;	if	U0630602	>= 0 and	U0630602	<= 1 then 	ben_med147	=	U0630602	;
ben_med148	= .;	if	U0630702	>= 0 and	U0630702	<= 1 then 	ben_med148	=	U0630702	;
ben_med149	= .;	if	U0630802	>= 0 and	U0630802	<= 1 then 	ben_med149	=	U0630802	;
ben_med150	= .;	if	U0630902	>= 0 and	U0630902	<= 1 then 	ben_med150	=	U0630902	;
ben_med151	= .;	if	U0631002	>= 0 and	U0631002	<= 1 then 	ben_med151	=	U0631002	;
ben_med152	= .;	if	U0631102	>= 0 and	U0631102	<= 1 then 	ben_med152	=	U0631102	;
ben_med153	= .;	if	U0631202	>= 0 and	U0631202	<= 1 then 	ben_med153	=	U0631202	;
ben_med154	= .;	if	U0631302	>= 0 and	U0631302	<= 1 then 	ben_med154	=	U0631302	;
ben_med155	= .;	if	U0631402	>= 0 and	U0631402	<= 1 then 	ben_med155	=	U0631402	;
ben_med156	= .;	if	U0631502	>= 0 and	U0631502	<= 1 then 	ben_med156	=	U0631502	;
ben_med157 = .;

ben_flex146	= .;	if	U0630501	>= 0 and	U0630501	<= 1 then 	ben_flex146	=	U0630501	;
ben_flex147	= .;	if	U0630601	>= 0 and	U0630601	<= 1 then 	ben_flex147	=	U0630601	;
ben_flex148	= .;	if	U0630701	>= 0 and	U0630701	<= 1 then 	ben_flex148	=	U0630701	;
ben_flex149	= .;	if	U0630801	>= 0 and	U0630801	<= 1 then 	ben_flex149	=	U0630801	;
ben_flex150	= .;	if	U0630901	>= 0 and	U0630901	<= 1 then 	ben_flex150	=	U0630901	;
ben_flex151	= .;	if	U0631001	>= 0 and	U0631001	<= 1 then 	ben_flex151	=	U0631001	;
ben_flex152	= .;	if	U0631101	>= 0 and	U0631101	<= 1 then 	ben_flex152	=	U0631101	;
ben_flex153	= .;	if	U0631201	>= 0 and	U0631201	<= 1 then 	ben_flex153	=	U0631201	;
ben_flex154	= .;	if	U0631301	>= 0 and	U0631301	<= 1 then 	ben_flex154	=	U0631301	;
ben_flex155	= .;	if	U0631401	>= 0 and	U0631401	<= 1 then 	ben_flex155	=	U0631401	;
ben_flex156	= .;	if	U0631501	>= 0 and	U0631501	<= 1 then 	ben_flex156	=	U0631501	;
ben_flex157 = .;

ben_life146	= .;	if	U0630503	>= 0 and	U0630503	<= 1 then 	ben_life146	=	U0630503	;
ben_life147	= .;	if	U0630603	>= 0 and	U0630603	<= 1 then 	ben_life147	=	U0630603	;
ben_life148	= .;	if	U0630703	>= 0 and	U0630703	<= 1 then 	ben_life148	=	U0630703	;
ben_life149	= .;	if	U0630803	>= 0 and	U0630803	<= 1 then 	ben_life149	=	U0630803	;
ben_life150	= .;	if	U0630903	>= 0 and	U0630903	<= 1 then 	ben_life150	=	U0630903	;
ben_life151	= .;	if	U0631003	>= 0 and	U0631003	<= 1 then 	ben_life151	=	U0631003	;
ben_life152	= .;	if	U0631103	>= 0 and	U0631103	<= 1 then 	ben_life152	=	U0631103	;
ben_life153	= .;	if	U0631203	>= 0 and	U0631203	<= 1 then 	ben_life153	=	U0631203	;
ben_life154	= .;	if	U0631303	>= 0 and	U0631303	<= 1 then 	ben_life154	=	U0631303	;
ben_life155	= .;	if	U0631403	>= 0 and	U0631403	<= 1 then 	ben_life155	=	U0631403	;
ben_life156	= .;	if	U0631503	>= 0 and	U0631503	<= 1 then 	ben_life156	=	U0631503	;
ben_life157 = .;

ben_dental146	= .;	if	U0630504	>= 0 and	U0630504	<= 1 then 	ben_dental146	=	U0630504	;
ben_dental147	= .;	if	U0630604	>= 0 and	U0630604	<= 1 then 	ben_dental147	=	U0630604	;
ben_dental148	= .;	if	U0630704	>= 0 and	U0630704	<= 1 then 	ben_dental148	=	U0630704	;
ben_dental149	= .;	if	U0630804	>= 0 and	U0630804	<= 1 then 	ben_dental149	=	U0630804	;
ben_dental150	= .;	if	U0630904	>= 0 and	U0630904	<= 1 then 	ben_dental150	=	U0630904	;
ben_dental151	= .;	if	U0631004	>= 0 and	U0631004	<= 1 then 	ben_dental151	=	U0631004	;
ben_dental152	= .;	if	U0631104	>= 0 and	U0631104	<= 1 then 	ben_dental152	=	U0631104	;
ben_dental153	= .;	if	U0631204	>= 0 and	U0631204	<= 1 then 	ben_dental153	=	U0631204	;
ben_dental154	= .;	if	U0631304	>= 0 and	U0631304	<= 1 then 	ben_dental154	=	U0631304	;
ben_dental155	= .;	if	U0631404	>= 0 and	U0631404	<= 1 then 	ben_dental155	=	U0631404	;
ben_dental156	= .;	if	U0631504	>= 0 and	U0631504	<= 1 then 	ben_dental156	=	U0631504	;
ben_dental157 = .;

ben_pdleave146	= .;	if	U0630505	>= 0 and	U0630505	<= 1 then 	ben_pdleave146	=	U0630505	;
ben_pdleave147	= .;	if	U0630605	>= 0 and	U0630605	<= 1 then 	ben_pdleave147	=	U0630605	;
ben_pdleave148	= .;	if	U0630705	>= 0 and	U0630705	<= 1 then 	ben_pdleave148	=	U0630705	;
ben_pdleave149	= .;	if	U0630805	>= 0 and	U0630805	<= 1 then 	ben_pdleave149	=	U0630805	;
ben_pdleave150	= .;	if	U0630905	>= 0 and	U0630905	<= 1 then 	ben_pdleave150	=	U0630905	;
ben_pdleave151	= .;	if	U0631005	>= 0 and	U0631005	<= 1 then 	ben_pdleave151	=	U0631005	;
ben_pdleave152	= .;	if	U0631105	>= 0 and	U0631105	<= 1 then 	ben_pdleave152	=	U0631105	;
ben_pdleave153	= .;	if	U0631205	>= 0 and	U0631205	<= 1 then 	ben_pdleave153	=	U0631205	;
ben_pdleave154	= .;	if	U0631305	>= 0 and	U0631305	<= 1 then 	ben_pdleave154	=	U0631305	;
ben_pdleave155	= .;	if	U0631405	>= 0 and	U0631405	<= 1 then 	ben_pdleave155	=	U0631405	;
ben_pdleave156	= .;	if	U0631505	>= 0 and	U0631505	<= 1 then 	ben_pdleave156	=	U0631505	;
ben_pdleave157 = .;

ben_unpdleave146	= .;	if	U0630506	>= 0 and	U0630506	<= 1 then 	ben_unpdleave146	=	U0630506	;
ben_unpdleave147	= .;	if	U0630606	>= 0 and	U0630606	<= 1 then 	ben_unpdleave147	=	U0630606	;
ben_unpdleave148	= .;	if	U0630706	>= 0 and	U0630706	<= 1 then 	ben_unpdleave148	=	U0630706	;
ben_unpdleave149	= .;	if	U0630806	>= 0 and	U0630806	<= 1 then 	ben_unpdleave149	=	U0630806	;
ben_unpdleave150	= .;	if	U0630906	>= 0 and	U0630906	<= 1 then 	ben_unpdleave150	=	U0630906	;
ben_unpdleave151	= .;	if	U0631006	>= 0 and	U0631006	<= 1 then 	ben_unpdleave151	=	U0631006	;
ben_unpdleave152	= .;	if	U0631106	>= 0 and	U0631106	<= 1 then 	ben_unpdleave152	=	U0631106	;
ben_unpdleave153	= .;	if	U0631206	>= 0 and	U0631206	<= 1 then 	ben_unpdleave153	=	U0631206	;
ben_unpdleave154	= .;	if	U0631306	>= 0 and	U0631306	<= 1 then 	ben_unpdleave154	=	U0631306	;
ben_unpdleave155	= .;	if	U0631406	>= 0 and	U0631406	<= 1 then 	ben_unpdleave155	=	U0631406	;
ben_unpdleave156	= .;	if	U0631506	>= 0 and	U0631506	<= 1 then 	ben_unpdleave156	=	U0631506	;
ben_unpdleave157 = .;

ben_retire146	= .;	if	U0630507	>= 0 and	U0630507	<= 1 then 	ben_retire146	=	U0630507	;
ben_retire147	= .;	if	U0630607	>= 0 and	U0630607	<= 1 then 	ben_retire147	=	U0630607	;
ben_retire148	= .;	if	U0630707	>= 0 and	U0630707	<= 1 then 	ben_retire148	=	U0630707	;
ben_retire149	= .;	if	U0630807	>= 0 and	U0630807	<= 1 then 	ben_retire149	=	U0630807	;
ben_retire150	= .;	if	U0630907	>= 0 and	U0630907	<= 1 then 	ben_retire150	=	U0630907	;
ben_retire151	= .;	if	U0631007	>= 0 and	U0631007	<= 1 then 	ben_retire151	=	U0631007	;
ben_retire152	= .;	if	U0631107	>= 0 and	U0631107	<= 1 then 	ben_retire152	=	U0631107	;
ben_retire153	= .;	if	U0631207	>= 0 and	U0631207	<= 1 then 	ben_retire153	=	U0631207	;
ben_retire154	= .;	if	U0631307	>= 0 and	U0631307	<= 1 then 	ben_retire154	=	U0631307	;
ben_retire155	= .;	if	U0631407	>= 0 and	U0631407	<= 1 then 	ben_retire155	=	U0631407	;
ben_retire156	= .;	if	U0631507	>= 0 and	U0631507	<= 1 then 	ben_retire156	=	U0631507	;
ben_retire157 = .;

ben_tuition146	= .;	if	U0630508	>= 0 and	U0630508	<= 1 then 	ben_tuition146	=	U0630508	;
ben_tuition147	= .;	if	U0630608	>= 0 and	U0630608	<= 1 then 	ben_tuition147	=	U0630608	;
ben_tuition148	= .;	if	U0630708	>= 0 and	U0630708	<= 1 then 	ben_tuition148	=	U0630708	;
ben_tuition149	= .;	if	U0630808	>= 0 and	U0630808	<= 1 then 	ben_tuition149	=	U0630808	;
ben_tuition150	= .;	if	U0630908	>= 0 and	U0630908	<= 1 then 	ben_tuition150	=	U0630908	;
ben_tuition151	= .;	if	U0631008	>= 0 and	U0631008	<= 1 then 	ben_tuition151	=	U0631008	;
ben_tuition152	= .;	if	U0631108	>= 0 and	U0631108	<= 1 then 	ben_tuition152	=	U0631108	;
ben_tuition153	= .;	if	U0631208	>= 0 and	U0631208	<= 1 then 	ben_tuition153	=	U0631208	;
ben_tuition154	= .;	if	U0631308	>= 0 and	U0631308	<= 1 then 	ben_tuition154	=	U0631308	;
ben_tuition155	= .;	if	U0631408	>= 0 and	U0631408	<= 1 then 	ben_tuition155	=	U0631408	;
ben_tuition156	= .;	if	U0631508	>= 0 and	U0631508	<= 1 then 	ben_tuition156	=	U0631508	;
ben_tuition157 = .;

ben_child146	= .;	if	U0630509	>= 0 and	U0630509	<= 1 then 	ben_child146	=	U0630509	;
ben_child147	= .;	if	U0630609	>= 0 and	U0630609	<= 1 then 	ben_child147	=	U0630609	;
ben_child148	= .;	if	U0630709	>= 0 and	U0630709	<= 1 then 	ben_child148	=	U0630709	;
ben_child149	= .;	if	U0630809	>= 0 and	U0630809	<= 1 then 	ben_child149	=	U0630809	;
ben_child150	= .;	if	U0630909	>= 0 and	U0630909	<= 1 then 	ben_child150	=	U0630909	;
ben_child151	= .;	if	U0631009	>= 0 and	U0631009	<= 1 then 	ben_child151	=	U0631009	;
ben_child152	= .;	if	U0631109	>= 0 and	U0631109	<= 1 then 	ben_child152	=	U0631109	;
ben_child153	= .;	if	U0631209	>= 0 and	U0631209	<= 1 then 	ben_child153	=	U0631209	;
ben_child154	= .;	if	U0631309	>= 0 and	U0631309	<= 1 then 	ben_child154	=	U0631309	;
ben_child155	= .;	if	U0631409	>= 0 and	U0631409	<= 1 then 	ben_child155	=	U0631409	;
ben_child156	= .;	if	U0631509	>= 0 and	U0631509	<= 1 then 	ben_child156	=	U0631509	;
ben_child157 = .;

ben_stock146	= .;	if	U0630510	>= 0 and	U0630510	<= 1 then 	ben_stock146	=	U0630510	;
ben_stock147	= .;	if	U0630610	>= 0 and	U0630610	<= 1 then 	ben_stock147	=	U0630610	;
ben_stock148	= .;	if	U0630710	>= 0 and	U0630710	<= 1 then 	ben_stock148	=	U0630710	;
ben_stock149	= .;	if	U0630810	>= 0 and	U0630810	<= 1 then 	ben_stock149	=	U0630810	;
ben_stock150	= .;	if	U0630910	>= 0 and	U0630910	<= 1 then 	ben_stock150	=	U0630910	;
ben_stock151	= .;	if	U0631010	>= 0 and	U0631010	<= 1 then 	ben_stock151	=	U0631010	;
ben_stock152	= .;	if	U0631110	>= 0 and	U0631110	<= 1 then 	ben_stock152	=	U0631110	;
ben_stock153	= .;	if	U0631210	>= 0 and	U0631210	<= 1 then 	ben_stock153	=	U0631210	;
ben_stock154	= .;	if	U0631310	>= 0 and	U0631310	<= 1 then 	ben_stock154	=	U0631310	;
ben_stock155	= .;	if	U0631410	>= 0 and	U0631410	<= 1 then 	ben_stock155	=	U0631410	;
ben_stock156	= .;	if	U0631510	>= 0 and	U0631510	<= 1 then 	ben_stock156	=	U0631510	;
ben_stock157 = .;

occcode146	= .; if	U1127100	ge 0 and	U1127100	le 9990 then	occcode146	=	U1127100	;
occcode147	= .; if	U1127200	ge 0 and	U1127200	le 9990 then	occcode147	=	U1127200	;
occcode148	= .; if	U1127300	ge 0 and	U1127300	le 9990 then	occcode148	=	U1127300	;
occcode149	= .; if	U1127400	ge 0 and	U1127400	le 9990 then	occcode149	=	U1127400	;
occcode150	= .; if	U1127500	ge 0 and	U1127500	le 9990 then	occcode150	=	U1127500	;
occcode151	= .; if	U1127600	ge 0 and	U1127600	le 9990 then	occcode151	=	U1127600	;
occcode152	= .; if	U1127700	ge 0 and	U1127700	le 9990 then	occcode152	=	U1127700	;
occcode153	= .; if	U1127800	ge 0 and	U1127800	le 9990 then	occcode153	=	U1127800	;
occcode154	= .; if	U1127900	ge 0 and	U1127900	le 9990 then	occcode154	=	U1127900	;
occcode155	= .; if	U1128000	ge 0 and	U1128000	le 9990 then	occcode155	=	U1128000	;
occcode156	= .; if	U1128100	ge 0 and	U1128100	le 9990 then	occcode156	=	U1128100	;
occcode157	= .; if	U1128200	ge 0 and	U1128200	le 9990 then	occcode157	=	U1128200	;

indcode146	= .; if	U1125900	ge 0 and	U1125900	le 9990 then	indcode146	=	U1125900	;
indcode147	= .; if	U1126000	ge 0 and	U1126000	le 9990 then	indcode147	=	U1126000	;
indcode148	= .; if	U1126100	ge 0 and	U1126100	le 9990 then	indcode148	=	U1126100	;
indcode149	= .; if	U1126200	ge 0 and	U1126200	le 9990 then	indcode149	=	U1126200	;
indcode150	= .; if	U1126300	ge 0 and	U1126300	le 9990 then	indcode150	=	U1126300	;
indcode151	= .; if	U1126400	ge 0 and	U1126400	le 9990 then	indcode151	=	U1126400	;
indcode152	= .; if	U1126500	ge 0 and	U1126500	le 9990 then	indcode152	=	U1126500	;
indcode153	= .; if	U1126600	ge 0 and	U1126600	le 9990 then	indcode153	=	U1126600	;
indcode154	= .; if	U1126700	ge 0 and	U1126700	le 9990 then	indcode154	=	U1126700	;
indcode155	= .; if	U1126800	ge 0 and	U1126800	le 9990 then	indcode155	=	U1126800	;
indcode156	= .; if	U1126900	ge 0 and	U1126900	le 9990 then	indcode156	=	U1126900	;
indcode157	= .; if	U1127000	ge 0 and	U1127000	le 9990 then	indcode157	=	U1127000	;

jobtype146	= .; if	U0351800	ge 1 &	U0351800	le 5 then	jobtype146	=	U0351800	;
jobtype147	= .; if	U0351900	ge 1 &	U0351900	le 5 then	jobtype147	=	U0351900	;
jobtype148	= .; if	U0352000	ge 1 &	U0352000	le 5 then	jobtype148	=	U0352000	;
jobtype149	= .; if	U0352100	ge 1 &	U0352100	le 5 then	jobtype149	=	U0352100	;
jobtype150	= .; if	U0352200	ge 1 &	U0352200	le 5 then	jobtype150	=	U0352200	;
jobtype151	= .; if	U0352300	ge 1 &	U0352300	le 5 then	jobtype151	=	U0352300	;
jobtype152	= .; if	U0352400	ge 1 &	U0352400	le 5 then	jobtype152	=	U0352400	;
jobtype153	= .; if	U0352500	ge 1 &	U0352500	le 5 then	jobtype153	=	U0352500	;
jobtype154	= .; if	U0352600	ge 1 &	U0352600	le 5 then	jobtype154	=	U0352600	;
jobtype155	= .; if	U0352700	ge 1 &	U0352700	le 5 then	jobtype155	=	U0352700	;
jobtype156	= .; if	U0352800	ge 1 &	U0352800	le 5 then	jobtype156	=	U0352800	;
jobtype157	= .; if	U0352900	ge 1 &	U0352900	le 5 then	jobtype157	=	U0352900	;

hourswk146	= .; if	U0011900	ge 0 &	U0011900	le 168 then	hourswk146	=	U0011900	;
hourswk147	= .; if	U0012000	ge 0 &	U0012000	le 168 then	hourswk147	=	U0012000	;
hourswk148	= .; if	U0012100	ge 0 &	U0012100	le 168 then	hourswk148	=	U0012100	;
hourswk149	= .; if	U0012200	ge 0 &	U0012200	le 168 then	hourswk149	=	U0012200	;
hourswk150	= .; if	U0012300	ge 0 &	U0012300	le 168 then	hourswk150	=	U0012300	;
hourswk151	= .; if	U0012400	ge 0 &	U0012400	le 168 then	hourswk151	=	U0012400	;
hourswk152	= .; if	U0012500	ge 0 &	U0012500	le 168 then	hourswk152	=	U0012500	;
hourswk153	= .; if	U0012600	ge 0 &	U0012600	le 168 then	hourswk153	=	U0012600	;
hourswk154	= .; if	U0012700	ge 0 &	U0012700	le 168 then	hourswk154	=	U0012700	;
hourswk155	= .; if	U0012800	ge 0 &	U0012800	le 168 then	hourswk155	=	U0012800	;
hourswk156	= .; if	U0012900	ge 0 &	U0012900	le 168 then	hourswk156	=	U0012900	;
hourswk157	= .; if	U0013000	ge 0 &	U0013000	le 168 then	hourswk157	=	U0013000	;

anygap146	= .; if	U0663300	ge -2 &	U0663300	le 0 then	anygap146	=	0	;	if 	U0663300	eq 1 then	anygap146	=	1	;
anygap147	= .; if	U0663400	ge -2 &	U0663400	le 0 then	anygap147	=	0	;	if 	U0663400	eq 1 then	anygap147	=	1	;
anygap148	= .; if	U0663500	ge -2 &	U0663500	le 0 then	anygap148	=	0	;	if 	U0663500	eq 1 then	anygap148	=	1	;
anygap149	= .; if	U0663600	ge -2 &	U0663600	le 0 then	anygap149	=	0	;	if 	U0663600	eq 1 then	anygap149	=	1	;
anygap150	= .; if	U0663700	ge -2 &	U0663700	le 0 then	anygap150	=	0	;	if 	U0663700	eq 1 then	anygap150	=	1	;
anygap151	= .; if	U0663800	ge -2 &	U0663800	le 0 then	anygap151	=	0	;	if 	U0663800	eq 1 then	anygap151	=	1	;
anygap152	= .; if	U0663900	ge -2 &	U0663900	le 0 then	anygap152	=	0	;	if 	U0663900	eq 1 then	anygap152	=	1	;
anygap153	= .; if	U0664000	ge -2 &	U0664000	le 0 then	anygap153	=	0	;	if 	U0664000	eq 1 then	anygap153	=	1	;
anygap154	= .; if	U0664100	ge -2 &	U0664100	le 0 then	anygap154	=	0	;	if 	U0664100	eq 1 then	anygap154	=	1	;
anygap155	= .; if	U0664200	ge -2 &	U0664200	le 0 then	anygap155	=	0	;	if 	U0664200	eq 1 then	anygap155	=	1	;
anygap156	= .; if	U0664300	ge -2 &	U0664300	le 0 then	anygap156	=	0	;	if 	U0664300	eq 1 then	anygap156	=	1	;
anygap157	= .; if	U0664400	ge -2 &	U0664400	le 0 then	anygap157	=	0	;	if 	U0664400	eq 1 then	anygap157	=	1	;

worksched146	= .; if	U0629400	ge 1 &	U0629400	le 9 then	worksched146	=	U0629400	;
worksched147	= .; if	U0629500	ge 1 &	U0629500	le 9 then	worksched147	=	U0629500	;
worksched148	= .; if	U0629600	ge 1 &	U0629600	le 9 then	worksched148	=	U0629600	;
worksched149	= .; if	U0629700	ge 1 &	U0629700	le 9 then	worksched149	=	U0629700	;
worksched150	= .; if	U0629800	ge 1 &	U0629800	le 9 then	worksched150	=	U0629800	;
worksched151	= .; if	U0629900	ge 1 &	U0629900	le 9 then	worksched151	=	U0629900	;
worksched152	= .; if	U0630000	ge 1 &	U0630000	le 9 then	worksched152	=	U0630000	;
worksched153	= .; if	U0630100	ge 1 &	U0630100	le 9 then	worksched153	=	U0630100	;
worksched154	= .; if	U0630200	ge 1 &	U0630200	le 9 then	worksched154	=	U0630200	;
worksched155	= .; if	U0630300	ge 1 &	U0630300	le 9 then	worksched155	=	U0630300	;
worksched156	= .; if	U0630400	ge 1 &	U0630400	le 9 then	worksched156	=	U0630400	;
worksched157 = .;

/* Collapse occ and industry variable coding */

ARRAY occcode_7cat(1:157);
ARRAY occcode_16cat(1:157);
ARRAY indcode_14cat(1:157);

ARRAY wocccode(1:157) occcode1-occcode157;
ARRAY windcode(1:157) indcode1-indcode157;
DO g = 1 to 157;

  if wocccode(g) >= 0010 & wocccode(g) <= 3540 then occcode_7cat(g) = 0; 
  if wocccode(g) >= 3600 & wocccode(g) <= 4650 then occcode_7cat(g) = 1; 
  if wocccode(g) >= 4700 & wocccode(g) <= 5930 then occcode_7cat(g) = 2; 
  if wocccode(g) >= 6000 & wocccode(g) <= 6130 then occcode_7cat(g) = 3; 
  if wocccode(g) >= 6200 & wocccode(g) <= 7620 then occcode_7cat(g) = 4; 
  if wocccode(g) >= 7700 & wocccode(g) <= 9750 then occcode_7cat(g) = 5; 
  if wocccode(g) >= 9760 & wocccode(g) <= 9900 then occcode_7cat(g) = 6; 

  if wocccode(g) >= 0010 & wocccode(g) <= 0950 then occcode_16cat(g) = 0; 
  if wocccode(g) >= 1000 & wocccode(g) <= 3540 then occcode_16cat(g) = 1; 
  if wocccode(g) >= 3600 & wocccode(g) <= 3650 then occcode_16cat(g) = 2; 
  if wocccode(g) >= 3700 & wocccode(g) <= 3950 then occcode_16cat(g) = 3; 
  if wocccode(g) >= 4000 & wocccode(g) <= 4160 then occcode_16cat(g) = 4; 
  if wocccode(g) >= 4200 & wocccode(g) <= 4250 then occcode_16cat(g) = 5; 
  if wocccode(g) >= 4300 & wocccode(g) <= 4650 then occcode_16cat(g) = 6; 
  if wocccode(g) >= 4700 & wocccode(g) <= 4960 then occcode_16cat(g) = 7; 
  if wocccode(g) >= 5000 & wocccode(g) <= 5930 then occcode_16cat(g) = 8; 
  if wocccode(g) >= 6000 & wocccode(g) <= 6050 then occcode_16cat(g) = 9; 
  if wocccode(g) >= 6100 & wocccode(g) <= 6130 then occcode_16cat(g) = 10; 
  if wocccode(g) >= 6200 & wocccode(g) <= 6940 then occcode_16cat(g) = 11; 
  if wocccode(g) >= 7000 & wocccode(g) <= 7620 then occcode_16cat(g) = 12; 
  if wocccode(g) >= 7700 & wocccode(g) <= 8960 then occcode_16cat(g) = 13; 
  if wocccode(g) >= 9000 & wocccode(g) <= 9750 then occcode_16cat(g) = 14; 
  if wocccode(g) >= 9760 & wocccode(g) <= 9900 then occcode_16cat(g) = 15; 

  if windcode(g) >= 0170 & windcode(g) <= 0490 then indcode_14cat(g) = 0;
  if windcode(g) = 0770 then indcode_14cat(g) = 1;
  if windcode(g) >= 1070 & windcode(g) <= 3990 then indcode_14cat(g) = 2;
  if windcode(g) >= 4070 & windcode(g) <= 4590 then indcode_14cat(g) = 3;
  if windcode(g) >= 4670 & windcode(g) <= 5790 then indcode_14cat(g) = 4;
  if (windcode(g) >= 6070 & windcode(g) <= 6390) or (windcode(g) >= 570 & windcode(g) <= 690) then indcode_14cat(g) = 5;
  if windcode(g) >= 6470 & windcode(g) <= 6780 then indcode_14cat(g) = 6;
  if windcode(g) >= 6870 & windcode(g) <= 7190 then indcode_14cat(g) = 7;
  if windcode(g) >= 7270 & windcode(g) <= 7790 then indcode_14cat(g) = 8;
  if windcode(g) >= 7860 & windcode(g) <= 8470 then indcode_14cat(g) = 9;
  if (windcode(g) = 5890) or (windcode(g) >= 8560 & windcode(g) <= 8690) then indcode_14cat(g) = 10;
  if windcode(g) >= 8770 & windcode(g) <= 9290 then indcode_14cat(g) = 11;
  if windcode(g) >= 9370 & windcode(g) <= 9590 then indcode_14cat(g) = 12;
  if windcode(g) >= 9950 & windcode(g) <= 9990 then indcode_14cat(g) = 13;

END;

/* Create new variables: one that codes for voluntary versus involuntary, anod another that distinguishes between health and non-health voluntary versus involuntary */

ARRAY left_volinvol(1:157);
ARRAY left_volinvolhea(1:157);

/* Recode 1997-1998 */

ARRAY wwhyleftjob(1:16) whyleftjob1-whyleftjob16;
ARRAY wleft_volinvolhe(1:16) left_volinvol1-left_volinvol16;

DO i = 1 to 16;
 if wwhyleftjob(i) >= 1 & wwhyleftjob(i) <= 5 then DO;
  left_volinvol(i) = 1;
  left_volinvolhea(i) = 1;
 end;

 else if wwhyleftjob(i) >= 6 & wwhyleftjob(i) <= 12 then DO;
  left_volinvol(i) = 2;
  left_volinvolhea(i) = 2;
 end;

 else if wwhyleftjob(i) = 13 then DO;
  left_volinvol(i) = 2;
  left_volinvolhea(i) = 3;
 end;

end;

/* Recode 1999: 15 (moved), 16 (transportation), 17 (sports) as quit */

ARRAY cwhyleftjob(17:25) whyleftjob17-whyleftjob25;
ARRAY cleft_volinvolhe(17:25) left_volinvol17-left_volinvol25;

DO c = 17 to 25;
 if cwhyleftjob(c) >= 1 & cwhyleftjob(c) <= 5 then DO;
  left_volinvol(c) = 1;
  left_volinvolhea(c) = 1;
 end;

 else if (cwhyleftjob(c) >= 6 & cwhyleftjob(c) <= 12) or (cwhyleftjob(c) >= 15 & cwhyleftjob(c) <= 17) then DO;
  left_volinvol(c) = 2;
  left_volinvolhea(c) = 2;
 end;

 else if cwhyleftjob(c) = 13 then DO;
  left_volinvol(c) = 2;
  left_volinvolhea(c) = 3;
 end;

end;

/* Recode 2000: same as 97/98; missing due to both invalid skip and uncodeable*/

ARRAY dwhyleftjob(26:34) whyleftjob26-whyleftjob34;
ARRAY dleft_volinvolhe(26:34) left_volinvol26-left_volinvol34;

DO d = 26 to 34;
 if dwhyleftjob(d) >= 1 & dwhyleftjob(d) <= 5 then DO;
  left_volinvol(d) = 1;
  left_volinvolhea(d) = 1;
 end;

 else if dwhyleftjob(d) >= 6 & dwhyleftjob(d) <= 12 then DO;
  left_volinvol(d) = 2;
  left_volinvolhea(d) = 2;
 end;

 else if dwhyleftjob(d) = 13 then DO;
  left_volinvol(d) = 2;
  left_volinvolhea(d) = 3;
 end;

end;

/* Recode 2001: same as 2000 but adds incarcerated (voluntary) */

ARRAY ewhyleftjob(35:42) whyleftjob35-whyleftjob42;
ARRAY eleft_volinvolhe(35:42) left_volinvol35-left_volinvol42;

DO e = 35 to 42;
 if ewhyleftjob(e) >= 1 & ewhyleftjob(e) <= 5 then DO;
  left_volinvol(e) = 1;
  left_volinvolhea(e) = 1;
 end;

 else if (ewhyleftjob(e) >= 6 & ewhyleftjob(e) <= 12) or (ewhyleftjob(e) = 14) then DO;
  left_volinvol(e) = 2;
  left_volinvolhea(e) = 2;
 end;

 else if ewhyleftjob(e) = 13 then DO;
  left_volinvol(e) = 2;
  left_volinvolhea(e) = 3;
 end;

end;

/* Recode 2002-2003 */

ARRAY vwhyleftjob(43:63) whyleftjob43-whyleftjob63;
ARRAY vleft_volinvolhe(43:63) left_volinvol43-left_volinvol63;

DO j = 43 to 63;
 if vwhyleftjob(j) >= 1 & vwhyleftjob(j) <= 5 then DO;
  left_volinvol(j) = 1;
  left_volinvolhea(j) = 1;
 end;

 else if (vwhyleftjob(j) >= 6 & vwhyleftjob(j) <= 12) or (vwhyleftjob(j) >= 14 & vwhyleftjob(j) <=15) then DO;
  left_volinvol(j) = 2;
  left_volinvolhea(j) = 2;
 end;

 else if vwhyleftjob(j) = 13 or vwhyleftjob(j) = 16 then DO;
  left_volinvol(j) = 2;
  left_volinvolhea(j) = 3;
 end;

end;

/* Recode 2004-2015 crabs */

ARRAY uwhyleftjob(64:157) whyleftjob64-whyleftjob157;
ARRAY uleft_volinvolhe(64:157) left_volinvol64-left_volinvol157;

DO k = 64 to 157;
 if uwhyleftjob(k) >= 1 & uwhyleftjob(k) <= 5 then DO;
  left_volinvol(k) = 1;
  left_volinvolhea(k) = 1;
 end;

 else if (uwhyleftjob(k) >= 6 & uwhyleftjob(k) <= 15) or (uwhyleftjob(k) = 19) or (uwhyleftjob(k) >= 21 & uwhyleftjob(k) <=24) then DO;
  left_volinvol(k) = 2;
  left_volinvolhea(k) = 2;
 end;

 else if uwhyleftjob(k) = 16 or uwhyleftjob(k) = 20 then DO;
  left_volinvol(k) = 2;
  left_volinvolhea(k) = 3;
 end;

end;

/* Set long1 as permanent dataset */

DATA nlsy.long2;
  SET nlsy.jobtraj9715;

  ARRAY xidjob(1:157) idjob1-idjob157;
  ARRAY xwhyleftjob(1:157) whyleftjob1-whyleftjob157;       
  ARRAY xintmo(1:157) intmo1-intmo157;      
  ARRAY xstartcontmo(1:157) startcontmo1-startcontmo157;
  ARRAY xweeksjob(1:157) weeksjob1-weeksjob157;
  ARRAY xcurjob(1:157) curjob1-curjob157;
  ARRAY xleft_volinvol(1:157) left_volinvol1-left_volinvol157;
  ARRAY xleft_volinvolhea(1:157) left_volinvolhea1-left_volinvolhea157;
  ARRAY xjobsat(1:157) jobsat1-jobsat157;
  ARRAY xunion(1:157) union1-union157;
  ARRAY xben_med(1:157) ben_med1-ben_med157;
  ARRAY xben_flex(1:157) ben_flex1-ben_flex157;
  ARRAY xben_dental(1:157) ben_dental1-ben_dental157;
  ARRAY xben_pdleave(1:157) ben_pdleave1-ben_pdleave157;
  ARRAY xben_unpdleave(1:157) ben_unpdleave1-ben_unpdleave157;
  ARRAY xben_retire(1:157) ben_retire1-ben_retire157;
  ARRAY xben_tuition(1:157) ben_tuition1-ben_tuition157;
  ARRAY xben_child(1:157) ben_child1-ben_child157;
  ARRAY xben_stock(1:157) ben_stock1-ben_stock157;
  ARRAY xben_life(1:157) ben_life1-ben_life157;
  ARRAY xendbyst(1:157) endbyst1-endbyst157;
  ARRAY xocccode(1:157) occcode1-occcode157;
  ARRAY xocccode_7cat(1:157) occcode_7cat1-occcode_7cat157;
  ARRAY xindcode(1:157) indcode1-indcode157;
  ARRAY xindcode_14cat(1:157) indcode_14cat1-indcode_14cat157;
  ARRAY xjobtype(1:157) jobtype1-jobtype157;
  ARRAY xhourswk(1:157) hourswk1-hourswk157;
  ARRAY xanygap(1:157) anygap1-anygap157;
  ARRAY xworksched(1:157) worksched1-worksched157;

  DO spell = 1 to 157;
    idjob = xidjob(spell);
    whyleftjob  = xwhyleftjob(spell); 
    intmo  = xintmo(spell);  
	startcontmo = xstartcontmo(spell);
	weeksjob = xweeksjob(spell);
	curjob = xcurjob(spell);
	left_volinvol = xleft_volinvol(spell);
	left_volinvolhea = xleft_volinvolhea(spell);
	jobsat = xjobsat(spell);
	union = xunion(spell);
	ben_med = xben_med(spell);
	ben_flex = xben_flex(spell);
	ben_dental = xben_dental(spell);
	ben_pdleave = xben_pdleave(spell);
	ben_unpdleave = xben_unpdleave(spell);
	ben_retire = xben_retire(spell);
	ben_tuition = xben_tuition(spell);
	ben_child = xben_child(spell);
	ben_stock = xben_stock(spell);
	ben_life = xben_life(spell);
    endbyst = xendbyst(spell);
    indcode = xindcode(spell);
	indcode_14cat = xindcode_14cat(spell);
	occcode = xocccode(spell);
	occcode_7cat = xocccode_7cat(spell);
	jobtype = xjobtype(spell);
	hourswk = xhourswk(spell);
    anygap = xanygap(spell);
	worksched = xworksched(spell);

    OUTPUT ;
  END ;

  DROP idjob1-idjob157 whyleftjob1-whyleftjob157 weeksjob1-weeksjob157 intmo1-intmo157 startcontmo1-startcontmo157 curjob1-curjob157 left_volinvol1-left_volinvol157 
  left_volinvolhea1-left_volinvolhea157 jobsat1-jobsat157 union1-union157 ben_med1-ben_med157 ben_flex1-ben_flex157 ben_dental1-ben_dental157 ben_pdleave1-ben_pdleave157 
  ben_unpdleave1-ben_unpdleave157 ben_retire1-ben_retire157 ben_tuition1-ben_tuition157 ben_child1-ben_child157 ben_life1-ben_life157 
  endbyst1-endbyst157 indcode1-indcode157 indcode_14cat1-indcode_14cat157 occcode1-occcode157 occcode_7cat1-occcode_7cat157 jobtype1-jobtype157 hourswk1-hourswk157
  anygap1-anygap157 worksched1-worksched157;

RUN ;

proc sort data = nlsy.long2;
  by R0000100 idjob intmo;
run;

data nlsy.long2a;
  set nlsy.long2;
  by R0000100 idjob;
  if first.idjob then sumgap = 0;
    sumgap+anygap;
  if anygap = . then sumgap = .;
run;

/* Retain last obs within each spell */

data nlsy.long3;
  set nlsy.long2a;
    by R0000100 idjob intmo;
    if last.idjob and last.intmo then last_whyleftjob = whyleftjob;
	if last.idjob and last.intmo then last_startcontmo = startcontmo;
	if last.idjob and last.intmo and curjob = 0 then last_weeksdonejob = weeksjob; 
 	if last.idjob and last.intmo then last_weeksjob = weeksjob; 
	if last.idjob and last.intmo then last_jobdonedum = curjob;
	if last.idjob and last.intmo then last_jobgap = sumgap;
  run;

data nlsy.long4;
  set nlsy.long3;
  by R0000100 idjob;
  if first.R0000100 then jobcount = 0;
  if first.idjob and idjob ne . then jobcount + 1;
run;

data nlsy.long5;
  set nlsy.long4;
  by R0000100 idjob;
  if last.idjob and idjob ne . then output;
run;

/* Drop all subsetted variables */

data nlsy.long5trimmed;
  set nlsy.long5;
  drop jobsat union ben_med ben_flex ben_dental ben_pdleave ben_unpdleave ben_retire ben_tuition ben_child ben_stock ben_life  
  occcode_7cat indcode_14cat jobtype hourswk anygap;
run;

/* Retain first obs within each spell and amend for each focal variable */

data long2worksched;
    set nlsy.long2a;
    where worksched ne .;
    by R0000100 idjob intmo;
    if first.idjob and first.intmo;
	keep worksched R0000100 idjob intmo;
 run;

data long2hourswk;
    set nlsy.long2a;
    where hourswk ne .;
    by R0000100 idjob intmo;
    if first.idjob and first.intmo;
	keep hourswk R0000100 idjob intmo;
 run;

data long2jobtype;
    set nlsy.long2a;
    where jobtype ne .;
    by R0000100 idjob intmo;
    if first.idjob and first.intmo;
	keep jobtype R0000100 idjob intmo;
 run;

data long2jobsat;
    set nlsy.long2a;
    where jobsat ne .;
    by R0000100 idjob intmo;
    if first.idjob and first.intmo;
	keep jobsat R0000100 idjob intmo;
 run;

data long2union;
    set nlsy.long2a;
    where union ne .;
    by R0000100 idjob intmo;
    if first.idjob and first.intmo;
    keep union R0000100 idjob intmo;
 run;

 data long2ben_med;
    set nlsy.long2a;
    where ben_med ne .;
    by R0000100 idjob intmo;
    if first.idjob and first.intmo;
	keep ben_med R0000100 idjob intmo;
run;

  data long2ben_flex;
    set nlsy.long2a;
    where ben_flex ne .;
    by R0000100 idjob intmo;
    if first.idjob and first.intmo;
	keep ben_flex R0000100 idjob intmo;
 run;

 data long2ben_dental;
    set nlsy.long2a;
    where ben_dental ne .;
    by R0000100 idjob intmo;
    if first.idjob and first.intmo;
	keep ben_dental R0000100 idjob intmo;
 run;

  data long2ben_pdleave;
    set nlsy.long2a;
    where ben_pdleave ne .;
    by R0000100 idjob intmo;
    if first.idjob and first.intmo;
	keep ben_pdleave R0000100 idjob intmo;
run;

  data long2ben_unpdleave;
    set nlsy.long2a;
    where ben_unpdleave ne .;
    by R0000100 idjob intmo;
    if first.idjob and first.intmo;
	keep ben_unpdleave R0000100 idjob intmo;
run;

  data long2ben_retire;
    set nlsy.long2a;
    where ben_retire ne .;
    by R0000100 idjob intmo;
    if first.idjob and first.intmo;
	keep ben_retire R0000100 idjob intmo;
run;

  data long2ben_tuition;
    set nlsy.long2a;
    where ben_tuition ne .;
    by R0000100 idjob intmo;
    if first.idjob and first.intmo;
	keep ben_tuition R0000100 idjob intmo;
run;

  data long2ben_child;
    set nlsy.long2a;
    where ben_child ne .;
    by R0000100 idjob intmo;
    if first.idjob and first.intmo;
	keep ben_child R0000100 idjob intmo;
run;

  data long2ben_stock;
    set nlsy.long2a;
    where ben_stock ne .;
    by R0000100 idjob intmo;
    if first.idjob and first.intmo;
	keep ben_stock R0000100 idjob intmo;
run;

   data long2ben_life;
    set nlsy.long2a;
    where ben_life ne .;
    by R0000100 idjob intmo;
    if first.idjob and first.intmo;
	keep ben_life R0000100 idjob intmo;
run;

data long2occcode_7cat;
    set nlsy.long2a;
    where occcode_7cat ne .;
    by R0000100 idjob intmo;
    if first.idjob and first.intmo;
	keep occcode_7cat R0000100 idjob intmo;
run;

data long2indcode;
    set nlsy.long2a;
    where indcode ne .;
    by R0000100 idjob intmo;
    if first.idjob and first.intmo;
	keep indcode indcode_14cat R0000100 idjob intmo;
run;

data nlsy.long6_070718;
  merge nlsy.long5trimmed long2jobsat long2union long2ben_med long2ben_flex long2ben_dental long2ben_pdleave long2ben_unpdleave long2ben_retire long2ben_tuition long2ben_child 
  long2ben_stock long2ben_life long2occcode_7cat long2indcode long2jobtype long2hourswk long2worksched;
    by R0000100 idjob;
run;

proc export data= nlsy.long6_070718 outfile= "C:\Users\alexa\Desktop\life\projects\disability\nlsy97\job trajectories\data\long6_070718.dta" replace; run;
